var child_process = require('child_process')

var cfg = {
  macplus: true,
  ibmpc: true
  emscripten: true,
  asmjs: true,
  optimise: true,
  memory: 268435456,
  sdl: true,
  x11: false,
  prefix: '$PWD/build/'
};


// utils

function configure() {
  var cmdParts = [];
  function c(part) { cmdParts.push(part) }; //shorthand for adding flags

  if (cfg.emscripten) c('emconfigure');

  c('./configure');
  if (cfg.emscripten) {
    // flags to be passed to emcc
    c('CFLAGS="');
    c('-Qunused-arguments');
    c('-include build/include/pcedeps.h');
    c('-s TOTAL_MEMORY='+cfg);
    if (cfg.asmjs) c('-s ASM_JS=1');
    if (cfg.optimise) c('-O2');
    c('"');
    // end flags to be passed to emcc
    
    c('EMSCRIPTEN="yes"'); // used by configure, make
  } else {
    c('CFLAGS="-I/usr/local/opt/emscripten/system/include/emscripten/"');
  }
  if (cfg.prefix) c('--prefix='+cfg.prefix);

  // target architectures
  if (!cfg.macplus) c('--disable-macplus');
  if (!cfg.ibmpc) c('--disable-ibmpc');

  // disabled architectures
  c('--disable-rc759');
  c('--disable-sim405');
  c('--disable-sim6502');
  c('--disable-sims32');
  c('--disable-simarm');

  // disabled char drivers
  c('--disable-char-termios');
  c('--disable-char-tcp');

  // terminal types
  if (!cfg.x11) c('--without-x');
  if (!cfg.sdl) c('--without-sdl');
}

function spawnRun(cmd, args, done) {

    process = child_process.spawn('ls', ['-lh', '/usr']);

    process.stdout.on('data', function (data) {
      console.log('stdout: ' + data);
    });

    process.stderr.on('data', function (data) {
      console.log('stderr: ' + data);
    });

    process.on('close', function (code) {
      console.log(cmd + ' process exited with code ' + code);

      done(code);
    });
  });
}


module.exports = function(grunt) {

  // Project configuration.
  grunt.initConfig({
    pkg: grunt.file.readJSON('package.json')
  });

  grunt.task.registerTask('configure', 'Configure emulator build', function(target) {
    if (target === 'native') cfg.emscripten = false;
    
    var done = this.async();


  grunt.task.registerTask('build', 'Build emulator', function() {
    var done = this.async();
    child_process.exec('make clean; make;', function (error, stdout, stderr) {
      if (error) console.error(stdout);
      done();
    });
  });

  // Default task(s).
  grunt.registerTask('default', ['uglify']);

  // build app resources
  grunt.registerTask('build', [
    'coffee:compile',
    'handlebars:compile',
    'less:compile',
    'concat:ratchet',
    'concat:csslibs',
    'concat:jslibs',
    'concat:resources',
    'concat:banners',
    'android-assets'
  ]);

};
