util = require('util')
path = require('path')
child_process = require('child_process')
_ = require('lodash')


# utils
spawnRun = (done, command, args, opts) ->
    process = child_process.spawn(command, args, opts)

    process.stdout.setEncoding('utf8')
    process.stdout.on('data', (data) -> util.print(data))

    process.stderr.setEncoding('utf8')
    process.stderr.on('data', (data) -> util.error(data))

    process.on('close', (code) -> done(code))

class EmpceBuild
  defaultConfig:
    target: 'macplus'
    emscripten: true
    asmjs: true
    optlvl: 'O2'
    memory: 256
    prefix: 'build/'
    packagedir: 'pce-js/'

  configFilePath: './empce-build-config.json'
  
  constructor: (@grunt, extraConfig) ->
    @config = _.clone(@defaultConfig)

    this.loadConfig()
    _.extend(@config, extraConfig) if extraConfig

  loadConfig: ->
    try
      _.extend(@config, @grunt.file.readJSON(@configFilePath))
    catch e
      console.warn(@configFilePath+' file not found')

  saveConfig: ->
    try
      @grunt.file.write(@configFilePath, JSON.stringify(@config, undefined, 2))
    catch e
      console.error(@configFilePath+' could not save')

  getEmscriptenFlags: ->
    flags = []
    flags.push('-s TOTAL_MEMORY=' + @config.memory*1024*1024) if @config.memory?
    flags.push('-s ASM_JS=1') if @config.asmjs
    if @config.exportfuncs
      flags.push('-s EXPORTED_FUNCTIONS='+JSON.stringify(@config.exportfuncs)+'')
      # flags.push('-s EXPORTED_FUNCTIONS=[\'_emstate_set\']')
    flags.push('-'+@config.optlvl) if @config.optlvl?
    flags.join(' ')

  getEnv: ->
    env =
      EMPCE_PREFIX: path.resolve(@config.prefix) 
      EMPCE_PACKAGEDIR: path.resolve(@config.packagedir) 
      EMPCE_TARGET: @config.target

    if @config.emscripten
      emflags = this.getEmscriptenFlags()

      env.EMPCE_EMSCRIPTEN = "yes"
      env.EMPCE_EMFLAGS = emflags
      env.EMPCE_CFLAGS = "-Qunused-arguments -include build/include/pcedeps.h #{emflags}"
      env.EMPCE_CONFIGURE = "emconfigure ./configure"
    else
      env.EMPCE_CFLAGS = "-I/usr/local/opt/emscripten/system/include/emscripten/"
      env.EMPCE_CONFIGURE = "./configure"

    return env

  extendEnv: (baseEnv) -> _.extend(_.clone(baseEnv), this.getEnv())

  run: (done, command, args = [], opts = {}) ->
    spawnRun done, command, args, _.extend(
        cwd: process.env.PWD
        env: this.extendEnv(process.env)
      , opts)

module.exports = EmpceBuild