// Note: For maximum-speed code, see "Optimizing Code" on the Emscripten wiki, https://github.com/kripken/emscripten/wiki/Optimizing-Code
// Note: Some Emscripten settings may limit the speed of the generated code.
try {
  this['Module'] = Module;
  Module.test;
} catch(e) {
  this['Module'] = Module = {};
}
// The environment setup code below is customized to use Module.
// *** Environment setup code ***
var ENVIRONMENT_IS_NODE = typeof process === 'object' && typeof require === 'function';
var ENVIRONMENT_IS_WEB = typeof window === 'object';
var ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
var ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;
if (ENVIRONMENT_IS_NODE) {
  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  Module['print'] = function(x) {
    process['stdout'].write(x + '\n');
  };
  Module['printErr'] = function(x) {
    process['stderr'].write(x + '\n');
  };
  var nodeFS = require('fs');
  var nodePath = require('path');
  Module['read'] = function(filename, binary) {
    filename = nodePath['normalize'](filename);
    var ret = nodeFS['readFileSync'](filename);
    // The path is absolute if the normalized version is the same as the resolved.
    if (!ret && filename != nodePath['resolve'](filename)) {
      filename = path.join(__dirname, '..', 'src', filename);
      ret = nodeFS['readFileSync'](filename);
    }
    if (ret && !binary) ret = ret.toString();
    return ret;
  };
  Module['readBinary'] = function(filename) { return Module['read'](filename, true) };
  Module['load'] = function(f) {
    globalEval(read(f));
  };
  if (!Module['arguments']) {
    Module['arguments'] = process['argv'].slice(2);
  }
  module.exports = Module;
}
if (ENVIRONMENT_IS_SHELL) {
  Module['print'] = print;
  if (typeof printErr != 'undefined') Module['printErr'] = printErr; // not present in v8 or older sm
  Module['read'] = read;
  Module['readBinary'] = function(f) {
    return read(f, 'binary');
  };
  if (!Module['arguments']) {
    if (typeof scriptArgs != 'undefined') {
      Module['arguments'] = scriptArgs;
    } else if (typeof arguments != 'undefined') {
      Module['arguments'] = arguments;
    }
  }
  this['Module'] = Module;
}
if (ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_WORKER) {
  if (!Module['print']) {
    Module['print'] = function(x) {
      console.log(x);
    };
  }
  if (!Module['printErr']) {
    Module['printErr'] = function(x) {
      console.log(x);
    };
  }
  this['Module'] = Module;
}
if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  Module['read'] = function(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, false);
    xhr.send(null);
    return xhr.responseText;
  };
  if (!Module['arguments']) {
    if (typeof arguments != 'undefined') {
      Module['arguments'] = arguments;
    }
  }
}
if (ENVIRONMENT_IS_WORKER) {
  // We can do very little here...
  var TRY_USE_DUMP = false;
  if (!Module['print']) {
    Module['print'] = (TRY_USE_DUMP && (typeof(dump) !== "undefined") ? (function(x) {
      dump(x);
    }) : (function(x) {
      // self.postMessage(x); // enable this if you want stdout to be sent as messages
    }));
  }
  Module['load'] = importScripts;
}
if (!ENVIRONMENT_IS_WORKER && !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_SHELL) {
  // Unreachable because SHELL is dependant on the others
  throw 'Unknown runtime environment. Where are we?';
}
function globalEval(x) {
  eval.call(null, x);
}
if (!Module['load'] == 'undefined' && Module['read']) {
  Module['load'] = function(f) {
    globalEval(Module['read'](f));
  };
}
if (!Module['print']) {
  Module['print'] = function(){};
}
if (!Module['printErr']) {
  Module['printErr'] = Module['print'];
}
if (!Module['arguments']) {
  Module['arguments'] = [];
}
// *** Environment setup code ***
// Closure helpers
Module.print = Module['print'];
Module.printErr = Module['printErr'];
// Callbacks
if (!Module['preRun']) Module['preRun'] = [];
if (!Module['postRun']) Module['postRun'] = [];
// === Auto-generated preamble library stuff ===
//========================================
// Runtime code shared with compiler
//========================================
var Runtime = {
  stackSave: function () {
    return STACKTOP;
  },
  stackRestore: function (stackTop) {
    STACKTOP = stackTop;
  },
  forceAlign: function (target, quantum) {
    quantum = quantum || 4;
    if (quantum == 1) return target;
    if (isNumber(target) && isNumber(quantum)) {
      return Math.ceil(target/quantum)*quantum;
    } else if (isNumber(quantum) && isPowerOfTwo(quantum)) {
      var logg = log2(quantum);
      return '((((' +target + ')+' + (quantum-1) + ')>>' + logg + ')<<' + logg + ')';
    }
    return 'Math.ceil((' + target + ')/' + quantum + ')*' + quantum;
  },
  isNumberType: function (type) {
    return type in Runtime.INT_TYPES || type in Runtime.FLOAT_TYPES;
  },
  isPointerType: function isPointerType(type) {
  return type[type.length-1] == '*';
},
  isStructType: function isStructType(type) {
  if (isPointerType(type)) return false;
  if (isArrayType(type)) return true;
  if (/<?{ ?[^}]* ?}>?/.test(type)) return true; // { i32, i8 } etc. - anonymous struct types
  // See comment in isStructPointerType()
  return type[0] == '%';
},
  INT_TYPES: {"i1":0,"i8":0,"i16":0,"i32":0,"i64":0},
  FLOAT_TYPES: {"float":0,"double":0},
  or64: function (x, y) {
    var l = (x | 0) | (y | 0);
    var h = (Math.round(x / 4294967296) | Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  and64: function (x, y) {
    var l = (x | 0) & (y | 0);
    var h = (Math.round(x / 4294967296) & Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  xor64: function (x, y) {
    var l = (x | 0) ^ (y | 0);
    var h = (Math.round(x / 4294967296) ^ Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  getNativeTypeSize: function (type, quantumSize) {
    if (Runtime.QUANTUM_SIZE == 1) return 1;
    var size = {
      '%i1': 1,
      '%i8': 1,
      '%i16': 2,
      '%i32': 4,
      '%i64': 8,
      "%float": 4,
      "%double": 8
    }['%'+type]; // add '%' since float and double confuse Closure compiler as keys, and also spidermonkey as a compiler will remove 's from '_i8' etc
    if (!size) {
      if (type.charAt(type.length-1) == '*') {
        size = Runtime.QUANTUM_SIZE; // A pointer
      } else if (type[0] == 'i') {
        var bits = parseInt(type.substr(1));
        assert(bits % 8 == 0);
        size = bits/8;
      }
    }
    return size;
  },
  getNativeFieldSize: function (type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  },
  dedup: function dedup(items, ident) {
  var seen = {};
  if (ident) {
    return items.filter(function(item) {
      if (seen[item[ident]]) return false;
      seen[item[ident]] = true;
      return true;
    });
  } else {
    return items.filter(function(item) {
      if (seen[item]) return false;
      seen[item] = true;
      return true;
    });
  }
},
  set: function set() {
  var args = typeof arguments[0] === 'object' ? arguments[0] : arguments;
  var ret = {};
  for (var i = 0; i < args.length; i++) {
    ret[args[i]] = 0;
  }
  return ret;
},
  STACK_ALIGN: 8,
  getAlignSize: function (type, size, vararg) {
    // we align i64s and doubles on 64-bit boundaries, unlike x86
    if (type == 'i64' || type == 'double' || vararg) return 8;
    if (!type) return Math.min(size, 8); // align structures internally to 64 bits
    return Math.min(size || (type ? Runtime.getNativeFieldSize(type) : 0), Runtime.QUANTUM_SIZE);
  },
  calculateStructAlignment: function calculateStructAlignment(type) {
    type.flatSize = 0;
    type.alignSize = 0;
    var diffs = [];
    var prev = -1;
    type.flatIndexes = type.fields.map(function(field) {
      var size, alignSize;
      if (Runtime.isNumberType(field) || Runtime.isPointerType(field)) {
        size = Runtime.getNativeTypeSize(field); // pack char; char; in structs, also char[X]s.
        alignSize = Runtime.getAlignSize(field, size);
      } else if (Runtime.isStructType(field)) {
        size = Types.types[field].flatSize;
        alignSize = Runtime.getAlignSize(null, Types.types[field].alignSize);
      } else if (field[0] == 'b') {
        // bN, large number field, like a [N x i8]
        size = field.substr(1)|0;
        alignSize = 1;
      } else {
        throw 'Unclear type in struct: ' + field + ', in ' + type.name_ + ' :: ' + dump(Types.types[type.name_]);
      }
      if (type.packed) alignSize = 1;
      type.alignSize = Math.max(type.alignSize, alignSize);
      var curr = Runtime.alignMemory(type.flatSize, alignSize); // if necessary, place this on aligned memory
      type.flatSize = curr + size;
      if (prev >= 0) {
        diffs.push(curr-prev);
      }
      prev = curr;
      return curr;
    });
    type.flatSize = Runtime.alignMemory(type.flatSize, type.alignSize);
    if (diffs.length == 0) {
      type.flatFactor = type.flatSize;
    } else if (Runtime.dedup(diffs).length == 1) {
      type.flatFactor = diffs[0];
    }
    type.needsFlattening = (type.flatFactor != 1);
    return type.flatIndexes;
  },
  generateStructInfo: function (struct, typeName, offset) {
    var type, alignment;
    if (typeName) {
      offset = offset || 0;
      type = (typeof Types === 'undefined' ? Runtime.typeInfo : Types.types)[typeName];
      if (!type) return null;
      if (type.fields.length != struct.length) {
        printErr('Number of named fields must match the type for ' + typeName + ': possibly duplicate struct names. Cannot return structInfo');
        return null;
      }
      alignment = type.flatIndexes;
    } else {
      var type = { fields: struct.map(function(item) { return item[0] }) };
      alignment = Runtime.calculateStructAlignment(type);
    }
    var ret = {
      __size__: type.flatSize
    };
    if (typeName) {
      struct.forEach(function(item, i) {
        if (typeof item === 'string') {
          ret[item] = alignment[i] + offset;
        } else {
          // embedded struct
          var key;
          for (var k in item) key = k;
          ret[key] = Runtime.generateStructInfo(item[key], type.fields[i], alignment[i]);
        }
      });
    } else {
      struct.forEach(function(item, i) {
        ret[item[1]] = alignment[i];
      });
    }
    return ret;
  },
  dynCall: function (sig, ptr, args) {
    if (args && args.length) {
      if (!args.splice) args = Array.prototype.slice.call(args);
      args.splice(0, 0, ptr);
      return Module['dynCall_' + sig].apply(null, args);
    } else {
      return Module['dynCall_' + sig].call(null, ptr);
    }
  },
  functionPointers: [],
  addFunction: function (func) {
    for (var i = 0; i < Runtime.functionPointers.length; i++) {
      if (!Runtime.functionPointers[i]) {
        Runtime.functionPointers[i] = func;
        return 2 + 2*i;
      }
    }
    throw 'Finished up all reserved function pointers. Use a higher value for RESERVED_FUNCTION_POINTERS.';
  },
  removeFunction: function (index) {
    Runtime.functionPointers[(index-2)/2] = null;
  },
  warnOnce: function (text) {
    if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
    if (!Runtime.warnOnce.shown[text]) {
      Runtime.warnOnce.shown[text] = 1;
      Module.printErr(text);
    }
  },
  funcWrappers: {},
  getFuncWrapper: function (func, sig) {
    assert(sig);
    if (!Runtime.funcWrappers[func]) {
      Runtime.funcWrappers[func] = function() {
        return Runtime.dynCall(sig, func, arguments);
      };
    }
    return Runtime.funcWrappers[func];
  },
  UTF8Processor: function () {
    var buffer = [];
    var needed = 0;
    this.processCChar = function (code) {
      code = code & 0xff;
      if (needed) {
        buffer.push(code);
        needed--;
      }
      if (buffer.length == 0) {
        if (code < 128) return String.fromCharCode(code);
        buffer.push(code);
        if (code > 191 && code < 224) {
          needed = 1;
        } else {
          needed = 2;
        }
        return '';
      }
      if (needed > 0) return '';
      var c1 = buffer[0];
      var c2 = buffer[1];
      var c3 = buffer[2];
      var ret;
      if (c1 > 191 && c1 < 224) {
        ret = String.fromCharCode(((c1 & 31) << 6) | (c2 & 63));
      } else {
        ret = String.fromCharCode(((c1 & 15) << 12) | ((c2 & 63) << 6) | (c3 & 63));
      }
      buffer.length = 0;
      return ret;
    }
    this.processJSString = function(string) {
      string = unescape(encodeURIComponent(string));
      var ret = [];
      for (var i = 0; i < string.length; i++) {
        ret.push(string.charCodeAt(i));
      }
      return ret;
    }
  },
  stackAlloc: function (size) { var ret = STACKTOP;STACKTOP = (STACKTOP + size)|0;STACKTOP = ((((STACKTOP)+7)>>3)<<3); return ret; },
  staticAlloc: function (size) { var ret = STATICTOP;STATICTOP = (STATICTOP + size)|0;STATICTOP = ((((STATICTOP)+7)>>3)<<3); return ret; },
  dynamicAlloc: function (size) { var ret = DYNAMICTOP;DYNAMICTOP = (DYNAMICTOP + size)|0;DYNAMICTOP = ((((DYNAMICTOP)+7)>>3)<<3); if (DYNAMICTOP >= TOTAL_MEMORY) enlargeMemory();; return ret; },
  alignMemory: function (size,quantum) { var ret = size = Math.ceil((size)/(quantum ? quantum : 8))*(quantum ? quantum : 8); return ret; },
  makeBigInt: function (low,high,unsigned) { var ret = (unsigned ? ((+(((low)>>>(0))))+((+(((high)>>>(0))))*(+(4294967296)))) : ((+(((low)>>>(0))))+((+(((high)|(0))))*(+(4294967296))))); return ret; },
  GLOBAL_BASE: 8,
  QUANTUM_SIZE: 4,
  __dummy__: 0
}
//========================================
// Runtime essentials
//========================================
var __THREW__ = 0; // Used in checking for thrown exceptions.
var ABORT = false; // whether we are quitting the application. no code should run after this. set in exit() and abort()
var undef = 0;
// tempInt is used for 32-bit signed values or smaller. tempBigInt is used
// for 32-bit unsigned values or more than 32 bits. TODO: audit all uses of tempInt
var tempValue, tempInt, tempBigInt, tempInt2, tempBigInt2, tempPair, tempBigIntI, tempBigIntR, tempBigIntS, tempBigIntP, tempBigIntD;
var tempI64, tempI64b;
var tempRet0, tempRet1, tempRet2, tempRet3, tempRet4, tempRet5, tempRet6, tempRet7, tempRet8, tempRet9;
function abort(text) {
  Module.print(text + ':\n' + (new Error).stack);
  ABORT = true;
  throw "Assertion: " + text;
}
function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}
var globalScope = this;
// C calling interface. A convenient way to call C functions (in C files, or
// defined with extern "C").
//
// Note: LLVM optimizations can inline and remove functions, after which you will not be
//       able to call them. Closure can also do so. To avoid that, add your function to
//       the exports using something like
//
//         -s EXPORTED_FUNCTIONS='["_main", "_myfunc"]'
//
// @param ident      The name of the C function (note that C++ functions will be name-mangled - use extern "C")
// @param returnType The return type of the function, one of the JS types 'number', 'string' or 'array' (use 'number' for any C pointer, and
//                   'array' for JavaScript arrays and typed arrays; note that arrays are 8-bit).
// @param argTypes   An array of the types of arguments for the function (if there are no arguments, this can be ommitted). Types are as in returnType,
//                   except that 'array' is not possible (there is no way for us to know the length of the array)
// @param args       An array of the arguments to the function, as native JS values (as in returnType)
//                   Note that string arguments will be stored on the stack (the JS string will become a C string on the stack).
// @return           The return value, as a native JS value (as in returnType)
function ccall(ident, returnType, argTypes, args) {
  return ccallFunc(getCFunc(ident), returnType, argTypes, args);
}
Module["ccall"] = ccall;
// Returns the C function with a specified identifier (for C++, you need to do manual name mangling)
function getCFunc(ident) {
  try {
    var func = globalScope['Module']['_' + ident]; // closure exported function
    if (!func) func = eval('_' + ident); // explicit lookup
  } catch(e) {
  }
  assert(func, 'Cannot call unknown function ' + ident + ' (perhaps LLVM optimizations or closure removed it?)');
  return func;
}
// Internal function that does a C call using a function, not an identifier
function ccallFunc(func, returnType, argTypes, args) {
  var stack = 0;
  function toC(value, type) {
    if (type == 'string') {
      if (value === null || value === undefined || value === 0) return 0; // null string
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length+1);
      writeStringToMemory(value, ret);
      return ret;
    } else if (type == 'array') {
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length);
      writeArrayToMemory(value, ret);
      return ret;
    }
    return value;
  }
  function fromC(value, type) {
    if (type == 'string') {
      return Pointer_stringify(value);
    }
    assert(type != 'array');
    return value;
  }
  var i = 0;
  var cArgs = args ? args.map(function(arg) {
    return toC(arg, argTypes[i++]);
  }) : [];
  var ret = fromC(func.apply(null, cArgs), returnType);
  if (stack) Runtime.stackRestore(stack);
  return ret;
}
// Returns a native JS wrapper for a C function. This is similar to ccall, but
// returns a function you can call repeatedly in a normal way. For example:
//
//   var my_function = cwrap('my_c_function', 'number', ['number', 'number']);
//   alert(my_function(5, 22));
//   alert(my_function(99, 12));
//
function cwrap(ident, returnType, argTypes) {
  var func = getCFunc(ident);
  return function() {
    return ccallFunc(func, returnType, argTypes, Array.prototype.slice.call(arguments));
  }
}
Module["cwrap"] = cwrap;
// Sets a value in memory in a dynamic way at run-time. Uses the
// type data. This is the same as makeSetValue, except that
// makeSetValue is done at compile-time and generates the needed
// code then, whereas this function picks the right code at
// run-time.
// Note that setValue and getValue only do *aligned* writes and reads!
// Note that ccall uses JS types as for defining types, while setValue and
// getValue need LLVM types ('i8', 'i32') - this is a lower-level operation
function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[(ptr)]=value; break;
      case 'i8': HEAP8[(ptr)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': (tempI64 = [value>>>0,((Math.min((+(Math.floor((value)/(+(4294967296))))), (+(4294967295))))|0)>>>0],HEAP32[((ptr)>>2)]=tempI64[0],HEAP32[(((ptr)+(4))>>2)]=tempI64[1]); break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': HEAPF64[((ptr)>>3)]=value; break;
      default: abort('invalid type for setValue: ' + type);
    }
}
Module['setValue'] = setValue;
// Parallel to setValue.
function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[(ptr)];
      case 'i8': return HEAP8[(ptr)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return HEAPF64[((ptr)>>3)];
      default: abort('invalid type for setValue: ' + type);
    }
  return null;
}
Module['getValue'] = getValue;
var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
var ALLOC_DYNAMIC = 3; // Cannot be freed except through sbrk
var ALLOC_NONE = 4; // Do not allocate
Module['ALLOC_NORMAL'] = ALLOC_NORMAL;
Module['ALLOC_STACK'] = ALLOC_STACK;
Module['ALLOC_STATIC'] = ALLOC_STATIC;
Module['ALLOC_DYNAMIC'] = ALLOC_DYNAMIC;
Module['ALLOC_NONE'] = ALLOC_NONE;
// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
function allocate(slab, types, allocator, ptr) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }
  var singleType = typeof types === 'string' ? types : null;
  var ret;
  if (allocator == ALLOC_NONE) {
    ret = ptr;
  } else {
    ret = [_malloc, Runtime.stackAlloc, Runtime.staticAlloc, Runtime.dynamicAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  }
  if (zeroinit) {
    var ptr = ret, stop;
    assert((ret & 3) == 0);
    stop = ret + (size & ~3);
    for (; ptr < stop; ptr += 4) {
      HEAP32[((ptr)>>2)]=0;
    }
    stop = ret + size;
    while (ptr < stop) {
      HEAP8[((ptr++)|0)]=0;
    }
    return ret;
  }
  if (singleType === 'i8') {
    if (slab.subarray || slab.slice) {
      HEAPU8.set(slab, ret);
    } else {
      HEAPU8.set(new Uint8Array(slab), ret);
    }
    return ret;
  }
  var i = 0, type, typeSize, previousType;
  while (i < size) {
    var curr = slab[i];
    if (typeof curr === 'function') {
      curr = Runtime.getFunctionIndex(curr);
    }
    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }
    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later
    setValue(ret+i, curr, type);
    // no need to look up size unless type changes, so cache it
    if (previousType !== type) {
      typeSize = Runtime.getNativeTypeSize(type);
      previousType = type;
    }
    i += typeSize;
  }
  return ret;
}
Module['allocate'] = allocate;
function Pointer_stringify(ptr, /* optional */ length) {
  // Find the length, and check for UTF while doing so
  var hasUtf = false;
  var t;
  var i = 0;
  while (1) {
    t = HEAPU8[(((ptr)+(i))|0)];
    if (t >= 128) hasUtf = true;
    else if (t == 0 && !length) break;
    i++;
    if (length && i == length) break;
  }
  if (!length) length = i;
  var ret = '';
  if (!hasUtf) {
    var MAX_CHUNK = 1024; // split up into chunks, because .apply on a huge string can overflow the stack
    var curr;
    while (length > 0) {
      curr = String.fromCharCode.apply(String, HEAPU8.subarray(ptr, ptr + Math.min(length, MAX_CHUNK)));
      ret = ret ? ret + curr : curr;
      ptr += MAX_CHUNK;
      length -= MAX_CHUNK;
    }
    return ret;
  }
  var utf8 = new Runtime.UTF8Processor();
  for (i = 0; i < length; i++) {
    t = HEAPU8[(((ptr)+(i))|0)];
    ret += utf8.processCChar(t);
  }
  return ret;
}
Module['Pointer_stringify'] = Pointer_stringify;
// Memory management
var PAGE_SIZE = 4096;
function alignMemoryPage(x) {
  return ((x+4095)>>12)<<12;
}
var HEAP;
var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;
var STATIC_BASE = 0, STATICTOP = 0, staticSealed = false; // static area
var STACK_BASE = 0, STACKTOP = 0, STACK_MAX = 0; // stack area
var DYNAMIC_BASE = 0, DYNAMICTOP = 0; // dynamic area handled by sbrk
function enlargeMemory() {
  abort('Cannot enlarge memory arrays in asm.js. Either (1) compile with -s TOTAL_MEMORY=X with X higher than the current value, or (2) set Module.TOTAL_MEMORY before the program runs.');
}
var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 268435456;
var FAST_MEMORY = Module['FAST_MEMORY'] || 2097152;
// Initialize the runtime's memory
// check for full engine support (use string 'subarray' to avoid closure compiler confusion)
assert(!!Int32Array && !!Float64Array && !!(new Int32Array(1)['subarray']) && !!(new Int32Array(1)['set']),
       'Cannot fallback to non-typed array case: Code is too specialized');
var buffer = new ArrayBuffer(TOTAL_MEMORY);
HEAP8 = new Int8Array(buffer);
HEAP16 = new Int16Array(buffer);
HEAP32 = new Int32Array(buffer);
HEAPU8 = new Uint8Array(buffer);
HEAPU16 = new Uint16Array(buffer);
HEAPU32 = new Uint32Array(buffer);
HEAPF32 = new Float32Array(buffer);
HEAPF64 = new Float64Array(buffer);
// Endianness check (note: assumes compiler arch was little-endian)
HEAP32[0] = 255;
assert(HEAPU8[0] === 255 && HEAPU8[3] === 0, 'Typed arrays 2 must be run on a little-endian system');
Module['HEAP'] = HEAP;
Module['HEAP8'] = HEAP8;
Module['HEAP16'] = HEAP16;
Module['HEAP32'] = HEAP32;
Module['HEAPU8'] = HEAPU8;
Module['HEAPU16'] = HEAPU16;
Module['HEAPU32'] = HEAPU32;
Module['HEAPF32'] = HEAPF32;
Module['HEAPF64'] = HEAPF64;
function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    if (typeof callback == 'function') {
      callback();
      continue;
    }
    var func = callback.func;
    if (typeof func === 'number') {
      if (callback.arg === undefined) {
        Runtime.dynCall('v', func);
      } else {
        Runtime.dynCall('vi', func, [callback.arg]);
      }
    } else {
      func(callback.arg === undefined ? null : callback.arg);
    }
  }
}
var __ATINIT__ = []; // functions called during startup
var __ATMAIN__ = []; // functions called when main() is to be run
var __ATEXIT__ = []; // functions called during shutdown
var runtimeInitialized = false;
function ensureInitRuntime() {
  if (runtimeInitialized) return;
  runtimeInitialized = true;
  callRuntimeCallbacks(__ATINIT__);
}
function preMain() {
  callRuntimeCallbacks(__ATMAIN__);
}
function exitRuntime() {
  callRuntimeCallbacks(__ATEXIT__);
}
// Tools
// This processes a JS string into a C-line array of numbers, 0-terminated.
// For LLVM-originating strings, see parser.js:parseLLVMString function
function intArrayFromString(stringy, dontAddNull, length /* optional */) {
  var ret = (new Runtime.UTF8Processor()).processJSString(stringy);
  if (length) {
    ret.length = length;
  }
  if (!dontAddNull) {
    ret.push(0);
  }
  return ret;
}
Module['intArrayFromString'] = intArrayFromString;
function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}
Module['intArrayToString'] = intArrayToString;
// Write a Javascript array to somewhere in the heap
function writeStringToMemory(string, buffer, dontAddNull) {
  var array = intArrayFromString(string, dontAddNull);
  var i = 0;
  while (i < array.length) {
    var chr = array[i];
    HEAP8[(((buffer)+(i))|0)]=chr
    i = i + 1;
  }
}
Module['writeStringToMemory'] = writeStringToMemory;
function writeArrayToMemory(array, buffer) {
  for (var i = 0; i < array.length; i++) {
    HEAP8[(((buffer)+(i))|0)]=array[i];
  }
}
Module['writeArrayToMemory'] = writeArrayToMemory;
function unSign(value, bits, ignore, sig) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
}
function reSign(value, bits, ignore, sig) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}
if (!Math['imul']) Math['imul'] = function(a, b) {
  var ah  = a >>> 16;
  var al = a & 0xffff;
  var bh  = b >>> 16;
  var bl = b & 0xffff;
  return (al*bl + ((ah*bl + al*bh) << 16))|0;
};
// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// PRE_RUN_ADDITIONS (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyTracking = {};
var calledInit = false, calledRun = false;
var runDependencyWatcher = null;
function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(!runDependencyTracking[id]);
    runDependencyTracking[id] = 1;
  } else {
    Module.printErr('warning: run dependency added without ID');
  }
}
Module['addRunDependency'] = addRunDependency;
function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(runDependencyTracking[id]);
    delete runDependencyTracking[id];
  } else {
    Module.printErr('warning: run dependency removed without ID');
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    } 
    // If run has never been called, and we should call run (INVOKE_RUN is true, and Module.noInitialRun is not false)
    if (!calledRun && shouldRunNow) run();
  }
}
Module['removeRunDependency'] = removeRunDependency;
Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data
function addPreRun(func) {
  if (!Module['preRun']) Module['preRun'] = [];
  else if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
  Module['preRun'].push(func);
}
function loadMemoryInitializer(filename) {
  function applyData(data) {
    HEAPU8.set(data, STATIC_BASE);
  }
  // always do this asynchronously, to keep shell and web as similar as possible
  addPreRun(function() {
    if (ENVIRONMENT_IS_NODE || ENVIRONMENT_IS_SHELL) {
      applyData(Module['readBinary'](filename));
    } else {
      Browser.asyncLoad(filename, function(data) {
        applyData(data);
      }, function(data) {
        throw 'could not load memory initializer ' + filename;
      });
    }
  });
}
// === Body ===
STATIC_BASE = 8;
STATICTOP = STATIC_BASE + 44984;
/* global initializers */ __ATINIT__.push({ func: function() { runPostSets() } });
var _stdout;
var _stdin;
var _stderr;
var _stdout = _stdout=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
var _stdin = _stdin=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
var _stderr = _stderr=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
/* memory initializer */ allocate([0,131,3,0,0,0,0,0,0,130,2,0,0,44,0,0,0,132,4,0,0,4,0,0,0,134,6,0,0,48,0,0,1,132,4,0,0,80,0,0,1,130,2,0,0,46,0,0,1,131,3,0,0,88,0,0,1,134,6,0,0,12,0,0,0,1,2,0,0,24,0,0,0,138,2,0,0,18,0,0,0,129,2,0,0,0,0,0,0,139,2,0,0,20,0,0,0,130,2,0,0,2,0,0,0,2,2,0,0,26,0,0,0,131,2,0,0,4,0,0,0,3,2,0,0,28,0,0,0,132,2,0,0,6,0,0,0,4,2,0,0,30,0,0,0,133,2,0,0,8,0,0,0,5,2,0,0,32,0,0,0,134,2,0,0,10,0,0,0,6,2,0,0,34,0,0,0,135,2,0,0,12,0,0,0,7,2,0,0,36,0,0,0,136,2,0,0,14,0,0,0,8,2,0,0,38,0,0,0,137,2,0,0,16,0,0,1,144,2,0,0,84,0,0,1,135,2,0,0,56,0,0,1,145,2,0,0,86,0,0,1,136,2,0,0,58,0,0,1,146,2,0,0,88,0,0,1,137,2,0,0,60,0,0,1,147,2,0,0,90,0,0,1,138,2,0,0,62,0,0,1,129,2,0,0,22,0,0,1,139,2,0,0,64,0,0,1,130,2,0,0,46,0,0,1,140,2,0,0,66,0,0,1,131,2,0,0,48,0,0,1,141,2,0,0,68,0,0,1,132,2,0,0,50,0,0,1,142,2,0,0,70,0,0,1,133,2,0,0,52,0,0,1,143,2,0,0,72,0,0,1,134,2,0,0,54,0,0,80,0,0,0,0,92,0,0,38,0,0,0,72,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,20,0,0,0,182,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,16,0,0,0,102,0,0,0,12,0,0,0,18,0,0,0,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,123,0,0,48,116,0,0,232,108,0,0,184,102,0,0,2,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,32,145,0,0,74,0,0,0,40,125,0,0,58,0,0,0,48,118,0,0,102,0,0,0,40,110,0,0,14,0,0,0,248,103,0,0,114,0,0,0,80,98,0,0,84,0,0,0,128,93,0,0,116,0,0,0,72,87,0,0,70,0,0,0,208,82,0,0,44,0,0,0,120,161,0,0,80,0,0,0,136,156,0,0,98,0,0,0,16,151,0,0,10,0,0,0,32,147,0,0,100,0,0,0,40,140,0,0,56,0,0,0,136,136,0,0,92,0,0,0,8,135,0,0,18,0,0,0,16,134,0,0,32,0,0,0,48,133,0,0,40,0,0,0,248,131,0,0,34,0,0,0,128,130,0,0,64,0,0,0,160,128,0,0,72,0,0,0,56,126,0,0,30,0,0,0,112,125,0,0,6,0,0,0,176,124,0,0,106,0,0,0,56,124,0,0,48,0,0,0,208,123,0,0,26,0,0,0,0,0,0,0,0,0,0,0,45,43,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,3,0,0,0,4,0,0,0,3,0,0,0,248,3,0,0,248,2,0,0,232,3,0,0,232,2,0,0,120,3,0,0,120,2,0,0,188,3,0,0,188,2,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,0,0,1,1,0,0,1,0,1,1,0,1,0,0,1,0,1,1,0,0,1,1,0,1,0,0,1,1,0,0,1,0,1,1,0,0,1,1,0,1,0,0,1,0,1,1,0,1,0,0,1,1,0,0,1,0,1,1,0,1,0,0,1,0,1,1,0,0,1,1,0,1,0,0,1,0,1,1,0,1,0,0,1,1,0,0,1,0,1,1,0,0,1,1,0,1,0,0,1,1,0,0,1,0,1,1,0,1,0,0,1,0,1,1,0,0,1,1,0,1,0,0,1,1,0,0,1,0,1,1,0,0,1,1,0,1,0,0,1,0,1,1,0,1,0,0,1,1,0,0,1,0,1,1,0,0,1,1,0,1,0,0,1,1,0,0,1,0,1,1,0,1,0,0,1,0,1,1,0,0,1,1,0,1,0,0,1,0,1,1,0,1,0,0,1,1,0,0,1,0,1,1,0,1,0,0,1,0,1,1,0,0,1,1,0,1,0,0,1,1,0,0,1,0,1,1,0,0,1,1,0,1,0,0,1,0,1,1,0,1,0,0,1,1,0,0,1,0,1,1,0,224,88,0,0,88,84,0,0,184,162,0,0,152,158,0,0,96,152,0,0,0,0,0,0,83,79,70,84,87,65,82,69,32,80,73,82,65,84,69,83,96,106,0,0,232,104,0,0,96,104,0,0,240,103,0,0,184,173,0,0,96,103,0,0,56,103,0,0,144,102,0,0,40,102,0,0,248,101,0,0,0,101,0,0,16,100,0,0,56,99,0,0,0,99,0,0,152,98,0,0,136,94,0,0,56,98,0,0,216,97,0,0,88,88,0,0,160,97,0,0,40,97,0,0,184,83,0,0,184,173,0,0,248,96,0,0,168,111,0,0,176,96,0,0,72,96,0,0,72,162,0,0,80,95,0,0,64,94,0,0,240,157,0,0,184,173,0,0,232,93,0,0,56,105,0,0,104,93,0,0,72,96,0,0,232,151,0,0,200,92,0,0,136,92,0,0,40,148,0,0,24,92,0,0,216,91,0,0,248,104,0,0,8,126,0,0,56,125,0,0,24,94,0,0,136,124,0,0,32,124,0,0,192,123,0,0,40,123,0,0,176,122,0,0,240,87,0,0,48,122,0,0,152,121,0,0,240,87,0,0,176,173,0,0,224,118,0,0,104,83,0,0,176,173,0,0,64,118,0,0,216,161,0,0,112,117,0,0,152,116,0,0,112,157,0,0,16,116,0,0,120,115,0,0,120,151,0,0,232,114,0,0,16,114,0,0,120,151,0,0,176,113,0,0,120,111,0,0,176,147,0,0,200,110,0,0,64,110,0,0,112,140,0,0,184,109,0,0,104,109,0,0,176,136,0,0,136,124,0,0,176,108,0,0,48,135,0,0,112,108,0,0,240,107,0,0,192,134,0,0,104,107,0,0,0,107,0,0,192,133,0,0,136,124,0,0,16,105,0,0,232,132,0,0,128,104,0,0,8,104,0,0,0,0,0,0,63,0,0,0,128,125,0,0,0,0,0,0,192,124,0,0,98,0,1,0,72,124,0,0,232,123,0,0,136,123,0,0,99,0,1,0,0,123,0,0,104,122,0,0,232,121,0,0,100,0,1,0,208,120,0,0,104,122,0,0,8,119,0,0,103,0,1,0,176,118,0,0,104,122,0,0,208,117,0,0,105,0,1,0,224,116,0,0,104,122,0,0,56,116,0,0,73,0,1,0,192,115,0,0,104,122,0,0,40,115,0,0,108,0,1,0,128,114,0,0,104,122,0,0,224,113,0,0,112,0,1,0,168,112,0,0,104,122,0,0,0,111,0,0,113,0,0,0,120,110,0,0,0,0,0,0,208,109,0,0,114,0,0,0,152,109,0,0,0,0,0,0,240,108,0,0,82,0,0,0,128,108,0,0,0,0,0,0,0,108,0,0,115,0,1,0,176,107,0,0,232,123,0,0,64,107,0,0,116,0,1,0,240,105,0,0,104,122,0,0,160,104,0,0,118,0,0,0,40,104,0,0,0,0,0,0,192,103,0,0,86,0,0,0,72,103,0,0,0,0,0,0,192,102,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,129,165,129,129,189,153,129,126,0,0,0,0,0,126,255,219,255,255,195,231,255,126,0,0,0,0,0,0,54,127,127,127,127,62,28,8,0,0,0,0,0,0,8,28,62,127,62,28,8,0,0,0,0,0,0,24,60,60,231,231,231,24,24,60,0,0,0,0,0,24,60,126,255,255,126,24,24,60,0,0,0,0,0,0,0,0,24,60,60,24,0,0,0,0,0,255,255,255,255,255,231,195,195,231,255,255,255,255,255,0,0,0,0,60,102,66,66,102,60,0,0,0,0,255,255,255,255,195,153,189,189,153,195,255,255,255,255,0,0,15,7,13,25,60,102,102,102,60,0,0,0,0,0,60,102,102,102,60,24,126,24,24,0,0,0,0,0,63,51,63,48,48,48,112,240,224,0,0,0,0,0,127,99,127,99,99,99,103,231,230,192,0,0,0,0,24,24,219,60,231,60,219,24,24,0,0,0,0,0,64,96,112,124,127,124,112,96,64,0,0,0,0,0,1,3,7,31,127,31,7,3,1,0,0,0,0,0,24,60,126,24,24,24,126,60,24,0,0,0,0,0,51,51,51,51,51,51,0,51,51,0,0,0,0,0,127,219,219,219,123,27,27,27,27,0,0,0,0,62,99,48,28,54,99,99,54,28,6,99,62,0,0,0,0,0,0,0,0,0,127,127,127,0,0,0,0,0,24,60,126,24,24,24,126,60,24,126,0,0,0,0,24,60,126,24,24,24,24,24,24,0,0,0,0,0,24,24,24,24,24,24,126,60,24,0,0,0,0,0,0,0,12,6,127,6,12,0,0,0,0,0,0,0,0,0,24,48,127,48,24,0,0,0,0,0,0,0,0,0,0,96,96,96,127,0,0,0,0,0,0,0,0,0,36,102,255,102,36,0,0,0,0,0,0,0,0,8,28,28,62,62,127,127,0,0,0,0,0,0,0,127,127,62,62,28,28,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,60,60,60,24,24,0,24,24,0,0,0,0,99,99,99,34,0,0,0,0,0,0,0,0,0,0,0,54,54,127,54,54,54,127,54,54,0,0,0,12,12,62,99,97,96,62,3,67,99,62,12,12,0,0,0,0,0,97,99,6,12,24,51,99,0,0,0,0,0,28,54,54,28,59,110,102,102,59,0,0,0,0,48,48,48,96,0,0,0,0,0,0,0,0,0,0,0,12,24,48,48,48,48,48,24,12,0,0,0,0,0,24,12,6,6,6,6,6,12,24,0,0,0,0,0,0,0,102,60,255,60,102,0,0,0,0,0,0,0,0,24,24,24,255,24,24,24,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,48,0,0,0,0,0,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,0,0,0,0,0,1,3,6,12,24,48,96,64,0,0,0,0,0,0,62,99,103,111,123,115,99,99,62,0,0,0,0,0,12,28,60,12,12,12,12,12,63,0,0,0,0,0,62,99,3,6,12,24,48,99,127,0,0,0,0,0,62,99,3,3,30,3,3,99,62,0,0,0,0,0,6,14,30,54,102,127,6,6,15,0,0,0,0,0,127,96,96,96,126,3,3,99,62,0,0,0,0,0,28,48,96,96,126,99,99,99,62,0,0,0,0,0,127,99,3,6,12,24,24,24,24,0,0,0,0,0,62,99,99,99,62,99,99,99,62,0,0,0,0,0,62,99,99,99,63,3,3,6,60,0,0,0,0,0,0,24,24,0,0,0,24,24,0,0,0,0,0,0,0,24,24,0,0,0,24,24,48,0,0,0,0,0,6,12,24,48,96,48,24,12,6,0,0,0,0,0,0,0,0,126,0,0,126,0,0,0,0,0,0,0,96,48,24,12,6,12,24,48,96,0,0,0,0,0,62,99,99,6,12,12,0,12,12,0,0,0,0,0,62,99,99,111,111,111,110,96,62,0,0,0,0,0,8,28,54,99,99,127,99,99,99,0,0,0,0,0,126,51,51,51,62,51,51,51,126,0,0,0,0,0,30,51,97,96,96,96,97,51,30,0,0,0,0,0,124,54,51,51,51,51,51,54,124,0,0,0,0,0,127,51,49,52,60,52,49,51,127,0,0,0,0,0,127,51,49,52,60,52,48,48,120,0,0,0,0,0,30,51,97,96,96,111,99,51,29,0,0,0,0,0,99,99,99,99,127,99,99,99,99,0,0,0,0,0,60,24,24,24,24,24,24,24,60,0,0,0,0,0,15,6,6,6,6,6,102,102,60,0,0,0,0,0,115,51,54,54,60,54,54,51,115,0,0,0,0,0,120,48,48,48,48,48,49,51,127,0,0,0,0,0,195,231,255,219,195,195,195,195,195,0,0,0,0,0,99,115,123,127,111,103,99,99,99,0,0,0,0,0,28,54,99,99,99,99,99,54,28,0,0,0,0,0,126,51,51,51,62,48,48,48,120,0,0,0,0,0,62,99,99,99,99,107,111,62,6,7,0,0,0,0,126,51,51,51,62,54,51,51,115,0,0,0,0,0,62,99,99,48,28,6,99,99,62,0,0,0,0,0,255,219,153,24,24,24,24,24,60,0,0,0,0,0,99,99,99,99,99,99,99,99,62,0,0,0,0,0,195,195,195,195,195,195,102,60,24,0,0,0,0,0,195,195,195,195,219,219,255,102,102,0,0,0,0,0,195,195,102,60,24,60,102,195,195,0,0,0,0,0,195,195,195,102,60,24,24,24,60,0,0,0,0,0,255,195,134,12,24,48,97,195,255,0,0,0,0,0,60,48,48,48,48,48,48,48,60,0,0,0,0,0,64,96,112,56,28,14,7,3,1,0,0,0,0,0,60,12,12,12,12,12,12,12,60,0,0,0,8,28,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,24,24,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,60,6,62,102,102,59,0,0,0,0,0,112,48,48,60,54,51,51,51,110,0,0,0,0,0,0,0,0,62,99,96,96,99,62,0,0,0,0,0,14,6,6,30,54,102,102,102,59,0,0,0,0,0,0,0,0,62,99,127,96,99,62,0,0,0,0,0,28,54,50,48,124,48,48,48,120,0,0,0,0,0,0,0,0,59,102,102,102,62,6,102,60,0,0,0,112,48,48,54,59,51,51,51,115,0,0,0,0,0,12,12,0,28,12,12,12,12,30,0,0,0,0,0,6,6,0,14,6,6,6,6,102,102,60,0,0,0,112,48,48,51,54,60,54,51,115,0,0,0,0,0,28,12,12,12,12,12,12,12,30,0,0,0,0,0,0,0,0,230,255,219,219,219,219,0,0,0,0,0,0,0,0,110,51,51,51,51,51,0,0,0,0,0,0,0,0,62,99,99,99,99,62,0,0,0,0,0,0,0,0,110,51,51,51,62,48,48,120,0,0,0,0,0,0,59,102,102,102,62,6,6,15,0,0,0,0,0,0,110,59,51,48,48,120,0,0,0,0,0,0,0,0,62,99,56,14,99,62,0,0,0,0,0,8,24,24,126,24,24,24,27,14,0,0,0,0,0,0,0,0,102,102,102,102,102,59,0,0,0,0,0,0,0,0,195,195,195,102,60,24,0,0,0,0,0,0,0,0,195,195,219,219,255,102,0,0,0,0,0,0,0,0,99,54,28,28,54,99,0,0,0,0,0,0,0,0,99,99,99,99,63,3,6,60,0,0,0,0,0,0,127,102,12,24,51,127,0,0,0,0,0,14,24,24,24,112,24,24,24,14,0,0,0,0,0,24,24,24,24,0,24,24,24,24,0,0,0,0,0,112,24,24,24,14,24,24,24,112,0,0,0,0,0,59,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,28,54,99,99,127,0,0,0,0,0,0,30,51,97,96,96,97,51,30,6,3,62,0,0,0,102,102,0,102,102,102,102,102,59,0,0,0,0,6,12,24,0,62,99,127,96,99,62,0,0,0,0,8,28,54,0,60,6,62,102,102,59,0,0,0,0,0,102,102,0,60,6,62,102,102,59,0,0,0,0,48,24,12,0,60,6,62,102,102,59,0,0,0,0,28,54,28,0,60,6,62,102,102,59,0,0,0,0,0,0,0,60,102,96,102,60,12,6,60,0,0,0,8,28,54,0,62,99,127,96,99,62,0,0,0,0,0,102,102,0,62,99,127,96,99,62,0,0,0,0,48,24,12,0,62,99,127,96,99,62,0,0,0,0,0,102,102,0,56,24,24,24,24,60,0,0,0,0,24,60,102,0,56,24,24,24,24,60,0,0,0,0,96,48,24,0,56,24,24,24,24,60,0,0,0,0,99,99,8,28,54,99,99,127,99,99,0,0,0,28,54,28,0,28,54,99,99,127,99,99,0,0,0,12,24,48,0,127,51,48,62,48,51,127,0,0,0,0,0,0,0,110,59,27,126,216,220,119,0,0,0,0,0,31,54,102,102,127,102,102,102,103,0,0,0,0,8,28,54,0,62,99,99,99,99,62,0,0,0,0,0,99,99,0,62,99,99,99,99,62,0,0,0,0,48,24,12,0,62,99,99,99,99,62,0,0,0,0,24,60,102,0,102,102,102,102,102,59,0,0,0,0,48,24,12,0,102,102,102,102,102,59,0,0,0,0,0,99,99,0,99,99,99,99,63,3,6,60,0,0,99,99,28,54,99,99,99,99,54,28,0,0,0,0,99,99,0,99,99,99,99,99,99,62,0,0,0,0,24,24,126,195,192,192,195,126,24,24,0,0,0,0,28,54,50,48,120,48,48,48,115,126,0,0,0,0,0,195,102,60,24,255,24,255,24,24,0,0,0,0,252,102,102,124,98,102,111,102,102,243,0,0,0,0,14,27,24,24,24,126,24,24,24,24,216,112,0,0,12,24,48,0,60,6,62,102,102,59,0,0,0,0,12,24,48,0,56,24,24,24,24,60,0,0,0,0,12,24,48,0,62,99,99,99,99,62,0,0,0,0,12,24,48,0,102,102,102,102,102,59,0,0,0,0,0,59,110,0,110,51,51,51,51,51,0,0,0,59,110,0,99,115,123,127,111,103,99,99,0,0,0,0,60,108,108,62,0,126,0,0,0,0,0,0,0,0,56,108,108,56,0,124,0,0,0,0,0,0,0,0,0,24,24,0,24,24,48,99,99,62,0,0,0,0,0,0,0,0,0,127,96,96,96,0,0,0,0,0,0,0,0,0,0,127,3,3,3,0,0,0,0,0,96,224,99,102,108,24,48,110,195,6,12,31,0,0,96,224,99,102,108,24,51,103,207,31,3,3,0,0,0,24,24,0,24,24,60,60,60,24,0,0,0,0,0,0,0,27,54,108,54,27,0,0,0,0,0,0,0,0,0,108,54,27,54,108,0,0,0,0,0,17,68,17,68,17,68,17,68,17,68,17,68,17,68,85,170,85,170,85,170,85,170,85,170,85,170,85,170,221,119,221,119,221,119,221,119,221,119,221,119,221,119,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,248,24,24,24,24,24,24,24,24,24,24,24,248,24,248,24,24,24,24,24,24,54,54,54,54,54,54,54,246,54,54,54,54,54,54,0,0,0,0,0,0,0,254,54,54,54,54,54,54,0,0,0,0,0,248,24,248,24,24,24,24,24,24,54,54,54,54,54,246,6,246,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,0,0,0,0,0,254,6,246,54,54,54,54,54,54,54,54,54,54,54,246,6,254,0,0,0,0,0,0,54,54,54,54,54,54,54,254,0,0,0,0,0,0,24,24,24,24,24,248,24,248,0,0,0,0,0,0,0,0,0,0,0,0,0,248,24,24,24,24,24,24,24,24,24,24,24,24,24,31,0,0,0,0,0,0,24,24,24,24,24,24,24,255,0,0,0,0,0,0,0,0,0,0,0,0,0,255,24,24,24,24,24,24,24,24,24,24,24,24,24,31,24,24,24,24,24,24,0,0,0,0,0,0,0,255,0,0,0,0,0,0,24,24,24,24,24,24,24,255,24,24,24,24,24,24,24,24,24,24,24,31,24,31,24,24,24,24,24,24,54,54,54,54,54,54,54,55,54,54,54,54,54,54,54,54,54,54,54,55,48,63,0,0,0,0,0,0,0,0,0,0,0,63,48,55,54,54,54,54,54,54,54,54,54,54,54,247,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,247,54,54,54,54,54,54,54,54,54,54,54,55,48,55,54,54,54,54,54,54,0,0,0,0,0,255,0,255,0,0,0,0,0,0,54,54,54,54,54,247,0,247,54,54,54,54,54,54,24,24,24,24,24,255,0,255,0,0,0,0,0,0,54,54,54,54,54,54,54,255,0,0,0,0,0,0,0,0,0,0,0,255,0,255,24,24,24,24,24,24,0,0,0,0,0,0,0,255,54,54,54,54,54,54,54,54,54,54,54,54,54,63,0,0,0,0,0,0,24,24,24,24,24,31,24,31,0,0,0,0,0,0,0,0,0,0,0,31,24,31,24,24,24,24,24,24,0,0,0,0,0,0,0,63,54,54,54,54,54,54,54,54,54,54,54,54,54,255,54,54,54,54,54,54,24,24,24,24,24,255,24,255,24,24,24,24,24,24,24,24,24,24,24,24,24,248,0,0,0,0,0,0,0,0,0,0,0,0,0,31,24,24,24,24,24,24,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,255,255,255,255,255,255,255,240,240,240,240,240,240,240,240,240,240,240,240,240,240,15,15,15,15,15,15,15,15,15,15,15,15,15,15,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,59,110,108,108,110,59,0,0,0,0,0,0,0,62,99,126,99,99,126,96,96,32,0,0,0,127,99,99,96,96,96,96,96,96,0,0,0,0,0,0,0,127,54,54,54,54,54,54,0,0,0,0,0,127,99,48,24,12,24,48,99,127,0,0,0,0,0,0,0,0,63,108,108,108,108,56,0,0,0,0,0,0,0,51,51,51,51,62,48,48,96,0,0,0,0,0,0,59,110,12,12,12,12,12,0,0,0,0,0,126,24,60,102,102,102,60,24,126,0,0,0,0,0,28,54,99,99,127,99,99,54,28,0,0,0,0,0,28,54,99,99,99,54,54,54,119,0,0,0,0,0,30,48,24,12,62,102,102,102,60,0,0,0,0,0,0,0,0,126,219,219,126,0,0,0,0,0,0,0,3,6,126,219,219,243,126,96,192,0,0,0,0,0,28,48,96,96,124,96,96,48,28,0,0,0,0,0,0,62,99,99,99,99,99,99,99,0,0,0,0,0,0,127,0,0,127,0,0,127,0,0,0,0,0,0,24,24,24,255,24,24,24,0,255,0,0,0,0,0,48,24,12,6,12,24,48,0,126,0,0,0,0,0,12,24,48,96,48,24,12,0,126,0,0,0,0,0,14,27,27,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,216,216,112,0,0,0,0,0,24,24,0,0,255,0,0,24,24,0,0,0,0,0,0,0,59,110,0,59,110,0,0,0,0,0,0,56,108,108,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,15,12,12,12,12,12,236,108,60,28,0,0,0,0,216,108,108,108,108,108,0,0,0,0,0,0,0,0,112,216,48,96,200,248,0,0,0,0,0,0,0,0,0,0,0,62,62,62,62,62,62,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,248,128,0,0,2,0,0,0,120,152,0,0,3,0,0,0,216,126,0,0,4,0,0,0,112,119,0,0,5,0,0,0,88,111,0,0,6,0,0,0,240,104,0,0,7,0,0,0,16,99,0,0,8,0,0,0,104,94,0,0,9,0,0,0,48,88,0,0,10,0,0,0,152,83,0,0,11,0,0,0,32,162,0,0,12,0,0,0,208,157,0,0,13,0,0,0,200,151,0,0,14,0,0,0,0,148,0,0,14,0,0,0,48,144,0,0,15,0,0,0,216,136,0,0,15,0,0,0,80,135,0,0,16,0,0,0,72,134,0,0,17,0,0,0,112,133,0,0,17,0,0,0,136,132,0,0,18,0,0,0,248,130,0,0,19,0,0,0,64,129,0,0,20,0,0,0,160,126,0,0,21,0,0,0,168,125,0,0,22,0,0,0,240,124,0,0,23,0,0,0,88,124,0,0,24,0,0,0,248,123,0,0,25,0,0,0,160,123,0,0,26,0,0,0,8,123,0,0,27,0,0,0,128,122,0,0,28,0,0,0,8,122,0,0,28,0,0,0,8,121,0,0,29,0,0,0,72,119,0,0,29,0,0,0,192,118,0,0,30,0,0,0,232,117,0,0,31,0,0,0,240,116,0,0,32,0,0,0,104,116,0,0,33,0,0,0,208,115,0,0,34,0,0,0,80,115,0,0,35,0,0,0,144,114,0,0,36,0,0,0,0,114,0,0,37,0,0,0,32,113,0,0,38,0,0,0,56,111,0,0,39,0,0,0,168,110,0,0,40,0,0,0,240,109,0,0,41,0,0,0,160,109,0,0,42,0,0,0,16,109,0,0,42,0,0,0,144,108,0,0,43,0,0,0,24,108,0,0,43,0,0,0,192,107,0,0,44,0,0,0,88,107,0,0,45,0,0,0,64,106,0,0,46,0,0,0,208,104,0,0,47,0,0,0,80,104,0,0,48,0,0,0,224,103,0,0,49,0,0,0,80,103,0,0,50,0,0,0,240,102,0,0,51,0,0,0,104,102,0,0,52,0,0,0,24,102,0,0,53,0,0,0,208,101,0,0,54,0,0,0,248,100,0,0,55,0,0,0,248,99,0,0,55,0,0,0,232,98,0,0,56,0,0,0,136,98,0,0,56,0,0,0,24,98,0,0,56,0,0,0,200,97,0,0,57,0,0,0,136,97,0,0,57,0,0,0,24,97,0,0,58,0,0,0,224,96,0,0,58,0,0,0,152,96,0,0,59,0,0,0,48,96,0,0,59,0,0,0,72,95,0,0,60,0,0,0,56,94,0,0,61,0,0,0,224,93,0,0,62,0,0,0,96,93,0,0,63,0,0,0,192,92,0,0,64,0,0,0,128,92,0,0,66,0,0,0,16,92,0,0,65,0,0,0,208,91,0,0,67,0,0,0,200,90,0,0,67,0,0,0,56,90,0,0,68,0,0,0,8,89,0,0,68,0,0,0,40,88,0,0,69,0,0,0,192,87,0,0,69,0,0,0,64,87,0,0,71,0,0,0,192,86,0,0,71,0,0,0,120,86,0,0,73,0,0,0,32,86,0,0,73,0,0,0,0,86,0,0,72,0,0,0,176,85,0,0,72,0,0,0,40,85,0,0,72,0,0,0,128,84,0,0,74,0,0,0,144,83,0,0,75,0,0,0,24,83,0,0,75,0,0,0,200,82,0,0,76,0,0,0,112,82,0,0,77,0,0,0,64,82,0,0,78,0,0,0,200,81,0,0,79,0,0,0,112,81,0,0,79,0,0,0,8,81,0,0,79,0,0,0,96,163,0,0,80,0,0,0,248,162,0,0,81,0,0,0,8,162,0,0,82,0,0,0,192,161,0,0,83,0,0,0,104,161,0,0,84,0,0,0,224,160,0,0,85,0,0,0,168,160,0,0,86,0,0,0,16,160,0,0,87,0,0,0,216,159,0,0,88,0,0,0,144,159,0,0,89,0,0,0,72,159,0,0,90,0,0,0,192,158,0,0,91,0,0,0,192,157,0,0,92,0,0,0,248,156,0,0,93,0,0,0,128,156,0,0,94,0,0,0,64,155,0,0,95,0,0,0,224,154,0,0,96,0,0,0,72,154,0,0,97,0,0,0,224,153,0,0,98,0,0,0,152,153,0,0,99,0,0,0,0,153,0,0,100,0,0,0,160,152,0,0,101,0,0,0,192,151,0,0,102,0,0,0,88,151,0,0,103,0,0,0,8,151,0,0,104,0,0,0,128,150,0,0,105,0,0,0,72,150,0,0,106,0,0,0,32,150,0,0,107,0,0,0,232,149,0,0,108,0,0,0,136,149,0,0,109,0,0,0,16,149,0,0,110,0,0,0,144,148,0,0,111,0,0,0,248,147,0,0,112,0,0,0,120,147,0,0,113,0,0,0,24,147,0,0,114,0,0,0,208,146,0,0,115,0,0,0,120,146,0,0,116,0,0,0,48,146,0,0,117,0,0,0,0,146,0,0,118,0,0,0,160,145,0,0,119,0,0,0,56,145,0,0,120,0,0,0,0,145,0,0,121,0,0,0,40,144,0,0,122,0,0,0,104,140,0,0,123,0,0,0,32,140,0,0,124,0,0,0,200,139,0,0,0,0,0,0,0,0,0,0,27,0,0,0,1,0,0,0,58,4,0,0,2,0,0,0,59,4,0,0,3,0,0,0,60,4,0,0,4,0,0,0,61,4,0,0,5,0,0,0,62,4,0,0,6,0,0,0,63,4,0,0,7,0,0,0,64,4,0,0,8,0,0,0,65,4,0,0,9,0,0,0,66,4,0,0,10,0,0,0,67,4,0,0,11,0,0,0,68,4,0,0,12,0,0,0,69,4,0,0,13,0,0,0,70,4,0,0,14,0,0,0,71,4,0,0,15,0,0,0,72,4,0,0,16,0,0,0,96,0,0,0,17,0,0,0,49,0,0,0,18,0,0,0,50,0,0,0,19,0,0,0,51,0,0,0,20,0,0,0,52,0,0,0,21,0,0,0,53,0,0,0,22,0,0,0,54,0,0,0,23,0,0,0,55,0,0,0,24,0,0,0,56,0,0,0,25,0,0,0,57,0,0,0,26,0,0,0,48,0,0,0,27,0,0,0,45,0,0,0,28,0,0,0,61,0,0,0,29,0,0,0,8,0,0,0,30,0,0,0,9,0,0,0,31,0,0,0,113,0,0,0,32,0,0,0,119,0,0,0,33,0,0,0,101,0,0,0,34,0,0,0,114,0,0,0,35,0,0,0,116,0,0,0,36,0,0,0,121,0,0,0,37,0,0,0,117,0,0,0,38,0,0,0,105,0,0,0,39,0,0,0,111,0,0,0,40,0,0,0,112,0,0,0,41,0,0,0,91,0,0,0,42,0,0,0,93,0,0,0,43,0,0,0,13,0,0,0,44,0,0,0,57,4,0,0,45,0,0,0,97,0,0,0,46,0,0,0,115,0,0,0,47,0,0,0,100,0,0,0,48,0,0,0,102,0,0,0,49,0,0,0,103,0,0,0,50,0,0,0,104,0,0,0,51,0,0,0,106,0,0,0,52,0,0,0,107,0,0,0,53,0,0,0,108,0,0,0,54,0,0,0,59,0,0,0,55,0,0,0,39,0,0,0,56,0,0,0,92,0,0,0,57,0,0,0,225,4,0,0,58,0,0,0,60,0,0,0,59,0,0,0,122,0,0,0,60,0,0,0,120,0,0,0,61,0,0,0,99,0,0,0,62,0,0,0,118,0,0,0,63,0,0,0,98,0,0,0,64,0,0,0,110,0,0,0,66,0,0,0,109,0,0,0,65,0,0,0,44,0,0,0,67,0,0,0,46,0,0,0,68,0,0,0,47,0,0,0,69,0,0,0,229,4,0,0,70,0,0,0,224,4,0,0,71,0,0,0,227,4,0,0,73,0,0,0,227,4,0,0,72,0,0,0,226,4,0,0,75,0,0,0,1,5,0,0,74,0,0,0,32,0,0,0,76,0,0,0,230,4,0,0,77,0,0,0,231,4,0,0,78,0,0,0,231,4,0,0,79,0,0,0,118,4,0,0,80,0,0,0,228,4,0,0,81,0,0,0,83,4,0,0,82,0,0,0,84,4,0,0,83,0,0,0,85,4,0,0,84,0,0,0,86,4,0,0,85,0,0,0,95,4,0,0,86,0,0,0,96,4,0,0,87,0,0,0,97,4,0,0,88,0,0,0,87,4,0,0,89,0,0,0,92,4,0,0,90,0,0,0,93,4,0,0,91,0,0,0,94,4,0,0,92,0,0,0,89,4,0,0,93,0,0,0,90,4,0,0,94,0,0,0,91,4,0,0,95,0,0,0,88,4,0,0,96,0,0,0,98,4,0,0,97,0,0,0,99,4,0,0,98,0,0,0,73,4,0,0,99,0,0,0,74,4,0,0,100,0,0,0,75,4,0,0,101,0,0,0,127,0,0,0,102,0,0,0,77,4,0,0,103,0,0,0,78,4,0,0,104,0,0,0,82,4,0,0,105,0,0,0,80,4,0,0,106,0,0,0,81,4,0,0,107,0,0,0,79,4,0,0,108,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,1,0,0,0,1,0,129,0,0,0,0,0,0,0,18,0,0,0,1,0,2,0,0,0,1,0,130,0,0,0,0,0,0,0,19,0,0,0,1,0,3,0,0,0,1,0,131,0,0,0,0,0,0,0,20,0,0,0,1,0,4,0,0,0,1,0,132,0,0,0,0,0,0,0,21,0,0,0,1,0,5,0,0,0,1,0,133,0,0,0,0,0,0,0,22,0,0,0,1,0,6,0,0,0,1,0,134,0,0,0,0,0,0,0,23,0,0,0,1,0,7,0,0,0,1,0,135,0,0,0,0,0,0,0,24,0,0,0,1,0,8,0,0,0,1,0,136,0,0,0,0,0,0,0,25,0,0,0,1,0,9,0,0,0,1,0,137,0,0,0,0,0,0,0,26,0,0,0,1,0,10,0,0,0,1,0,138,0,0,0,0,0,0,0,27,0,0,0,1,0,11,0,0,0,1,0,139,0,0,0,0,0,0,0,28,0,0,0,1,0,12,0,0,0,1,0,140,0,0,0,0,0,0,0,29,0,0,0,1,0,13,0,0,0,1,0,141,0,0,0,0,0,0,0,30,0,0,0,1,0,14,0,0,0,1,0,142,0,0,0,0,0,0,0,31,0,0,0,1,0,15,0,0,0,1,0,143,0,0,0,0,0,0,0,32,0,0,0,1,0,16,0,0,0,1,0,144,0,0,0,0,0,0,0,33,0,0,0,1,0,17,0,0,0,1,0,145,0,0,0,0,0,0,0,34,0,0,0,1,0,18,0,0,0,1,0,146,0,0,0,0,0,0,0,35,0,0,0,1,0,19,0,0,0,1,0,147,0,0,0,0,0,0,0,36,0,0,0,1,0,20,0,0,0,1,0,148,0,0,0,0,0,0,0,37,0,0,0,1,0,21,0,0,0,1,0,149,0,0,0,0,0,0,0,38,0,0,0,1,0,22,0,0,0,1,0,150,0,0,0,0,0,0,0,39,0,0,0,1,0,23,0,0,0,1,0,151,0,0,0,0,0,0,0,40,0,0,0,1,0,24,0,0,0,1,0,152,0,0,0,0,0,0,0,41,0,0,0,1,0,25,0,0,0,1,0,153,0,0,0,0,0,0,0,42,0,0,0,1,0,26,0,0,0,1,0,154,0,0,0,0,0,0,0,43,0,0,0,1,0,27,0,0,0,1,0,155,0,0,0,0,0,0,0,44,0,0,0,1,0,28,0,0,0,1,0,156,0,0,0,0,0,0,0,71,0,0,0,1,0,29,0,0,0,1,0,157,0,0,0,0,0,0,0,81,0,0,0,1,0,29,0,0,0,1,0,157,0,0,0,0,0,0,0,46,0,0,0,1,0,30,0,0,0,1,0,158,0,0,0,0,0,0,0,47,0,0,0,1,0,31,0,0,0,1,0,159,0,0,0,0,0,0,0,48,0,0,0,1,0,32,0,0,0,1,0,160,0,0,0,0,0,0,0,49,0,0,0,1,0,33,0,0,0,1,0,161,0,0,0,0,0,0,0,50,0,0,0,1,0,34,0,0,0,1,0,162,0,0,0,0,0,0,0,51,0,0,0,1,0,35,0,0,0,1,0,163,0,0,0,0,0,0,0,52,0,0,0,1,0,36,0,0,0,1,0,164,0,0,0,0,0,0,0,53,0,0,0,1,0,37,0,0,0,1,0,165,0,0,0,0,0,0,0,54,0,0,0,1,0,38,0,0,0,1,0,166,0,0,0,0,0,0,0,55,0,0,0,1,0,39,0,0,0,1,0,167,0,0,0,0,0,0,0,56,0,0,0,1,0,40,0,0,0,1,0,168,0,0,0,0,0,0,0,17,0,0,0,1,0,41,0,0,0,1,0,169,0,0,0,0,0,0,0,58,0,0,0,1,0,42,0,0,0,1,0,170,0,0,0,0,0,0,0,57,0,0,0,1,0,43,0,0,0,1,0,171,0,0,0,0,0,0,0,60,0,0,0,1,0,44,0,0,0,1,0,172,0,0,0,0,0,0,0,61,0,0,0,1,0,45,0,0,0,1,0,173,0,0,0,0,0,0,0,62,0,0,0,1,0,46,0,0,0,1,0,174,0,0,0,0,0,0,0,63,0,0,0,1,0,47,0,0,0,1,0,175,0,0,0,0,0,0,0,64,0,0,0,1,0,48,0,0,0,1,0,176,0,0,0,0,0,0,0,66,0,0,0,1,0,49,0,0,0,1,0,177,0,0,0,0,0,0,0,65,0,0,0,1,0,50,0,0,0,1,0,178,0,0,0,0,0,0,0,67,0,0,0,1,0,51,0,0,0,1,0,179,0,0,0,0,0,0,0,68,0,0,0,1,0,52,0,0,0,1,0,180,0,0,0,0,0,0,0,69,0,0,0,1,0,53,0,0,0,1,0,181,0,0,0,0,0,0,0,70,0,0,0,1,0,54,0,0,0,1,0,182,0,0,0,0,0,0,0,84,0,0,0,1,0,55,0,0,0,1,0,183,0,0,0,0,0,0,0,75,0,0,0,1,0,56,0,0,0,1,0,184,0,0,0,0,0,0,0,76,0,0,0,1,0,57,0,0,0,1,0,185,0,0,0,0,0,0,0,45,0,0,0,1,0,58,0,0,0,1,0,186,0,0,0,0,0,0,0,2,0,0,0,1,0,59,0,0,0,1,0,187,0,0,0,0,0,0,0,3,0,0,0,1,0,60,0,0,0,1,0,188,0,0,0,0,0,0,0,4,0,0,0,1,0,61,0,0,0,1,0,189,0,0,0,0,0,0,0,5,0,0,0,1,0,62,0,0,0,1,0,190,0,0,0,0,0,0,0,6,0,0,0,1,0,63,0,0,0,1,0,191,0,0,0,0,0,0,0,7,0,0,0,1,0,64,0,0,0,1,0,192,0,0,0,0,0,0,0,8,0,0,0,1,0,65,0,0,0,1,0,193,0,0,0,0,0,0,0,9,0,0,0,1,0,66,0,0,0,1,0,194,0,0,0,0,0,0,0,10,0,0,0,1,0,67,0,0,0,1,0,195,0,0,0,0,0,0,0,11,0,0,0,1,0,68,0,0,0,1,0,196,0,0,0,0,0,0,0,82,0,0,0,1,0,69,0,0,0,1,0,197,0,0,0,0,0,0,0,15,0,0,0,1,0,70,0,0,0,1,0,198,0,0,0,0,0,0,0,86,0,0,0,1,0,71,0,0,0,1,0,199,0,0,0,0,0,0,0,100,0,0,0,1,0,71,0,0,0,1,0,199,0,0,0,0,0,0,0,87,0,0,0,1,0,72,0,0,0,1,0,200,0,0,0,0,0,0,0,105,0,0,0,1,0,72,0,0,0,1,0,200,0,0,0,0,0,0,0,88,0,0,0,1,0,73,0,0,0,1,0,201,0,0,0,0,0,0,0,101,0,0,0,1,0,73,0,0,0,1,0,201,0,0,0,0,0,0,0,85,0,0,0,1,0,74,0,0,0,1,0,202,0,0,0,0,0,0,0,90,0,0,0,1,0,75,0,0,0,1,0,203,0,0,0,0,0,0,0,106,0,0,0,1,0,75,0,0,0,1,0,203,0,0,0,0,0,0,0,91,0,0,0,1,0,76,0,0,0,1,0,204,0,0,0,0,0,0,0,92,0,0,0,1,0,77,0,0,0,1,0,205,0,0,0,0,0,0,0,108,0,0,0,1,0,77,0,0,0,1,0,205,0,0,0,0,0,0,0,89,0,0,0,1,0,78,0,0,0,1,0,206,0,0,0,0,0,0,0,93,0,0,0,1,0,79,0,0,0,1,0,207,0,0,0,0,0,0,0,103,0,0,0,1,0,79,0,0,0,1,0,207,0,0,0,0,0,0,0,94,0,0,0,1,0,80,0,0,0,1,0,208,0,0,0,0,0,0,0,107,0,0,0,1,0,80,0,0,0,1,0,208,0,0,0,0,0,0,0,95,0,0,0,1,0,81,0,0,0,1,0,209,0,0,0,0,0,0,0,104,0,0,0,1,0,81,0,0,0,1,0,209,0,0,0,0,0,0,0,96,0,0,0,1,0,28,0,0,0,1,0,156,0,0,0,0,0,0,0,97,0,0,0,1,0,82,0,0,0,1,0,210,0,0,0,0,0,0,0,99,0,0,0,1,0,82,0,0,0,1,0,210,0,0,0,0,0,0,0,98,0,0,0,1,0,83,0,0,0,1,0,211,0,0,0,0,0,0,0,102,0,0,0,1,0,83,0,0,0,1,0,211,0,0,0,0,0,0,0,83,0,0,0,2,0,224,53,0,0,2,0,224,181,0,0,0,0,0,0,12,0,0,0,1,0,87,0,0,0,1,0,215,0,0,0,0,0,0,0,13,0,0,0,1,0,88,0,0,0,1,0,216,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,129,165,129,129,189,153,129,126,0,0,0,0,0,126,255,219,255,255,195,231,255,126,0,0,0,0,0,0,54,127,127,127,127,62,28,8,0,0,0,0,0,0,8,28,62,127,62,28,8,0,0,0,0,0,0,24,60,60,231,231,231,24,24,60,0,0,0,0,0,24,60,126,255,255,126,24,24,60,0,0,0,0,0,0,0,0,24,60,60,24,0,0,0,0,0,255,255,255,255,255,231,195,195,231,255,255,255,255,255,0,0,0,0,60,102,66,66,102,60,0,0,0,0,255,255,255,255,195,153,189,189,153,195,255,255,255,255,0,0,15,7,13,25,60,102,102,102,60,0,0,0,0,0,60,102,102,102,60,24,126,24,24,0,0,0,0,0,63,51,63,48,48,48,112,240,224,0,0,0,0,0,127,99,127,99,99,99,103,231,230,192,0,0,0,0,24,24,219,60,231,60,219,24,24,0,0,0,0,0,64,96,112,124,127,124,112,96,64,0,0,0,0,0,1,3,7,31,127,31,7,3,1,0,0,0,0,0,24,60,126,24,24,24,126,60,24,0,0,0,0,0,51,51,51,51,51,51,0,51,51,0,0,0,0,0,127,219,219,219,123,27,27,27,27,0,0,0,0,62,99,48,28,54,99,99,54,28,6,99,62,0,0,0,0,0,0,0,0,0,127,127,127,0,0,0,0,0,24,60,126,24,24,24,126,60,24,126,0,0,0,0,24,60,126,24,24,24,24,24,24,0,0,0,0,0,24,24,24,24,24,24,126,60,24,0,0,0,0,0,0,0,12,6,127,6,12,0,0,0,0,0,0,0,0,0,24,48,127,48,24,0,0,0,0,0,0,0,0,0,0,96,96,96,127,0,0,0,0,0,0,0,0,0,36,102,255,102,36,0,0,0,0,0,0,0,0,8,28,28,62,62,127,127,0,0,0,0,0,0,0,127,127,62,62,28,28,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,60,60,60,24,24,0,24,24,0,0,0,0,99,99,99,34,0,0,0,0,0,0,0,0,0,0,0,54,54,127,54,54,54,127,54,54,0,0,0,12,12,62,99,97,96,62,3,67,99,62,12,12,0,0,0,0,0,97,99,6,12,24,51,99,0,0,0,0,0,28,54,54,28,59,110,102,102,59,0,0,0,0,48,48,48,96,0,0,0,0,0,0,0,0,0,0,0,12,24,48,48,48,48,48,24,12,0,0,0,0,0,24,12,6,6,6,6,6,12,24,0,0,0,0,0,0,0,102,60,255,60,102,0,0,0,0,0,0,0,0,24,24,24,255,24,24,24,0,0,0,0,0,0,0,0,0,0,0,0,24,24,24,48,0,0,0,0,0,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,0,0,0,0,0,1,3,6,12,24,48,96,64,0,0,0,0,0,0,62,99,103,111,123,115,99,99,62,0,0,0,0,0,12,28,60,12,12,12,12,12,63,0,0,0,0,0,62,99,3,6,12,24,48,99,127,0,0,0,0,0,62,99,3,3,30,3,3,99,62,0,0,0,0,0,6,14,30,54,102,127,6,6,15,0,0,0,0,0,127,96,96,96,126,3,3,99,62,0,0,0,0,0,28,48,96,96,126,99,99,99,62,0,0,0,0,0,127,99,3,6,12,24,24,24,24,0,0,0,0,0,62,99,99,99,62,99,99,99,62,0,0,0,0,0,62,99,99,99,63,3,3,6,60,0,0,0,0,0,0,24].concat([24,0,0,0,24,24,0,0,0,0,0,0,0,24,24,0,0,0,24,24,48,0,0,0,0,0,6,12,24,48,96,48,24,12,6,0,0,0,0,0,0,0,0,126,0,0,126,0,0,0,0,0,0,0,96,48,24,12,6,12,24,48,96,0,0,0,0,0,62,99,99,6,12,12,0,12,12,0,0,0,0,0,62,99,99,111,111,111,110,96,62,0,0,0,0,0,8,28,54,99,99,127,99,99,99,0,0,0,0,0,126,51,51,51,62,51,51,51,126,0,0,0,0,0,30,51,97,96,96,96,97,51,30,0,0,0,0,0,124,54,51,51,51,51,51,54,124,0,0,0,0,0,127,51,49,52,60,52,49,51,127,0,0,0,0,0,127,51,49,52,60,52,48,48,120,0,0,0,0,0,30,51,97,96,96,111,99,51,29,0,0,0,0,0,99,99,99,99,127,99,99,99,99,0,0,0,0,0,60,24,24,24,24,24,24,24,60,0,0,0,0,0,15,6,6,6,6,6,102,102,60,0,0,0,0,0,115,51,54,54,60,54,54,51,115,0,0,0,0,0,120,48,48,48,48,48,49,51,127,0,0,0,0,0,195,231,255,219,195,195,195,195,195,0,0,0,0,0,99,115,123,127,111,103,99,99,99,0,0,0,0,0,28,54,99,99,99,99,99,54,28,0,0,0,0,0,126,51,51,51,62,48,48,48,120,0,0,0,0,0,62,99,99,99,99,107,111,62,6,7,0,0,0,0,126,51,51,51,62,54,51,51,115,0,0,0,0,0,62,99,99,48,28,6,99,99,62,0,0,0,0,0,255,219,153,24,24,24,24,24,60,0,0,0,0,0,99,99,99,99,99,99,99,99,62,0,0,0,0,0,195,195,195,195,195,195,102,60,24,0,0,0,0,0,195,195,195,195,219,219,255,102,102,0,0,0,0,0,195,195,102,60,24,60,102,195,195,0,0,0,0,0,195,195,195,102,60,24,24,24,60,0,0,0,0,0,255,195,134,12,24,48,97,195,255,0,0,0,0,0,60,48,48,48,48,48,48,48,60,0,0,0,0,0,64,96,112,56,28,14,7,3,1,0,0,0,0,0,60,12,12,12,12,12,12,12,60,0,0,0,8,28,54,99,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,24,24,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,60,6,62,102,102,59,0,0,0,0,0,112,48,48,60,54,51,51,51,110,0,0,0,0,0,0,0,0,62,99,96,96,99,62,0,0,0,0,0,14,6,6,30,54,102,102,102,59,0,0,0,0,0,0,0,0,62,99,127,96,99,62,0,0,0,0,0,28,54,50,48,124,48,48,48,120,0,0,0,0,0,0,0,0,59,102,102,102,62,6,102,60,0,0,0,112,48,48,54,59,51,51,51,115,0,0,0,0,0,12,12,0,28,12,12,12,12,30,0,0,0,0,0,6,6,0,14,6,6,6,6,102,102,60,0,0,0,112,48,48,51,54,60,54,51,115,0,0,0,0,0,28,12,12,12,12,12,12,12,30,0,0,0,0,0,0,0,0,230,255,219,219,219,219,0,0,0,0,0,0,0,0,110,51,51,51,51,51,0,0,0,0,0,0,0,0,62,99,99,99,99,62,0,0,0,0,0,0,0,0,110,51,51,51,62,48,48,120,0,0,0,0,0,0,59,102,102,102,62,6,6,15,0,0,0,0,0,0,110,59,51,48,48,120,0,0,0,0,0,0,0,0,62,99,56,14,99,62,0,0,0,0,0,8,24,24,126,24,24,24,27,14,0,0,0,0,0,0,0,0,102,102,102,102,102,59,0,0,0,0,0,0,0,0,195,195,195,102,60,24,0,0,0,0,0,0,0,0,195,195,219,219,255,102,0,0,0,0,0,0,0,0,99,54,28,28,54,99,0,0,0,0,0,0,0,0,99,99,99,99,63,3,6,60,0,0,0,0,0,0,127,102,12,24,51,127,0,0,0,0,0,14,24,24,24,112,24,24,24,14,0,0,0,0,0,24,24,24,24,0,24,24,24,24,0,0,0,0,0,112,24,24,24,14,24,24,24,112,0,0,0,0,0,59,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,28,54,99,99,127,0,0,0,0,0,0,30,51,97,96,96,97,51,30,6,3,62,0,0,0,102,102,0,102,102,102,102,102,59,0,0,0,0,6,12,24,0,62,99,127,96,99,62,0,0,0,0,8,28,54,0,60,6,62,102,102,59,0,0,0,0,0,102,102,0,60,6,62,102,102,59,0,0,0,0,48,24,12,0,60,6,62,102,102,59,0,0,0,0,28,54,28,0,60,6,62,102,102,59,0,0,0,0,0,0,0,60,102,96,102,60,12,6,60,0,0,0,8,28,54,0,62,99,127,96,99,62,0,0,0,0,0,102,102,0,62,99,127,96,99,62,0,0,0,0,48,24,12,0,62,99,127,96,99,62,0,0,0,0,0,102,102,0,56,24,24,24,24,60,0,0,0,0,24,60,102,0,56,24,24,24,24,60,0,0,0,0,96,48,24,0,56,24,24,24,24,60,0,0,0,0,99,99,8,28,54,99,99,127,99,99,0,0,0,28,54,28,0,28,54,99,99,127,99,99,0,0,0,12,24,48,0,127,51,48,62,48,51,127,0,0,0,0,0,0,0,110,59,27,126,216,220,119,0,0,0,0,0,31,54,102,102,127,102,102,102,103,0,0,0,0,8,28,54,0,62,99,99,99,99,62,0,0,0,0,0,99,99,0,62,99,99,99,99,62,0,0,0,0,48,24,12,0,62,99,99,99,99,62,0,0,0,0,24,60,102,0,102,102,102,102,102,59,0,0,0,0,48,24,12,0,102,102,102,102,102,59,0,0,0,0,0,99,99,0,99,99,99,99,63,3,6,60,0,0,99,99,28,54,99,99,99,99,54,28,0,0,0,0,99,99,0,99,99,99,99,99,99,62,0,0,0,0,24,24,126,195,192,192,195,126,24,24,0,0,0,0,28,54,50,48,120,48,48,48,115,126,0,0,0,0,0,195,102,60,24,255,24,255,24,24,0,0,0,0,252,102,102,124,98,102,111,102,102,243,0,0,0,0,14,27,24,24,24,126,24,24,24,24,216,112,0,0,12,24,48,0,60,6,62,102,102,59,0,0,0,0,12,24,48,0,56,24,24,24,24,60,0,0,0,0,12,24,48,0,62,99,99,99,99,62,0,0,0,0,12,24,48,0,102,102,102,102,102,59,0,0,0,0,0,59,110,0,110,51,51,51,51,51,0,0,0,59,110,0,99,115,123,127,111,103,99,99,0,0,0,0,60,108,108,62,0,126,0,0,0,0,0,0,0,0,56,108,108,56,0,124,0,0,0,0,0,0,0,0,0,24,24,0,24,24,48,99,99,62,0,0,0,0,0,0,0,0,0,127,96,96,96,0,0,0,0,0,0,0,0,0,0,127,3,3,3,0,0,0,0,0,96,224,99,102,108,24,48,110,195,6,12,31,0,0,96,224,99,102,108,24,51,103,207,31,3,3,0,0,0,24,24,0,24,24,60,60,60,24,0,0,0,0,0,0,0,27,54,108,54,27,0,0,0,0,0,0,0,0,0,108,54,27,54,108,0,0,0,0,0,17,68,17,68,17,68,17,68,17,68,17,68,17,68,85,170,85,170,85,170,85,170,85,170,85,170,85,170,221,119,221,119,221,119,221,119,221,119,221,119,221,119,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,248,24,24,24,24,24,24,24,24,24,24,24,248,24,248,24,24,24,24,24,24,54,54,54,54,54,54,54,246,54,54,54,54,54,54,0,0,0,0,0,0,0,254,54,54,54,54,54,54,0,0,0,0,0,248,24,248,24,24,24,24,24,24,54,54,54,54,54,246,6,246,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,54,0,0,0,0,0,254,6,246,54,54,54,54,54,54,54,54,54,54,54,246,6,254,0,0,0,0,0,0,54,54,54,54,54,54,54,254,0,0,0,0,0,0,24,24,24,24,24,248,24,248,0,0,0,0,0,0,0,0,0,0,0,0,0,248,24,24,24,24,24,24,24,24,24,24,24,24,24,31,0,0,0,0,0,0,24,24,24,24,24,24,24,255,0,0,0,0,0,0,0,0,0,0,0,0,0,255,24,24,24,24,24,24,24,24,24,24,24,24,24,31,24,24,24,24,24,24,0,0,0,0,0,0,0,255,0,0,0,0,0,0,24,24,24,24,24,24,24,255,24,24,24,24,24,24,24,24,24,24,24,31,24,31,24,24,24,24,24,24,54,54,54,54,54,54,54,55,54,54,54,54,54,54,54,54,54,54,54,55,48,63,0,0,0,0,0,0,0,0,0,0,0,63,48,55,54,54,54,54,54,54,54,54,54,54,54,247,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,247,54,54,54,54,54,54,54,54,54,54,54,55,48,55,54,54,54,54,54,54,0,0,0,0,0,255,0,255,0,0,0,0,0,0,54,54,54,54,54,247,0,247,54,54,54,54,54,54,24,24,24,24,24,255,0,255,0,0,0,0,0,0,54,54,54,54,54,54,54,255,0,0,0,0,0,0,0,0,0,0,0,255,0,255,24,24,24,24,24,24,0,0,0,0,0,0,0,255,54,54,54,54,54,54,54,54,54,54,54,54,54,63,0,0,0,0,0,0,24,24,24,24,24,31,24,31,0,0,0,0,0,0,0,0,0,0,0,31,24,31,24,24,24,24,24,24,0,0,0,0,0,0,0,63,54,54,54,54,54,54,54,54,54,54,54,54,54,255,54,54,54,54,54,54,24,24,24,24,24,255,24,255,24,24,24,24,24,24,24,24,24,24,24,24,24,248,0,0,0,0,0,0,0,0,0,0,0,0,0,31,24,24,24,24,24,24,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,255,255,255,255,255,255,255,240,240,240,240,240,240,240,240,240,240,240,240,240,240,15,15,15,15,15,15,15,15,15,15,15,15,15,15,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,59,110,108,108,110,59,0,0,0,0,0,0,0,62,99,126,99,99,126,96,96,32,0,0,0,127,99,99,96,96,96,96,96,96,0,0,0,0,0,0,0,127,54,54,54,54,54,54,0,0,0,0,0,127,99,48,24,12,24,48,99,127,0,0,0,0,0,0,0,0,63,108,108,108,108,56,0,0,0,0,0,0,0,51,51,51,51,62,48,48,96,0,0,0,0,0,0,59,110,12,12,12,12,12,0,0,0,0,0,126,24,60,102,102,102,60,24,126,0,0,0,0,0,28,54,99,99,127,99,99,54,28,0,0,0,0,0,28,54,99,99,99,54,54,54,119,0,0,0,0,0,30,48,24,12,62,102,102,102,60,0,0,0,0,0,0,0,0,126,219,219,126,0,0,0,0,0,0,0,3,6,126,219,219,243,126,96,192,0,0,0,0,0,28,48,96,96,124,96,96,48,28,0,0,0,0,0,0,62,99,99,99,99,99,99,99,0,0,0,0,0,0,127,0,0,127,0,0,127,0,0,0,0,0,0,24,24,24,255,24,24,24,0,255,0,0,0,0,0,48,24,12,6,12,24,48,0,126,0,0,0,0,0,12,24,48,96,48,24,12,0,126,0,0,0,0,0,14,27,27,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,24,216,216,112,0,0,0,0,0,24,24,0,0,255,0,0,24,24,0,0,0,0,0,0,0,59,110,0,59,110,0,0,0,0,0,0,56,108,108,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,24,0,0,0,0,0,0,0,0,0,0,0,0,0,24,0,0,0,0,0,0,0,15,12,12,12,12,12,236,108,60,28,0,0,0,0,216,108,108,108,108,108,0,0,0,0,0,0,0,0,112,216,48,96,200,248,0,0,0,0,0,0,0,0,0,0,0,62,62,62,62,62,62,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,2,2,1,1,1,0,2,2,0,0,0,0,112,0,0,0,110,0,0,0,116,0,0,0,114,0,0,0,120,0,0,0,118,0,0,0,122,0,0,0,56,1,0,0,100,0,0,0,56,1,0,0,96,0,0,0,98,0,0,0,106,0,0,0,108,0,0,0,102,0,0,0,104,0,0,0,66,0,0,0,56,1,0,0,70,0,0,0,68,0,0,0,74,0,0,0,72,0,0,0,78,0,0,0,76,0,0,0,44,1,0,0,58,1,0,0,60,1,0,0,62,1,0,0,48,1,0,0,50,1,0,0,52,1,0,0,54,1,0,0,68,1,0,0,70,1,0,0,64,1,0,0,66,1,0,0,76,1,0,0,78,1,0,0,72,1,0,0,74,1,0,0,110,1,0,0,108,1,0,0,114,1,0,0,112,1,0,0,118,1,0,0,116,1,0,0,122,1,0,0,120,1,0,0,248,1,0,0,246,1,0,0,8,1,0,0,4,1,0,0,254,1,0,0,252,1,0,0,12,1,0,0,250,1,0,0,6,2,0,0,156,1,0,0,218,1,0,0,216,1,0,0,214,1,0,0,226,1,0,0,224,1,0,0,40,2,0,0,84,1,0,0,86,1,0,0,88,1,0,0,90,1,0,0,186,1,0,0,240,1,0,0,188,1,0,0,82,1,0,0,100,1,0,0,102,1,0,0,132,1,0,0,134,1,0,0,136,1,0,0,126,1,0,0,128,1,0,0,130,1,0,0,238,0,0,0,236,0,0,0,150,0,0,0,240,0,0,0,244,0,0,0,242,0,0,0,248,0,0,0,246,0,0,0,234,0,0,0,232,0,0,0,204,0,0,0,208,0,0,0,206,0,0,0,212,0,0,0,210,0,0,0,214,0,0,0,34,0,0,0,16,1,0,0,30,0,0,0,32,0,0,0,22,1,0,0,28,1,0,0,36,0,0,0,38,0,0,0,26,0,0,0,28,0,0,0,58,0,0,0,54,0,0,0,56,0,0,0,62,0,0,0,64,0,0,0,60,0,0,0,190,1,0,0,190,1,0,0,190,1,0,0,190,1,0,0,190,1,0,0,190,1,0,0,190,1,0,0,190,1,0,0,2,1,0,0,2,1,0,0,2,1,0,0,2,1,0,0,2,1,0,0,2,1,0,0,2,1,0,0,2,1,0,0,32,1,0,0,32,1,0,0,32,1,0,0,32,1,0,0,32,1,0,0,32,1,0,0,32,1,0,0,32,1,0,0,34,1,0,0,34,1,0,0,34,1,0,0,34,1,0,0,34,1,0,0,34,1,0,0,34,1,0,0,34,1,0,0,56,1,0,0,56,1,0,0,56,1,0,0,56,1,0,0,56,1,0,0,56,1,0,0,188,0,0,0,56,1,0,0,56,1,0,0,56,1,0,0,56,1,0,0,56,1,0,0,56,1,0,0,56,1,0,0,56,1,0,0,56,1,0,0,30,2,0,0,32,2,0,0,26,2,0,0,28,2,0,0,22,2,0,0,24,2,0,0,154,1,0,0,20,2,0,0,34,2,0,0,36,2,0,0,52,2,0,0,48,2,0,0,50,2,0,0,44,2,0,0,46,2,0,0,42,2,0,0,132,0,0,0,130,0,0,0,132,0,0,0,128,0,0,0,140,0,0,0,138,0,0,0,136,0,0,0,134,0,0,0,126,0,0,0,124,0,0,0,86,0,0,0,84,0,0,0,82,0,0,0,92,0,0,0,90,0,0,0,88,0,0,0,200,0,0,0,200,0,0,0,200,0,0,0,200,0,0,0,200,0,0,0,200,0,0,0,200,0,0,0,200,0,0,0,220,1,0,0,198,0,0,0,10,2,0,0,12,2,0,0,14,2,0,0,0,2,0,0,2,2,0,0,4,2,0,0,152,0,0,0,154,0,0,0,156,0,0,0,158,0,0,0,144,0,0,0,146,0,0,0,148,0,0,0,80,0,0,0,160,0,0,0,162,0,0,0,182,0,0,0,184,0,0,0,186,0,0,0,176,0,0,0,178,0,0,0,180,0,0,0,24,1,0,0,18,1,0,0,158,1,0,0,30,1,0,0,38,1,0,0,8,2,0,0,46,1,0,0,40,1,0,0,244,1,0,0,242,1,0,0,228,1,0,0,232,1,0,0,230,1,0,0,236,1,0,0,234,1,0,0,238,1,0,0,56,1,0,0,56,1,0,0,92,1,0,0,94,1,0,0,104,1,0,0,106,1,0,0,206,1,0,0,208,1,0,0,56,1,0,0,56,1,0,0,142,1,0,0,138,1,0,0,140,1,0,0,146,1,0,0,148,1,0,0,144,1,0,0,230,0,0,0,228,0,0,0,226,0,0,0,224,0,0,0,222,0,0,0,220,0,0,0,56,1,0,0,218,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,8,0,0,0,250,0,0,0,10,0,0,0,12,0,0,0,14,0,0,0,16,0,0,0,18,0,0,0,20,0,0,0,22,0,0,0,24,0,0,0,40,0,0,0,42,0,0,0,44,0,0,0,46,0,0,0,48,0,0,0,50,0,0,0,170,1,0,0,56,1,0,0,180,1,0,0,178,1,0,0,162,1,0,0,160,1,0,0,168,1,0,0,166,1,0,0,184,1,0,0,182,1,0,0,26,1,0,0,36,1,0,0,174,1,0,0,172,1,0,0,14,1,0,0,20,1,0,0,150,0,0,0,148,0,0,0,154,0,0,0,152,0,0,0,140,0,0,0,156,0,0,0,138,0,0,0,158,0,0,0,162,0,0,0,160,0,0,0,126,0,0,0,130,0,0,0,128,0,0,0,134,0,0,0,132,0,0,0,136,0,0,0,72,0,0,0,74,0,0,0,68,0,0,0,70,0,0,0,80,0,0,0,82,0,0,0,76,0,0,0,78,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,18,0,0,0,248,127,0,0,52,0,0,0,64,120,0,0,52,0,0,0,72,112,0,0,254,0,0,0,0,0,0,0,0,0,0,0,56,148,0,0,198,1,0,0,0,157,0,0,202,1,0,0,0,129,0,0,164,1,0,0,224,120,0,0,164,1,0,0,192,112,0,0,200,1,0,0,16,106,0,0,142,0,0,0,0,0,0,0,0,0,0,0,80,97,0,0,96,92,0,0,72,86,0,0,40,82,0,0,152,160,0,0,192,154,0,0,56,150,0,0,96,146,0,0,160,139,0,0,120,136,0,0,248,134,0,0,248,133,0,0,8,133,0,0,216,131,0,0,112,130,0,0,224,127,0,0,248,0,0,0,250,0,0,0,252,0,0,0,254,0,0,0,128,0,0,0,48,0,0,0,50,0,0,0,246,0,0,0,0,1,0,0,2,1,0,0,20,1,0,0,22,1,0,0,24,1,0,0,14,1,0,0,16,1,0,0,18,1,0,0,76,1,0,0,146,0,0,0,202,0,0,0,200,0,0,0,198,0,0,0,144,0,0,0,196,0,0,0,194,0,0,0,150,0,0,0,148,0,0,0,168,0,0,0,132,0,0,0,164,0,0,0,162,0,0,0,130,0,0,0,158,0,0,0,40,0,0,0,42,0,0,0,240,0,0,0,242,0,0,0,234,0,0,0,38,0,0,0,228,0,0,0,230,0,0,0,34,0,0,0,36,0,0,0,128,1,0,0,124,1,0,0,60,0,0,0,58,0,0,0,122,1,0,0,106,1,0,0,158,1,0,0,174,1,0,0,178,1,0,0,176,1,0,0,182,1,0,0,180,1,0,0,186,1,0,0,184,1,0,0,190,1,0,0,188,1,0,0,146,1,0,0,150,1,0,0,148,1,0,0,154,1,0,0,152,1,0,0,156,1,0,0,86,1,0,0,86,1,0,0,86,1,0,0,86,1,0,0,86,1,0,0,86,1,0,0,86,1,0,0,86,1,0,0,84,1,0,0,84,1,0,0,84,1,0,0,84,1,0,0,84,1,0,0,84,1,0,0,84,1,0,0,84,1,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,180,0,0,0,180,0,0,0,180,0,0,0,180,0,0,0,180,0,0,0,180,0,0,0,180,0,0,0,180,0,0,0,120,0,0,0,122,0,0,0,118,0,0,0,176,0,0,0,176,0,0,0,176,0,0,0,124,0,0,0,176,0,0,0,126,0,0,0,176,0,0,0,136,0,0,0,176,0,0,0,134,0,0,0,140,0,0,0,142,0,0,0,138,0,0,0,208,1,0,0,208,1,0,0,208,1,0,0,208,1,0,0,208,1,0,0,208,1,0,0,208,1,0,0,208,1,0,0,208,1,0,0,208,1,0,0,208,1,0,0,208,1,0,0,208,1,0,0,208,1,0,0,208,1,0,0,208,1,0,0,140,1,0,0,142,1,0,0,140,1,0,0,144,1,0,0,132,1,0,0,134,1,0,0,136,1,0,0,138,1,0,0,26,1,0,0,130,1,0,0,166,1,0,0,168,1,0,0,170,1,0,0,160,1,0,0,162,1,0,0,164,1,0,0,226,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,222,0,0,0,220,0,0,0,212,0,0,0,210,0,0,0,198,1,0,0,88,1,0,0,208,0,0,0,206,0,0,0,66,1,0,0,64,1,0,0,62,1,0,0,60,1,0,0,58,1,0,0,56,1,0,0,54,1,0,0,74,1,0,0,70,1,0,0,68,1,0,0,192,0,0,0,190,0,0,0,40,1,0,0,38,1,0,0,188,0,0,0,34,1,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,216,0,0,0,214,0,0,0,214,0,0,0,214,0,0,0,214,0,0,0,214,0,0,0,214,0,0,0,214,0,0,0,214,0,0,0,80,0,0,0,78,0,0,0,84,0,0,0,82,0,0,0,88,0,0,0,86,0,0,0,92,0,0,0,90,0,0,0,96,0,0,0,94,0,0,0,62,0,0,0,66,0,0,0,64,0,0,0,70,0,0,0,68,0,0,0,72,0,0,0,4,0,0,0,6,0,0,0,8,0,0,0,10,0,0,0,12,0,0,0,176,0,0,0,176,0,0,0,14,0,0,0,176,0,0,0,176,0,0,0,176,0,0,0,176,0,0,0,176,0,0,0,176,0,0,0,176,0,0,0,176,0,0,0,112,1,0,0,112,1,0,0,112,1,0,0,112,1,0,0,120,1,0,0,118,1,0,0,116,1,0,0,114,1,0,0,110,1,0,0,108,1,0,0,96,1,0,0,94,1,0,0,92,1,0,0,102,1,0,0,100,1,0,0,98,1,0,0,36,1,0,0,176,0,0,0,32,1,0,0,186,0,0,0,44,1,0,0,46,1,0,0,244,0,0,0,42,1,0,0,48,1,0,0,48,1,0,0,48,1,0,0,48,1,0,0,48,1,0,0,48,1,0,0,82,1,0,0,80,1,0,0,0,128,2,0,40,0,0,0,1,0,0,0,8,0,0,0,0,2,0,0,2,0,0,0,0,208,2,0,40,0,0,0,1,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,0,5,0,40,0,0,0,2,0,0,0,8,0,0,0,0,2,0,0,2,0,0,0,0,160,5,0,40,0,0,0,2,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,0,10,0,80,0,0,0,2,0,0,0,8,0,0,0,0,2,0,0,2,0,0,0,0,64,11,0,80,0,0,0,2,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,192,18,0,80,0,0,0,2,0,0,0,15,0,0,0,0,2,0,0,2,128,0,0,0,128,22,0,80,0,0,0,2,0,0,0,18,0,0,0,0,2,0,0,2,128,0,0,0,0,45,0,80,0,0,0,2,0,0,0,36,0,0,0,0,2,0,0,2,128,0,0,0,64,19,0,77,0,0,0,2,0,0,0,8,0,0,0,0,4,0,0,2,128,0,0,0,233,3,0,77,0,0,0,1,0,0,0,26,0,0,0,128,0,0,0,1,128,0,0,0,210,7,0,77,0,0,0,2,0,0,0,26,0,0,0,128,0,0,0,1,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,158,0,0,120,157,0,0,232,156,0,0,96,156,0,0,200,173,0,0,128,136,0,0,0,135,0,0,8,134,0,0,16,133,0,0,0,0,0,0,120,123,0,0,200,122,0,0,80,122,0,0,192,121,0,0,104,120,0,0,240,118,0,0,88,118,0,0,152,117,0,0,192,116,0,0,32,116,0,0,160,115,0,0,48,124,0,0,240,114,0,0,200,123,0,0,80,125,0,0,168,124,0,0,72,114,0,0,192,113,0,0,96,112,0,0,216,110,0,0,96,110,0,0,200,109,0,0,0,0,0,0,232,131,0,0,0,0,0,0,120,130,0,0,0,0,0,0,48,128,0,0,0,0,0,0,48,126,0,0,0,0,0,0,80,125,0,0,0,0,0,0,168,124,0,0,2,0,0,0,0,0,0,0,0,0,0,0,48,124,0,0,1,0,0,0,232,131,0,0,1,0,0,0,120,130,0,0,1,0,0,0,48,128,0,0,1,0,0,0,48,126,0,0,1,0,0,0,80,125,0,0,1,0,0,0,168,124,0,0,1,0,0,0,200,123,0,0,1,0,0,0,48,124,0,0,2,0,0,0,232,131,0,0,2,0,0,0,120,130,0,0,2,0,0,0,48,128,0,0,2,0,0,0,48,126,0,0,2,0,0,0,80,125,0,0,2,0,0,0,168,124,0,0,2,0,0,0,200,123,0,0,2,0,0,0,48,124,0,0,16,98,0,0,192,97,0,0,72,97,0,0,16,97,0,0,40,96,0,0,216,94,0,0,248,93,0,0,152,93,0,0,48,93,0,0,168,92,0,0,48,92,0,0,0,92,0,0,200,153,0,0,112,153,0,0,240,152,0,0,88,152,0,0,128,151,0,0,48,151,0,0,224,150,0,0,88,150,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,150,0,0,16,150,0,0,216,149,0,0,88,149,0,0,248,148,0,0,112,148,0,0,184,147,0,0,72,147,0,0,8,147,0,0,144,146,0,0,88,146,0,0,32,146,0,0,224,145,0,0,144,145,0,0,48,145,0,0,240,144,0,0,31,6,0,0,9,0,0,0,94,0,0,0,31,2,0,0,9,0,0,0,14,0,0,0,191,10,0,0,2,0,0,0,166,0,0,0,63,5,0,0,9,0,0,0,100,0,0,0,191,13,0,0,6,0,0,0,176,0,0,0,255,7,0,0,2,0,0,0,120,0,0,0,255,15,0,0,3,0,0,0,194,0,0,0,255,8,0,0,1,0,0,0,34,0,0,0,255,4,0,0,2,0,0,0,164,0,0,0,255,3,0,0,3,0,0,0,108,0,0,0,0,0,0,0,1,0,0,0,48,0,0,0,0,0,0,0,0,0,0,0,0,170,0,170,0,0,170,170,170,0,0,170,0,170,170,85,0,170,170,170,85,85,85,85,85,255,85,255,85,85,255,255,255,85,85,255,85,255,255,255,85,255,255,255,0,0,0,0,0,0,0,0,126,129,165,129,189,153,129,126,126,255,219,255,195,231,255,126,108,254,254,254,124,56,16,0,16,56,124,254,124,56,16,0,56,124,56,254,254,214,16,56,16,16,56,124,254,124,16,56,0,0,24,60,60,24,0,0,255,255,231,195,195,231,255,255,0,60,102,66,66,102,60,0,255,195,153,189,189,153,195,255,15,3,5,125,132,132,132,120,60,66,66,66,60,24,126,24,63,33,63,32,32,96,224,192,63,33,63,33,35,103,230,192,24,219,60,231,231,60,219,24,128,224,248,254,248,224,128,0,2,14,62,254,62,14,2,0,24,60,126,24,24,126,60,24,36,36,36,36,36,0,36,0,127,146,146,114,18,18,18,0,62,99,56,68,68,56,204,120,0,0,0,0,126,126,126,0,24,60,126,24,126,60,24,255,16,56,124,84,16,16,16,0,16,16,16,84,124,56,16,0,0,24,12,254,12,24,0,0,0,48,96,254,96,48,0,0,0,0,64,64,64,126,0,0,0,36,102,255,102,36,0,0,0,16,56,124,254,254,0,0,0,254,254,124,56,16,0,0,0,0,0,0,0,0,0,0,16,56,56,16,16,0,16,0,36,36,36,0,0,0,0,0,36,36,126,36,126,36,36,0,24,62,64,60,2,124,24,0,0,98,100,8,16,38,70,0,48,72,48,86,136,136,118,0,16,16,32,0,0,0,0,0,16,32,64,64,64,32,16,0,32,16,8,8,8,16,32,0,0,68,56,254,56,68,0,0,0,16,16,124,16,16,0,0,0,0,0,0,0,16,16,32,0,0,0,126,0,0,0,0,0,0,0,0,0,16,16,0,0,2,4,8,16,32,64,0,60,66,70,74,82,98,60,0,16,48,80,16,16,16,124,0,60,66,2,12,48,66,126,0,60,66,2,28,2,66,60,0,8,24,40,72,254,8,28,0,126,64,124,2,2,66,60,0,28,32,64,124,66,66,60,0,126,66,4,8,16,16,16,0,60,66,66,60,66,66,60,0,60,66,66,62,2,4,56,0,0,16,16,0,0,16,16,0,0,16,16,0,0,16,16,32,8,16,32,64,32,16,8,0,0,0,126,0,0,126,0,0,16,8,4,2,4,8,16,0,60,66,2,4,8,0,8,0,60,66,94,82,94,64,60,0,24,36,66,66,126,66,66,0,124,34,34,60,34,34,124,0,28,34,64,64,64,34,28,0,120,36,34,34,34,36,120,0,126,34,40,56,40,34,126,0,126,34,40,56,40,32,112,0,28,34,64,64,78,34,30,0,66,66,66,126,66,66,66,0,56,16,16,16,16,16,56,0,14,4,4,4,68,68,56,0,98,36,40,48,40,36,99,0,112,32,32,32,32,34,126,0,99,85,73,65,65,65,65,0,98,82,74,70,66,66,66,0,24,36,66,66,66,36,24,0,124,34,34,60,32,32,112,0,60,66,66,66,74,60,3,0,124,34,34,60,40,36,114,0,60,66,64,60,2,66,60,0,127,73,8,8,8,8,28,0,66,66,66,66,66,66,60,0,65,65,65,65,34,20,8,0,65,65,65,73,73,73,54,0,65,34,20,8,20,34,65,0,65,34,20,8,8,8,28,0,127,66,4,8,16,33,127,0,120,64,64,64,64,64,120,0,128,64,32,16,8,4,2,0,120,8,8,8,8,8,120,0,16,40,68,130,0,0,0,0,0,0,0,0,0,0,0,255,16,16,8,0,0,0,0,0,0,0,60,2,62,66,63,0,96,32,32,46,49,49,46,0,0,0,60,66,64,66,60,0,6,2,2,58,70,70,59,0,0,0,60,66,126,64,60,0,12,18,16,56,16,16,56,0,0,0,61,66,66,62,2,124,96,32,44,50,34,34,98,0,16,0,48,16,16,16,56,0,2,0,6,2,2,66,66,60,96,32,36,40,48,40,38,0,48,16,16,16,16,16,56,0,0,0,118,73,73,73,73,0,0,0,92,98,66,66,66,0,0,0,60,66,66,66,60,0,0,0,108,50,50,44,32,112,0,0,54,76,76,52,4,14,0,0,108,50,34,32,112,0,0,0,62,64,60,2,124,0,16,16,124,16,16,18,12,0,0,0,66,66,66,70,58,0,0,0,65,65,34,20,8,0,0,0,65,73,73,73,54,0,0,0,68,40,16,40,68,0,0,0,66,66,66,62,2,124,0,0,124,8,16,32,124,0,12,16,16,96,16,16,12,0,16,16,16,0,16,16,16,0,48,8,8,6,8,8,48,0,50,76,0,0,0,0,0,0,0,8,20,34,65,65,127,0,60,66,64,66,60,12,2,60,0,68,0,68,68,68,62,0,12,0,60,66,126,64,60,0,60,66,56,4,60,68,62,0,66,0,56,4,60,68,62,0,48,0,56,4,60,68,62,0,16,0,56,4,60,68,62,0,0,0,60,64,64,60,6,28,60,66,60,66,126,64,60,0,66,0,60,66,126,64,60,0,48,0,60,66,126,64,60,0,36,0,24,8,8,8,28,0,124,130,48,16,16,16,56,0,48,0,24,8,8,8,28,0,66,24,36,66,126,66,66,0,24,24,0,60,66,126,66,0,12,0,124,32,56,32,124,0,0,0,51,12,63,68,59,0,31,36,68,127,68,68,71,0,24,36,0,60,66,66,60,0,0,66,0,60,66,66,60,0,32,16,0,60,66,66,60,0,24,36,0,66,66,66,60,0,32,16,0,66,66,66,60,0,0,66,0,66,66,62,2,60,66,24,36,66,66,36,24,0,66,0,66,66,66,66,60,0,8,8,62,64,64,62,8,8,24,36,32,112,32,66,124,0,68,40,124,16,124,16,16,0,248,76,120,68,79,68,69,230,28,18,16,124,16,16,144,96,12,0,56,4,60,68,62,0,12,0,24,8,8,8,28,0,4,8,0,60,66,66,60,0,0,4,8,66,66,66,60,0,50,76,0,124,66,66,66,0,52,76,0,98,82,74,70,0,60,68,68,62,0,126,0,0,56,68,68,56,0,124,0,0,16,0,16,32,64,66,60,0,0,0,0,126,64,64,0,0,0,0,0,126,2,2,0,0,66,196,72,246,41,67,140,31,66,196,74,246,42,95,130,2,0,16,0,16,16,16,16,0,0,18,36,72,36,18,0,0,0,72,36,18,36,72,0,0,34,136,34,136,34,136,34,136,85,170,85,170,85,170,85,170,219,119,219,238,219,119,219,238,16,16,16,16,16,16,16,16,16,16,16,16,240,16,16,16,16,16,240,16,240,16,16,16,20,20,20,20,244,20,20,20,0,0,0,0,252,20,20,20,0,0,240,16,240,16,16,16,20,20,244,4,244,20,20,20,20,20,20,20,20,20,20,20,0,0,252,4,244,20,20,20,20,20,244,4,252,0,0,0,20,20,20,20,252,0,0,0,16,16,240,16,240,0,0,0,0,0,0,0,240,16,16,16,16,16,16,16,31,0,0,0,16,16,16,16,255,0,0,0,0,0,0,0,255,16,16,16,16,16,16,16,31,16,16,16,0,0,0,0,255,0,0,0,16,16,16,16,255,16,16,16,16,16,31,16,31,16,16,16,20,20,20,20,23,20,20,20,20,20,23,16,31,0,0,0,0,0,31,16,23,20,20,20,20,20,247,0,255,0,0,0,0,0,255,0,247,20,20,20,20,20,23,16,23,20,20,20,0,0,255,0,255,0,0,0,20,20,247,0,247,20,20,20,16,16,255,0,255,0,0,0,20,20,20,20,255,0,0,0,0,0,255,0,255,16,16,16,0,0,0,0,255,20,20,20,20,20,20,20,31,0,0,0,16,16,31,16,31,0,0,0,0,0,31,16,31,16,16,16,0,0,0,0,31,20,20,20,20,20,20,20,255,20,20,20,16,16,255,16,255,16,16,16,16,16,16,16,240,0,0,0,0,0,0,0,31,16,16,16,255,255,255,255,255,255,255,255,0,0,0,0,255,255,255,255,240,240,240,240,240,240,240,240,15,15,15,15,15,15,15,15,255,255,255,255,0,0,0,0,0,0,49,74,68,74,49,0,0,60,66,124,66,124,64,64,0,126,66,64,64,64,64,0,0,63,84,20,20,20,20,0,126,66,32,24,32,66,126,0,0,0,62,72,72,72,48,0,0,68,68,68,122,64,64,128,0,51,76,8,8,8,8,0,124,16,56,68,68,56,16,124,24,36,66,126,66,36,24,0,24,36,66,66,36,36,102,0,28,32,24,60,66,66,60,0,0,98,149,137,149,98,0,0,2,4,60,74,82,60,64,128,12,16,32,60,32,16,12,0,60,66,66,66,66,66,66,0,0,126,0,126,0,126,0,0,16,16,124,16,16,0,124,0,16,8,4,8,16,0,126,0,8,16,32,16,8,0,126,0,12,18,18,16,16,16,16,16,16,16,16,16,16,144,144,96,24,24,0,126,0,24,24,0,0,50,76,0,50,76,0,0,48,72,72,48,0,0,0,0,0,0,0,24,24,0,0,0,0,0,0,0,24,0,0,0,15,8,8,8,8,200,40,24,120,68,68,68,68,0,0,0,48,72,16,32,120,0,0,0,0,0,60,60,60,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,126,129,165,129,189,153,129,126,126,255,219,255,195,231,255,126,108,254,254,254,124,56,16,0,16,56,124,254,124,56,16,0,56,124,56,254,254,214,16,56,16,16,56,124,254,124,16,56,0,0,24,60,60,24,0,0,255,255,231,195,195,231,255,255,0,60,102,66,66,102,60,0,255,195,153,189,189,153,195,255,15,7,15,125,204,204,204,120,60,102,102,102,60,24,126,24,63,51,63,48,48,112,240,224,127,99,127,99,99,103,230,192,24,219,60,231,231,60,219,24,128,224,248,254,248,224,128,0,2,14,62,254,62,14,2,0,24,60,126,24,24,126,60,24,102,102,102,102,102,0,102,0,127,219,219,123,27,27,27,0,62,99,56,108,108,56,204,120,0,0,0,0,126,126,126,0,24,60,126,24,126,60,24,255,24,60,126,24,24,24,24,0,24,24,24,24,126,60,24,0,0,24,12,254,12,24,0,0,0,48,96,254,96,48,0,0,0,0,192,192,192,254,0,0,0,36,102,255,102,36,0,0,0,24,60,126,255,255,0,0,0,255,255,126,60,24,0,0,0,0,0,0,0,0,0,0,48,120,120,48,48,0,48,0,108,108,108,0,0,0,0,0,108,108,254,108,254,108,108,0,48,124,192,120,12,248,48,0,0,198,204,24,48,102,198,0,56,108,56,118,220,204,118,0,96,96,192,0,0,0,0,0,24,48,96,96,96,48,24,0,96,48,24,24,24,48,96,0,0,102,60,255,60,102,0,0,0,48,48,252,48,48,0,0,0,0,0,0,0,48,48,96,0,0,0,252,0,0,0,0,0,0,0,0,0,48,48,0,6,12,24,48,96,192,128,0,124,198,206,222,246,230,124,0,48,112,48,48,48,48,252,0,120,204,12,56,96,204,252,0,120,204,12,56,12,204,120,0,28,60,108,204,254,12,30,0,252,192,248,12,12,204,120,0,56,96,192,248,204,204,120,0,252,204,12,24,48,48,48,0,120,204,204,120,204,204,120,0,120,204,204,124,12,24,112,0,0,48,48,0,0,48,48,0,0,48,48,0,0,48,48,96,24,48,96,192,96,48,24,0,0,0,252,0,0,252,0,0,96,48,24,12,24,48,96,0,120,204,12,24,48,0,48,0,124,198,222,222,222,192,120,0,48,120,204,204,252,204,204,0,252,102,102,124,102,102,252,0,60,102,192,192,192,102,60,0,248,108,102,102,102,108,248,0,254,98,104,120,104,98,254,0,254,98,104,120,104,96,240,0,60,102,192,192,206,102,62,0,204,204,204,252,204,204,204,0,120,48,48,48,48,48,120,0,30,12,12,12,204,204,120,0,230,102,108,120,108,102,230,0,240,96,96,96,98,102,254,0,198,238,254,254,214,198,198,0,198,230,246,222,206,198,198,0,56,108,198,198,198,108,56,0,252,102,102,124,96,96,240,0,120,204,204,204,220,120,28,0,252,102,102,124,108,102,230,0,120,204,96,48,24,204,120,0,252,180,48,48,48,48,120,0,204,204,204,204,204,204,252,0,204,204,204,204,204,120,48,0,198,198,198,214,254,238,198,0,198,198,108,56,56,108,198,0,204,204,204,120,48,48,120,0,254,198,140,24,50,102,254,0,120,96,96,96,96,96,120,0,192,96,48,24,12,6,2,0,120,24,24,24,24,24,120,0,16,56,108,198,0,0,0,0,0,0,0,0,0,0,0,255,48,48,24,0,0,0,0,0,0,0,120,12,124,204,118,0,224,96,96,124,102,102,220,0,0,0,120,204,192,204,120,0,28,12,12,124,204,204,118,0,0,0,120,204,252,192,120,0,56,108,96,240,96,96,240,0,0,0,118,204,204,124,12,248,224,96,108,118,102,102,230,0,48,0,112,48,48,48,120,0,12,0,12,12,12,204,204,120,224,96,102,108,120,108,230,0,112,48,48,48,48,48,120,0,0,0,204,254,254,214,198,0,0,0,248,204,204,204,204,0,0,0,120,204,204,204,120,0,0,0,220,102,102,124,96,240,0,0,118,204,204,124,12,30,0,0,220,118,102,96,240,0,0,0,124,192,120,12,248,0,16,48,124,48,48,52,24,0,0,0,204,204,204,204,118,0,0,0,204,204,204,120,48,0,0,0,198,214,254,254,108,0,0,0,198,108,56,108,198,0,0,0,204,204,204,124,12,248,0,0,252,152,48,100,252,0,28,48,48,224,48,48,28,0,24,24,24,0,24,24,24,0,224,48,48,28,48,48,224,0,118,220,0,0,0,0,0,0,0,16,56,108,198,198,254,0,120,204,192,204,120,24,12,120,0,204,0,204,204,204,126,0,28,0,120,204,252,192,120,0,126,195,60,6,62,102,63,0,204,0,120,12,124,204,126,0,224,0,120,12,124,204,126,0,48,48,120,12,124,204,126,0,0,0,120,192,192,120,12,56,126,195,60,102,126,96,60,0,204,0,120,204,252,192,120,0,224,0,120,204,252,192,120,0,204,0,112,48,48,48,120,0,124,198,56,24,24,24,60,0,224,0,112,48,48,48,120,0,198,56,108,198,254,198,198,0,48,48,0,120,204,252,204,0,28,0,252,96,120,96,252,0,0,0,127,12,127,204,127,0,62,108,204,254,204,204,206,0,120,204,0,120,204,204,120,0,0,204,0,120,204,204,120,0,0,224,0,120,204,204,120,0,120,204,0,204,204,204,126,0,0,224,0,204,204,204,126,0,0,204,0,204,204,124,12,248,195,24,60,102,102,60,24,0,204,0,204,204,204,204,120,0,24,24,126,192,192,126,24,24,56,108,100,240,96,230,252,0,204,204,120,252,48,252,48,48,248,204,204,250,198,207,198,199,14,27,24,60,24,24,216,112,28,0,120,12,124,204,126,0,56,0,112,48,48,48,120,0,0,28,0,120,204,204,120,0,0,28,0,204,204,204,126,0,0,248,0,248,204,204,204,0,252,0,204,236,252,220,204,0,60,108,108,62,0,126,0,0,56,108,108,56,0,124,0,0,48,0,48,96,192,204,120,0,0,0,0,252,192,192,0,0,0,0,0,252,12,12,0,0,195,198,204,222,51,102,204,15,195,198,204,219,55,111,207,3,24,24,0,24,24,24,24,0,0,51,102,204,102,51,0,0,0,204,102,51,102,204,0,0,34,136,34,136,34,136,34,136,85,170,85,170,85,170,85,170,219,119,219,238,219,119,219,238,24,24,24,24,24,24,24,24,24,24,24,24,248,24,24,24,24,24,248,24,248,24,24,24,54,54,54,54,246,54,54,54,0,0,0,0,254,54,54,54,0,0,248,24,248,24,24,24,54,54,246,6,246,54,54,54,54,54,54,54,54,54,54,54,0,0,254,6,246,54,54,54,54,54,246,6,254,0,0,0,54,54,54,54,254,0,0,0,24,24,248,24,248,0,0,0,0,0,0,0,248,24,24,24,24,24,24,24,31,0,0,0,24,24,24,24,255,0,0,0,0,0,0,0,255,24,24,24,24,24,24,24,31,24,24,24,0,0,0,0,255,0,0,0,24,24,24,24,255,24,24,24,24,24,31,24,31,24,24,24,54,54,54,54,55,54,54,54,54,54,55,48,63,0,0,0,0,0,63,48,55,54,54,54,54,54,247,0,255,0,0,0,0,0,255,0,247,54,54,54,54,54,55,48,55,54,54,54,0,0,255,0,255,0,0,0,54,54,247,0,247,54,54,54,24,24,255,0,255,0,0,0,54,54,54,54,255,0,0,0,0,0,255,0,255,24,24,24,0,0,0,0,255,54,54,54,54,54,54,54,63,0,0,0,24,24,31,24,31,0,0,0,0,0,31,24,31,24,24,24,0,0,0,0,63,54,54,54,54,54,54,54,255,54,54,54,24,24,255,24,255,24,24,24,24,24,24,24,248,0,0,0,0,0,0,0,31,24,24,24,255,255,255,255,255,255,255,255,0,0,0,0,255,255,255,255,240,240,240,240,240,240,240,240,15,15,15,15,15,15,15,15,255,255,255,255,0,0,0,0,0,0,118,220,200,220,118,0,0,120,204,248,204,248,192,192,0,252,204,192,192,192,192,0,0,254,108,108,108,108,108,0,252,204,96,48,96,204,252,0,0,0,126,216,216,216,112,0,0,102,102,102,102,124,96,192,0,118,220,24,24,24,24,0,252,48,120,204,204,120,48,252,56,108,198,254,198,108,56,0,56,108,198,198,108,108,238,0,28,48,24,124,204,204,120,0,0,0,126,219,219,126,0,0])
.concat([6,12,126,219,219,126,96,192,56,96,192,248,192,96,56,0,120,204,204,204,204,204,204,0,0,252,0,252,0,252,0,0,48,48,252,48,48,0,252,0,96,48,24,48,96,0,252,0,24,48,96,48,24,0,252,0,14,27,27,24,24,24,24,24,24,24,24,24,24,216,216,112,48,48,0,252,0,48,48,0,0,118,220,0,118,220,0,0,56,108,108,56,0,0,0,0,0,0,0,24,24,0,0,0,0,0,0,0,24,0,0,0,15,12,12,12,236,108,60,28,120,108,108,108,108,0,0,0,112,24,48,96,120,0,0,0,0,0,60,60,60,60,0,0,0,0,0,0,0,0,0,0,99,111,108,111,114,95,110,111,114,109,97,108,0,0,0,0,103,114,101,101,110,0,0,0,77,79,86,83,87,0,0,0,105,111,0,0,0,0,0,0,77,79,85,84,61,37,48,50,88,32,32,83,84,48,61,37,48,50,88,32,32,83,84,49,61,37,48,50,88,10,0,0,42,42,42,32,111,112,101,110,105,110,103,32,102,105,108,101,32,102,97,105,108,101,100,32,40,37,115,41,10,0,0,0,83,116,97,114,116,82,105,103,104,116,0,0,0,0,0,0,42,42,42,32,108,111,97,100,105,110,103,32,67,71,65,32,102,111,110,116,32,102,97,105,108,101,100,32,40,37,115,41,10,0,0,0,0,0,0,0,32,32,65,61,79,91,37,48,50,88,93,0,0,0,0,0,67,77,80,83,66,0,0,0,42,42,42,32,97,108,108,111,99,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,83,117,112,101,114,82,105,103,104,116,0,0,0,0,0,0,32,32,65,61,73,91,37,48,50,88,93,0,0,0,0,0,102,105,108,101,61,37,115,32,109,111,100,101,61,37,115,32,112,99,109,61,37,100,32,102,105,108,116,101,114,61,37,100,32,112,111,115,61,37,108,117,32,97,112,112,101,110,100,61,37,100,10,0,0,0,0,0,77,101,116,97,82,105,103,104,116,0,0,0,0,0,0,0,105,111,0,0,0,0,0,0,77,79,68,61,37,48,50,88,32,32,77,79,68,65,61,37,117,32,32,77,79,68,66,61,37,117,0,0,0,0,0,0,101,109,115,58,32,117,110,107,110,111,119,110,32,102,117,110,99,116,105,111,110,58,32,65,88,61,37,48,52,88,10,0,67,77,80,83,87,0,0,0,98,108,0,0,0,0,0,0,67,65,83,83,69,84,84,69,58,0,0,0,0,0,0,0,65,108,116,82,105,103,104,116,0,0,0,0,0,0,0,0,56,50,53,53,45,80,80,73,0,0,0,0,0,0,0,0,83,84,79,83,66,0,0,0,112,99,109,0,0,0,0,0,83,112,97,99,101,0,0,0,91,37,115,37,48,52,88,93,0,0,0,0,0,0,0,0,105,111,0,0,0,0,0,0,32,32,78,37,117,61,37,48,52,108,88,0,0,0,0,0,32,32,37,117,58,32,37,108,117,75,32,32,108,111,99,107,61,37,100,10,0,0,0,0,83,84,79,83,87,0,0,0,102,105,108,116,101,114,0,0,65,108,116,0,0,0,0,0,101,109,117,46,101,120,105,116,0,0,0,0,0,0,0,0,78,48,61,37,48,52,108,88,0,0,0,0,0,0,0,0,114,111,109,115,47,112,99,101,45,99,111,110,102,105,103,46,99,102,103,0,0,0,0,0,76,79,68,83,66,0,0,0,97,112,112,101,110,100,0,0,65,108,116,76,101,102,116,0,73,67,87,61,91,37,48,50,88,32,37,48,50,88,32,37,48,50,88,32,37,48,50,88,93,32,32,79,67,87,61,91,37,48,50,88,32,37,48,50,88,32,37,48,50,88,93,10,0,0,0,0,0,0,0,0,105,111,0,0,0,0,0,0,76,79,68,83,87,0,0,0,104,109,0,0,0,0,0,0,101,109,117,46,101,120,105,116,0,0,0,0,0,0,0,0,112,111,115,105,116,105,111,110,0,0,0,0,0,0,0,0,77,111,100,101,0,0,0,0,70,57,0,0,0,0,0,0,33,61,0,0,0,0,0,0,73,83,82,61,0,0,0,0,123,0,0,0,0,0,0,0,104,0,0,0,0,0,0,0,98,105,110,0,0,0,0,0,109,111,117,115,101,95,109,117,108,95,120,0,0,0,0,0,97,100,100,114,61,48,120,37,48,56,108,120,32,115,105,122,101,61,37,108,117,32,102,105,108,101,61,37,115,10,0,0,104,0,0,0,0,0,0,0,45,45,37,115,0,0,0,0,101,120,112,101,99,116,105,110,103,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,118,51,48,0,0,0,0,0,83,67,65,83,66,0,0,0,116,100,48,58,32,100,114,111,112,112,105,110,103,32,112,104,97,110,116,111,109,32,115,101,99,116,111,114,32,37,117,47,37,117,47,37,117,10,0,0,82,101,108,101,97,115,101,32,51,46,48,55,36,48,0,0,46,116,100,48,0,0,0,0,79,0,0,0,0,0,0,0,108,111,97,100,0,0,0,0,87,105,110,100,111,119,115,76,101,102,116,0,0,0,0,0,82,69,71,58,32,77,79,68,69,61,37,48,50,88,32,32,67,83,69,76,61,37,48,50,88,32,32,83,84,65,84,85,83,61,37,48,50,88,32,32,80,65,76,61,91,37,48,50,88,32,37,48,50,88,32,37,48,50,88,32,37,48,50,88,93,10,0,0,0,0,0,0,67,82,84,0,0,0,0,0,67,82,84,67,61,91,37,48,50,88,0,0,0,0,0,0,67,82,84,67,61,91,37,48,50,88,0,0,0,0,0,0,32,32,73,78,84,82,61,37,100,10,0,0,0,0,0,0,105,111,0,0,0,0,0,0,83,67,65,83,87,0,0,0,109,111,100,101,0,0,0,0,83,116,97,114,116,76,101,102,116,0,0,0,0,0,0,0,73,77,82,61,0,0,0,0,112,99,109,47,102,0,0,0,99,111,108,111,114,95,98,97,99,107,103,114,111,117,110,100,0,0,0,0,0,0,0,0,99,111,108,111,114,95,103,114,97,112,104,105,99,115,0,0,82,69,84,78,0,0,0,0,67,76,75,58,32,67,76,75,61,37,108,117,32,32,72,84,61,37,108,117,32,72,68,61,37,108,117,32,32,86,84,61,37,108,117,32,86,68,61,37,108,117,10,0,0,0,0,0,102,105,108,101,0,0,0,0,83,117,112,101,114,76,101,102,116,0,0,0,0,0,0,0,60,110,111,110,101,62,0,0,32,32,80,82,73,79,61,37,117,10,0,0,0,0,0,0,69,56,50,55,50,58,32,67,77,68,61,37,48,50,88,32,68,61,63,32,73,78,86,65,76,73,68,10,0,0,0,0,101,110,97,98,108,101,0,0,77,101,116,97,0,0,0,0,73,82,82,61,0,0,0,0,99,97,115,115,101,116,116,101,0,0,0,0,0,0,0,0,77,101,116,97,76,101,102,116,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,32,32,37,117,58,32,37,117,32,112,97,103,101,115,10,0,100,108,0,0,0,0,0,0,42,42,42,32,115,101,116,116,105,110,103,32,115,111,117,110,100,32,100,114,105,118,101,114,32,102,97,105,108,101,100,32,40,37,115,41,10,0,0,0,67,116,114,108,0,0,0,0,73,78,80,61,0,0,0,0,69,78,84,69,82,0,0,0,118,111,108,117,109,101,61,37,117,32,115,114,97,116,101,61,37,108,117,32,108,111,119,112,97,115,115,61,37,108,117,32,100,114,105,118,101,114,61,37,115,10,0,0,0,0,0,0,67,116,114,108,76,101,102,116,0,0,0,0,0,0,0,0,66,89,84,69,32,0,0,0,56,50,53,57,65,45,80,73,67,0,0,0,0,0,0,0,69,77,66,58,32,98,108,107,61,37,117,32,117,115,101,100,61,37,108,117,32,109,97,120,61,37,108,117,10,0,0,0,101,56,50,53,57,58,32,73,78,84,65,32,119,105,116,104,111,117,116,32,73,82,81,10,0,0,0,0,0,0,0,0,76,69,65,86,69,0,0,0,83,80,69,65,75,69,82,58,0,0,0,0,0,0,0,0,47,0,0,0,0,0,0,0,101,109,117,46,100,105,115,107,46,105,110,115,101,114,116,0,67,72,78,32,37,117,58,32,77,79,68,69,61,37,48,50,88,32,65,68,68,82,61,37,48,52,88,91,37,48,52,88,93,32,67,78,84,61,37,48,52,88,91,37,48,52,88,93,32,68,82,69,81,61,37,100,32,83,82,69,81,61,37,100,32,77,65,83,75,61,37,100,10,0,0,0,0,0,0,0,118,103,97,0,0,0,0,0,82,69,84,70,0,0,0,0,108,111,119,112,97,115,115,0,83,108,97,115,104,0,0,0,67,77,68,61,37,48,50,88,32,32,80,82,73,61,37,48,50,88,32,32,67,72,75,61,37,100,10,0,0,0,0,0,73,78,84,51,0,0,0,0,103,0,0,0,0,0,0,0,115,100,108,58,32,98,108,105,116,32,101,114,114,111,114,10,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,115,97,109,112,108,101,95,114,97,116,101,0,0,0,0,0,46,0,0,0,0,0,0,0,70,56,0,0,0,0,0,0,61,61,0,0,0,0,0,0,56,50,51,55,45,68,77,65,67,0,0,0,0,0,0,0,115,101,99,116,105,111,110,0,102,0,0,0,0,0,0,0,115,114,101,99,0,0,0,0,115,99,97,108,101,0,0,0,82,65,77,58,0,0,0,0,99,0,0,0,0,0,0,0,32,32,0,0,0,0,0,0,101,120,112,101,99,116,105,110,103,32,111,102,102,115,101,116,0,0,0,0,0,0,0,0,56,48,49,56,56,0,0,0,116,100,48,58,32,99,114,99,32,101,114,114,111,114,32,97,116,32,115,101,99,116,111,114,32,37,117,47,37,117,47,37,117,32,40,37,48,50,88,32,37,48,52,88,32,37,48,52,88,41,10,0,0,0,0,0,82,101,108,101,97,115,101,32,51,46,48,50,36,48,0,0,46,116,99,0,0,0,0,0,78,0,0,0,0,0,0,0,118,111,108,117,109,101,0,0,80,101,114,105,111,100,0,0,104,100,99,58,32,102,111,114,109,97,116,32,101,114,114,111,114,32,40,100,61,37,117,41,10,0,0,0,0,0,0,0,67,71,65,58,32,79,70,83,61,37,48,52,88,32,32,80,79,83,61,37,48,52,88,32,32,66,71,61,37,48,50,88,32,32,80,65,76,61,37,117,10,0,0,0,0,0,0,0,77,79,85,84,61,37,48,50,88,32,32,83,84,48,61,37,48,50,88,32,32,83,84,49,61,37,48,50,88,10,0,0,82,69,71,58,32,77,79,68,69,61,37,48,50,88,32,32,67,83,69,76,61,37,48,50,88,32,32,83,84,65,84,85,83,61,37,48,50,88,32,32,83,80,69,67,61,37,48,50,88,32,32,80,65,76,61,91,37,48,50,88,32,37,48,50,88,32,37,48,50,88,32,37,48,50,88,93,10,0,0,0,82,69,71,58,32,77,79,68,69,61,37,48,50,88,32,32,67,83,69,76,61,37,48,50,88,32,32,83,84,65,84,85,83,61,37,48,50,88,32,32,83,80,69,67,61,37,48,50,88,32,32,80,65,76,61,91,37,48,50,88,32,37,48,50,88,32,37,48,50,88,32,37,48,50,88,93,10,0,0,0,80,67,32,77,69,77,0,0,73,78,84,79,0,0,0,0,115,112,101,97,107,101,114,0,44,0,0,0,0,0,0,0,80,67,32,80,79,82,84,83,0,0,0,0,0,0,0,0,60,110,111,110,101,62,0,0,103,114,101,101,110,0,0,0,99,111,108,111,114,95,98,114,105,103,104,116,0,0,0,0,73,82,69,84,0,0,0,0,69,71,65,58,32,65,68,68,82,61,37,48,52,88,32,32,82,79,70,83,61,37,48,52,88,32,32,67,85,82,83,61,37,48,52,88,32,32,76,67,77,80,61,37,48,52,88,10,0,0,0,0,0,0,0,0,86,71,65,32,105,114,113,61,37,117,32,40,37,115,41,10,0,0,0,0,0,0,0,0,67,111,109,109,97,0,0,0,67,71,65,32,105,111,61,48,120,37,48,52,108,120,32,97,100,100,114,61,48,120,37,48,53,108,120,32,115,105,122,101,61,48,120,37,48,53,108,120,32,102,111,110,116,61,37,117,32,102,105,108,101,61,37,115,10,0,0,0,0,0,0,0,73,79,61,37,48,52,88,32,32,37,108,117,32,37,117,37,99,37,117,32,32,68,84,82,61,37,100,32,32,82,84,83,61,37,100,32,32,32,68,83,82,61,37,100,32,32,67,84,83,61,37,100,32,32,68,67,68,61,37,100,32,32,82,73,61,37,100,10,84,120,68,61,37,48,50,88,37,99,32,82,120,68,61,37,48,50,88,37,99,32,83,67,82,61,37,48,50,88,32,32,68,73,86,61,37,48,52,88,10,73,69,82,61,37,48,50,88,32,32,73,73,82,61,37,48,50,88,32,32,76,67,82,61,37,48,50,88,32,32,76,83,82,61,37,48,50,88,32,32,77,67,82,61,37,48,50,88,32,32,77,83,82,61,37,48,50,88,10,0,0,0,0,0,0,0,0,100,105,115,97,98,108,101,100,0,0,0,0,0,0,0,0,109,0,0,0,0,0,0,0,99,111,112,121,32,109,101,109,111,114,121,0,0,0,0,0,56,50,53,48,45,85,65,82,84,0,0,0,0,0,0,0,56,50,53,48,0,0,0,0,83,65,82,0,0,0,0,0,101,110,97,98,108,101,100,0,110,0,0,0,0,0,0,0,115,114,99,32,100,115,116,32,99,110,116,0,0,0,0,0,69,77,83,0,0,0,0,0,63,63,63,0,0,0,0,0,32,32,109,97,112,112,105,110,103,58,32,91,37,117,47,37,117,32,37,117,47,37,117,32,37,117,47,37,117,32,37,117,47,37,117,93,10,0,0,0,99,108,0,0,0,0,0,0,69,71,65,32,105,114,113,61,37,117,32,40,37,115,41,10,0,0,0,0,0,0,0,0,98,0,0,0,0,0,0,0,101,118,97,108,117,97,116,101,32,101,120,112,114,101,115,115,105,111,110,115,0,0,0,0,88,77,83,0,0,0,0,0,83,72,82,0,0,0,0,0,101,110,97,98,108,101,95,105,114,113,0,0,0,0,0,0,118,0,0,0,0,0,0,0,91,101,120,112,114,46,46,46,93,0,0,0,0,0,0,0,87,79,82,68,32,0,0,0,117,110,107,110,111,119,110,32,99,111,109,112,111,110,101,110,116,32,40,37,115,41,10,0,88,77,83,58,32,69,77,66,58,32,37,108,117,75,47,37,108,117,75,32,32,85,77,66,58,32,37,108,117,75,47,37,108,117,75,32,32,72,77,65,58,32,37,108,117,75,47,37,108,117,75,10,0,0,0,0,83,72,76,0,0,0,0,0,42,42,42,32,115,101,116,116,105,110,103,32,117,112,32,118,105,100,101,111,32,100,101,118,105,99,101,32,102,97,105,108,101,100,10,0,0,0,0,0,99,0,0,0,0,0,0,0,110,97,109,101,32,91,102,93,32,91,97,32,110,46,46,46,93,0,0,0,0,0,0,0,101,109,117,46,100,105,115,107,46,101,106,101,99,116,0,0,120,109,115,0,0,0,0,0,82,67,82,0,0,0,0,0,37,115,58,32,117,110,107,110,111,119,110,32,111,112,116,105,111,110,32,40,37,115,41,10,0,0,0,0,0,0,0,0,42,42,42,32,117,110,107,110,111,119,110,32,118,105,100,101,111,32,100,101,118,105,99,101,32,40,37,115,41,10,0,0,120,0,0,0,0,0,0,0,113,117,105,116,0,0,0,0,101,109,115,0,0,0,0,0,82,67,76,0,0,0,0,0,115,100,108,58,32,107,101,121,32,61,32,48,120,37,48,52,120,10,0,0,0,0,0,0,99,0,0,0,0,0,0,0,116,101,114,109,46,102,117,108,108,115,99,114,101,101,110,0,119,121,55,48,48,0,0,0,122,0,0,0,0,0,0,0,115,101,110,100,32,97,32,109,101,115,115,97,103,101,32,116,111,32,116,104,101,32,101,109,117,108,97,116,111,114,32,99,111,114,101,0,0,0,0,0,70,55,0,0,0,0,0,0,38,0,0,0,0,0,0,0,34,37,115,34,0,0,0,0,118,105,100,101,111,0,0,0,101,0,0,0,0,0,0,0,105,104,120,0,0,0,0,0,109,105,110,95,104,0,0,0,100,101,102,97,117,108,116,0,111,102,102,115,101,116,0,0,44,32,0,0,0,0,0,0,115,121,110,116,97,120,32,101,114,114,111,114,0,0,0,0,58,0,0,0,0,0,0,0,56,48,49,56,54,0,0,0,82,79,82,0,0,0,0,0,116,100,48,58,32,115,101,99,116,111,114,32,99,114,99,32,111,118,101,114,32,104,101,97,100,101,114,43,100,97,116,97,10,0,0,0,0,0,0,0,99,112,50,58,32,119,97,114,110,105,110,103,58,32,117,110,107,110,111,119,110,32,67,80,50,32,118,101,114,115,105,111,110,10,0,0,0,0,0,0,46,114,97,119,0,0,0,0,108,111,103,0,0,0,0,0,119,121,115,101,0,0,0,0,60,0,0,0,0,0,0,0,109,115,103,32,91,118,97,108,93,0,0,0,0,0,0,0,104,100,99,58,32,102,111,114,109,97,116,32,116,114,97,99,107,32,101,114,114,111,114,32,40,100,61,37,117,41,10,0,68,69,86,58,32,87,121,115,101,32,55,48,48,10,0,0,67,76,75,58,32,67,76,75,61,37,108,117,32,32,72,84,61,37,108,117,32,72,68,61,37,108,117,32,32,86,84,61,37,108,117,32,86,68,61,37,108,117,10,0,0,0,0,0,67,71,65,58,32,79,70,83,61,37,48,52,88,32,32,80,79,83,61,37,48,52,88,32,32,66,71,61,37,48,50,88,32,32,80,65,76,61,37,117,10,0,0,0,0,0,0,0,67,71,65,58,32,79,70,83,61,37,48,52,88,32,32,80,79,83,61,37,48,52,88,32,32,66,71,61,37,48,50,88,32,32,80,65,76,61,37,117,10,0,0,0,0,0,0,0,117,97,114,116,0,0,0,0,82,79,76,0,0,0,0,0,76,101,115,115,0,0,0,0,112,108,97,110,116,114,111,110,105,99,115,0,0,0,0,0,114,101,97,100,32,97,32,102,105,108,101,32,105,110,116,111,32,109,101,109,111,114,121,0,112,111,114,116,115,0,0,0,111,102,102,0,0,0,0,0,99,111,108,111,114,0,0,0,99,111,108,111,114,95,110,111,114,109,97,108,0,0,0,0,68,69,86,58,32,69,71,65,10,0,0,0,0,0,0,0,83,104,105,102,116,0,0,0,111,108,105,118,101,116,116,105,0,0,0,0,0,0,0,0,110,97,109,101,32,91,102,93,32,91,97,32,91,110,93,93,0,0,0,0,0,0,0,0,86,73,68,69,79,58,0,0,109,101,109,0,0,0,0,0,88,76,65,84,0,0,0,0,83,104,105,102,116,76,101,102,116,0,0,0,0,0,0,0,109,100,97,0,0,0,0,0,112,114,105,110,116,32,104,101,108,112,0,0,0,0,0,0,100,109,97,0,0,0,0,0,74,67,88,90,0,0,0,0,92,0,0,0,0,0,0,0,104,103,99,0,0,0,0,0,102,105,110,100,32,98,121,116,101,115,32,105,110,32,109,101,109,111,114,121,0,0,0,0,112,105,99,0,0,0,0,0,76,79,79,80,0,0,0,0,97,108,0,0,0,0,0,0,69,77,83,58,32,37,117,47,37,117,32,112,97,103,101,115,32,32,37,108,117,75,47,37,108,117,75,32,32,37,117,32,104,97,110,100,108,101,115,10,0,0,0,0,0,0,0,0,66,97,99,107,115,108,97,115,104,0,0,0,0,0,0,0,101,103,97,0,0,0,0,0,97,100,100,114,32,99,110,116,32,91,118,97,108,46,46,46,93,0,0,0,0,0,0,0,112,112,105,0,0,0,0,0,76,79,79,80,90,0,0,0,39,0,0,0,0,0,0,0,118,103,97,0,0,0,0,0,101,110,116,101,114,32,98,121,116,101,115,32,105,110,116,111,32,109,101,109,111,114,121,0,80,85,83,72,0,0,0,0,112,105,116,0,0,0,0,0,114,101,115,101,116,32,120,109,115,10,0,0,0,0,0,0,76,79,79,80,78,90,0,0,65,112,111,115,116,114,111,112,104,101,0,0,0,0,0,0,100,101,118,105,99,101,61,37,115,10,0,0,0,0,0,0,97,100,100,114,32,91,118,97,108,124,115,116,114,105,110,103,46,46,46,93,0,0,0,0,101,109,117,46,100,105,115,107,46,99,111,109,109,105,116,0,116,105,109,101,0,0,0,0,105,112,0,0,0,0,0,0,74,77,80,78,0,0,0,0,99,112,117,46,115,112,101,101,100,32,61,32,0,0,0,0,81,117,111,116,101,0,0,0,86,73,68,69,79,58,0,0,100,117,109,112,32,109,101,109,111,114,121,0,0,0,0,0,66,79,85,78,68,32,69,65,32,105,115,32,114,101,103,105,115,116,101,114,10,0,0,0,99,112,117,0,0,0,0,0,37,48,52,88,58,37,48,52,88,0,0,0,0,0,0,0,101,109,117,46,115,116,111,112,0,0,0,0,0,0,0,0,59,0,0,0,0,0,0,0,99,103,97,0,0,0,0,0,98,0,0,0,0,0,0,0,91,97,100,100,114,32,91,99,110,116,93,93,0,0,0,0,70,54,0,0,0,0,0,0,94,0,0,0,0,0,0,0,48,120,37,108,120,0,0,0,112,99,0,0,0,0,0,0,60,110,108,62,0,0,0,0,100,0,0,0,0,0,0,0,105,104,101,120,0,0,0,0,109,105,110,95,119,0,0,0,115,105,122,101,0,0,0,0,97,117,116,111,0,0,0,0,32,32,45,37,99,0,0,0,115,116,114,105,110,103,32,116,111,111,32,108,111,110,103,0,101,120,112,101,99,116,105,110,103,32,97,100,100,114,101,115,115,0,0,0,0,0,0,0,56,48,56,56,0,0,0,0,74,77,80,83,0,0,0,0,116,100,48,58,32,117,110,107,110,111,119,110,32,99,111,109,112,114,101,115,115,105,111,110,32,40,37,117,47,37,117,47,37,117,32,37,117,41,10,0,99,112,50,58,32,110,111,116,32,97,32,67,80,50,32,102,105,108,101,10,0,0,0,0,46,105,109,103,0,0,0,0,119,0,0,0,0,0,0,0,121,100,105,118,0,0,0,0,83,101,109,105,99,111,108,111,110,0,0,0,0,0,0,0,100,101,118,105,99,101,0,0,115,101,116,32,97,110,32,101,120,112,114,101,115,115,105,111,110,32,98,114,101,97,107,112,111,105,110,116,32,91,112,97,115,115,61,49,32,114,101,115,101,116,61,48,93,0,0,0,104,100,99,58,32,114,101,97,100,32,101,114,114,111,114,32,40,100,61,37,117,41,10,0,87,89,55,48,48,58,32,117,110,107,110,111,119,110,32,109,111,100,101,32,40,37,48,50,88,41,10,0,0,0,0,0,86,71,65,58,32,65,68,68,82,61,37,48,52,88,32,32,76,79,70,83,61,37,48,52,88,32,32,67,85,82,83,61,37,48,52,88,32,32,76,67,77,80,61,37,48,52,88,10,0,0,0,0,0,0,0,0,68,69,86,58,32,80,108,97,110,116,114,111,110,105,99,115,32,67,111,108,111,114,112,108,117,115,10,0,0,0,0,0,68,69,86,58,32,79,108,105,118,101,116,116,105,32,77,50,52,10,0,0,0,0,0,0,37,115,44,32,37,115,0,0,73,78,0,0,0,0,0,0,108,0,0,0,0,0,0,0,101,120,112,114,32,91,112,97,115,115,32,91,114,101,115,101,116,93,93,0,0,0,0,0,118,105,100,101,111,0,0,0,111,110,32,0,0,0,0,0,79,108,105,118,101,116,116,105,32,105,111,61,48,120,37,48,52,108,120,32,97,100,100,114,61,48,120,37,48,53,108,120,32,115,105,122,101,61,48,120,37,48,53,108,120,10,0,0,77,68,65,32,105,111,61,48,120,37,48,52,108,120,32,97,100,100,114,61,48,120,37,48,53,108,120,32,115,105,122,101,61,48,120,37,48,53,108,120,10,0,0,0,0,0,0,0,99,111,108,111,114,95,98,97,99,107,103,114,111,117,110,100,0,0,0,0,0,0,0,0,69,71,65,32,105,111,61,48,120,37,48,52,108,120,32,97,100,100,114,61,48,120,37,48,53,108,120,32,115,119,105,116,99,104,101,115,61,37,48,50,88,10,0,0,0,0,0,0,107,0,0,0,0,0,0,0,42,42,42,32,108,111,97,100,105,110,103,32,100,114,105,118,101,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,98,115,120,0,0,0,0,0,102,105,108,101,0,0,0,0,32,37,48,52,88,0,0,0,76,79,67,75,32,0,0,0,106,0,0,0,0,0,0,0,100,105,115,107,0,0,0,0,115,101,116,32,97,110,32,97,100,100,114,101,115,115,32,98,114,101,97,107,112,111,105,110,116,32,91,112,97,115,115,61,49,32,114,101,115,101,116,61,48,93,0,0,0,0,0,0,115,105,122,101,107,0,0,0,82,69,80,78,69,32,0,0,104,0,0,0,0,0,0,0,42,42,42,32,99,114,101,97,116,105,110,103,32,102,100,99,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,0,97,100,100,114,32,91,112,97,115,115,32,91,114,101,115,101,116,93,93,0,0,0,0,0,32,37,48,50,88,0,0,0,82,69,80,32,0,0,0,0,100,115,0,0,0,0,0,0,80,114,105,110,116,32,118,101,114,115,105,111,110,32,105,110,102,111,114,109,97,116,105,111,110,0,0,0,0,0,0,0,114,101,115,101,116,32,101,109,115,10,0,0,0,0,0,0,103,0,0,0,0,0,0,0,97,100,100,114,61,48,120,37,48,56,108,120,32,105,114,113,61,37,117,32,97,99,99,117,114,97,116,101,61,37,100,32,101,111,116,61,37,100,32,100,114,118,61,91,37,117,32,37,117,32,37,117,32,37,117,93,10,0,0,0,0,0,0,0,98,115,0,0,0,0,0,0,37,48,50,88,0,0,0,0,118,101,114,115,105,111,110,0,102,0,0,0,0,0,0,0,70,68,67,58,0,0,0,0,108,105,115,116,32,98,114,101,97,107,112,111,105,110,116,115,0,0,0,0,0,0,0,0,74,77,80,70,0,0,0,0,37,48,52,88,58,37,48,52,88,32,32,37,115,10,0,0,69,77,66,61,37,108,117,91,37,108,117,77,93,32,85,77,66,61,37,108,117,91,37,108,117,75,93,32,97,116,32,48,120,37,48,52,120,32,72,77,65,61,37,100,10,0,0,0,83,101,116,32,116,104,101,32,108,111,103,32,108,101,118,101,108,32,116,111,32,100,101,98,117,103,32,91,110,111,93,0,100,0,0,0,0,0,0,0,100,114,105,118,101,51,0,0,98,108,0,0,0,0,0,0,101,109,117,46,100,105,115,107,46,98,111,111,116,0,0,0,100,105,115,97,115,115,101,109,98,108,101,0,0,0,0,0,37,48,50,88,0,0,0,0,34,10,0,0,0,0,0,0,118,101,114,98,111,115,101,0,109,50,52,32,114,116,99,32,103,101,116,32,112,111,114,116,32,56,32,37,48,52,108,88,10,0,0,0,0,0,0,0,115,0,0,0,0,0,0,0,100,114,105,118,101,50,0,0,99,108,101,97,114,32,97,32,98,114,101,97,107,112,111,105,110,116,32,111,114,32,97,108,108,0,0,0,0,0,0,0,91,97,100,100,114,32,91,99,110,116,32,91,109,111,100,101,93,93,93,0,0,0,0,0,37,48,52,88,0,0,0,0,83,101,116,32,116,104,101,32,116,101,114,109,105,110,97,108,32,100,101,118,105,99,101,0,49,0,0,0,0,0,0,0,116,101,114,109,46,114,101,108,101,97,115,101,0,0,0,0,97,0,0,0,0,0,0,0,105,103,110,111,114,101,95,101,111,116,0,0,0,0,0,0,91,105,110,100,101,120,93,0,70,53,0,0,0,0,0,0,98,111,111,116,0,0,0,0,94,94,0,0,0,0,0,0,37,115,32,61,32,0,0,0,101,120,101,99,117,116,101,32,99,110,116,32,105,110,115,116,114,117,99,116,105,111,110,115,32,91,49,93,0,0,0,0,60,101,111,102,62,0,0,0,115,97,118,101,0,0,0,0,97,117,116,111,0,0,0,0,97,115,112,101,99,116,95,121,0,0,0,0,0,0,0,0,115,105,122,101,107,0,0,0,116,121,112,101,0,0,0,0,37,115,58,32,109,105,115,115,105,110,103,32,111,112,116,105,111,110,32,97,114,103,117,109,101,110,116,32,40,45,37,99,41,10,0,0,0,0,0,0,105,100,101,110,116,105,102,105,101,114,32,116,111,111,32,108,111,110,103,0,0,0,0,0,120,0,0,0,0,0,0,0,110,111,0,0,0,0,0,0,56,48,56,54,0,0,0,0,73,68,73,86,0,0,0,0,116,100,48,58,32,122,101,114,111,32,100,97,116,97,32,108,101,110,103,116,104,32,40,37,117,47,37,117,47,37,117,41,10,0,0,0,0,0,0,0,116,101,114,109,105,110,97,108,0,0,0,0,0,0,0,0,46,105,109,100,0,0,0,0,115,101,114,99,111,110,0,0,115,116,100,105,111,0,0,0,121,109,117,108,0,0,0,0,100,105,115,107,32,37,117,58,32,119,114,105,116,105,110,103,32,98,97,99,107,32,102,97,105,108,101,100,10,0,0,0,67,97,112,115,76,111,99,107,0,0,0,0,0,0,0,0,97,99,99,117,114,97,116,101,0,0,0,0,0,0,0,0,98,99,0,0,0,0,0,0,104,100,99,58,32,119,114,105,116,101,32,101,114,114,111,114,32,40,100,61,37,117,41,10,0,0,0,0,0,0,0,0,87,89,45,55,48,48,32,105,111,61,48,120,37,48,52,108,120,32,97,100,100,114,61,48,120,37,48,53,108,120,32,115,105,122,101,61,48,120,37,48,53,108,120,10,0,0,0,0,68,69,86,58,32,86,71,65,10,0,0,0,0,0,0,0,80,108,97,110,116,114,111,110,105,99,115,32,105,111,61,48,120,37,48,52,108,120,32,97,100,100,114,61,48,120,37,48,53,108,120,32,115,105,122,101,61,48,120,37,48,53,108,120,10,0,0,0,0,0,0,0,112,114,105,110,116,32,115,116,97,116,117,115,32,40,112,99,124,99,112,117,124,109,101,109,124,112,105,116,124,112,112,105,124,112,105,99,124,116,105,109,101,124,117,97,114,116,124,118,105,100,101,111,124,120,109,115,41,0,0,0,0,0,0,0,83,101,116,32,116,104,101,32,67,80,85,32,115,112,101,101,100,0,0,0,0,0,0,0,82,101,116,117,114,110,0,0,102,100,99,0,0,0,0,0,91,119,104,97,116,93,0,0,99,97,115,115,101,116,116,101,32,109,111,116,111,114,32,37,115,32,97,116,32,37,108,117,32,40,37,115,41,10,0,0,86,73,68,69,79,58,0,0,86,73,68,69,79,58,0,0,73,77,85,76,0,0,0,0,97,109,98,101,114,0,0,0,115,112,101,101,100,0,0,0,86,73,68,69,79,58,0,0,93,0,0,0,0,0,0,0,42,42,42,32,99,114,101,97,116,105,110,103,32,104,100,99,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,0,98,108,105,110,107,0,0,0,115,101,116,32,97,32,114,101,103,105,115,116,101,114,0,0,78,101,118,101,114,32,115,116,111,112,32,114,117,110,110,105,110,103,32,91,110,111,93,0,82,105,103,104,116,66,114,97,99,107,101,116,0,0,0,0,97,100,100,114,61,48,120,37,48,56,108,120,32,105,114,113,61,37,117,32,100,114,118,61,91,37,117,32,37,117,93,32,115,101,99,116,111,114,115,61,37,117,32,115,119,105,116,99,104,101,115,61,48,120,37,48,50,120,32,105,100,61,34,37,115,34,10,0,0,0,0,0,91,114,101,103,32,118,97,108,93,0,0,0,0,0,0,0,110,111,45,109,111,110,105,116,111,114,0,0,0,0,0,0,91,0,0,0,0,0,0,0,72,68,67,58,0,0,0,0,120,109,115,95,115,105,122,101,0,0,0,0,0,0,0,0,101,120,101,99,117,116,101,32,99,110,116,32,105,110,115,116,114,117,99,116,105,111,110,115,44,32,119,105,116,104,111,117,116,32,116,114,97,99,101,32,105,110,32,99,97,108,108,115,32,91,49,93,0,0,0,0,115,115,0,0,0,0,0,0,83,116,97,114,116,32,114,117,110,110,105,110,103,32,105,109,109,101,100,105,97,116,101,108,121,32,91,110,111,93,0,0,76,101,102,116,66,114,97,99,107,101,116,0,0,0,0,0,115,105,122,101,61,37,108,117,75,32,40,37,108,117,32,112,97,103,101,115,41,32,115,101,103,109,101,110,116,61,48,120,37,48,52,120,10,0,0,0,115,119,105,116,99,104,101,115,0,0,0,0,0,0,0,0,98,108,111,99,107,95,99,111,117,110,116,0,0,0,0,0,112,114,101,102,101,116,99,104,32,113,117,101,117,101,32,99,108,101,97,114,47,102,105,108,108,47,115,116,97,116,117,115,0,0,0,0,0,0,0,0,84,69,83,84,0,0,0,0,114,117,110,0,0,0,0,0,112,0,0,0,0,0,0,0,98,108,111,99,107,95,115,116,97,114,116,0,0,0,0,0,91,99,124,102,124,115,93,0,88,77,83,58,0,0,0,0,83,84,68,0,0,0,0,0,83,101,116,32,116,104,101,32,108,111,103,32,108,101,118,101,108,32,116,111,32,101,114,114,111,114,32,91,110,111,93,0,111,0,0,0,0,0,0,0,99,111,110,102,105,103,95,105,100,0,0,0,0,0,0,0,100,114,105,118,101,61,37,117,32,118,99,104,115,61,37,108,117,47,37,108,117,47,37,108,117,10,0,0,0,0,0,0,101,109,117,46,99,112,117,46,115,112,101,101,100,46,115,116,101,112,0,0,0,0,0,0,111,117,116,112,117,116,32,97,32,98,121,116,101,32,111,114,32,119,111,114,100,32,116,111,32,97,32,112,111,114,116,0,67,76,68,0,0,0,0,0,99,112,117,46,109,111,100,101,108,32,61,32,34,0,0,0,113,117,105,101,116,0,0,0,115,119,105,116,99,104,101,115,48,61,48,120,37,48,50,88,32,115,119,105,116,99,104,101,115,49,61,48,120,37,48,50,88,10,0,0,0,0,0,0,73,0,0,0,0,0,0,0,115,101,99,116,111,114,115,0,118,105,115,105,98,108,101,95,115,0,0,0,0,0,0,0,91,98,124,119,93,32,112,111,114,116,32,118,97,108,0,0,83,84,73,0,0,0,0,0,42,42,42,32,99,111,109,109,105,116,32,101,114,114,111,114,32,102,111,114,32,100,114,105,118,101,32,37,117,10,0,0,83,101,116,32,116,104,101,32,67,80,85,32,109,111,100,101,108,0,0,0,0,0,0,0,101,109,117,46,101,120,105,116,0,0,0,0,0,0,0,0,116,101,114,109,46,115,99,114,101,101,110,115,104,111,116,0,117,0,0,0,0,0,0,0,100,114,105,118,101,49,0,0,118,105,115,105,98,108,101,95,104,0,0,0,0,0,0,0,70,52,0,0,0,0,0,0,124,0,0,0,0,0,0,0,125,10,0,0,0,0,0,0,72,65,76,84,61,49,10,0,115,101,116,32,105,110,116,101,114,114,117,112,116,32,110,32,108,111,103,32,101,120,112,114,101,115,115,105,111,110,32,116,111,32,101,120,112,114,0,0,58,32,0,0,0,0,0,0,108,111,97,100,0,0,0,0,102,105,108,101,61,37,115,32,102,111,114,109,97,116,61,98,105,110,97,114,121,32,97,100,100,114,61,48,120,37,48,56,108,120,10,0,0,0,0,0,97,115,112,101,99,116,95,120,0,0,0,0,0,0,0,0,115,105,122,101,109,0,0,0,100,114,105,118,101,0,0,0,37,115,58,32,117,110,107,110,111,119,110,32,111,112,116,105,111,110,32,40,45,37,99,41,10,0,0,0,0,0,0,0,42,42,42,32,37,115,32,91,37,115,93,10,0,0,0,0,98,58,32,117,110,107,110,111,119,110,32,99,111,109,109,97,110,100,0,0,0,0,0,0,102,97,108,115,101,0,0,0,115,100,108,0,0,0,0,0,114,101,115,101,116,32,112,99,10,0,0,0,0,0,0,0,67,76,73,0,0,0,0,0,116,100,48,58,32,99,114,99,32,101,114,114,111,114,32,97,116,32,115,101,99,116,111,114,32,37,117,47,37,117,47,37,117,32,40,110,111,32,100,97,116,97,41,10,0,0,0,0,99,111,109,109,105,116,0,0,32,37,48,50,88,0,0,0,99,112,117,0,0,0,0,0,46,105,109,97,0,0,0,0,45,45,0,0,0,0,0,0,112,116,121,0,0,0,0,0,120,100,105,118,0,0,0,0,113,101,100,58,32,117,110,107,110,111,119,110,32,102,101,97,116,117,114,101,115,32,40,48,120,37,48,56,108,108,120,41,10,0,0,0,0,0,0,0,100,105,115,107,32,37,117,58,32,119,114,105,116,105,110,103,32,98,97,99,107,32,102,100,99,32,105,109,97,103,101,10,0,0,0,0,0,0,0,0,121,0,0,0,0,0,0,0,100,114,105,118,101,48,0,0,118,105,115,105,98,108,101,95,99,0,0,0,0,0,0,0,105,110,105,116,32,100,114,105,118,101,32,37,117,32,40,99,61,37,117,32,104,61,37,117,32,115,61,37,117,32,114,99,61,37,117,32,119,112,61,37,117,32,101,99,99,61,37,117,32,115,105,122,101,61,37,108,117,46,37,117,75,41,10,0,86,73,68,69,79,58,0,0,86,71,65,32,105,111,61,48,120,37,48,52,108,120,32,97,100,100,114,61,48,120,37,48,53,108,120,10,0,0,0,0,86,73,68,69,79,58,0,0,105,110,116,32,110,32,91,101,120,112,114,93,0,0,0,0,83,84,67,0,0,0,0,0,99,111,109,109,105,116,105,110,103,32,100,114,105,118,101,32,37,117,10,0,0,0,0,0,83,101,116,32,116,104,101,32,108,111,103,32,102,105,108,101,32,110,97,109,101,32,91,110,111,110,101,93,0,0,0,0,116,0,0,0,0,0,0,0,104,100,99,0,0,0,0,0,108,105,115,116,32,105,110,116,101,114,114,117,112,116,32,108,111,103,32,101,120,112,114,101,115,115,105,111,110,115,0,0,46,99,97,115,0,0,0,0,98,108,105,110,107,0,0,0,98,108,105,110,107,0,0,0,67,76,67,0,0,0,0,0,99,111,108,111,114,0,0,0,42,42,42,32,99,111,109,109,105,116,32,101,114,114,111,114,58,32,98,97,100,32,100,114,105,118,101,32,40,37,115,41,10,0,0,0,0,0,0,0,108,111,103,0,0,0,0,0,98,108,105,110,107,0,0,0,114,0,0,0,0,0,0,0,42,42,42,32,117,110,107,110,111,119,110,32,85,65,82,84,32,99,104,105,112,32,40,37,115,41,10,0,0,0,0,0,42,42,42,32,108,111,97,100,105,110,103,32,100,114,105,118,101,32,48,120,37,48,50,120,32,102,97,105,108,101,100,32,40,99,111,119,41,10,0,0,102,111,110,116,0,0,0,0,105,110,116,32,108,0,0,0,83,80,0,0,0,0,0,0,42,42,42,32,99,111,109,109,105,116,32,102,97,105,108,101,100,32,102,111,114,32,97,116,32,108,101,97,115,116,32,111,110,101,32,100,105,115,107,10,0,0,0,0,0,0,0,0,65,100,100,32,97,110,32,105,110,105,32,115,116,114,105,110,103,32,97,102,116,101,114,32,116,104,101,32,99,111,110,102,105,103,32,102,105,108,101,0,101,0,0,0,0,0,0,0,42,42,42,32,99,97,110,39,116,32,111,112,101,110,32,108,111,103,32,102,105,108,101,32,40,37,115,41,10,0,0,0,115,105,109,117,108,97,116,101,32,112,114,101,115,115,105,110,103,32,111,114,32,114,101,108,101,97,115,105,110,103,32,107,101,121,115,0,0,0,0,0,68,88,0,0,0,0,0,0,99,111,109,109,105,116,105,110,103,32,97,108,108,32,100,114,105,118,101,115,10,0,0,0,105,110,105,45,97,112,112,101,110,100,0,0,0,0,0,0,119,0,0,0,0,0,0,0,42,42,42,32,115,101,114,105,97,108,32,112,111,114,116,32,115,101,116,117,112,32,102,97,105,108,101,100,32,91,37,48,52,88,47,37,117,32,45,62,32,37,115,93,10,0,0,0,114,119,0,0,0,0,0,0,91,91,43,124,45,93,107,101,121,46,46,46,93,0,0,0,67,88,0,0,0,0,0,0,97,108,108,0,0,0,0,0,99,115,0,0,0,0,0,0,65,100,100,32,97,110,32,105,110,105,32,115,116,114,105,110,103,32,98,101,102,111,114,101,32,116,104,101,32,99,111,110,102,105,103,32,102,105,108,101,0,0,0,0,0,0,0,0,113,0,0,0,0,0,0,0,67,79,77,37,117,32,100,114,105,118,101,114,61,37,115,10,0,0,0,0,0,0,0,0,114,111,0,0,0,0,0,0,69,77,83,58,0,0,0,0,105,110,112,117,116,32,97,32,98,121,116,101,32,111,114,32,119,111,114,100,32,102,114,111,109,32,97,32,112,111,114,116,0,0,0,0,0,0,0,0,65,88,0,0,0,0,0,0,101,106,101,99,116,105,110,103,32,100,114,105,118,101,32,37,108,117,10,0,0,0,0,0,105,110,105,45,112,114,101,102,105,120,0,0,0,0,0,0,84,97,98,0,0,0,0,0,67,79,77,37,117,32,97,100,100,114,61,48,120,37,48,52,108,120,32,105,114,113,61,37,117,32,109,117,108,116,105,99,104,97,114,61,114,61,37,117,47,119,61,37,117,32,117,97,114,116,61,37,115,10,0,0,100,114,105,118,101,61,37,117,32,116,121,112,101,61,37,115,32,98,108,111,99,107,115,61,37,108,117,32,99,104,115,61,37,108,117,47,37,108,117,47,37,108,117,32,37,115,32,102,105,108,101,61,37,115,10,0,67,65,76,76,70,0,0,0,91,98,124,119,93,32,112,111,114,116,0,0,0,0,0,0,91,37,48,52,88,58,37,48,52,88,93,32,0,0,0,0,104,109,97,0,0,0,0,0,66,72,0,0,0,0,0,0,42,42,42,32,100,105,115,107,32,101,106,101,99,116,32,101,114,114,111,114,58,32,110,111,32,115,117,99,104,32,100,105,115,107,32,40,37,108,117,41,10,0,0,0,0,0,0,0,83,101,116,32,116,104,101,32,118,105,100,101,111,32,100,101,118,105,99,101,0,0,0,0,66,97,99,107,115,112,97,99,101,0,0,0,0,0,0,0,83,69,82,80,79,82,84,58,0,0,0,0,0,0,0,0,42,42,42,32,108,111,97,100,105,110,103,32,100,114,105,118,101,32,48,120,37,48,50,120,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,0,101,109,117,46,99,112,117,46,115,112,101,101,100,0,0,0,112,114,105,110,116,32,104,101,108,112,32,111,110,32,109,101,115,115,97,103,101,115,0,0,68,72,0,0,0,0,0,0,37,115,58,32,101,114,114,111,114,32,112,97,114,115,105,110,103,32,105,110,105,32,115,116,114,105,110,103,32,40,37,115,41,10,0,0,0,0,0,0,42,42,42,32,100,105,115,107,32,101,106,101,99,116,32,101,114,114,111,114,58,32,98,97,100,32,100,114,105,118,101,32,40,37,115,41,10,0,0,0,118,105,100,101,111,0,0,0,77,50,52,58,0,0,0,0,61,0,0,0,0,0,0,0,108,111,103,0,0,0,0,0,116,101,108,101,100,105,115,107,0,0,0,0,0,0,0,0,114,117,110,0,0,0,0,0,109,50,52,0,0,0,0,0,67,72,0,0,0,0,0,0,68,105,115,97,98,108,105,110,103,0,0,0,0,0,0,0,65,100,100,32,97,32,100,105,114,101,99,116,111,114,121,32,116,111,32,116,104,101,32,115,101,97,114,99,104,32,112,97,116,104,0,0,0,0,0,0,107,101,121,109,97,112,0,0,116,101,114,109,46,101,115,99,97,112,101,0,0,0,0,0,69,113,117,97,108,0,0,0,109,117,108,116,105,99,104,97,114,95,119,114,105,116,101,0,112,102,100,99,45,97,117,116,111,0,0,0,0,0,0,0,70,51,0,0,0,0,0,0,38,38,0,0,0,0,0,0,37,115,32,123,10,0,0,0,37,115,58,37,108,117,58,32,37,115,0,0,0,0,0,0,32,32,73,37,99,32,68,37,99,32,79,37,99,32,83,37,99,32,90,37,99,32,65,37,99,32,80,37,99,32,67,37,99,10,0,0,0,0,0,0,102,105,108,101,61,37,115,32,102,111,114,109,97,116,61,115,114,101,99,10,0,0,0,0,101,115,99,97,112,101,0,0,98,97,115,101,0,0,0,0,100,114,105,118,101,61,37,117,32,116,121,112,101,61,99,111,119,32,102,105,108,101,61,37,115,10,0,0,0,0,0,0])
.concat([37,115,58,32,109,105,115,115,105,110,103,32,111,112,116,105,111,110,32,97,114,103,117,109,101,110,116,32,40,37,115,41,10,0,0,0,0,0,0,0,99,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,119,97,118,0,0,0,0,0,112,97,116,99,104,105,110,103,32,116,104,101,32,98,105,111,115,32,40,48,120,37,48,52,120,41,10,0,0,0,0,0,65,72,0,0,0,0,0,0,116,100,48,58,32,116,114,97,99,107,32,99,114,99,32,40,37,48,50,88,32,37,48,52,88,41,10,0,0,0,0,0,100,99,52,50,58,32,116,97,103,32,99,104,101,99,107,115,117,109,32,101,114,114,111,114,10,0,0,0,0,0,0,0,69,110,97,98,108,105,110,103,0,0,0,0,0,0,0,0,46,105,109,97,103,101,0,0,119,98,0,0,0,0,0,0,112,97,116,104,0,0,0,0,45,0,0,0,0,0,0,0,115,101,114,99,111,110,0,0,120,109,117,108,0,0,0,0,99,111,109,109,105,116,0,0,99,111,109,109,105,116,0,0,99,111,109,109,105,116,0,0,45,0,0,0,0,0,0,0,48,98,0,0,0,0,0,0,109,117,108,116,105,99,104,97,114,95,114,101,97,100,0,0,112,102,100,99,0,0,0,0,115,101,116,32,109,111,100,101,32,100,114,105,118,101,32,37,117,32,40,99,61,37,117,32,104,61,37,117,32,115,61,37,117,32,114,99,61,37,117,32,119,112,61,37,117,32,101,99,99,61,37,117,32,115,114,61,37,117,32,115,105,122,101,61,37,108,117,46,37,117,75,41,10,0,0,0,0,0,0,0,98,108,105,110,107,0,0,0,86,73,68,69,79,58,0,0,98,108,105,110,107,0,0,0,114,117,110,32,117,110,116,105,108,32,67,83,32,99,104,97,110,103,101,115,0,0,0,0,114,101,115,101,116,32,107,101,121,98,111,97,114,100,10,0,66,76,0,0,0,0,0,0,37,115,32,116,104,101,32,70,68,67,32,97,99,99,117,114,97,116,101,32,109,111,100,101,10,0,0,0,0,0,0,0,83,101,116,32,116,104,101,32,99,111,110,102,105,103,32,102,105,108,101,32,110,97,109,101,32,91,110,111,110,101,93,0,77,105,110,117,115,0,0,0,48,120,0,0,0,0,0,0,109,117,108,116,105,99,104,97,114,0,0,0,0,0,0,0,105,109,100,0,0,0,0,0,102,97,114,0,0,0,0,0,46,114,97,119,0,0,0,0,115,105,122,101,0,0,0,0,115,105,122,101,0,0,0,0,68,76,0,0,0,0,0,0,98,108,105,110,107,0,0,0,32,9,0,0,0,0,0,0,115,116,114,105,110,103,0,0,115,119,105,116,99,104,101,115,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,102,97,108,115,101,0,0,0,56,50,53,48,0,0,0,0,105,109,97,103,101,100,105,115,107,0,0,0,0,0,0,0,115,105,122,101,0,0,0,0,114,117,110,32,119,105,116,104,32,98,114,101,97,107,112,111,105,110,116,115,0,0,0,0,67,76,0,0,0,0,0,0,101,56,50,53,57,58,32,115,112,101,99,105,97,108,32,109,97,115,107,32,109,111,100,101,32,101,110,97,98,108,101,100,10,0,0,0,0,0,0,0,58,0,0,0,0,0,0,0,99,111,110,102,105,103,0,0,57,0,0,0,0,0,0,0,116,114,117,101,0,0,0,0,117,97,114,116,0,0,0,0,100,99,52,50,0,0,0,0,91,97,100,100,114,46,46,46,93,0,0,0,0,0,0,0,101,56,50,53,48,58,32,111,118,101,114,119,114,105,116,101,32,116,120,100,32,32,116,120,100,61,37,48,50,88,32,108,115,114,61,37,48,50,88,32,105,105,114,61,37,48,50,88,32,118,97,108,61,37,48,50,88,10,0,0,0,0,0,0,65,76,0,0,0,0,0,0,101,110,100,0,0,0,0,0,83,101,116,32,116,104,101,32,98,111,111,116,32,100,114,105,118,101,0,0,0,0,0,0,56,0,0,0,0,0,0,0,100,101,102,105,110,101,100,0,105,114,113,0,0,0,0,0,99,112,50,0,0,0,0,0,103,98,0,0,0,0,0,0,66,80,0,0,0,0,0,0,101,109,117,46,116,97,112,101,46,115,116,97,116,101,0,0,101,115,0,0,0,0,0,0,105,110,116,0,0,0,0,0,43,49,0,0,0,0,0,0,55,0,0,0,0,0,0,0,41,0,0,0,0,0,0,0,105,111,0,0,0,0,0,0,97,110,97,100,105,115,107,0,115,101,103,109,101,110,116,0,99,108,111,99,107,32,91,49,93,0,0,0,0,0,0,0,66,88,0,0,0,0,0,0,101,109,117,46,116,97,112,101,46,115,97,118,101,0,0,0,98,111,111,116,0,0,0,0,45,49,0,0,0,0,0,0,54,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,115,101,114,105,97,108,0,0,112,97,114,116,105,116,105,111,110,0,0,0,0,0,0,0,32,32,0,0,0,0,0,0,91,99,110,116,93,0,0,0,67,65,76,76,0,0,0,0,117,109,98,95,115,101,103,109,0,0,0,0,0,0,0,0,68,73,0,0,0,0,0,0,101,109,117,46,116,97,112,101,46,114,101,119,105,110,100,0,80,114,105,110,116,32,117,115,97,103,101,32,105,110,102,111,114,109,97,116,105,111,110,0,101,109,117,46,99,112,117,46,115,112,101,101,100,46,115,116,101,112,0,0,0,0,0,0,53,0,0,0,0,0,0,0,42,42,42,32,99,97,110,39,116,32,111,112,101,110,32,100,114,105,118,101,114,32,40,37,115,41,10,0,0,0,0,0,113,101,100,0,0,0,0,0,32,32,32,0,0,0,0,0,101,109,117,46,99,112,117,46,109,111,100,101,108,0,0,0,115,101,116,32,116,104,101,32,98,111,111,116,32,100,114,105,118,101,0,0,0,0,0,0,83,73,0,0,0,0,0,0,10,0,0,0,0,0,0,0,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,101,109,117,46,116,97,112,101,46,112,99,109,0,0,0,0,104,101,108,112,0,0,0,0,115,119,105,116,99,104,101,115,49,0,0,0,0,0,0,0,101,109,117,46,114,101,115,101,116,0,0,0,0,0,0,0,52,0,0,0,0,0,0,0,33,0,0,0,0,0,0,0,42,42,42,32,112,97,114,112,111,114,116,32,37,117,32,115,101,116,117,112,32,102,97,105,108,101,100,10,0,0,0,0,112,99,101,0,0,0,0,0,32,37,48,50,88,0,0,0,107,101,121,98,111,97,114,100,32,98,117,102,102,101,114,32,111,118,101,114,102,108,111,119,10,0,0,0,0,0,0,0,91,100,114,105,118,101,93,0,101,109,117,46,118,105,100,101,111,46,98,108,105,110,107,0,112,99,101,37,48,52,117,46,112,112,109,0,0,0,0,0,66,80,43,68,73,0,0,0,101,109,117,46,116,97,112,101,46,108,111,97,100,0,0,0,117,115,97,103,101,58,32,112,99,101,45,105,98,109,112,99,32,91,111,112,116,105,111,110,115,93,0,0,0,0,0,0,114,101,112,111,114,116,95,107,101,121,115,0,0,0,0,0,80,54,10,37,117,32,37,117,10,37,117,10,0,0,0,0,101,109,117,46,112,97,117,115,101,46,116,111,103,103,108,101,0,0,0,0,0,0,0,0,51,0,0,0,0,0,0,0,126,0,0,0,0,0,0,0,42,42,42,32,110,111,32,116,101,114,109,105,110,97,108,32,102,111,117,110,100,10,0,0,60,110,111,110,101,62,0,0,100,111,115,101,109,117,0,0,70,50,0,0,0,0,0,0,60,45,0,0,0,0,0,0,99,111,109,109,105,116,0,0,124,124,0,0,0,0,0,0,112,97,116,99,104,105,110,103,32,105,110,116,32,49,57,32,40,48,120,37,48,52,120,41,10,0,0,0,0,0,0,0,93,10,0,0,0,0,0,0,60,110,111,110,101,62,0,0,32,9,0,0,0,0,0,0,37,45,57,115,32,0,0,0,102,105,108,101,61,37,115,32,102,111,114,109,97,116,61,105,104,101,120,10,0,0,0,0,67,83,61,37,48,52,88,32,32,68,83,61,37,48,52,88,32,32,69,83,61,37,48,52,88,32,32,83,83,61,37,48,52,88,32,32,73,80,61,37,48,52,88,32,32,70,32,61,37,48,52,88,0,0,0,0,110,117,108,108,0,0,0,0,97,100,100,114,101,115,115,0,42,42,42,32,99,111,119,32,102,97,105,108,101,100,32,40,100,114,105,118,101,61,37,117,32,102,105,108,101,61,37,115,41,10,0,0,0,0,0,0,37,115,58,32,117,110,107,110,111,119,110,32,111,112,116,105,111,110,32,40,37,115,41,10,0,0,0,0,0,0,0,0,100,105,0,0,0,0,0,0,115,0,0,0,0,0,0,0,121,101,115,0,0,0,0,0,110,117,108,108,0,0,0,0,115,116,100,105,111,58,102,105,108,101,61,0,0,0,0,0,116,100,48,58,32,104,101,97,100,101,114,32,99,114,99,32,40,37,48,52,88,32,37,48,52,88,41,10,0,0,0,0,66,80,43,83,73,0,0,0,109,102,109,0,0,0,0,0,112,102,100,99,58,32,117,110,107,110,111,119,110,32,118,101,114,115,105,111,110,32,40,37,108,117,41,10,0,0,0,0,50,48,49,51,48,53,48,56,45,51,55,101,54,98,55,56,0,0,0,0,0,0,0,0,100,99,52,50,58,32,100,97,116,97,32,99,104,101,99,107,115,117,109,32,101,114,114,111,114,10,0,0,0,0,0,0,32,45,0,0,0,0,0,0,101,109,117,46,116,97,112,101,46,102,105,108,101,0,0,0,46,99,112,50,0,0,0,0,45,0,0,0,0,0,0,0,99,104,97,114,45,112,116,121,58,32,37,115,10,0,0,0,112,99,101,45,105,98,109,112,99,58,32,73,66,77,32,80,67,32,53,49,53,48,32,101,109,117,108,97,116,111,114,0,119,114,105,116,101,0,0,0,69,83,67,0,0,0,0,0,112,111,115,105,120,0,0,0,114,98,0,0,0,0,0,0,109,115,121,115,0,0,0,0,119,98,0,0,0,0,0,0,114,43,98,0,0,0,0,0,114,98,0,0,0,0,0,0,101,109,117,46,115,116,111,112,0,0,0,0,0,0,0,0,50,0,0,0,0,0,0,0,37,0,0,0,0,0,0,0,114,43,98,0,0,0,0,0,42,42,42,32,117,110,107,110,111,119,110,32,116,101,114,109,105,110,97,108,32,100,114,105,118,101,114,58,32,37,115,10,0,0,0,0,0,0,0,0,105,109,97,103,101,0,0,0,76,80,84,37,117,32,97,100,100,114,61,48,120,37,48,52,108,120,32,100,114,105,118,101,114,61,37,115,10,0,0,0,45,62,0,0,0,0,0,0,72,68,67,58,0,0,0,0,115,105,122,101,0,0,0,0,98,108,105,110,107,0,0,0,115,105,122,101,0,0,0,0,37,48,52,88,58,37,48,52,88,58,32,105,110,116,32,37,48,50,88,32,91,65,88,61,37,48,52,88,32,66,88,61,37,48,52,88,32,67,88,61,37,48,52,88,32,68,88,61,37,48,52,88,32,68,83,61,37,48,52,88,32,69,83,61,37,48,52,88,93,10,0,0,37,48,50,88,0,0,0,0,101,109,117,46,118,105,100,101,111,46,98,108,105,110,107,0,101,109,117,46,118,105,100,101,111,46,98,108,105,110,107,0,63,0,0,0,0,0,0,0,35,32,71,101,110,101,114,97,116,101,100,32,97,117,116,111,109,97,116,105,99,97,108,108,121,32,98,121,32,108,105,98,105,110,105,10,10,0,0,0,115,105,0,0,0,0,0,0,66,88,43,68,73,0,0,0,101,109,117,46,116,97,112,101,46,102,105,108,116,101,114,0,112,99,101,45,105,98,109,112,99,32,118,101,114,115,105,111,110,32,50,48,49,51,48,53,48,56,45,51,55,101,54,98,55,56,10,10,67,111,112,121,114,105,103,104,116,32,40,67,41,32,49,57,57,53,45,50,48,49,50,32,72,97,109,112,97,32,72,117,103,32,60,104,97,109,112,97,64,104,97,109,112,97,46,99,104,62,10,0,116,101,114,109,46,103,114,97,98,0,0,0,0,0,0,0,49,0,0,0,0,0,0,0,47,0,0,0,0,0,0,0,42,42,42,32,115,101,116,116,105,110,103,32,117,112,32,110,117,108,108,32,116,101,114,109,105,110,97,108,32,102,97,105,108,101,100,10,0,0,0,0,114,97,109,0,0,0,0,0,80,65,82,80,79,82,84,58,0,0,0,0,0,0,0,0,37,115,32,37,48,50,88,0,114,0,0,0,0,0,0,0,37,48,52,88,58,37,48,52,88,58,32,117,110,100,101,102,105,110,101,100,32,111,112,101,114,97,116,105,111,110,32,91,37,48,50,88,32,37,48,50,120,93,10,0,0,0,0,0,46,112,99,109,0,0,0,0,93,10,0,0,0,0,0,0,97,100,100,114,101,115,115,0,101,109,117,46,118,105,100,101,111,46,98,108,105,110,107,0,93,10,0,0,0,0,0,0,112,97,114,115,101,32,101,114,114,111,114,32,98,101,102,111,114,101,0,0,0,0,0,0,97,100,100,114,101,115,115,0,98,112,0,0,0,0,0,0,114,0,0,0,0,0,0,0,66,88,43,83,73,0,0,0,97,100,100,114,101,115,115,0,101,109,117,46,116,97,112,101,46,97,112,112,101,110,100,0,116,114,117,101,0,0,0,0,112,99,101,45,105,98,109,112,99,32,118,101,114,115,105,111,110,32,50,48,49,51,48,53,48,56,45,51,55,101,54,98,55,56,10,67,111,112,121,114,105,103,104,116,32,40,67,41,32,49,57,57,53,45,50,48,49,50,32,72,97,109,112,97,32,72,117,103,32,60,104,97,109,112,97,64,104,97,109,112,97,46,99,104,62,10,0,0,97,100,100,114,101,115,115,0,116,101,114,109,46,102,117,108,108,115,99,114,101,101,110,46,116,111,103,103,108,101,0,0,96,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,42,42,42,32,115,101,116,116,105,110,103,32,117,112,32,115,100,108,32,116,101,114,109,105,110,97,108,32,102,97,105,108,101,100,10,0,0,0,0,0,114,98,0,0,0,0,0,0,100,114,105,118,101,114,0,0,45,45,32,37,115,61,37,100,10,0,0,0,0,0,0,0,97,100,100,114,101,115,115,0,117,0,0,0,0,0,0,0,37,48,50,88,0,0,0,0,93,10,0,0,0,0,0,0,37,48,50,88,0,0,0,0,115,112,0,0,0,0,0,0,68,83,58,0,0,0,0,0,101,56,50,53,57,58,32,112,111,108,108,32,99,111,109,109,97,110,100,10,0,0,0,0,101,109,117,46,115,116,111,112,0,0,0,0,0,0,0,0,42,42,42,32,108,111,97,100,105,110,103,32,99,111,110,102,105,103,32,102,105,108,101,32,102,97,105,108,101,100,10,0,56,0,0,0,0,0,0,0,97,0,0,0,0,0,0,0,66,97,99,107,113,117,111,116,101,0,0,0,0,0,0,0,37,108,117,0,0,0,0,0,115,100,108,0,0,0,0,0,102,105,108,101,0,0,0,0,97,100,100,114,101,115,115,0,82,73,0,0,0,0,0,0,101,109,117,46,118,105,100,101,111,46,98,108,105,110,107,0,114,98,0,0,0,0,0,0,116,0,0,0,0,0,0,0,67,82,84,67,61,91,37,48,50,88,0,0,0,0,0,0,37,48,50,88,0,0,0,0,49,54,52,53,48,0,0,0,116,101,114,109,105,110,97,108,0,0,0,0,0,0,0,0,98,120,0,0,0,0,0,0,114,97,109,0,0,0,0,0,83,83,58,0,0,0,0,0,101,109,117,46,115,101,114,112,111,114,116,46,102,105,108,101,0,0,0,0,0,0,0,0,102,105,108,101,61,34,37,115,34,10,0,0,0,0,0,0,112,99,101,0,0,0,0,0,55,0,0,0,0,0,0,0,80,97,117,115,101,0,0,0,45,0,0,0,0,0,0,0,101,108,115,101,0,0,0,0,42,42,42,32,116,101,114,109,105,110,97,108,32,100,114,105,118,101,114,32,39,120,49,49,39,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,0,111,112,116,105,111,110,97,108,0,0,0,0,0,0,0,0,112,97,114,112,111,114,116,0,67,68,0,0,0,0,0,0,93,10,0,0,0,0,0,0,99,111,119,0,0,0,0,0,115,0,0,0,0,0,0,0,82,69,71,58,32,67,82,84,67,61,37,48,50,88,32,32,77,79,68,69,61,37,48,50,88,32,32,83,84,65,84,85,83,61,37,48,50,88,10,0,37,115,10,10,0,0,0,0,100,120,0,0,0,0,0,0,67,83,58,0,0,0,0,0,101,109,117,46,115,101,114,112,111,114,116,46,100,114,105,118,101,114,0,0,0,0,0,0,102,108,97,103,115,0,0,0,67,79,78,70,73,71,58,0,114,0,0,0,0,0,0,0,116,101,114,109,46,102,117,108,108,115,99,114,101,101,110,0,54,0,0,0,0,0,0,0,83,99,114,76,107,0,0,0,43,0,0,0,0,0,0,0,59,0,0,0,0,0,0,0,42,42,42,32,108,111,97,100,105,110,103,32,102,97,105,108,101,100,32,40,37,115,41,10,0,0,0,0,0,0,0,0,120,49,49,0,0,0,0,0,114,101,97,100,111,110,108,121,0,0,0,0,0,0,0,0,101,109,115,0,0,0,0,0,37,52,117,32,32,0,0,0,68,83,82,0,0,0,0,0,37,48,50,88,0,0,0,0,49,0,0,0,0,0,0,0,56,48,56,54,0,0,0,0,67,76,75,58,32,67,76,75,61,37,108,117,32,32,72,84,61,37,108,117,32,72,68,61,37,108,117,32,32,86,84,61,37,108,117,32,86,68,61,37,108,117,10,0,0,0,0,0,67,82,84,67,61,91,37,48,50,88,0,0,0,0,0,0,67,82,84,67,61,91,37,48,50,88,0,0,0,0,0,0,119,97,118,0,0,0,0,0,115,105,122,101,0,0,0,0,115,110,100,45,115,100,108,58,32,101,114,114,111,114,32,105,110,105,116,105,97,108,105,122,105,110,103,32,97,117,100,105,111,32,115,117,98,115,121,115,116,101,109,32,40,37,115,41,10,0,0,0,0,0,0,0,119,97,118,102,105,108,116,101,114,0,0,0,0,0,0,0,99,120,0,0,0,0,0,0,69,83,58,0,0,0,0,0,101,109,117,46,114,101,115,101,116,0,0,0,0,0,0,0,112,99,101,45,105,98,109,112,99,58,32,115,105,103,105,110,116,10,0,0,0,0,0,0,112,0,0,0,0,0,0,0,116,101,114,109,46,102,117,108,108,115,99,114,101,101,110,46,116,111,103,103,108,101,0,0,53,0,0,0,0,0,0,0,83,99,114,111,108,108,76,111,99,107,0,0,0,0,0,0,62,62,0,0,0,0,0,0,99,97,110,39,116,32,111,112,101,110,32,105,110,99,108,117,100,101,32,102,105,108,101,58,0,0,0,0,0,0,0,0,98,97,115,101,0,0,0,0,69,83,67,0,0,0,0,0,42,42,42,32,108,111,97,100,105,110,103,32,114,111,109,32,102,97,105,108,101,100,32,40,37,115,41,10,0,0,0,0,115,105,122,101,103,0,0,0,120,109,115,0,0,0,0,0,82,84,83,0,0,0,0,0,116,99,58,32,117,110,107,110,111,119,110,32,109,97,114,107,32,48,120,37,48,50,120,32,40,37,115,44,32,99,61,37,117,44,32,104,61,37,117,44,32,98,105,116,61,37,108,117,47,37,108,117,41,10,0,0,93,10,0,0,0,0,0,0,116,101,114,109,46,116,105,116,108,101,0,0,0,0,0,0,80,85,83,72,65,0,0,0,99,97,115,115,101,116,116,101,32,69,79,70,32,97,116,32,37,108,117,10,0,0,0,0,112,102,100,99,58,32,99,114,99,32,101,114,114,111,114,10,0,0,0,0,0,0,0,0,77,68,65,58,32,79,70,83,61,37,48,52,88,32,32,80,79,83,61,37,48,52,88,10,0,0,0,0,0,0,0,0,82,69,71,58,32,67,82,84,67,61,37,48,50,88,32,32,77,79,68,69,61,37,48,50,88,32,32,83,84,65,84,85,83,61,37,48,50,88,32,32,67,79,78,70,61,37,48,50,88,10,0,0,0,0,0,0,37,115,61,91,37,48,50,88,0,0,0,0,0,0,0,0,112,102,100,99,58,32,119,97,114,110,105,110,103,58,32,108,111,97,100,105,110,103,32,100,101,112,114,101,99,97,116,101,100,32,118,101,114,115,105,111,110,32,50,32,102,105,108,101,10,0,0,0,0,0,0,0,82,69,71,58,32,77,79,68,69,61,37,48,50,88,32,32,67,83,69,76,61,37,48,50,88,32,32,83,84,65,84,85,83,61,37,48,50,88,32,32,80,65,76,61,91,37,48,50,88,32,37,48,50,88,32,37,48,50,88,32,37,48,50,88,93,10,0,0,0,0,0,0,80,79,80,65,0,0,0,0,112,102,100,99,58,32,119,97,114,110,105,110,103,58,32,108,111,97,100,105,110,103,32,100,101,112,114,101,99,97,116,101,100,32,118,101,114,115,105,111,110,32,49,32,102,105,108,101,10,0,0,0,0,0,0,0,66,79,85,78,68,0,0,0,112,102,100,99,58,32,119,97,114,110,105,110,103,58,32,108,111,97,100,105,110,103,32,100,101,112,114,101,99,97,116,101,100,32,118,101,114,115,105,111,110,32,48,32,102,105,108,101,10,0,0,0,0,0,0,0,105,110,116,49,53,58,32,99,111,112,121,32,37,48,56,120,32,45,62,32,37,48,56,120,44,32,37,48,52,120,10,0,68,66,0,0,0,0,0,0,117,109,98,95,115,105,122,101,0,0,0,0,0,0,0,0,101,120,112,101,99,116,105,110,103,32,98,111,111,116,32,100,114,105,118,101,0,0,0,0,80,67,69,72,0,0,0,0,97,120,0,0,0,0,0,0,98,111,111,116,32,100,114,105,118,101,32,105,115,32,48,120,37,48,50,120,10,0,0,0,73,78,83,66,0,0,0,0,69,120,116,114,97,49,54,0,101,120,112,101,99,116,105,110,103,32,111,102,102,115,101,116,0,0,0,0,0,0,0,0,73,78,83,87,0,0,0,0,99,112,50,58,32,37,117,47,37,117,47,37,117,58,32,115,101,99,116,111,114,32,100,97,116,97,32,116,111,111,32,98,105,103,32,40,37,117,41,10,0,0,0,0,0,0,0,0,69,120,116,114,97,49,53,0,101,109,117,46,112,97,117,115,101,46,116,111,103,103,108,101,0,0,0,0,0,0,0,0,58,0,0,0,0,0,0,0,79,85,84,83,66,0,0,0,112,99,101,45,105,98,109,112,99,58,32,115,105,103,116,101,114,109,10,0,0,0,0,0,69,120,116,114,97,49,52,0,112,113,0,0,0,0,0,0,101,109,117,46,99,111,110,102,105,103,46,115,97,118,101,32,32,32,32,32,32,60,102,105,108,101,110,97,109,101,62,10,101,109,117,46,101,120,105,116,10,101,109,117,46,115,116,111,112,10,101,109,117,46,112,97,117,115,101,32,32,32,32,32,32,32,32,32,32,32,32,34,48,34,32,124,32,34,49,34,10,101,109,117,46,112,97,117,115,101,46,116,111,103,103,108,101,10,101,109,117,46,114,101,115,101,116,10,10,101,109,117,46,99,112,117,46,109,111,100,101,108,32,32,32,32,32,32,32,32,34,56,48,56,54,34,32,124,32,34,56,48,56,56,34,32,124,32,34,56,48,49,56,54,34,32,124,32,34,56,48,49,56,56,34,10,101,109,117,46,99,112,117,46,115,112,101,101,100,32,32,32,32,32,32,32,32,60,102,97,99,116,111,114,62,10,101,109,117,46,99,112,117,46,115,112,101,101,100,46,115,116,101,112,32,32,32,60,97,100,106,117,115,116,109,101,110,116,62,10,10,101,109,117,46,100,105,115,107,46,98,111,111,116,32,32,32,32,32,32,32,32,60,98,111,111,116,100,114,105,118,101,62,10,101,109,117,46,100,105,115,107,46,99,111,109,109,105,116,32,32,32,32,32,32,91,60,100,114,105,118,101,62,93,10,101,109,117,46,100,105,115,107,46,101,106,101,99,116,32,32,32,32,32,32,32,60,100,114,105,118,101,62,10,101,109,117,46,100,105,115,107,46,105,110,115,101,114,116,32,32,32,32,32,32,60,100,114,105,118,101,62,58,60,102,110,97,109,101,62,10,10,101,109,117,46,102,100,99,46,97,99,99,117,114,97,116,101,32,32,32,32,32,34,48,34,32,124,32,34,49,34,10,10,101,109,117,46,112,97,114,112,111,114,116,46,100,114,105,118,101,114,32,32,32,60,100,114,105,118,101,114,62,10,101,109,117,46,112,97,114,112,111,114,116,46,102,105,108,101,32,32,32,32,32,60,102,105,108,101,110,97,109,101,62,10,10,101,109,117,46,115,101,114,112,111,114,116,46,100,114,105,118,101,114,32,32,32,60,100,114,105,118,101,114,62,10,101,109,117,46,115,101,114,112,111,114,116,46,102,105,108,101,32,32,32,32,32,60,102,105,108,101,110,97,109,101,62,10,10,101,109,117,46,116,97,112,101,46,97,112,112,101,110,100,10,101,109,117,46,116,97,112,101,46,102,105,108,101,32,32,32,32,32,32,32,32,60,102,105,108,101,110,97,109,101,62,10,101,109,117,46,116,97,112,101,46,108,111,97,100,32,32,32,32,32,32,32,32,91,60,112,111,115,105,116,105,111,110,62,32,124,32,34,101,110,100,34,93,10,101,109,117,46,116,97,112,101,46,114,101,119,105,110,100,10,101,109,117,46,116,97,112,101,46,115,97,118,101,32,32,32,32,32,32,32,32,91,60,112,111,115,105,116,105,111,110,62,32,124,32,34,101,110,100,34,93,10,101,109,117,46,116,97,112,101,46,115,116,97,116,101,10,10,101,109,117,46,116,101,114,109,46,102,117,108,108,115,99,114,101,101,110,32,32,34,48,34,32,124,32,34,49,34,10,101,109,117,46,116,101,114,109,46,102,117,108,108,115,99,114,101,101,110,46,116,111,103,103,108,101,10,101,109,117,46,116,101,114,109,46,103,114,97,98,10,101,109,117,46,116,101,114,109,46,114,101,108,101,97,115,101,10,101,109,117,46,116,101,114,109,46,115,99,114,101,101,110,115,104,111,116,32,32,91,60,102,105,108,101,110,97,109,101,62,93,10,101,109,117,46,116,101,114,109,46,116,105,116,108,101,32,32,32,32,32,32,32,60,116,105,116,108,101,62,10,10,101,109,117,46,118,105,100,101,111,46,98,108,105,110,107,32,32,32,32,32,32,60,98,108,105,110,107,45,114,97,116,101,62,10,101,109,117,46,118,105,100,101,111,46,114,101,100,114,97,119,32,32,32,32,32,91,34,110,111,119,34,93,10,0,0,0,0,79,85,84,83,87,0,0,0,116,101,114,109,46,115,101,116,95,98,111,114,100,101,114,95,121,0,0,0,0,0,0,0,52,0,0,0,0,0,0,0,69,120,116,114,97,49,51,0,80,114,116,83,99,110,0,0,60,60,0,0,0,0,0,0,37,48,52,88,58,32,37,48,50,88,10,0,0,0,0,0,105,110,99,108,117,100,101,0,97,100,100,114,101,115,115,0,100,114,105,118,101,114,61,37,115,32,69,83,67,61,37,115,32,97,115,112,101,99,116,61,37,117,47,37,117,32,109,105,110,95,115,105,122,101,61,37,117,42,37,117,32,115,99,97,108,101,61,37,117,32,109,111,117,115,101,61,91,37,117,47,37,117,32,37,117,47,37,117,93,10,0,0,0,0,0,0,82,79,77,58,0,0,0,0,115,105,122,101,109,0,0,0,104,111,115,116,32,115,121,115,116,101,109,32,116,111,111,32,115,108,111,119,44,32,115,107,105,112,112,105,110,103,32,49,32,115,101,99,111,110,100,46,10,0,0,0,0,0,0,0,74,71,0,0,0,0,0,0,68,84,82,0,0,0,0,0,69,120,116,114,97,49,50,0,37,48,50,88,0,0,0,0,37,48,52,88,58,32,37,48,52,88,10,0,0,0,0,0,101,109,117,46,99,111,110,102,105,103,46,115,97,118,101,0,74,76,69,0,0,0,0,0,69,120,116,114,97,49,49,0,45,0,0,0,0,0,0,0,108,111,97,100,0,0,0,0,68,69,86,58,32,77,68,65,10,0,0,0,0,0,0,0,67,76,75,58,32,67,76,75,61,37,108,117,32,32,72,84,61,37,108,117,32,72,68,61,37,108,117,32,32,86,84,61,37,108,117,32,86,68,61,37,108,117,10,0,0,0,0,0,74,71,69,0,0,0,0,0,71,82,67,0,0,0,0,0,69,120,116,114,97,49,48,0,67,76,75,58,32,67,76,75,61,37,108,117,32,32,72,84,61,37,108,117,32,72,68,61,37,108,117,32,32,86,84,61,37,108,117,32,86,68,61,37,108,117,10,0,0,0,0,0,43,0,0,0,0,0,0,0,74,76,0,0,0,0,0,0,42,42,42,32,117,110,107,110,111,119,110,32,109,111,100,101,108,32,40,37,115,41,10,0,69,120,116,114,97,57,0,0,107,101,121,58,32,37,115,37,115,10,0,0,0,0,0,0,102,105,108,101,0,0,0,0,74,80,79,0,0,0,0,0,109,50,52,0,0,0,0,0,69,120,116,114,97,56,0,0,115,121,109,108,105,110,107,0,117,110,107,110,111,119,110,32,107,101,121,58,32,37,115,10,0,0,0,0,0,0,0,0,74,80,69,0,0,0,0,0,98,104,0,0,0,0,0,0,102,105,108,101,0,0,0,0,53,49,54,48,0,0,0,0,69,120,116,114,97,55,0,0,37,48,50,88,58,32,37,115,10,0,0,0,0,0,0,0,74,78,83,0,0,0,0,0,109,111,100,101,108,61,37,115,32,102,108,111,112,112,105,101,115,61,37,117,32,112,97,116,99,104,45,105,110,105,116,61,37,100,32,112,97,116,99,104,45,105,110,116,49,57,61,37,100,10,0,0,0,0,0,0,69,120,116,114,97,54,0,0,60,98,97,100,62,0,0,0,115,121,115,116,101,109,46,98,111,111,116,32,61,32,0,0,110,101,101,100,32,97,110,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,0,0,74,83,0,0,0,0,0,0,83,89,83,84,69,77,58,0,69,120,116,114,97,53,0,0,101,109,117,46,112,97,117,115,101,0,0,0,0,0,0,0,37,48,50,88,58,32,60,100,101,108,101,116,101,100,62,10,0,0,0,0,0,0,0,0,74,65,0,0,0,0,0,0,112,99,101,45,105,98,109,112,99,58,32,115,101,103,109,101,110,116,97,116,105,111,110,32,102,97,117,108,116,10,0,0,109,101,109,116,101,115,116,0,69,120,116,114,97,52,0,0,115,119,105,116,99,104,101,115,48,0,0,0,0,0,0,0,110,101,101,100,32,97,110,32,105,110,116,101,114,114,117,112,116,32,110,117,109,98,101,114,0,0,0,0,0,0,0,0,111,0,0,0,0,0,0,0,74,66,69,0,0,0,0,0,116,101,114,109,46,115,101,116,95,98,111,114,100,101,114,95,120,0,0,0,0,0,0,0,51,0,0,0,0,0,0,0,112,97,116,99,104,95,98,105,111,115,95,105,110,116,49,57,0,0,0,0,0,0,0,0,69,120,116,114,97,51,0,0,80,114,105,110,116,83,99,114,101,101,110,0,0,0,0,0,62,0,0,0,0,0,0,0,108,0,0,0,0,0,0,0,105,102,0,0,0,0,0,0,121,0,0,0,0,0,0,0,102,105,108,101,0,0,0,0,109,111,117,115,101,0,0,0,84,69,82,77,58,0,0,0,114,111,109,0,0,0,0,0,115,105,122,101,107,0,0,0,115,101,116,116,105,110,103,32,115,112,101,101,100,32,116,111,32,37,117,88,10,0,0,0,74,78,90,0,0,0,0,0,67,84,83,0,0,0,0,0,112,97,116,99,104,95,98,105,111,115,95,105,110,105,116,0,69,120,116,114,97,50,0,0,37,115,61,91,37,48,50,88,0,0,0,0,0,0,0,0,93,10,0,0,0,0,0,0,93,10,0,0,0,0,0,0,117,110,104,97,110,100,108,101,100,32,109,97,103,105,99,32,107,101,121,32,40,37,117,41,10,0,0,0,0,0,0,0,108,111,103,32,119,104,97,116,63,0,0,0,0,0,0,0,112,114,111,116,111,99,111,108,0,0,0,0,0,0,0,0,74,90,0,0,0,0,0,0,114,98,0,0,0,0,0,0,114,116,99,0,0,0,0,0,69,120,116,114,97,49,0,0,105,110,116,0,0,0,0,0,115,97,118,101,0,0,0,0,103,114,97,121,0,0,0,0,72,71,67,58,32,80,65,71,69,61,37,100,32,32,79,70,83,61,37,48,52,88,32,32,80,79,83,61,37,48,52,88,10,0,0,0,0,0,0,0,74,78,67,0,0,0,0,0,114,98,0,0,0,0,0,0,83,69,81,0,0,0,0,0,102,108,111,112,112,121,95,100,105,115,107,95,100,114,105,118,101,115,0,0,0,0,0,0,82,105,103,104,116,0,0,0,67,71,65,58,32,79,70,83,61,37,48,52,88,32,32,80,79,83,61,37,48,52,88,32,32,66,71,61,37,48,50,88,32,32,80,65,76,61,37,117,10,0,0,0,0,0,0,0,110,101,101,100,32,97,32,118,97,108,117,101,0,0,0,0,114,98,0,0,0,0,0,0,74,67,0,0,0,0,0,0,98,111,111,116,0,0,0,0,68,111,119,110,0,0,0,0,110,101,101,100,32,97,32,112,111,114,116,32,97,100,100,114,101,115,115,0,0,0,0,0,68,79,83,69,77,85,0,0,74,78,79,0,0,0,0,0,53,49,53,48,0,0,0,0,76,101,102,116,0,0,0,0,119,0,0,0,0,0,0,0,74,79,0,0,0,0,0,0,100,104,0,0,0,0,0,0,115,121,115,116,101,109,0,0,85,112,0,0,0,0,0,0,80,81,58,0,0,0,0,0,67,77,80,0,0,0,0,0,42,42,42,32,108,111,97,100,105,110,103,32,110,118,114,97,109,32,102,97,105,108,101,100,32,40,37,115,41,10,0,0,80,97,103,101,68,111,119,110,0,0,0,0,0,0,0,0,91,37,115,37,115,37,99,37,48,52,88,93,0,0,0,0,112,113,58,32,117,110,107,110,111,119,110,32,99,111,109,109,97,110,100,32,40,37,115,41,10,0,0,0,0,0,0,0,120,109,115,58,32,117,110,107,110,111,119,110,32,102,117,110,99,116,105,111,110,32,40,37,120,41,10,0,0,0,0,0,88,79,82,0,0,0,0,0,42,42,42,32,99,114,101,97,116,105,110,103,32,110,118,114,97,109,32,102,97,105,108,101,100,10,0,0,0,0,0,0,69,110,100,0,0,0,0,0,101,109,117,46,112,97,114,112,111,114,116,46,102,105,108,101,0,0,0,0,0,0,0,0,102,0,0,0,0,0,0,0,83,85,66,0,0,0,0,0,105,110,116,118,0,0,0,0,98,111,114,100,101,114,0,0,99,111,109,109,105,116,0,0,60,62,0,0,0,0,0,0,68,101,108,101,116,101,0,0,109,105,115,115,105,110,103,32,118,97,108,117,101,10,0,0,119,98,0,0,0,0,0,0,108,111,103,0,0,0,0,0,65,78,68,0,0,0,0,0,116,101,114,109,46,116,105,116,108,101,0,0,0,0,0,0,50,0,0,0,0,0,0,0,97,100,100,114,61,48,120,37,48,56,108,120,32,115,105,122,101,61,37,108,117,32,102,105,108,101,61,37,115,10,0,0,80,97,103,101,85,112,0,0,70,49,50,0,0,0,0,0,60,0,0,0,0,0,0,0,37,48,52,108,88,10,0,0,61,0,0,0,0,0,0,0,118,0,0,0,0,0,0,0,102,111,114,109,97,116,0,0,109,111,117,115,101,95,100,105,118,95,121,0,0,0,0,0,42,42,42,32,108,111,97,100,105,110,103,32,114,97,109,32,102,97,105,108,101,100,32,40,37,115,41,10,0,0,0,0,115,105,122,101,0,0,0,0,114,98,0,0,0,0,0,0,67,80,85,58,0,0,0,0,65,32,32,37,48,56,108,88,32,32,37,48,52,88,32,32,37,48,52,88,10,0,0,0,83,66,66,0,0,0,0,0,82,101,108,101,97,115,101,32,54,46,48,10,36,48,0,0,119,98,0,0,0,0,0,0,70,49,0,0,0,0,0,0,45,45,32,37,108,117,32,37,117,37,115,37,117,10,0,0,78,86,82,65,77,58,0,0,114,43,98,0,0,0,0,0,72,111,109,101,0,0,0,0,119,43,98,0,0,0,0,0,71,82,67,0,0,0,0,0,37,48,50,88,0,0,0,0,37,48,50,88,0,0,0,0,98,97,100,32,114,101,103,105,115,116,101,114,32,40,37,115,41,10,0,0,0,0,0,0,58,0,0,0,0,0,0,0,119,98,0,0,0,0,0,0,65,68,67,0,0,0,0,0,115,105,122,101,0,0,0,0,73,110,115,101,114,116,0,0,109,105,115,115,105,110,103,32,114,101,103,105,115,116,101,114,10,0,0,0,0,0,0,0,99,97,115,115,101,116,116,101,32,37,115,32,37,115,32,97,116,32,37,108,117,32,40,37,115,41,10,0,0,0,0,0,114,98,0,0,0,0,0,0,97,109,98,101,114,0,0,0,68,69,86,58,32,72,101,114,99,117,108,101,115,32,71,114,97,112,104,105,99,115,32,67,97,114,100,10,0,0,0,0,79,82,0,0,0,0,0,0,112,97,116,104,0,0,0,0,102,97,108,115,101,0,0,0,65,84,67,0,0,0,0,0,98,97,115,101,0,0,0,0,75,80,95,80,101,114,105,111,100,0,0,0,0,0,0,0,68,69,86,58,32,67,71,65,10,0,0,0,0,0,0,0,67,80,73,61,37,46,52,102,10,0,0,0,0,0,0,0,65,68,68,0,0,0,0,0,114,43,98,0,0,0,0,0,110,118,114,97,109,0,0,0,75,80,95,48,0,0,0,0,76,111,97,100,58,0,0,0,79,80,83,61,37,108,108,117,10,0,0,0,0,0,0,0,100,114,105,118,101,114,0,0,45,37,48,50,88,0,0,0,102,105,108,101,0,0,0,0,67,76,75,61,37,108,108,117,32,43,32,37,108,117,10,0,42,42,42,32,117,110,107,110,111,119,110,32,99,112,117,32,109,111,100,101,108,32,40,37,115,41,10,0,0,0,0,0,75,80,95,69,110,116,101,114,0,0,0,0,0,0,0,0,68,73,83,75,58,0,0,0,65,88,61,37,48,52,88,32,32,66,88,61,37,48,52,88,32,32,67,88,61,37,48,52,88,32,32,68,88,61,37,48,52,88,32,32,83,80,61,37,48,52,88,32,32,66,80,61,37,48,52,88,32,32,83,73,61,37,48,52,88,32,32,68,73,61,37,48,52,88,32,73,78,84,61,37,48,50,88,37,99,10,0,0,0,0,0,0,43,37,48,50,88,0,0,0,99,104,0,0,0,0,0,0,109,111,100,101,108,61,37,115,32,115,112,101,101,100,61,37,117,88,10,0,0,0,0,0,75,80,95,51,0,0,0,0,108,0,0,0,0,0,0,0,116,114,117,101,0,0,0,0,84,73,77,69,0,0,0,0,119,98,0,0,0,0,0,0,115,110,100,45,115,100,108,58,32,101,114,114,111,114,32,111,112,101,110,105,110,103,32,111,117,116,112,117,116,32,40,37,115,41,10,0,0,0,0,0,108,111,119,112,97,115,115,0,115,112,101,101,100,0,0,0,75,80,95,50,0,0,0,0,112,99,101,45,105,98,109,112,99,0,0,0,0,0,0,0,116,100,48,58,32,97,100,118,97,110,99,101,100,32,99,111,109,112,114,101,115,115,105,111,110,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,0,102,109,0,0,0,0,0,0,91,37,115,37,115,37,99,37,48,50,88,93,0,0,0,0,112,102,100,99,58,32,111,114,112,104,97,110,101,100,32,97,108,116,101,114,110,97,116,101,32,115,101,99,116,111,114,10,0,0,0,0,0,0,0,0,79,76,48,0,0,0,0,0,112,99,101,58,32,104,111,111,107,32,91,37,48,50,120,32,37,48,50,120,93,32,65,88,61,37,48,52,88,32,66,88,61,37,48,52,88,32,67,88,61,37,48,52,88,32,68,88,61,37,48,52,88,10,0,0,32,32,37,117,58,32,48,120,37,48,52,120,58,48,120,48,48,48,48,32,43,32,48,120,37,48,53,120,32,32,97,108,108,111,99,61,37,100,10,0,73,77,68,32,49,46,49,55,58,32,37,50,100,47,37,50,100,47,37,52,100,32,37,48,50,100,58,37,48,50,100,58,37,48,50,100,0,0,0,0,6,78,111,110,97,109,101,0,68,83,0,0,0,0,0,0,99,112,50,58,32,37,117,47,37,117,47,37,117,58,0,0,109,111,100,101,108,0,0,0,75,80,95,49,0,0,0,0,101,109,117,46,112,97,114,112,111,114,116,46,100,114,105,118,101,114,0,0,0,0,0,0,111,108,48,0,0,0,0,0,46,97,110,97,0,0,0,0,102,108,117,115,104,0,0,0,42,42,42,32,101,114,114,111,114,32,99,114,101,97,116,105,110,103,32,115,121,109,108,105,110,107,32,37,115,32,45,62,32,37,115,10,0,0,0,0,114,101,97,100,0,0,0,0,83,83,0,0,0,0,0,0,99,112,117,0,0,0,0,0,75,80,95,54,0,0,0,0,110,117,108,108,0,0,0,0,109,105,99,114,111,115,111,102,116,0,0,0,0,0,0,0,114,43,98,0,0,0,0,0,79,76,49,0,0,0,0,0,114,43,98,0,0,0,0,0,114,43,98,0,0,0,0,0,114,98,0,0,0,0,0,0,66,76,75,32,37,48,52,88,58,32,65,49,61,37,48,56,108,88,32,65,50,61,37,48,56,108,88,32,83,61,37,48,56,108,88,32,82,79,61,37,100,10,0,0,0,0,0,0,107,101,121,0,0,0,0,0,67,83,0,0,0,0,0,0,116,101,114,109,46,114,101,108,101,97,115,101,0,0,0,0,101,109,117,46,99,112,117,46,115,112,101,101,100,0,0,0,42,42,42,32,97,108,108,111,99,97,116,105,110,103,32,68,77,65,67,32,102,97,105,108,101,100,10,0,0,0,0,0,75,80,95,53,0,0,0,0,114,43,98,0,0,0,0,0,70,49,49,0,0,0,0,0,62,61,0,0,0,0,0,0,111,108,49,0,0,0,0,0,63,61,0,0,0,0,0,0,113,0,0,0,0,0,0,0,119,43,98,0,0,0,0,0,108,111,97,100,0,0,0,0,109,111,117,115,101,95,109,117,108,95,121,0,0,0,0,0,42,42,42,32,109,101,109,111,114,121,32,98,108,111,99,107,32,99,114,101,97,116,105,111,110,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,98,108,111,99,107,115,0,0,83,32,32,37,48,52,88,58,37,48,52,108,88,32,32,37,48,52,88,32,32,37,48,52,88,10,0,0,0,0,0,0,56,48,50,56,54,0,0,0,69,83,0,0,0,0,0,0,116,100,48,58,32,99,111,109,109,101,110,116,32,99,114,99,32,40,37,48,52,88,32,37,48,52,88,41,10,0,0,0,82,101,108,101,97,115,101,32,53,46,48,49,36,48,0,0,114,98,0,0,0,0,0,0,63,0,0,0,0,0,0,0,68,77,65,67,58,0,0,0,75,80,95,52,0,0,0,0,67,82,84,67,61,91,37,48,50,88,0,0,0,0,0,0,83,69,81,0,0,0,0,0,67,82,48,0,0,0,0,0,72,68,67,58,32,67,77,68,61,37,48,50,88,32,68,61,42,32,32,117,110,107,110,111,119,110,32,99,111,109,109,97,110,100,32,91,37,48,50,88,32,37,48,50,88,32,37,48,50,88,32,37,48,50,88,32,37,48,50,88,32,37,48,50,88,93,10,0,0,0,0,0,97,100,100,114,101,115,115,0,100,109,97,99,0,0,0,0,97,100,100,114,101,115,115,0,75,80,95,80,108,117,115,0,97,100,100,114,101,115,115,0,99,114,48,0,0,0,0,0,99,97,115,0,0,0,0,0,99,111,108,111,114,95,98,114,105,103,104,116,0,0,0,0,103,114,97,121,0,0,0,0,67,82,84,0,0,0,0,0,80,73,67,58,0,0,0,0,75,80,95,57,0,0,0,0,114,98,0,0,0,0,0,0,72,68,67,58,32,117,110,107,110,111,119,110,32,114,101,97,100,58,32,37,48,52,108,88,10,0,0,0,0,0,0,0,67,82,49,0,0,0,0,0,88,67,72,71,0,0,0,0,112,105,99,0,0,0,0,0,75,80,95,56,0,0,0,0,99,114,49,0,0,0,0,0,102,100,99,0,0,0,0,0,97,100,100,114,61,48,120,37,48,56,108,120,32,115,105,122,101,61,48,120,37,48,52,120])
.concat([10,0,0,0,0,0,0,0,75,80,95,55,0,0,0,0,67,37,100,58,32,83,82,61,37,48,50,88,32,77,61,37,117,32,82,87,61,37,100,32,32,67,69,61,37,48,52,88,32,32,37,115,61,37,48,50,88,32,37,115,61,37,48,50,88,32,32,37,115,61,37,48,50,88,32,37,115,61,37,48,50,88,32,32,71,61,37,117,32,79,61,37,117,32,82,61,37,100,10,0,0,0,0,0,101,109,115,58,32,117,110,107,110,111,119,110,32,115,117,98,102,117,110,99,116,105,111,110,58,32,65,88,61,37,48,52,88,10,0,0,0,0,0,0,97,104,0,0,0,0,0,0,80,73,84,58,0,0,0,0,75,80,95,77,105,110,117,115,0,0,0,0,0,0,0,0,105,111,0,0,0,0,0,0,56,50,53,51,45,80,73,84,0,0,0,0,0,0,0,0,87,65,73,84,0,0,0,0,112,105,116,0,0,0,0,0,75,80,95,83,116,97,114,0,91,37,115,37,115,93,0,0,32,32,67,72,61,73,91,37,88,93,32,32,67,76,61,79,91,37,88,93,0,0,0,0,85,77,66,58,32,98,108,107,61,37,117,32,117,115,101,100,61,37,108,117,32,109,97,120,61,37,108,117,10,0,0,0,80,85,83,72,70,0,0,0,101,109,117,46,118,105,100,101,111,46,114,101,100,114,97,119,0,0,0,0,0,0,0,0,97,100,100,114,61,48,120,37,48,56,120,32,115,105,122,101,61,48,120,37,48,52,120,10,0,0,0,0,0,0,0,0,75,80,95,83,108,97,115,104,0,0,0,0,0,0,0,0,101,109,117,46,102,100,99,46,97,99,99,117,114,97,116,101,0,0,0,0,0,0,0,0,32,32,67,72,61,79,91,37,88,93,32,32,67,76,61,73,91,37,88,93,0,0,0,0,112,99,0,0,0,0,0,0,80,79,80,70,0,0,0,0,80,80,73,58,0,0,0,0,78,117,109,76,111,99,107,0,32,32,67,61,79,91,37,48,50,88,93,0,0,0,0,0,105,0,0,0,0,0,0,0,83,65,72,70,0,0,0,0,116,101,114,109,46,103,114,97,98,0,0,0,0,0,0,0,49,0,0,0,0,0,0,0,112,112,105,0,0,0,0,0,67,116,114,108,82,105,103,104,116,0,0,0,0,0,0,0,105,111,0,0,0,0,0,0,70,49,48,0,0,0,0,0,60,61,0,0,0,0,0,0,32,32,67,61,73,91,37,48,50,88,93,0,0,0,0,0,125,0,0,0,0,0,0,0,109,0,0,0,0,0,0,0,98,105,110,97,114,121,0,0,109,111,117,115,101,95,100,105,118,95,120,0,0,0,0,0,60,110,111,110,101,62,0,0,115,0,0,0,0,0,0,0,32,37,115,0,0,0,0,0,69,32,32,34,37,115,34,10,0,0,0,0,0,0,0,0,118,50,48,0,0,0,0,0,76,65,72,70,0,0,0,0,116,100,48,58,32,114,101,97,100,32,101,114,114,111,114,10,0,0,0,0,0,0,0,0,82,101,108,101,97,115,101,32,52,46,48,48,36,48,0,0,46,120,100,102,0,0,0,0,69,0,0,0,0,0,0,0,42,42,42,32,117,110,107,110,111,119,110,32,99,97,115,115,101,116,116,101,32,109,111,100,101,32,40,37,115,41,10,0,77,101,110,117,0,0,0,0,82,69,71,58,32,67,84,76,61,37,48,50,88,32,32,66,65,78,75,32,79,70,83,61,37,48,50,88,32,32,66,65,78,75,32,66,65,83,61,37,48,50,88,10,0,0,0,0,65,84,67,0,0,0,0,0,32,32,66,61,79,91,37,48,50,88,93,0,0,0,0,0,105,111,0,0,0,0,0,0,77,79,86,83,66,0,0,0,115,97,118,101,0,0,0,0,87,105,110,100,111,119,115,82,105,103,104,116,0,0,0,0,32,32,66,61,73,91,37,48,50,88,93,0,0,0,0,0,112,99,109,47,114,0,0,0,119,43,98,0,0,0,0,0,114,43,98,0,0,0,0,0])
, "i8", ALLOC_NONE, Runtime.GLOBAL_BASE)
var tempDoublePtr = Runtime.alignMemory(allocate(12, "i8", ALLOC_STATIC), 8);
assert(tempDoublePtr % 8 == 0);
function copyTempFloat(ptr) { // functions, because inlining this code increases code size too much
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
}
function copyTempDouble(ptr) {
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];
  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];
  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];
  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];
}
  var ERRNO_CODES={EPERM:1,ENOENT:2,ESRCH:3,EINTR:4,EIO:5,ENXIO:6,E2BIG:7,ENOEXEC:8,EBADF:9,ECHILD:10,EAGAIN:11,EWOULDBLOCK:11,ENOMEM:12,EACCES:13,EFAULT:14,ENOTBLK:15,EBUSY:16,EEXIST:17,EXDEV:18,ENODEV:19,ENOTDIR:20,EISDIR:21,EINVAL:22,ENFILE:23,EMFILE:24,ENOTTY:25,ETXTBSY:26,EFBIG:27,ENOSPC:28,ESPIPE:29,EROFS:30,EMLINK:31,EPIPE:32,EDOM:33,ERANGE:34,ENOMSG:35,EIDRM:36,ECHRNG:37,EL2NSYNC:38,EL3HLT:39,EL3RST:40,ELNRNG:41,EUNATCH:42,ENOCSI:43,EL2HLT:44,EDEADLK:45,ENOLCK:46,EBADE:50,EBADR:51,EXFULL:52,ENOANO:53,EBADRQC:54,EBADSLT:55,EDEADLOCK:56,EBFONT:57,ENOSTR:60,ENODATA:61,ETIME:62,ENOSR:63,ENONET:64,ENOPKG:65,EREMOTE:66,ENOLINK:67,EADV:68,ESRMNT:69,ECOMM:70,EPROTO:71,EMULTIHOP:74,ELBIN:75,EDOTDOT:76,EBADMSG:77,EFTYPE:79,ENOTUNIQ:80,EBADFD:81,EREMCHG:82,ELIBACC:83,ELIBBAD:84,ELIBSCN:85,ELIBMAX:86,ELIBEXEC:87,ENOSYS:88,ENMFILE:89,ENOTEMPTY:90,ENAMETOOLONG:91,ELOOP:92,EOPNOTSUPP:95,EPFNOSUPPORT:96,ECONNRESET:104,ENOBUFS:105,EAFNOSUPPORT:106,EPROTOTYPE:107,ENOTSOCK:108,ENOPROTOOPT:109,ESHUTDOWN:110,ECONNREFUSED:111,EADDRINUSE:112,ECONNABORTED:113,ENETUNREACH:114,ENETDOWN:115,ETIMEDOUT:116,EHOSTDOWN:117,EHOSTUNREACH:118,EINPROGRESS:119,EALREADY:120,EDESTADDRREQ:121,EMSGSIZE:122,EPROTONOSUPPORT:123,ESOCKTNOSUPPORT:124,EADDRNOTAVAIL:125,ENETRESET:126,EISCONN:127,ENOTCONN:128,ETOOMANYREFS:129,EPROCLIM:130,EUSERS:131,EDQUOT:132,ESTALE:133,ENOTSUP:134,ENOMEDIUM:135,ENOSHARE:136,ECASECLASH:137,EILSEQ:138,EOVERFLOW:139,ECANCELED:140,ENOTRECOVERABLE:141,EOWNERDEAD:142,ESTRPIPE:143};
  var ___errno_state=0;function ___setErrNo(value) {
      // For convenient setting and returning of errno.
      HEAP32[((___errno_state)>>2)]=value
      return value;
    }
  var _stdin=allocate(1, "i32*", ALLOC_STATIC);
  var _stdout=allocate(1, "i32*", ALLOC_STATIC);
  var _stderr=allocate(1, "i32*", ALLOC_STATIC);
  var __impure_ptr=allocate(1, "i32*", ALLOC_STATIC);var FS={currentPath:"/",nextInode:2,streams:[null],ignorePermissions:true,createFileHandle:function (stream, fd) {
        if (typeof stream === 'undefined') {
          stream = null;
        }
        if (!fd) {
          if (stream && stream.socket) {
            for (var i = 1; i < 64; i++) {
              if (!FS.streams[i]) {
                fd = i;
                break;
              }
            }
            assert(fd, 'ran out of low fds for sockets');
          } else {
            fd = Math.max(FS.streams.length, 64);
            for (var i = FS.streams.length; i < fd; i++) {
              FS.streams[i] = null; // Keep dense
            }
          }
        }
        // Close WebSocket first if we are about to replace the fd (i.e. dup2)
        if (FS.streams[fd] && FS.streams[fd].socket && FS.streams[fd].socket.close) {
          FS.streams[fd].socket.close();
        }
        FS.streams[fd] = stream;
        return fd;
      },removeFileHandle:function (fd) {
        FS.streams[fd] = null;
      },joinPath:function (parts, forceRelative) {
        var ret = parts[0];
        for (var i = 1; i < parts.length; i++) {
          if (ret[ret.length-1] != '/') ret += '/';
          ret += parts[i];
        }
        if (forceRelative && ret[0] == '/') ret = ret.substr(1);
        return ret;
      },absolutePath:function (relative, base) {
        if (typeof relative !== 'string') return null;
        if (base === undefined) base = FS.currentPath;
        if (relative && relative[0] == '/') base = '';
        var full = base + '/' + relative;
        var parts = full.split('/').reverse();
        var absolute = [''];
        while (parts.length) {
          var part = parts.pop();
          if (part == '' || part == '.') {
            // Nothing.
          } else if (part == '..') {
            if (absolute.length > 1) absolute.pop();
          } else {
            absolute.push(part);
          }
        }
        return absolute.length == 1 ? '/' : absolute.join('/');
      },analyzePath:function (path, dontResolveLastLink, linksVisited) {
        var ret = {
          isRoot: false,
          exists: false,
          error: 0,
          name: null,
          path: null,
          object: null,
          parentExists: false,
          parentPath: null,
          parentObject: null
        };
        path = FS.absolutePath(path);
        if (path == '/') {
          ret.isRoot = true;
          ret.exists = ret.parentExists = true;
          ret.name = '/';
          ret.path = ret.parentPath = '/';
          ret.object = ret.parentObject = FS.root;
        } else if (path !== null) {
          linksVisited = linksVisited || 0;
          path = path.slice(1).split('/');
          var current = FS.root;
          var traversed = [''];
          while (path.length) {
            if (path.length == 1 && current.isFolder) {
              ret.parentExists = true;
              ret.parentPath = traversed.length == 1 ? '/' : traversed.join('/');
              ret.parentObject = current;
              ret.name = path[0];
            }
            var target = path.shift();
            if (!current.isFolder) {
              ret.error = ERRNO_CODES.ENOTDIR;
              break;
            } else if (!current.read) {
              ret.error = ERRNO_CODES.EACCES;
              break;
            } else if (!current.contents.hasOwnProperty(target)) {
              ret.error = ERRNO_CODES.ENOENT;
              break;
            }
            current = current.contents[target];
            if (current.link && !(dontResolveLastLink && path.length == 0)) {
              if (linksVisited > 40) { // Usual Linux SYMLOOP_MAX.
                ret.error = ERRNO_CODES.ELOOP;
                break;
              }
              var link = FS.absolutePath(current.link, traversed.join('/'));
              ret = FS.analyzePath([link].concat(path).join('/'),
                                   dontResolveLastLink, linksVisited + 1);
              return ret;
            }
            traversed.push(target);
            if (path.length == 0) {
              ret.exists = true;
              ret.path = traversed.join('/');
              ret.object = current;
            }
          }
        }
        return ret;
      },findObject:function (path, dontResolveLastLink) {
        FS.ensureRoot();
        var ret = FS.analyzePath(path, dontResolveLastLink);
        if (ret.exists) {
          return ret.object;
        } else {
          ___setErrNo(ret.error);
          return null;
        }
      },createObject:function (parent, name, properties, canRead, canWrite) {
        if (!parent) parent = '/';
        if (typeof parent === 'string') parent = FS.findObject(parent);
        if (!parent) {
          ___setErrNo(ERRNO_CODES.EACCES);
          throw new Error('Parent path must exist.');
        }
        if (!parent.isFolder) {
          ___setErrNo(ERRNO_CODES.ENOTDIR);
          throw new Error('Parent must be a folder.');
        }
        if (!parent.write && !FS.ignorePermissions) {
          ___setErrNo(ERRNO_CODES.EACCES);
          throw new Error('Parent folder must be writeable.');
        }
        if (!name || name == '.' || name == '..') {
          ___setErrNo(ERRNO_CODES.ENOENT);
          throw new Error('Name must not be empty.');
        }
        if (parent.contents.hasOwnProperty(name)) {
          ___setErrNo(ERRNO_CODES.EEXIST);
          throw new Error("Can't overwrite object.");
        }
        parent.contents[name] = {
          read: canRead === undefined ? true : canRead,
          write: canWrite === undefined ? false : canWrite,
          timestamp: Date.now(),
          inodeNumber: FS.nextInode++
        };
        for (var key in properties) {
          if (properties.hasOwnProperty(key)) {
            parent.contents[name][key] = properties[key];
          }
        }
        return parent.contents[name];
      },createFolder:function (parent, name, canRead, canWrite) {
        var properties = {isFolder: true, isDevice: false, contents: {}};
        return FS.createObject(parent, name, properties, canRead, canWrite);
      },createPath:function (parent, path, canRead, canWrite) {
        var current = FS.findObject(parent);
        if (current === null) throw new Error('Invalid parent.');
        path = path.split('/').reverse();
        while (path.length) {
          var part = path.pop();
          if (!part) continue;
          if (!current.contents.hasOwnProperty(part)) {
            FS.createFolder(current, part, canRead, canWrite);
          }
          current = current.contents[part];
        }
        return current;
      },createFile:function (parent, name, properties, canRead, canWrite) {
        properties.isFolder = false;
        return FS.createObject(parent, name, properties, canRead, canWrite);
      },createDataFile:function (parent, name, data, canRead, canWrite) {
        if (typeof data === 'string') {
          var dataArray = new Array(data.length);
          for (var i = 0, len = data.length; i < len; ++i) dataArray[i] = data.charCodeAt(i);
          data = dataArray;
        }
        var properties = {
          isDevice: false,
          contents: data.subarray ? data.subarray(0) : data // as an optimization, create a new array wrapper (not buffer) here, to help JS engines understand this object
        };
        return FS.createFile(parent, name, properties, canRead, canWrite);
      },createLazyFile:function (parent, name, url, canRead, canWrite) {
        if (typeof XMLHttpRequest !== 'undefined') {
          if (!ENVIRONMENT_IS_WORKER) throw 'Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc';
          // Lazy chunked Uint8Array (implements get and length from Uint8Array). Actual getting is abstracted away for eventual reuse.
          var LazyUint8Array = function() {
            this.lengthKnown = false;
            this.chunks = []; // Loaded chunks. Index is the chunk number
          }
          LazyUint8Array.prototype.get = function(idx) {
            if (idx > this.length-1 || idx < 0) {
              return undefined;
            }
            var chunkOffset = idx % this.chunkSize;
            var chunkNum = Math.floor(idx / this.chunkSize);
            return this.getter(chunkNum)[chunkOffset];
          }
          LazyUint8Array.prototype.setDataGetter = function(getter) {
            this.getter = getter;
          }
          LazyUint8Array.prototype.cacheLength = function() {
              // Find length
              var xhr = new XMLHttpRequest();
              xhr.open('HEAD', url, false);
              xhr.send(null);
              if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
              var datalength = Number(xhr.getResponseHeader("Content-length"));
              var header;
              var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
              var chunkSize = 1024*1024; // Chunk size in bytes
              if (!hasByteServing) chunkSize = datalength;
              // Function to get a range from the remote URL.
              var doXHR = (function(from, to) {
                if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
                if (to > datalength-1) throw new Error("only " + datalength + " bytes available! programmer error!");
                // TODO: Use mozResponseArrayBuffer, responseStream, etc. if available.
                var xhr = new XMLHttpRequest();
                xhr.open('GET', url, false);
                if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
                // Some hints to the browser that we want binary data.
                if (typeof Uint8Array != 'undefined') xhr.responseType = 'arraybuffer';
                if (xhr.overrideMimeType) {
                  xhr.overrideMimeType('text/plain; charset=x-user-defined');
                }
                xhr.send(null);
                if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
                if (xhr.response !== undefined) {
                  return new Uint8Array(xhr.response || []);
                } else {
                  return intArrayFromString(xhr.responseText || '', true);
                }
              });
              var lazyArray = this;
              lazyArray.setDataGetter(function(chunkNum) {
                var start = chunkNum * chunkSize;
                var end = (chunkNum+1) * chunkSize - 1; // including this byte
                end = Math.min(end, datalength-1); // if datalength-1 is selected, this is the last block
                if (typeof(lazyArray.chunks[chunkNum]) === "undefined") {
                  lazyArray.chunks[chunkNum] = doXHR(start, end);
                }
                if (typeof(lazyArray.chunks[chunkNum]) === "undefined") throw new Error("doXHR failed!");
                return lazyArray.chunks[chunkNum];
              });
              this._length = datalength;
              this._chunkSize = chunkSize;
              this.lengthKnown = true;
          }
          var lazyArray = new LazyUint8Array();
          Object.defineProperty(lazyArray, "length", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._length;
              }
          });
          Object.defineProperty(lazyArray, "chunkSize", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._chunkSize;
              }
          });
          var properties = { isDevice: false, contents: lazyArray };
        } else {
          var properties = { isDevice: false, url: url };
        }
        return FS.createFile(parent, name, properties, canRead, canWrite);
      },createPreloadedFile:function (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile) {
        Browser.init();
        var fullname = FS.joinPath([parent, name], true);
        function processData(byteArray) {
          function finish(byteArray) {
            if (!dontCreateFile) {
              FS.createDataFile(parent, name, byteArray, canRead, canWrite);
            }
            if (onload) onload();
            removeRunDependency('cp ' + fullname);
          }
          var handled = false;
          Module['preloadPlugins'].forEach(function(plugin) {
            if (handled) return;
            if (plugin['canHandle'](fullname)) {
              plugin['handle'](byteArray, fullname, finish, function() {
                if (onerror) onerror();
                removeRunDependency('cp ' + fullname);
              });
              handled = true;
            }
          });
          if (!handled) finish(byteArray);
        }
        addRunDependency('cp ' + fullname);
        if (typeof url == 'string') {
          Browser.asyncLoad(url, function(byteArray) {
            processData(byteArray);
          }, onerror);
        } else {
          processData(url);
        }
      },createLink:function (parent, name, target, canRead, canWrite) {
        var properties = {isDevice: false, link: target};
        return FS.createFile(parent, name, properties, canRead, canWrite);
      },createDevice:function (parent, name, input, output) {
        if (!(input || output)) {
          throw new Error('A device must have at least one callback defined.');
        }
        var ops = {isDevice: true, input: input, output: output};
        return FS.createFile(parent, name, ops, Boolean(input), Boolean(output));
      },forceLoadFile:function (obj) {
        if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
        var success = true;
        if (typeof XMLHttpRequest !== 'undefined') {
          throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
        } else if (Module['read']) {
          // Command-line.
          try {
            // WARNING: Can't read binary files in V8's d8 or tracemonkey's js, as
            //          read() will try to parse UTF8.
            obj.contents = intArrayFromString(Module['read'](obj.url), true);
          } catch (e) {
            success = false;
          }
        } else {
          throw new Error('Cannot load without read() or XMLHttpRequest.');
        }
        if (!success) ___setErrNo(ERRNO_CODES.EIO);
        return success;
      },ensureRoot:function () {
        if (FS.root) return;
        // The main file system tree. All the contents are inside this.
        FS.root = {
          read: true,
          write: true,
          isFolder: true,
          isDevice: false,
          timestamp: Date.now(),
          inodeNumber: 1,
          contents: {}
        };
      },init:function (input, output, error) {
        // Make sure we initialize only once.
        assert(!FS.init.initialized, 'FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)');
        FS.init.initialized = true;
        FS.ensureRoot();
        // Allow Module.stdin etc. to provide defaults, if none explicitly passed to us here
        input = input || Module['stdin'];
        output = output || Module['stdout'];
        error = error || Module['stderr'];
        // Default handlers.
        var stdinOverridden = true, stdoutOverridden = true, stderrOverridden = true;
        if (!input) {
          stdinOverridden = false;
          input = function() {
            if (!input.cache || !input.cache.length) {
              var result;
              if (typeof window != 'undefined' &&
                  typeof window.prompt == 'function') {
                // Browser.
                result = window.prompt('Input: ');
                if (result === null) result = String.fromCharCode(0); // cancel ==> EOF
              } else if (typeof readline == 'function') {
                // Command line.
                result = readline();
              }
              if (!result) result = '';
              input.cache = intArrayFromString(result + '\n', true);
            }
            return input.cache.shift();
          };
        }
        var utf8 = new Runtime.UTF8Processor();
        function simpleOutput(val) {
          if (val === null || val === 10) {
            output.printer(output.buffer.join(''));
            output.buffer = [];
          } else {
            output.buffer.push(utf8.processCChar(val));
          }
        }
        if (!output) {
          stdoutOverridden = false;
          output = simpleOutput;
        }
        if (!output.printer) output.printer = Module['print'];
        if (!output.buffer) output.buffer = [];
        if (!error) {
          stderrOverridden = false;
          error = simpleOutput;
        }
        if (!error.printer) error.printer = Module['print'];
        if (!error.buffer) error.buffer = [];
        // Create the temporary folder, if not already created
        try {
          FS.createFolder('/', 'tmp', true, true);
        } catch(e) {}
        // Create the I/O devices.
        var devFolder = FS.createFolder('/', 'dev', true, true);
        var stdin = FS.createDevice(devFolder, 'stdin', input);
        stdin.isTerminal = !stdinOverridden;
        var stdout = FS.createDevice(devFolder, 'stdout', null, output);
        stdout.isTerminal = !stdoutOverridden;
        var stderr = FS.createDevice(devFolder, 'stderr', null, error);
        stderr.isTerminal = !stderrOverridden;
        FS.createDevice(devFolder, 'tty', input, output);
        FS.createDevice(devFolder, 'null', function(){}, function(){});
        // Create default streams.
        FS.streams[1] = {
          path: '/dev/stdin',
          object: stdin,
          position: 0,
          isRead: true,
          isWrite: false,
          isAppend: false,
          error: false,
          eof: false,
          ungotten: []
        };
        FS.streams[2] = {
          path: '/dev/stdout',
          object: stdout,
          position: 0,
          isRead: false,
          isWrite: true,
          isAppend: false,
          error: false,
          eof: false,
          ungotten: []
        };
        FS.streams[3] = {
          path: '/dev/stderr',
          object: stderr,
          position: 0,
          isRead: false,
          isWrite: true,
          isAppend: false,
          error: false,
          eof: false,
          ungotten: []
        };
        // TODO: put these low in memory like we used to assert on: assert(Math.max(_stdin, _stdout, _stderr) < 15000); // make sure these are low, we flatten arrays with these
        HEAP32[((_stdin)>>2)]=1;
        HEAP32[((_stdout)>>2)]=2;
        HEAP32[((_stderr)>>2)]=3;
        // Other system paths
        FS.createPath('/', 'dev/shm/tmp', true, true); // temp files
        // Newlib initialization
        for (var i = FS.streams.length; i < Math.max(_stdin, _stdout, _stderr) + 4; i++) {
          FS.streams[i] = null; // Make sure to keep FS.streams dense
        }
        FS.streams[_stdin] = FS.streams[1];
        FS.streams[_stdout] = FS.streams[2];
        FS.streams[_stderr] = FS.streams[3];
        allocate([ allocate(
          [0, 0, 0, 0, _stdin, 0, 0, 0, _stdout, 0, 0, 0, _stderr, 0, 0, 0],
          'void*', ALLOC_NORMAL) ], 'void*', ALLOC_NONE, __impure_ptr);
      },quit:function () {
        if (!FS.init.initialized) return;
        // Flush any partially-printed lines in stdout and stderr. Careful, they may have been closed
        if (FS.streams[2] && FS.streams[2].object.output.buffer.length > 0) FS.streams[2].object.output(10);
        if (FS.streams[3] && FS.streams[3].object.output.buffer.length > 0) FS.streams[3].object.output(10);
      },standardizePath:function (path) {
        if (path.substr(0, 2) == './') path = path.substr(2);
        return path;
      },deleteFile:function (path) {
        path = FS.analyzePath(path);
        if (!path.parentExists || !path.exists) {
          throw 'Invalid path ' + path;
        }
        delete path.parentObject.contents[path.name];
      }};function _close(fildes) {
      // int close(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/close.html
      if (FS.streams[fildes]) {
        if (FS.streams[fildes].currentEntry) {
          _free(FS.streams[fildes].currentEntry);
        }
        FS.streams[fildes] = null;
        return 0;
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }
  function _fsync(fildes) {
      // int fsync(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fsync.html
      if (FS.streams[fildes]) {
        // We write directly to the file system, so there's nothing to do here.
        return 0;
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }function _fclose(stream) {
      // int fclose(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fclose.html
      _fsync(stream);
      return _close(stream);
    }
  var ___dirent_struct_layout={__size__:1040,d_ino:0,d_name:4,d_off:1028,d_reclen:1032,d_type:1036};function _open(path, oflag, varargs) {
      // int open(const char *path, int oflag, ...);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/open.html
      // NOTE: This implementation tries to mimic glibc rather than strictly
      // following the POSIX standard.
      var mode = HEAP32[((varargs)>>2)];
      // Simplify flags.
      var accessMode = oflag & 3;
      var isWrite = accessMode != 0;
      var isRead = accessMode != 1;
      var isCreate = Boolean(oflag & 512);
      var isExistCheck = Boolean(oflag & 2048);
      var isTruncate = Boolean(oflag & 1024);
      var isAppend = Boolean(oflag & 8);
      // Verify path.
      var origPath = path;
      path = FS.analyzePath(Pointer_stringify(path));
      if (!path.parentExists) {
        ___setErrNo(path.error);
        return -1;
      }
      var target = path.object || null;
      var finalPath;
      // Verify the file exists, create if needed and allowed.
      if (target) {
        if (isCreate && isExistCheck) {
          ___setErrNo(ERRNO_CODES.EEXIST);
          return -1;
        }
        if ((isWrite || isTruncate) && target.isFolder) {
          ___setErrNo(ERRNO_CODES.EISDIR);
          return -1;
        }
        if (isRead && !target.read || isWrite && !target.write) {
          ___setErrNo(ERRNO_CODES.EACCES);
          return -1;
        }
        if (isTruncate && !target.isDevice) {
          target.contents = [];
        } else {
          if (!FS.forceLoadFile(target)) {
            ___setErrNo(ERRNO_CODES.EIO);
            return -1;
          }
        }
        finalPath = path.path;
      } else {
        if (!isCreate) {
          ___setErrNo(ERRNO_CODES.ENOENT);
          return -1;
        }
        if (!path.parentObject.write) {
          ___setErrNo(ERRNO_CODES.EACCES);
          return -1;
        }
        target = FS.createDataFile(path.parentObject, path.name, [],
                                   mode & 0x100, mode & 0x80);  // S_IRUSR, S_IWUSR.
        finalPath = path.parentPath + '/' + path.name;
      }
      // Actually create an open stream.
      var id;
      if (target.isFolder) {
        var entryBuffer = 0;
        if (___dirent_struct_layout) {
          entryBuffer = _malloc(___dirent_struct_layout.__size__);
        }
        var contents = [];
        for (var key in target.contents) contents.push(key);
        id = FS.createFileHandle({
          path: finalPath,
          object: target,
          // An index into contents. Special values: -2 is ".", -1 is "..".
          position: -2,
          isRead: true,
          isWrite: false,
          isAppend: false,
          error: false,
          eof: false,
          ungotten: [],
          // Folder-specific properties:
          // Remember the contents at the time of opening in an array, so we can
          // seek between them relying on a single order.
          contents: contents,
          // Each stream has its own area for readdir() returns.
          currentEntry: entryBuffer
        });
      } else {
        id = FS.createFileHandle({
          path: finalPath,
          object: target,
          position: 0,
          isRead: isRead,
          isWrite: isWrite,
          isAppend: isAppend,
          error: false,
          eof: false,
          ungotten: []
        });
      }
      return id;
    }function _fopen(filename, mode) {
      // FILE *fopen(const char *restrict filename, const char *restrict mode);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fopen.html
      var flags;
      mode = Pointer_stringify(mode);
      if (mode[0] == 'r') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 0;
        }
      } else if (mode[0] == 'w') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 512;
        flags |= 1024;
      } else if (mode[0] == 'a') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 512;
        flags |= 8;
      } else {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return 0;
      }
      var ret = _open(filename, flags, allocate([0x1FF, 0, 0, 0], 'i32', ALLOC_STACK));  // All creation permissions.
      return (ret == -1) ? 0 : ret;
    }
  Module["_strlen"] = _strlen;
  Module["_memcpy"] = _memcpy;var _llvm_memcpy_p0i8_p0i8_i32=_memcpy;
  function _strncmp(px, py, n) {
      var i = 0;
      while (i < n) {
        var x = HEAPU8[(((px)+(i))|0)];
        var y = HEAPU8[(((py)+(i))|0)];
        if (x == y && x == 0) return 0;
        if (x == 0) return -1;
        if (y == 0) return 1;
        if (x == y) {
          i ++;
          continue;
        } else {
          return x > y ? 1 : -1;
        }
      }
      return 0;
    }function _strcmp(px, py) {
      return _strncmp(px, py, TOTAL_MEMORY);
    }
  function _fflush(stream) {
      // int fflush(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fflush.html
      var flush = function(filedes) {
        // Right now we write all data directly, except for output devices.
        if (FS.streams[filedes] && FS.streams[filedes].object.output) {
          if (!FS.streams[filedes].object.isTerminal) { // don't flush terminals, it would cause a \n to also appear
            FS.streams[filedes].object.output(null);
          }
        }
      };
      try {
        if (stream === 0) {
          for (var i = 0; i < FS.streams.length; i++) if (FS.streams[i]) flush(i);
        } else {
          flush(stream);
        }
        return 0;
      } catch (e) {
        ___setErrNo(ERRNO_CODES.EIO);
        return -1;
      }
    }
  function _lseek(fildes, offset, whence) {
      // off_t lseek(int fildes, off_t offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/lseek.html
      if (FS.streams[fildes] && !FS.streams[fildes].object.isDevice) {
        var stream = FS.streams[fildes];
        var position = offset;
        if (whence === 1) {  // SEEK_CUR.
          position += stream.position;
        } else if (whence === 2) {  // SEEK_END.
          position += stream.object.contents.length;
        }
        if (position < 0) {
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
        } else {
          stream.ungotten = [];
          stream.position = position;
          return position;
        }
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }function _fseek(stream, offset, whence) {
      // int fseek(FILE *stream, long offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fseek.html
      var ret = _lseek(stream, offset, whence);
      if (ret == -1) {
        return -1;
      } else {
        FS.streams[stream].eof = false;
        return 0;
      }
    }function _rewind(stream) {
      // void rewind(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/rewind.html
      _fseek(stream, 0, 0);  // SEEK_SET.
      if (FS.streams[stream]) FS.streams[stream].error = false;
    }
  function _ftell(stream) {
      // long ftell(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ftell.html
      if (FS.streams[stream]) {
        stream = FS.streams[stream];
        if (stream.object.isDevice) {
          ___setErrNo(ERRNO_CODES.ESPIPE);
          return -1;
        } else {
          return stream.position;
        }
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }
  function _feof(stream) {
      // int feof(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/feof.html
      return Number(FS.streams[stream] && FS.streams[stream].eof);
    }
  function _recv(fd, buf, len, flags) {
      var info = FS.streams[fd];
      if (!info) return -1;
      if (!info.hasData()) {
        ___setErrNo(ERRNO_CODES.EAGAIN); // no data, and all sockets are nonblocking, so this is the right behavior
        return -1;
      }
      var buffer = info.inQueue.shift();
      if (len < buffer.length) {
        if (info.stream) {
          // This is tcp (reliable), so if not all was read, keep it
          info.inQueue.unshift(buffer.subarray(len));
        }
        buffer = buffer.subarray(0, len);
      }
      HEAPU8.set(buffer, buf);
      return buffer.length;
    }
  function _pread(fildes, buf, nbyte, offset) {
      // ssize_t pread(int fildes, void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.streams[fildes];
      if (!stream || stream.object.isDevice) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      } else if (!stream.isRead) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else if (stream.object.isFolder) {
        ___setErrNo(ERRNO_CODES.EISDIR);
        return -1;
      } else if (nbyte < 0 || offset < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        var bytesRead = 0;
        while (stream.ungotten.length && nbyte > 0) {
          HEAP8[((buf++)|0)]=stream.ungotten.pop()
          nbyte--;
          bytesRead++;
        }
        var contents = stream.object.contents;
        var size = Math.min(contents.length - offset, nbyte);
        if (contents.subarray) { // typed array
          HEAPU8.set(contents.subarray(offset, offset+size), buf);
        } else
        if (contents.slice) { // normal array
          for (var i = 0; i < size; i++) {
            HEAP8[(((buf)+(i))|0)]=contents[offset + i]
          }
        } else {
          for (var i = 0; i < size; i++) { // LazyUint8Array from sync binary XHR
            HEAP8[(((buf)+(i))|0)]=contents.get(offset + i)
          }
        }
        bytesRead += size;
        return bytesRead;
      }
    }function _read(fildes, buf, nbyte) {
      // ssize_t read(int fildes, void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.streams[fildes];
      if (stream && ('socket' in stream)) {
        return _recv(fildes, buf, nbyte, 0);
      } else if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      } else if (!stream.isRead) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else if (nbyte < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        var bytesRead;
        if (stream.object.isDevice) {
          if (stream.object.input) {
            bytesRead = 0;
            while (stream.ungotten.length && nbyte > 0) {
              HEAP8[((buf++)|0)]=stream.ungotten.pop()
              nbyte--;
              bytesRead++;
            }
            for (var i = 0; i < nbyte; i++) {
              try {
                var result = stream.object.input();
              } catch (e) {
                ___setErrNo(ERRNO_CODES.EIO);
                return -1;
              }
              if (result === undefined && bytesRead === 0) {
                ___setErrNo(ERRNO_CODES.EAGAIN);
                return -1;
              }
              if (result === null || result === undefined) break;
              bytesRead++;
              HEAP8[(((buf)+(i))|0)]=result
            }
            return bytesRead;
          } else {
            ___setErrNo(ERRNO_CODES.ENXIO);
            return -1;
          }
        } else {
          var ungotSize = stream.ungotten.length;
          bytesRead = _pread(fildes, buf, nbyte, stream.position);
          if (bytesRead != -1) {
            stream.position += (stream.ungotten.length - ungotSize) + bytesRead;
          }
          return bytesRead;
        }
      }
    }function _fgetc(stream) {
      // int fgetc(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgetc.html
      if (!FS.streams[stream]) return -1;
      var streamObj = FS.streams[stream];
      if (streamObj.eof || streamObj.error) return -1;
      var ret = _read(stream, _fgetc.ret, 1);
      if (ret == 0) {
        streamObj.eof = true;
        return -1;
      } else if (ret == -1) {
        streamObj.error = true;
        return -1;
      } else {
        return HEAPU8[((_fgetc.ret)|0)];
      }
    }
  function _send(fd, buf, len, flags) {
      var info = FS.streams[fd];
      if (!info) return -1;
      info.sender(HEAPU8.subarray(buf, buf+len));
      return len;
    }
  function _pwrite(fildes, buf, nbyte, offset) {
      // ssize_t pwrite(int fildes, const void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.streams[fildes];
      if (!stream || stream.object.isDevice) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      } else if (!stream.isWrite) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else if (stream.object.isFolder) {
        ___setErrNo(ERRNO_CODES.EISDIR);
        return -1;
      } else if (nbyte < 0 || offset < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        var contents = stream.object.contents;
        while (contents.length < offset) contents.push(0);
        for (var i = 0; i < nbyte; i++) {
          contents[offset + i] = HEAPU8[(((buf)+(i))|0)];
        }
        stream.object.timestamp = Date.now();
        return i;
      }
    }function _write(fildes, buf, nbyte) {
      // ssize_t write(int fildes, const void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.streams[fildes];
      if (stream && ('socket' in stream)) {
          return _send(fildes, buf, nbyte, 0);
      } else if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      } else if (!stream.isWrite) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else if (nbyte < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        if (stream.object.isDevice) {
          if (stream.object.output) {
            for (var i = 0; i < nbyte; i++) {
              try {
                stream.object.output(HEAP8[(((buf)+(i))|0)]);
              } catch (e) {
                ___setErrNo(ERRNO_CODES.EIO);
                return -1;
              }
            }
            stream.object.timestamp = Date.now();
            return i;
          } else {
            ___setErrNo(ERRNO_CODES.ENXIO);
            return -1;
          }
        } else {
          var bytesWritten = _pwrite(fildes, buf, nbyte, stream.position);
          if (bytesWritten != -1) stream.position += bytesWritten;
          return bytesWritten;
        }
      }
    }function _fputc(c, stream) {
      // int fputc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputc.html
      var chr = unSign(c & 0xFF);
      HEAP8[((_fputc.ret)|0)]=chr
      var ret = _write(stream, _fputc.ret, 1);
      if (ret == -1) {
        if (FS.streams[stream]) FS.streams[stream].error = true;
        return -1;
      } else {
        return chr;
      }
    }
  Module["_memset"] = _memset;var _llvm_memset_p0i8_i64=_memset;
  function _emscripten_set_main_loop(func, fps, simulateInfiniteLoop) {
      Module['noExitRuntime'] = true;
      Browser.mainLoop.runner = function() {
        if (ABORT) return;
        if (Browser.mainLoop.queue.length > 0) {
          var start = Date.now();
          var blocker = Browser.mainLoop.queue.shift();
          blocker.func(blocker.arg);
          if (Browser.mainLoop.remainingBlockers) {
            var remaining = Browser.mainLoop.remainingBlockers;
            var next = remaining%1 == 0 ? remaining-1 : Math.floor(remaining);
            if (blocker.counted) {
              Browser.mainLoop.remainingBlockers = next;
            } else {
              // not counted, but move the progress along a tiny bit
              next = next + 0.5; // do not steal all the next one's progress
              Browser.mainLoop.remainingBlockers = (8*remaining + next)/9;
            }
          }
          console.log('main loop blocker "' + blocker.name + '" took ' + (Date.now() - start) + ' ms'); //, left: ' + Browser.mainLoop.remainingBlockers);
          Browser.mainLoop.updateStatus();
          setTimeout(Browser.mainLoop.runner, 0);
          return;
        }
        if (Browser.mainLoop.shouldPause) {
          // catch pauses from non-main loop sources
          Browser.mainLoop.paused = true;
          Browser.mainLoop.shouldPause = false;
          return;
        }
        if (Module['preMainLoop']) {
          Module['preMainLoop']();
        }
        Runtime.dynCall('v', func);
        if (Module['postMainLoop']) {
          Module['postMainLoop']();
        }
        if (Browser.mainLoop.shouldPause) {
          // catch pauses from the main loop itself
          Browser.mainLoop.paused = true;
          Browser.mainLoop.shouldPause = false;
          return;
        }
        Browser.mainLoop.scheduler();
      }
      if (fps && fps > 0) {
        Browser.mainLoop.scheduler = function() {
          setTimeout(Browser.mainLoop.runner, 1000/fps); // doing this each time means that on exception, we stop
        }
      } else {
        Browser.mainLoop.scheduler = function() {
          Browser.requestAnimationFrame(Browser.mainLoop.runner);
        }
      }
      Browser.mainLoop.scheduler();
      if (simulateInfiniteLoop) {
        throw 'SimulateInfiniteLoop';
      }
    }
  function _emscripten_cancel_main_loop() {
      Browser.mainLoop.scheduler = null;
      Browser.mainLoop.shouldPause = true;
    }
  function __reallyNegative(x) {
      return x < 0 || (x === 0 && (1/x) === -Infinity);
    }function __formatString(format, varargs) {
      var textIndex = format;
      var argIndex = 0;
      function getNextArg(type) {
        // NOTE: Explicitly ignoring type safety. Otherwise this fails:
        //       int x = 4; printf("%c\n", (char)x);
        var ret;
        if (type === 'double') {
          ret = HEAPF64[(((varargs)+(argIndex))>>3)];
        } else if (type == 'i64') {
          ret = [HEAP32[(((varargs)+(argIndex))>>2)],
                 HEAP32[(((varargs)+(argIndex+8))>>2)]];
          argIndex += 8; // each 32-bit chunk is in a 64-bit block
        } else {
          type = 'i32'; // varargs are always i32, i64, or double
          ret = HEAP32[(((varargs)+(argIndex))>>2)];
        }
        argIndex += Math.max(Runtime.getNativeFieldSize(type), Runtime.getAlignSize(type, null, true));
        return ret;
      }
      var ret = [];
      var curr, next, currArg;
      while(1) {
        var startTextIndex = textIndex;
        curr = HEAP8[(textIndex)];
        if (curr === 0) break;
        next = HEAP8[((textIndex+1)|0)];
        if (curr == 37) {
          // Handle flags.
          var flagAlwaysSigned = false;
          var flagLeftAlign = false;
          var flagAlternative = false;
          var flagZeroPad = false;
          flagsLoop: while (1) {
            switch (next) {
              case 43:
                flagAlwaysSigned = true;
                break;
              case 45:
                flagLeftAlign = true;
                break;
              case 35:
                flagAlternative = true;
                break;
              case 48:
                if (flagZeroPad) {
                  break flagsLoop;
                } else {
                  flagZeroPad = true;
                  break;
                }
              default:
                break flagsLoop;
            }
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          }
          // Handle width.
          var width = 0;
          if (next == 42) {
            width = getNextArg('i32');
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          } else {
            while (next >= 48 && next <= 57) {
              width = width * 10 + (next - 48);
              textIndex++;
              next = HEAP8[((textIndex+1)|0)];
            }
          }
          // Handle precision.
          var precisionSet = false;
          if (next == 46) {
            var precision = 0;
            precisionSet = true;
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
            if (next == 42) {
              precision = getNextArg('i32');
              textIndex++;
            } else {
              while(1) {
                var precisionChr = HEAP8[((textIndex+1)|0)];
                if (precisionChr < 48 ||
                    precisionChr > 57) break;
                precision = precision * 10 + (precisionChr - 48);
                textIndex++;
              }
            }
            next = HEAP8[((textIndex+1)|0)];
          } else {
            var precision = 6; // Standard default.
          }
          // Handle integer sizes. WARNING: These assume a 32-bit architecture!
          var argSize;
          switch (String.fromCharCode(next)) {
            case 'h':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 104) {
                textIndex++;
                argSize = 1; // char (actually i32 in varargs)
              } else {
                argSize = 2; // short (actually i32 in varargs)
              }
              break;
            case 'l':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 108) {
                textIndex++;
                argSize = 8; // long long
              } else {
                argSize = 4; // long
              }
              break;
            case 'L': // long long
            case 'q': // int64_t
            case 'j': // intmax_t
              argSize = 8;
              break;
            case 'z': // size_t
            case 't': // ptrdiff_t
            case 'I': // signed ptrdiff_t or unsigned size_t
              argSize = 4;
              break;
            default:
              argSize = null;
          }
          if (argSize) textIndex++;
          next = HEAP8[((textIndex+1)|0)];
          // Handle type specifier.
          switch (String.fromCharCode(next)) {
            case 'd': case 'i': case 'u': case 'o': case 'x': case 'X': case 'p': {
              // Integer.
              var signed = next == 100 || next == 105;
              argSize = argSize || 4;
              var currArg = getNextArg('i' + (argSize * 8));
              var origArg = currArg;
              var argText;
              // Flatten i64-1 [low, high] into a (slightly rounded) double
              if (argSize == 8) {
                currArg = Runtime.makeBigInt(currArg[0], currArg[1], next == 117);
              }
              // Truncate to requested size.
              if (argSize <= 4) {
                var limit = Math.pow(256, argSize) - 1;
                currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8);
              }
              // Format the number.
              var currAbsArg = Math.abs(currArg);
              var prefix = '';
              if (next == 100 || next == 105) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], null); else
                argText = reSign(currArg, 8 * argSize, 1).toString(10);
              } else if (next == 117) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], true); else
                argText = unSign(currArg, 8 * argSize, 1).toString(10);
                currArg = Math.abs(currArg);
              } else if (next == 111) {
                argText = (flagAlternative ? '0' : '') + currAbsArg.toString(8);
              } else if (next == 120 || next == 88) {
                prefix = (flagAlternative && currArg != 0) ? '0x' : '';
                if (argSize == 8 && i64Math) {
                  if (origArg[1]) {
                    argText = (origArg[1]>>>0).toString(16);
                    var lower = (origArg[0]>>>0).toString(16);
                    while (lower.length < 8) lower = '0' + lower;
                    argText += lower;
                  } else {
                    argText = (origArg[0]>>>0).toString(16);
                  }
                } else
                if (currArg < 0) {
                  // Represent negative numbers in hex as 2's complement.
                  currArg = -currArg;
                  argText = (currAbsArg - 1).toString(16);
                  var buffer = [];
                  for (var i = 0; i < argText.length; i++) {
                    buffer.push((0xF - parseInt(argText[i], 16)).toString(16));
                  }
                  argText = buffer.join('');
                  while (argText.length < argSize * 2) argText = 'f' + argText;
                } else {
                  argText = currAbsArg.toString(16);
                }
                if (next == 88) {
                  prefix = prefix.toUpperCase();
                  argText = argText.toUpperCase();
                }
              } else if (next == 112) {
                if (currAbsArg === 0) {
                  argText = '(nil)';
                } else {
                  prefix = '0x';
                  argText = currAbsArg.toString(16);
                }
              }
              if (precisionSet) {
                while (argText.length < precision) {
                  argText = '0' + argText;
                }
              }
              // Add sign if needed
              if (flagAlwaysSigned) {
                if (currArg < 0) {
                  prefix = '-' + prefix;
                } else {
                  prefix = '+' + prefix;
                }
              }
              // Add padding.
              while (prefix.length + argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad) {
                    argText = '0' + argText;
                  } else {
                    prefix = ' ' + prefix;
                  }
                }
              }
              // Insert the result into the buffer.
              argText = prefix + argText;
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 'f': case 'F': case 'e': case 'E': case 'g': case 'G': {
              // Float.
              var currArg = getNextArg('double');
              var argText;
              if (isNaN(currArg)) {
                argText = 'nan';
                flagZeroPad = false;
              } else if (!isFinite(currArg)) {
                argText = (currArg < 0 ? '-' : '') + 'inf';
                flagZeroPad = false;
              } else {
                var isGeneral = false;
                var effectivePrecision = Math.min(precision, 20);
                // Convert g/G to f/F or e/E, as per:
                // http://pubs.opengroup.org/onlinepubs/9699919799/functions/printf.html
                if (next == 103 || next == 71) {
                  isGeneral = true;
                  precision = precision || 1;
                  var exponent = parseInt(currArg.toExponential(effectivePrecision).split('e')[1], 10);
                  if (precision > exponent && exponent >= -4) {
                    next = ((next == 103) ? 'f' : 'F').charCodeAt(0);
                    precision -= exponent + 1;
                  } else {
                    next = ((next == 103) ? 'e' : 'E').charCodeAt(0);
                    precision--;
                  }
                  effectivePrecision = Math.min(precision, 20);
                }
                if (next == 101 || next == 69) {
                  argText = currArg.toExponential(effectivePrecision);
                  // Make sure the exponent has at least 2 digits.
                  if (/[eE][-+]\d$/.test(argText)) {
                    argText = argText.slice(0, -1) + '0' + argText.slice(-1);
                  }
                } else if (next == 102 || next == 70) {
                  argText = currArg.toFixed(effectivePrecision);
                  if (currArg === 0 && __reallyNegative(currArg)) {
                    argText = '-' + argText;
                  }
                }
                var parts = argText.split('e');
                if (isGeneral && !flagAlternative) {
                  // Discard trailing zeros and periods.
                  while (parts[0].length > 1 && parts[0].indexOf('.') != -1 &&
                         (parts[0].slice(-1) == '0' || parts[0].slice(-1) == '.')) {
                    parts[0] = parts[0].slice(0, -1);
                  }
                } else {
                  // Make sure we have a period in alternative mode.
                  if (flagAlternative && argText.indexOf('.') == -1) parts[0] += '.';
                  // Zero pad until required precision.
                  while (precision > effectivePrecision++) parts[0] += '0';
                }
                argText = parts[0] + (parts.length > 1 ? 'e' + parts[1] : '');
                // Capitalize 'E' if needed.
                if (next == 69) argText = argText.toUpperCase();
                // Add sign.
                if (flagAlwaysSigned && currArg >= 0) {
                  argText = '+' + argText;
                }
              }
              // Add padding.
              while (argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad && (argText[0] == '-' || argText[0] == '+')) {
                    argText = argText[0] + '0' + argText.slice(1);
                  } else {
                    argText = (flagZeroPad ? '0' : ' ') + argText;
                  }
                }
              }
              // Adjust case.
              if (next < 97) argText = argText.toUpperCase();
              // Insert the result into the buffer.
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 's': {
              // String.
              var arg = getNextArg('i8*');
              var argLength = arg ? _strlen(arg) : '(null)'.length;
              if (precisionSet) argLength = Math.min(argLength, precision);
              if (!flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              if (arg) {
                for (var i = 0; i < argLength; i++) {
                  ret.push(HEAPU8[((arg++)|0)]);
                }
              } else {
                ret = ret.concat(intArrayFromString('(null)'.substr(0, argLength), true));
              }
              if (flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              break;
            }
            case 'c': {
              // Character.
              if (flagLeftAlign) ret.push(getNextArg('i8'));
              while (--width > 0) {
                ret.push(32);
              }
              if (!flagLeftAlign) ret.push(getNextArg('i8'));
              break;
            }
            case 'n': {
              // Write the length written so far to the next parameter.
              var ptr = getNextArg('i32*');
              HEAP32[((ptr)>>2)]=ret.length
              break;
            }
            case '%': {
              // Literal percent sign.
              ret.push(curr);
              break;
            }
            default: {
              // Unknown specifiers remain untouched.
              for (var i = startTextIndex; i < textIndex + 2; i++) {
                ret.push(HEAP8[(i)]);
              }
            }
          }
          textIndex += 2;
          // TODO: Support a/A (hex float) and m (last error) specifiers.
          // TODO: Support %1${specifier} for arg selection.
        } else {
          ret.push(curr);
          textIndex += 1;
        }
      }
      return ret;
    }function _snprintf(s, n, format, varargs) {
      // int snprintf(char *restrict s, size_t n, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var limit = (n === undefined) ? result.length
                                    : Math.min(result.length, Math.max(n - 1, 0));
      if (s < 0) {
        s = -s;
        var buf = _malloc(limit+1);
        HEAP32[((s)>>2)]=buf;
        s = buf;
      }
      for (var i = 0; i < limit; i++) {
        HEAP8[(((s)+(i))|0)]=result[i];
      }
      if (limit < n || (n === undefined)) HEAP8[(((s)+(i))|0)]=0;
      return result.length;
    }function _sprintf(s, format, varargs) {
      // int sprintf(char *restrict s, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      return _snprintf(s, undefined, format, varargs);
    }
  Module["_strcpy"] = _strcpy;
  var _llvm_memset_p0i8_i32=_memset;
  function _llvm_lifetime_start() {}
  function _llvm_lifetime_end() {}
  function _time(ptr) {
      var ret = Math.floor(Date.now()/1000);
      if (ptr) {
        HEAP32[((ptr)>>2)]=ret
      }
      return ret;
    }
  var ___tm_struct_layout={__size__:44,tm_sec:0,tm_min:4,tm_hour:8,tm_mday:12,tm_mon:16,tm_year:20,tm_wday:24,tm_yday:28,tm_isdst:32,tm_gmtoff:36,tm_zone:40};
  var ___tm_current=allocate(4*26, "i8", ALLOC_STATIC);
  var ___tm_timezones={};
  var __tzname=allocate(8, "i32*", ALLOC_STATIC);
  var __daylight=allocate(1, "i32*", ALLOC_STATIC);
  var __timezone=allocate(1, "i32*", ALLOC_STATIC);function _tzset() {
      // TODO: Use (malleable) environment variables instead of system settings.
      if (_tzset.called) return;
      _tzset.called = true;
      HEAP32[((__timezone)>>2)]=-(new Date()).getTimezoneOffset() * 60
      var winter = new Date(2000, 0, 1);
      var summer = new Date(2000, 6, 1);
      HEAP32[((__daylight)>>2)]=Number(winter.getTimezoneOffset() != summer.getTimezoneOffset())
      var winterName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | winter.toString().match(/\(([A-Z]+)\)/)[1];
      var summerName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | summer.toString().match(/\(([A-Z]+)\)/)[1];
      var winterNamePtr = allocate(intArrayFromString(winterName), 'i8', ALLOC_NORMAL);
      var summerNamePtr = allocate(intArrayFromString(summerName), 'i8', ALLOC_NORMAL);
      HEAP32[((__tzname)>>2)]=winterNamePtr
      HEAP32[(((__tzname)+(4))>>2)]=summerNamePtr
    }function _localtime_r(time, tmPtr) {
      _tzset();
      var offsets = ___tm_struct_layout;
      var date = new Date(HEAP32[((time)>>2)]*1000);
      HEAP32[(((tmPtr)+(offsets.tm_sec))>>2)]=date.getSeconds()
      HEAP32[(((tmPtr)+(offsets.tm_min))>>2)]=date.getMinutes()
      HEAP32[(((tmPtr)+(offsets.tm_hour))>>2)]=date.getHours()
      HEAP32[(((tmPtr)+(offsets.tm_mday))>>2)]=date.getDate()
      HEAP32[(((tmPtr)+(offsets.tm_mon))>>2)]=date.getMonth()
      HEAP32[(((tmPtr)+(offsets.tm_year))>>2)]=date.getFullYear()-1900
      HEAP32[(((tmPtr)+(offsets.tm_wday))>>2)]=date.getDay()
      var start = new Date(date.getFullYear(), 0, 1);
      var yday = Math.floor((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24));
      HEAP32[(((tmPtr)+(offsets.tm_yday))>>2)]=yday
      HEAP32[(((tmPtr)+(offsets.tm_gmtoff))>>2)]=start.getTimezoneOffset() * 60
      var dst = Number(start.getTimezoneOffset() != date.getTimezoneOffset());
      HEAP32[(((tmPtr)+(offsets.tm_isdst))>>2)]=dst
      var timezone = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | date.toString().match(/\(([A-Z]+)\)/)[1];
      if (!(timezone in ___tm_timezones)) {
        ___tm_timezones[timezone] = allocate(intArrayFromString(timezone), 'i8', ALLOC_NORMAL);
      }
      HEAP32[(((tmPtr)+(offsets.tm_zone))>>2)]=___tm_timezones[timezone]
      return tmPtr;
    }function _localtime(time) {
      return _localtime_r(time, ___tm_current);
    }
  function _gettimeofday(ptr) {
      // %struct.timeval = type { i32, i32 }
      var now = Date.now();
      HEAP32[((ptr)>>2)]=Math.floor(now/1000); // seconds
      HEAP32[(((ptr)+(4))>>2)]=Math.floor((now-1000*Math.floor(now/1000))*1000); // microseconds
      return 0;
    }
  var _llvm_va_start=undefined;
  function _llvm_va_end() {}
  function _fwrite(ptr, size, nitems, stream) {
      // size_t fwrite(const void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fwrite.html
      var bytesToWrite = nitems * size;
      if (bytesToWrite == 0) return 0;
      var bytesWritten = _write(stream, ptr, bytesToWrite);
      if (bytesWritten == -1) {
        if (FS.streams[stream]) FS.streams[stream].error = true;
        return 0;
      } else {
        return Math.floor(bytesWritten / size);
      }
    }function _fprintf(stream, format, varargs) {
      // int fprintf(FILE *restrict stream, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var stack = Runtime.stackSave();
      var ret = _fwrite(allocate(result, 'i8', ALLOC_STACK), 1, result.length, stream);
      Runtime.stackRestore(stack);
      return ret;
    }
  function _atexit(func, arg) {
      __ATEXIT__.unshift({ func: func, arg: arg });
    }
  var Browser={mainLoop:{scheduler:null,shouldPause:false,paused:false,queue:[],pause:function () {
          Browser.mainLoop.shouldPause = true;
        },resume:function () {
          if (Browser.mainLoop.paused) {
            Browser.mainLoop.paused = false;
            Browser.mainLoop.scheduler();
          }
          Browser.mainLoop.shouldPause = false;
        },updateStatus:function () {
          if (Module['setStatus']) {
            var message = Module['statusMessage'] || 'Please wait...';
            var remaining = Browser.mainLoop.remainingBlockers;
            var expected = Browser.mainLoop.expectedBlockers;
            if (remaining) {
              if (remaining < expected) {
                Module['setStatus'](message + ' (' + (expected - remaining) + '/' + expected + ')');
              } else {
                Module['setStatus'](message);
              }
            } else {
              Module['setStatus']('');
            }
          }
        }},isFullScreen:false,pointerLock:false,moduleContextCreatedCallbacks:[],workers:[],init:function () {
        if (!Module["preloadPlugins"]) Module["preloadPlugins"] = []; // needs to exist even in workers
        if (Browser.initted || ENVIRONMENT_IS_WORKER) return;
        Browser.initted = true;
        try {
          new Blob();
          Browser.hasBlobConstructor = true;
        } catch(e) {
          Browser.hasBlobConstructor = false;
          console.log("warning: no blob constructor, cannot create blobs with mimetypes");
        }
        Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : (typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : (!Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null));
        Browser.URLObject = typeof window != "undefined" ? (window.URL ? window.URL : window.webkitURL) : console.log("warning: cannot create object URLs");
        // Support for plugins that can process preloaded files. You can add more of these to
        // your app by creating and appending to Module.preloadPlugins.
        //
        // Each plugin is asked if it can handle a file based on the file's name. If it can,
        // it is given the file's raw data. When it is done, it calls a callback with the file's
        // (possibly modified) data. For example, a plugin might decompress a file, or it
        // might create some side data structure for use later (like an Image element, etc.).
        function getMimetype(name) {
          return {
            'jpg': 'image/jpeg',
            'jpeg': 'image/jpeg',
            'png': 'image/png',
            'bmp': 'image/bmp',
            'ogg': 'audio/ogg',
            'wav': 'audio/wav',
            'mp3': 'audio/mpeg'
          }[name.substr(name.lastIndexOf('.')+1)];
        }
        var imagePlugin = {};
        imagePlugin['canHandle'] = function(name) {
          return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/i.test(name);
        };
        imagePlugin['handle'] = function(byteArray, name, onload, onerror) {
          var b = null;
          if (Browser.hasBlobConstructor) {
            try {
              b = new Blob([byteArray], { type: getMimetype(name) });
              if (b.size !== byteArray.length) { // Safari bug #118630
                // Safari's Blob can only take an ArrayBuffer
                b = new Blob([(new Uint8Array(byteArray)).buffer], { type: getMimetype(name) });
              }
            } catch(e) {
              Runtime.warnOnce('Blob constructor present but fails: ' + e + '; falling back to blob builder');
            }
          }
          if (!b) {
            var bb = new Browser.BlobBuilder();
            bb.append((new Uint8Array(byteArray)).buffer); // we need to pass a buffer, and must copy the array to get the right data range
            b = bb.getBlob();
          }
          var url = Browser.URLObject.createObjectURL(b);
          var img = new Image();
          img.onload = function() {
            assert(img.complete, 'Image ' + name + ' could not be decoded');
            var canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            Module["preloadedImages"][name] = canvas;
            Browser.URLObject.revokeObjectURL(url);
            if (onload) onload(byteArray);
          };
          img.onerror = function(event) {
            console.log('Image ' + url + ' could not be decoded');
            if (onerror) onerror();
          };
          img.src = url;
        };
        Module['preloadPlugins'].push(imagePlugin);
        var audioPlugin = {};
        audioPlugin['canHandle'] = function(name) {
          return !Module.noAudioDecoding && name.substr(-4) in { '.ogg': 1, '.wav': 1, '.mp3': 1 };
        };
        audioPlugin['handle'] = function(byteArray, name, onload, onerror) {
          var done = false;
          function finish(audio) {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = audio;
            if (onload) onload(byteArray);
          }
          function fail() {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = new Audio(); // empty shim
            if (onerror) onerror();
          }
          if (Browser.hasBlobConstructor) {
            try {
              var b = new Blob([byteArray], { type: getMimetype(name) });
            } catch(e) {
              return fail();
            }
            var url = Browser.URLObject.createObjectURL(b); // XXX we never revoke this!
            var audio = new Audio();
            audio.addEventListener('canplaythrough', function() { finish(audio) }, false); // use addEventListener due to chromium bug 124926
            audio.onerror = function(event) {
              if (done) return;
              console.log('warning: browser could not fully decode audio ' + name + ', trying slower base64 approach');
              function encode64(data) {
                var BASE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
                var PAD = '=';
                var ret = '';
                var leftchar = 0;
                var leftbits = 0;
                for (var i = 0; i < data.length; i++) {
                  leftchar = (leftchar << 8) | data[i];
                  leftbits += 8;
                  while (leftbits >= 6) {
                    var curr = (leftchar >> (leftbits-6)) & 0x3f;
                    leftbits -= 6;
                    ret += BASE[curr];
                  }
                }
                if (leftbits == 2) {
                  ret += BASE[(leftchar&3) << 4];
                  ret += PAD + PAD;
                } else if (leftbits == 4) {
                  ret += BASE[(leftchar&0xf) << 2];
                  ret += PAD;
                }
                return ret;
              }
              audio.src = 'data:audio/x-' + name.substr(-3) + ';base64,' + encode64(byteArray);
              finish(audio); // we don't wait for confirmation this worked - but it's worth trying
            };
            audio.src = url;
            // workaround for chrome bug 124926 - we do not always get oncanplaythrough or onerror
            Browser.safeSetTimeout(function() {
              finish(audio); // try to use it even though it is not necessarily ready to play
            }, 10000);
          } else {
            return fail();
          }
        };
        Module['preloadPlugins'].push(audioPlugin);
        // Canvas event setup
        var canvas = Module['canvas'];
        canvas.requestPointerLock = canvas['requestPointerLock'] ||
                                    canvas['mozRequestPointerLock'] ||
                                    canvas['webkitRequestPointerLock'];
        canvas.exitPointerLock = document['exitPointerLock'] ||
                                 document['mozExitPointerLock'] ||
                                 document['webkitExitPointerLock'] ||
                                 function(){}; // no-op if function does not exist
        canvas.exitPointerLock = canvas.exitPointerLock.bind(document);
        function pointerLockChange() {
          Browser.pointerLock = document['pointerLockElement'] === canvas ||
                                document['mozPointerLockElement'] === canvas ||
                                document['webkitPointerLockElement'] === canvas;
        }
        document.addEventListener('pointerlockchange', pointerLockChange, false);
        document.addEventListener('mozpointerlockchange', pointerLockChange, false);
        document.addEventListener('webkitpointerlockchange', pointerLockChange, false);
        if (Module['elementPointerLock']) {
          canvas.addEventListener("click", function(ev) {
            if (!Browser.pointerLock && canvas.requestPointerLock) {
              canvas.requestPointerLock();
              ev.preventDefault();
            }
          }, false);
        }
      },createContext:function (canvas, useWebGL, setInModule) {
        var ctx;
        try {
          if (useWebGL) {
            ctx = canvas.getContext('experimental-webgl', {
              alpha: false
            });
          } else {
            ctx = canvas.getContext('2d');
          }
          if (!ctx) throw ':(';
        } catch (e) {
          Module.print('Could not create canvas - ' + e);
          return null;
        }
        if (useWebGL) {
          // Set the background of the WebGL canvas to black
          canvas.style.backgroundColor = "black";
          // Warn on context loss
          canvas.addEventListener('webglcontextlost', function(event) {
            alert('WebGL context lost. You will need to reload the page.');
          }, false);
        }
        if (setInModule) {
          Module.ctx = ctx;
          Module.useWebGL = useWebGL;
          Browser.moduleContextCreatedCallbacks.forEach(function(callback) { callback() });
          Browser.init();
        }
        return ctx;
      },destroyContext:function (canvas, useWebGL, setInModule) {},fullScreenHandlersInstalled:false,lockPointer:undefined,resizeCanvas:undefined,requestFullScreen:function (lockPointer, resizeCanvas) {
        Browser.lockPointer = lockPointer;
        Browser.resizeCanvas = resizeCanvas;
        if (typeof Browser.lockPointer === 'undefined') Browser.lockPointer = true;
        if (typeof Browser.resizeCanvas === 'undefined') Browser.resizeCanvas = false;
        var canvas = Module['canvas'];
        function fullScreenChange() {
          Browser.isFullScreen = false;
          if ((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
               document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
               document['fullScreenElement'] || document['fullscreenElement']) === canvas) {
            canvas.cancelFullScreen = document['cancelFullScreen'] ||
                                      document['mozCancelFullScreen'] ||
                                      document['webkitCancelFullScreen'];
            canvas.cancelFullScreen = canvas.cancelFullScreen.bind(document);
            if (Browser.lockPointer) canvas.requestPointerLock();
            Browser.isFullScreen = true;
            if (Browser.resizeCanvas) Browser.setFullScreenCanvasSize();
          } else if (Browser.resizeCanvas){
            Browser.setWindowedCanvasSize();
          }
          if (Module['onFullScreen']) Module['onFullScreen'](Browser.isFullScreen);
        }
        if (!Browser.fullScreenHandlersInstalled) {
          Browser.fullScreenHandlersInstalled = true;
          document.addEventListener('fullscreenchange', fullScreenChange, false);
          document.addEventListener('mozfullscreenchange', fullScreenChange, false);
          document.addEventListener('webkitfullscreenchange', fullScreenChange, false);
        }
        canvas.requestFullScreen = canvas['requestFullScreen'] ||
                                   canvas['mozRequestFullScreen'] ||
                                   (canvas['webkitRequestFullScreen'] ? function() { canvas['webkitRequestFullScreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null);
        canvas.requestFullScreen();
      },requestAnimationFrame:function (func) {
        if (!window.requestAnimationFrame) {
          window.requestAnimationFrame = window['requestAnimationFrame'] ||
                                         window['mozRequestAnimationFrame'] ||
                                         window['webkitRequestAnimationFrame'] ||
                                         window['msRequestAnimationFrame'] ||
                                         window['oRequestAnimationFrame'] ||
                                         window['setTimeout'];
        }
        window.requestAnimationFrame(func);
      },safeCallback:function (func) {
        return function() {
          if (!ABORT) return func.apply(null, arguments);
        };
      },safeRequestAnimationFrame:function (func) {
        return Browser.requestAnimationFrame(function() {
          if (!ABORT) func();
        });
      },safeSetTimeout:function (func, timeout) {
        return setTimeout(function() {
          if (!ABORT) func();
        }, timeout);
      },safeSetInterval:function (func, timeout) {
        return setInterval(function() {
          if (!ABORT) func();
        }, timeout);
      },getUserMedia:function (func) {
        if(!window.getUserMedia) {
          window.getUserMedia = navigator['getUserMedia'] ||
                                navigator['mozGetUserMedia'];
        }
        window.getUserMedia(func);
      },getMovementX:function (event) {
        return event['movementX'] ||
               event['mozMovementX'] ||
               event['webkitMovementX'] ||
               0;
      },getMovementY:function (event) {
        return event['movementY'] ||
               event['mozMovementY'] ||
               event['webkitMovementY'] ||
               0;
      },mouseX:0,mouseY:0,mouseMovementX:0,mouseMovementY:0,calculateMouseEvent:function (event) { // event should be mousemove, mousedown or mouseup
        if (Browser.pointerLock) {
          // When the pointer is locked, calculate the coordinates
          // based on the movement of the mouse.
          // Workaround for Firefox bug 764498
          if (event.type != 'mousemove' &&
              ('mozMovementX' in event)) {
            Browser.mouseMovementX = Browser.mouseMovementY = 0;
          } else {
            Browser.mouseMovementX = Browser.getMovementX(event);
            Browser.mouseMovementY = Browser.getMovementY(event);
          }
          // check if SDL is available
          if (typeof SDL != "undefined") {
          	Browser.mouseX = SDL.mouseX + Browser.mouseMovementX;
          	Browser.mouseY = SDL.mouseY + Browser.mouseMovementY;
          } else {
          	// just add the mouse delta to the current absolut mouse position
          	// FIXME: ideally this should be clamped against the canvas size and zero
          	Browser.mouseX += Browser.mouseMovementX;
          	Browser.mouseY += Browser.mouseMovementY;
          }        
        } else {
          // Otherwise, calculate the movement based on the changes
          // in the coordinates.
          if (Module["canvasFront"]) {
            var rect = Module["canvasFront"].getBoundingClientRect();
          } else {
            var rect = Module["canvas"].getBoundingClientRect();
          }
          var x = event.pageX - (window.scrollX + rect.left);
          var y = event.pageY - (window.scrollY + rect.top);
          // the canvas might be CSS-scaled compared to its backbuffer;
          // SDL-using content will want mouse coordinates in terms
          // of backbuffer units.
          var cw = Module["canvas"].width;
          var ch = Module["canvas"].height;
          x = x * (cw / rect.width);
          y = y * (ch / rect.height);
          Browser.mouseMovementX = x - Browser.mouseX;
          Browser.mouseMovementY = y - Browser.mouseY;
          Browser.mouseX = x;
          Browser.mouseY = y;
        }
      },xhrLoad:function (url, onload, onerror) {
        var xhr = new XMLHttpRequest();
        xhr.open('GET', url, true);
        xhr.responseType = 'arraybuffer';
        xhr.onload = function() {
          if (xhr.status == 200 || (xhr.status == 0 && xhr.response)) { // file URLs can return 0
            onload(xhr.response);
          } else {
            onerror();
          }
        };
        xhr.onerror = onerror;
        xhr.send(null);
      },asyncLoad:function (url, onload, onerror, noRunDep) {
        Browser.xhrLoad(url, function(arrayBuffer) {
          assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
          onload(new Uint8Array(arrayBuffer));
          if (!noRunDep) removeRunDependency('al ' + url);
        }, function(event) {
          if (onerror) {
            onerror();
          } else {
            throw 'Loading data file "' + url + '" failed.';
          }
        });
        if (!noRunDep) addRunDependency('al ' + url);
      },resizeListeners:[],updateResizeListeners:function () {
        var canvas = Module['canvas'];
        Browser.resizeListeners.forEach(function(listener) {
          listener(canvas.width, canvas.height);
        });
      },setCanvasSize:function (width, height, noUpdates) {
        var canvas = Module['canvas'];
        canvas.width = width;
        canvas.height = height;
        if (!noUpdates) Browser.updateResizeListeners();
      },windowedWidth:0,windowedHeight:0,setFullScreenCanvasSize:function () {
        var canvas = Module['canvas'];
        this.windowedWidth = canvas.width;
        this.windowedHeight = canvas.height;
        canvas.width = screen.width;
        canvas.height = screen.height;
        // check if SDL is available   
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags | 0x00800000; // set SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },setWindowedCanvasSize:function () {
        var canvas = Module['canvas'];
        canvas.width = this.windowedWidth;
        canvas.height = this.windowedHeight;
        // check if SDL is available       
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags & ~0x00800000; // clear SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      }};var SDL={defaults:{width:320,height:200,copyOnLock:true},version:null,surfaces:{},canvasPool:[],events:[],fonts:[null],audios:[null],music:{audio:null,volume:1},mixerFrequency:22050,mixerFormat:32784,mixerNumChannels:2,mixerChunkSize:1024,channelMinimumNumber:0,GL:false,keyboardState:null,keyboardMap:{},textInput:false,startTime:null,buttonState:0,modState:0,DOMButtons:[0,0,0],DOMEventToSDLEvent:{},keyCodes:{16:1249,17:1248,18:1250,33:1099,34:1102,37:1104,38:1106,39:1103,40:1105,46:127,96:1112,97:1113,98:1114,99:1115,100:1116,101:1117,102:1118,103:1119,104:1120,105:1121,112:1082,113:1083,114:1084,115:1085,116:1086,117:1087,118:1088,119:1089,120:1090,121:1091,122:1092,123:1093,173:45,188:44,190:46,191:47,192:96},scanCodes:{9:43,13:40,27:41,32:44,44:54,46:55,47:56,48:39,49:30,50:31,51:32,52:33,53:34,54:35,55:36,56:37,57:38,92:49,97:4,98:5,99:6,100:7,101:8,102:9,103:10,104:11,105:12,106:13,107:14,108:15,109:16,110:17,111:18,112:19,113:20,114:21,115:22,116:23,117:24,118:25,119:26,120:27,121:28,122:29,305:224,308:226},structs:{Rect:{__size__:16,x:0,y:4,w:8,h:12},PixelFormat:{__size__:36,format:0,palette:4,BitsPerPixel:8,BytesPerPixel:9,padding1:10,padding2:11,Rmask:12,Gmask:16,Bmask:20,Amask:24,Rloss:28,Gloss:29,Bloss:30,Aloss:31,Rshift:32,Gshift:33,Bshift:34,Ashift:35},KeyboardEvent:{__size__:16,type:0,windowID:4,state:8,repeat:9,padding2:10,padding3:11,keysym:12},keysym:{__size__:16,scancode:0,sym:4,mod:8,unicode:12},TextInputEvent:{__size__:264,type:0,windowID:4,text:8},MouseMotionEvent:{__size__:28,type:0,windowID:4,state:8,padding1:9,padding2:10,padding3:11,x:12,y:16,xrel:20,yrel:24},MouseButtonEvent:{__size__:20,type:0,windowID:4,button:8,state:9,padding1:10,padding2:11,x:12,y:16},ResizeEvent:{__size__:12,type:0,w:4,h:8},AudioSpec:{__size__:24,freq:0,format:4,channels:6,silence:7,samples:8,size:12,callback:16,userdata:20},version:{__size__:3,major:0,minor:1,patch:2}},loadRect:function (rect) {
        return {
          x: HEAP32[((rect + SDL.structs.Rect.x)>>2)],
          y: HEAP32[((rect + SDL.structs.Rect.y)>>2)],
          w: HEAP32[((rect + SDL.structs.Rect.w)>>2)],
          h: HEAP32[((rect + SDL.structs.Rect.h)>>2)]
        };
      },loadColorToCSSRGB:function (color) {
        var rgba = HEAP32[((color)>>2)];
        return 'rgb(' + (rgba&255) + ',' + ((rgba >> 8)&255) + ',' + ((rgba >> 16)&255) + ')';
      },loadColorToCSSRGBA:function (color) {
        var rgba = HEAP32[((color)>>2)];
        return 'rgba(' + (rgba&255) + ',' + ((rgba >> 8)&255) + ',' + ((rgba >> 16)&255) + ',' + (((rgba >> 24)&255)/255) + ')';
      },translateColorToCSSRGBA:function (rgba) {
        return 'rgba(' + (rgba&0xff) + ',' + (rgba>>8 & 0xff) + ',' + (rgba>>16 & 0xff) + ',' + (rgba>>>24)/0xff + ')';
      },translateRGBAToCSSRGBA:function (r, g, b, a) {
        return 'rgba(' + (r&0xff) + ',' + (g&0xff) + ',' + (b&0xff) + ',' + (a&0xff)/255 + ')';
      },translateRGBAToColor:function (r, g, b, a) {
        return r | g << 8 | b << 16 | a << 24;
      },makeSurface:function (width, height, flags, usePageCanvas, source, rmask, gmask, bmask, amask) {
        flags = flags || 0;
        var surf = _malloc(14*Runtime.QUANTUM_SIZE);  // SDL_Surface has 14 fields of quantum size
        var buffer = _malloc(width*height*4); // TODO: only allocate when locked the first time
        var pixelFormat = _malloc(18*Runtime.QUANTUM_SIZE);
        flags |= 1; // SDL_HWSURFACE - this tells SDL_MUSTLOCK that this needs to be locked
        //surface with SDL_HWPALETTE flag is 8bpp surface (1 byte)
        var is_SDL_HWPALETTE = flags & 0x00200000;  
        var bpp = is_SDL_HWPALETTE ? 1 : 4;
        HEAP32[((surf+Runtime.QUANTUM_SIZE*0)>>2)]=flags         // SDL_Surface.flags
        HEAP32[((surf+Runtime.QUANTUM_SIZE*1)>>2)]=pixelFormat // SDL_Surface.format TODO
        HEAP32[((surf+Runtime.QUANTUM_SIZE*2)>>2)]=width         // SDL_Surface.w
        HEAP32[((surf+Runtime.QUANTUM_SIZE*3)>>2)]=height        // SDL_Surface.h
        HEAP32[((surf+Runtime.QUANTUM_SIZE*4)>>2)]=width * bpp       // SDL_Surface.pitch, assuming RGBA or indexed for now,
                                                                                 // since that is what ImageData gives us in browsers
        HEAP32[((surf+Runtime.QUANTUM_SIZE*5)>>2)]=buffer      // SDL_Surface.pixels
        HEAP32[((surf+Runtime.QUANTUM_SIZE*6)>>2)]=0      // SDL_Surface.offset
        HEAP32[((pixelFormat + SDL.structs.PixelFormat.format)>>2)]=-2042224636 // SDL_PIXELFORMAT_RGBA8888
        HEAP32[((pixelFormat + SDL.structs.PixelFormat.palette)>>2)]=0 // TODO
        HEAP8[((pixelFormat + SDL.structs.PixelFormat.BitsPerPixel)|0)]=bpp * 8
        HEAP8[((pixelFormat + SDL.structs.PixelFormat.BytesPerPixel)|0)]=bpp
        HEAP32[((pixelFormat + SDL.structs.PixelFormat.Rmask)>>2)]=rmask || 0x000000ff
        HEAP32[((pixelFormat + SDL.structs.PixelFormat.Gmask)>>2)]=gmask || 0x0000ff00
        HEAP32[((pixelFormat + SDL.structs.PixelFormat.Bmask)>>2)]=bmask || 0x00ff0000
        HEAP32[((pixelFormat + SDL.structs.PixelFormat.Amask)>>2)]=amask || 0xff000000
        // Decide if we want to use WebGL or not
        var useWebGL = (flags & 0x04000000) != 0; // SDL_OPENGL
        SDL.GL = SDL.GL || useWebGL;
        var canvas;
        if (!usePageCanvas) {
          if (SDL.canvasPool.length > 0) {
            canvas = SDL.canvasPool.pop();
          } else {
            canvas = document.createElement('canvas');
          }
          canvas.width = width;
          canvas.height = height;
        } else {
          canvas = Module['canvas'];
        }
        var ctx = Browser.createContext(canvas, useWebGL, usePageCanvas);
        SDL.surfaces[surf] = {
          width: width,
          height: height,
          canvas: canvas,
          ctx: ctx,
          surf: surf,
          buffer: buffer,
          pixelFormat: pixelFormat,
          alpha: 255,
          flags: flags,
          locked: 0,
          usePageCanvas: usePageCanvas,
          source: source,
          isFlagSet: function (flag) {
            return flags & flag;
          }
        };
        return surf;
      },copyIndexedColorData:function (surfData, rX, rY, rW, rH) {
        // HWPALETTE works with palette
        // setted by SDL_SetColors
        if (!surfData.colors) {
          return;
        }
        var fullWidth  = Module['canvas'].width;
        var fullHeight = Module['canvas'].height;
        var startX  = rX || 0;
        var startY  = rY || 0;
        var endX    = (rW || (fullWidth - startX)) + startX;
        var endY    = (rH || (fullHeight - startY)) + startY;
        var buffer  = surfData.buffer;
        var data    = surfData.image.data;
        var colors  = surfData.colors;
        for (var y = startY; y < endY; ++y) {
          var indexBase = y * fullWidth;
          var colorBase = indexBase * 4;
          for (var x = startX; x < endX; ++x) {
            // HWPALETTE have only 256 colors (not rgba)
            var index = HEAPU8[((buffer + indexBase + x)|0)] * 3;
            var colorOffset = colorBase + x * 4;
            data[colorOffset   ] = colors[index   ];
            data[colorOffset +1] = colors[index +1];
            data[colorOffset +2] = colors[index +2];
            //unused: data[colorOffset +3] = color[index +3];
          }
        }
      },freeSurface:function (surf) {
        var info = SDL.surfaces[surf];
        if (!info) return; // surface has already been freed
        if (!info.usePageCanvas && info.canvas) SDL.canvasPool.push(info.canvas);
        _free(info.buffer);
        _free(info.pixelFormat);
        _free(surf);
        SDL.surfaces[surf] = null;
      },touchX:0,touchY:0,receiveEvent:function (event) {
        switch(event.type) {
          case 'touchstart':
            event.preventDefault();
            var touch = event.touches[0];
            touchX = touch.pageX;
            touchY = touch.pageY;
            var event = {
              type: 'mousedown',
              button: 0,
              pageX: touchX,
              pageY: touchY
            };
            SDL.DOMButtons[0] = 1;
            SDL.events.push(event);
            break;
          case 'touchmove':
            event.preventDefault();
            var touch = event.touches[0];
            touchX = touch.pageX;
            touchY = touch.pageY;
            event = {
              type: 'mousemove',
              button: 0,
              pageX: touchX,
              pageY: touchY
            };
            SDL.events.push(event);
            break;
          case 'touchend':
            event.preventDefault();
            event = {
              type: 'mouseup',
              button: 0,
              pageX: touchX,
              pageY: touchY
            };
            SDL.DOMButtons[0] = 0;
            SDL.events.push(event);
            break;
          case 'mousemove':
            if (Browser.pointerLock) {
              // workaround for firefox bug 750111
              if ('mozMovementX' in event) {
                event['movementX'] = event['mozMovementX'];
                event['movementY'] = event['mozMovementY'];
              }
              // workaround for Firefox bug 782777
              if (event['movementX'] == 0 && event['movementY'] == 0) {
                // ignore a mousemove event if it doesn't contain any movement info
                // (without pointer lock, we infer movement from pageX/pageY, so this check is unnecessary)
                event.preventDefault();
                return;
              }
            }
            // fall through
          case 'keydown': case 'keyup': case 'keypress': case 'mousedown': case 'mouseup': case 'DOMMouseScroll': case 'mousewheel':
            if (event.type == 'DOMMouseScroll' || event.type == 'mousewheel') {
              var button = (event.type == 'DOMMouseScroll' ? event.detail : -event.wheelDelta) > 0 ? 4 : 3;
              var event2 = {
                type: 'mousedown',
                button: button,
                pageX: event.pageX,
                pageY: event.pageY
              };
              SDL.events.push(event2);
              event = {
                type: 'mouseup',
                button: button,
                pageX: event.pageX,
                pageY: event.pageY
              };
            } else if (event.type == 'mousedown') {
              SDL.DOMButtons[event.button] = 1;
            } else if (event.type == 'mouseup') {
              // ignore extra ups, can happen if we leave the canvas while pressing down, then return,
              // since we add a mouseup in that case
              if (!SDL.DOMButtons[event.button]) {
                event.preventDefault();
                return;
              }
              SDL.DOMButtons[event.button] = 0;
            }
            if (event.type == 'keypress' && !SDL.textInput) {
              break;
            }
            SDL.events.push(event);
            break;
          case 'mouseout':
            // Un-press all pressed mouse buttons, because we might miss the release outside of the canvas
            for (var i = 0; i < 3; i++) {
              if (SDL.DOMButtons[i]) {
                SDL.events.push({
                  type: 'mouseup',
                  button: i,
                  pageX: event.pageX,
                  pageY: event.pageY
                });
                SDL.DOMButtons[i] = 0;
              }
            }
            break;
          case 'blur':
          case 'visibilitychange': {
            // Un-press all pressed keys: TODO
            for (var code in SDL.keyboardMap) {
              SDL.events.push({
                type: 'keyup',
                keyCode: SDL.keyboardMap[code]
              });
            }
            break;
          }
          case 'unload':
            if (Browser.mainLoop.runner) {
              SDL.events.push(event);
              // Force-run a main event loop, since otherwise this event will never be caught!
              Browser.mainLoop.runner();
            }
            return;
          case 'resize':
            SDL.events.push(event);
            break;
        }
        if (SDL.events.length >= 10000) {
          Module.printErr('SDL event queue full, dropping events');
          SDL.events = SDL.events.slice(0, 10000);
        }
        // manually triggered resize event doesn't have a preventDefault member
        if (event.preventDefault) {
          event.preventDefault();
        }
        return;
      },makeCEvent:function (event, ptr) {
        if (typeof event === 'number') {
          // This is a pointer to a native C event that was SDL_PushEvent'ed
          _memcpy(ptr, event, SDL.structs.KeyboardEvent.__size__); // XXX
          return;
        }
        switch(event.type) {
          case 'keydown': case 'keyup': {
            var down = event.type === 'keydown';
            //Module.print('Received key event: ' + event.keyCode);
            var key = event.keyCode;
            if (key >= 65 && key <= 90) {
              key += 32; // make lowercase for SDL
            } else {
              key = SDL.keyCodes[event.keyCode] || event.keyCode;
            }
            var scan;
            if (key >= 1024) {
              scan = key - 1024;
            } else {
              scan = SDL.scanCodes[key] || key;
            }
            var code = SDL.keyCodes[event.keyCode] || event.keyCode;
            HEAP8[(((SDL.keyboardState)+(code))|0)]=down;
            if (down) {
              SDL.keyboardMap[code] = event.keyCode; // save the DOM input, which we can use to unpress it during blur
            } else {
              delete SDL.keyboardMap[code];
            }
            // TODO: lmeta, rmeta, numlock, capslock, KMOD_MODE, KMOD_RESERVED
            SDL.modState = (HEAP8[(((SDL.keyboardState)+(1248))|0)] ? 0x0040 | 0x0080 : 0) | // KMOD_LCTRL & KMOD_RCTRL
              (HEAP8[(((SDL.keyboardState)+(1249))|0)] ? 0x0001 | 0x0002 : 0) | // KMOD_LSHIFT & KMOD_RSHIFT
              (HEAP8[(((SDL.keyboardState)+(1250))|0)] ? 0x0100 | 0x0200 : 0); // KMOD_LALT & KMOD_RALT
            HEAP32[(((ptr)+(SDL.structs.KeyboardEvent.type))>>2)]=SDL.DOMEventToSDLEvent[event.type]
            HEAP8[(((ptr)+(SDL.structs.KeyboardEvent.state))|0)]=down ? 1 : 0
            HEAP8[(((ptr)+(SDL.structs.KeyboardEvent.repeat))|0)]=0 // TODO
            HEAP32[(((ptr)+(SDL.structs.KeyboardEvent.keysym + SDL.structs.keysym.scancode))>>2)]=scan
            HEAP32[(((ptr)+(SDL.structs.KeyboardEvent.keysym + SDL.structs.keysym.sym))>>2)]=key
            HEAP32[(((ptr)+(SDL.structs.KeyboardEvent.keysym + SDL.structs.keysym.mod))>>2)]=SDL.modState
            HEAP32[(((ptr)+(SDL.structs.KeyboardEvent.keysym + SDL.structs.keysym.unicode))>>2)]=key
            break;
          }
          case 'keypress': {
            HEAP32[(((ptr)+(SDL.structs.TextInputEvent.type))>>2)]=SDL.DOMEventToSDLEvent[event.type]
            // Not filling in windowID for now
            var cStr = intArrayFromString(String.fromCharCode(event.charCode));
            for (var i = 0; i < cStr.length; ++i) {
              HEAP8[(((ptr)+(SDL.structs.TextInputEvent.text + i))|0)]=cStr[i];
            }
            break;
          }
          case 'mousedown': case 'mouseup':
            if (event.type == 'mousedown') {
              // SDL_BUTTON(x) is defined as (1 << ((x)-1)).  SDL buttons are 1-3,
              // and DOM buttons are 0-2, so this means that the below formula is
              // correct.
              SDL.buttonState |= 1 << event.button;
            } else if (event.type == 'mouseup') {
              SDL.buttonState &= ~(1 << event.button);
            }
            // fall through
          case 'mousemove': {
            Browser.calculateMouseEvent(event);
            if (event.type != 'mousemove') {
              var down = event.type === 'mousedown';
              HEAP32[(((ptr)+(SDL.structs.MouseButtonEvent.type))>>2)]=SDL.DOMEventToSDLEvent[event.type];
              HEAP8[(((ptr)+(SDL.structs.MouseButtonEvent.button))|0)]=event.button+1; // DOM buttons are 0-2, SDL 1-3
              HEAP8[(((ptr)+(SDL.structs.MouseButtonEvent.state))|0)]=down ? 1 : 0;
              HEAP32[(((ptr)+(SDL.structs.MouseButtonEvent.x))>>2)]=Browser.mouseX;
              HEAP32[(((ptr)+(SDL.structs.MouseButtonEvent.y))>>2)]=Browser.mouseY;
            } else {
              HEAP32[(((ptr)+(SDL.structs.MouseMotionEvent.type))>>2)]=SDL.DOMEventToSDLEvent[event.type];
              HEAP8[(((ptr)+(SDL.structs.MouseMotionEvent.state))|0)]=SDL.buttonState;
              HEAP32[(((ptr)+(SDL.structs.MouseMotionEvent.x))>>2)]=Browser.mouseX;
              HEAP32[(((ptr)+(SDL.structs.MouseMotionEvent.y))>>2)]=Browser.mouseY;
              HEAP32[(((ptr)+(SDL.structs.MouseMotionEvent.xrel))>>2)]=Browser.mouseMovementX;
              HEAP32[(((ptr)+(SDL.structs.MouseMotionEvent.yrel))>>2)]=Browser.mouseMovementY;
            }
            break;
          }
          case 'unload': {
            HEAP32[(((ptr)+(SDL.structs.KeyboardEvent.type))>>2)]=SDL.DOMEventToSDLEvent[event.type];
            break;
          }
          case 'resize': {
            HEAP32[(((ptr)+(SDL.structs.KeyboardEvent.type))>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP32[(((ptr)+(SDL.structs.ResizeEvent.w))>>2)]=event.w;
            HEAP32[(((ptr)+(SDL.structs.ResizeEvent.h))>>2)]=event.h;
            break;
          }
          default: throw 'Unhandled SDL event: ' + event.type;
        }
      },estimateTextWidth:function (fontData, text) {
        var h = fontData.size;
        var fontString = h + 'px ' + fontData.name;
        var tempCtx = SDL.ttfContext;
        tempCtx.save();
        tempCtx.font = fontString;
        var ret = tempCtx.measureText(text).width | 0;
        tempCtx.restore();
        return ret;
      },allocateChannels:function (num) { // called from Mix_AllocateChannels and init
        if (SDL.numChannels && SDL.numChannels >= num) return;
        SDL.numChannels = num;
        SDL.channels = [];
        for (var i = 0; i < num; i++) {
          SDL.channels[i] = {
            audio: null,
            volume: 1.0
          };
        }
      },setGetVolume:function (info, volume) {
        if (!info) return 0;
        var ret = info.volume * 128; // MIX_MAX_VOLUME
        if (volume != -1) {
          info.volume = volume / 128;
          if (info.audio) info.audio.volume = info.volume;
        }
        return ret;
      },debugSurface:function (surfData) {
        console.log('dumping surface ' + [surfData.surf, surfData.source, surfData.width, surfData.height]);
        var image = surfData.ctx.getImageData(0, 0, surfData.width, surfData.height);
        var data = image.data;
        var num = Math.min(surfData.width, surfData.height);
        for (var i = 0; i < num; i++) {
          console.log('   diagonal ' + i + ':' + [data[i*surfData.width*4 + i*4 + 0], data[i*surfData.width*4 + i*4 + 1], data[i*surfData.width*4 + i*4 + 2], data[i*surfData.width*4 + i*4 + 3]]);
        }
      }};function _SDL_Init(what) {
      SDL.startTime = Date.now();
      // capture all key events. we just keep down and up, but also capture press to prevent default actions
      if (!Module['doNotCaptureKeyboard']) {
        document.addEventListener("keydown", SDL.receiveEvent);
        document.addEventListener("keyup", SDL.receiveEvent);
        document.addEventListener("keypress", SDL.receiveEvent);
        document.addEventListener("blur", SDL.receiveEvent);
        document.addEventListener("visibilitychange", SDL.receiveEvent);
      }
      window.addEventListener("unload", SDL.receiveEvent);
      SDL.keyboardState = _malloc(0x10000); // Our SDL needs 512, but 64K is safe for older SDLs
      _memset(SDL.keyboardState, 0, 0x10000);
      // Initialize this structure carefully for closure
      SDL.DOMEventToSDLEvent['keydown'] = 0x300 /* SDL_KEYDOWN */;
      SDL.DOMEventToSDLEvent['keyup'] = 0x301 /* SDL_KEYUP */;
      SDL.DOMEventToSDLEvent['keypress'] = 0x303 /* SDL_TEXTINPUT */;
      SDL.DOMEventToSDLEvent['mousedown'] = 0x401 /* SDL_MOUSEBUTTONDOWN */;
      SDL.DOMEventToSDLEvent['mouseup'] = 0x402 /* SDL_MOUSEBUTTONUP */;
      SDL.DOMEventToSDLEvent['mousemove'] = 0x400 /* SDL_MOUSEMOTION */;
      SDL.DOMEventToSDLEvent['unload'] = 0x100 /* SDL_QUIT */;
      SDL.DOMEventToSDLEvent['resize'] = 0x7001 /* SDL_VIDEORESIZE/SDL_EVENT_COMPAT2 */;
      return 0; // success
    }
  function _signal(sig, func) {
      // TODO
      return 0;
    }
  function __exit(status) {
      // void _exit(int status);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/exit.html
      function ExitStatus() {
        this.name = "ExitStatus";
        this.message = "Program terminated with exit(" + status + ")";
        this.status = status;
        Module.print('Exit Status: ' + status);
      };
      ExitStatus.prototype = new Error();
      ExitStatus.prototype.constructor = ExitStatus;
      exitRuntime();
      ABORT = true;
      throw new ExitStatus();
    }function _exit(status) {
      __exit(status);
    }
  Module["_strcat"] = _strcat;
  function _fread(ptr, size, nitems, stream) {
      // size_t fread(void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fread.html
      var bytesToRead = nitems * size;
      if (bytesToRead == 0) return 0;
      var bytesRead = _read(stream, ptr, bytesToRead);
      var streamObj = FS.streams[stream];
      if (bytesRead == -1) {
        if (streamObj) streamObj.error = true;
        return 0;
      } else {
        if (bytesRead < bytesToRead) streamObj.eof = true;
        return Math.floor(bytesRead / size);
      }
    }
  var _sin=Math.sin;
  var _cos=Math.cos;
  function _truncate(path, length) {
      // int truncate(const char *path, off_t length);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/truncate.html
      // NOTE: The path argument may be a string, to simplify ftruncate().
      if (length < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        if (typeof path !== 'string') path = Pointer_stringify(path);
        var target = FS.findObject(path);
        if (target === null) return -1;
        if (target.isFolder) {
          ___setErrNo(ERRNO_CODES.EISDIR);
          return -1;
        } else if (target.isDevice) {
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
        } else if (!target.write) {
          ___setErrNo(ERRNO_CODES.EACCES);
          return -1;
        } else {
          var contents = target.contents;
          if (length < contents.length) contents.length = length;
          else while (length > contents.length) contents.push(0);
          target.timestamp = Date.now();
          return 0;
        }
      }
    }function _ftruncate(fildes, length) {
      // int ftruncate(int fildes, off_t length);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ftruncate.html
      if (FS.streams[fildes] && FS.streams[fildes].isWrite) {
        return _truncate(FS.streams[fildes].path, length);
      } else if (FS.streams[fildes]) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }
  function _fileno(stream) {
      // int fileno(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fileno.html
      // We use file descriptor numbers and FILE* streams interchangeably.
      return stream;
    }
  Module["_memcmp"] = _memcmp;
  var ___pollfd_struct_layout={__size__:8,fd:0,events:4,revents:6};function _poll(fds, nfds, timeout) {
      // int poll(struct pollfd fds[], nfds_t nfds, int timeout);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/poll.html
      // NOTE: This is pretty much a no-op mimicking glibc.
      var offsets = ___pollfd_struct_layout;
      var nonzero = 0;
      for (var i = 0; i < nfds; i++) {
        var pollfd = fds + ___pollfd_struct_layout.__size__ * i;
        var fd = HEAP32[(((pollfd)+(offsets.fd))>>2)];
        var events = HEAP16[(((pollfd)+(offsets.events))>>1)];
        var revents = 0;
        if (FS.streams[fd]) {
          var stream = FS.streams[fd];
          if (events & 1) revents |= 1;
          if (events & 2) revents |= 2;
        } else {
          if (events & 4) revents |= 4;
        }
        if (revents) nonzero++;
        HEAP16[(((pollfd)+(offsets.revents))>>1)]=revents
      }
      return nonzero;
    }
  function _unlink(path) {
      // int unlink(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/unlink.html
      path = FS.analyzePath(Pointer_stringify(path));
      if (!path.parentExists || !path.exists) {
        ___setErrNo(path.error);
        return -1;
      } else if (path.object.isFolder) {
        ___setErrNo(ERRNO_CODES.EISDIR);
        return -1;
      } else if (!path.object.write) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else {
        delete path.parentObject.contents[path.name];
        return 0;
      }
    }
  function _posix_openpt() {
  Module['printErr']('missing function: posix_openpt'); abort(-1);
  }
  function _symlink(path1, path2) {
      // int symlink(const char *path1, const char *path2);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/symlink.html
      var path = FS.analyzePath(Pointer_stringify(path2), true);
      if (!path.parentExists) {
        ___setErrNo(path.error);
        return -1;
      } else if (path.exists) {
        ___setErrNo(ERRNO_CODES.EEXIST);
        return -1;
      } else {
        FS.createLink(path.parentPath, path.name,
                      Pointer_stringify(path1), true, true);
        return 0;
      }
    }
  function _tcgetattr() {
  Module['printErr']('missing function: tcgetattr'); abort(-1);
  }
  function _tcsetattr() {
  Module['printErr']('missing function: tcsetattr'); abort(-1);
  }
  function _tcflush() {
  Module['printErr']('missing function: tcflush'); abort(-1);
  }
  var ___flock_struct_layout={__size__:16,l_type:0,l_whence:2,l_start:4,l_len:8,l_pid:12,l_xxx:14};function _fcntl(fildes, cmd, varargs, dup2) {
      // int fcntl(int fildes, int cmd, ...);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/fcntl.html
      if (!FS.streams[fildes]) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      var stream = FS.streams[fildes];
      switch (cmd) {
        case 0:
          var arg = HEAP32[((varargs)>>2)];
          if (arg < 0) {
            ___setErrNo(ERRNO_CODES.EINVAL);
            return -1;
          }
          var newStream = {};
          for (var member in stream) {
            newStream[member] = stream[member];
          }
          arg = dup2 ? arg : Math.max(arg, FS.streams.length); // dup2 wants exactly arg; fcntl wants a free descriptor >= arg
          FS.createFileHandle(newStream, arg);
          return arg;
        case 1:
        case 2:
          return 0;  // FD_CLOEXEC makes no sense for a single process.
        case 3:
          var flags = 0;
          if (stream.isRead && stream.isWrite) flags = 2;
          else if (!stream.isRead && stream.isWrite) flags = 1;
          else if (stream.isRead && !stream.isWrite) flags = 0;
          if (stream.isAppend) flags |= 8;
          // Synchronization and blocking flags are irrelevant to us.
          return flags;
        case 4:
          var arg = HEAP32[((varargs)>>2)];
          stream.isAppend = Boolean(arg | 8);
          // Synchronization and blocking flags are irrelevant to us.
          return 0;
        case 7:
        case 20:
          var arg = HEAP32[((varargs)>>2)];
          var offset = ___flock_struct_layout.l_type;
          // We're always unlocked.
          HEAP16[(((arg)+(offset))>>1)]=3
          return 0;
        case 8:
        case 9:
        case 21:
        case 22:
          // Pretend that the locking is successful.
          return 0;
        case 6:
        case 5:
          // These are for sockets. We don't have them fully implemented yet.
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
        default:
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
      }
      // Should never be reached. Only to silence strict warnings.
      return -1;
    }
  function _grantpt() {
  Module['printErr']('missing function: grantpt'); abort(-1);
  }
  function _unlockpt() {
  Module['printErr']('missing function: unlockpt'); abort(-1);
  }
  function _ptsname() {
  Module['printErr']('missing function: ptsname'); abort(-1);
  }
  function _strdup(ptr) {
      var len = _strlen(ptr);
      var newStr = _malloc(len + 1);
      (_memcpy(newStr, ptr, len)|0);
      HEAP8[(((newStr)+(len))|0)]=0;
      return newStr;
    }
  Module["_tolower"] = _tolower; 
  Module["_strncasecmp"] = _strncasecmp; 
  Module["_strcasecmp"] = _strcasecmp;
  function _gmtime_r(time, tmPtr) {
      var date = new Date(HEAP32[((time)>>2)]*1000);
      var offsets = ___tm_struct_layout;
      HEAP32[(((tmPtr)+(offsets.tm_sec))>>2)]=date.getUTCSeconds()
      HEAP32[(((tmPtr)+(offsets.tm_min))>>2)]=date.getUTCMinutes()
      HEAP32[(((tmPtr)+(offsets.tm_hour))>>2)]=date.getUTCHours()
      HEAP32[(((tmPtr)+(offsets.tm_mday))>>2)]=date.getUTCDate()
      HEAP32[(((tmPtr)+(offsets.tm_mon))>>2)]=date.getUTCMonth()
      HEAP32[(((tmPtr)+(offsets.tm_year))>>2)]=date.getUTCFullYear()-1900
      HEAP32[(((tmPtr)+(offsets.tm_wday))>>2)]=date.getUTCDay()
      HEAP32[(((tmPtr)+(offsets.tm_gmtoff))>>2)]=0
      HEAP32[(((tmPtr)+(offsets.tm_isdst))>>2)]=0
      var start = new Date(date.getFullYear(), 0, 1);
      var yday = Math.round((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24));
      HEAP32[(((tmPtr)+(offsets.tm_yday))>>2)]=yday
      var timezone = "GMT";
      if (!(timezone in ___tm_timezones)) {
        ___tm_timezones[timezone] = allocate(intArrayFromString(timezone), 'i8', ALLOC_NORMAL);
      }
      HEAP32[(((tmPtr)+(offsets.tm_zone))>>2)]=___tm_timezones[timezone]
      return tmPtr;
    }function _gmtime(time) {
      return _gmtime_r(time, ___tm_current);
    }
  var _tan=Math.tan;
  function _SDL_PauseAudio(pauseOn) {
      if (SDL.audio.paused !== pauseOn) {
        SDL.audio.timer = pauseOn ? SDL.audio.timer && clearInterval(SDL.audio.timer) : Browser.safeSetInterval(SDL.audio.caller, 1/35);
      }
      SDL.audio.paused = pauseOn;
    }function _SDL_CloseAudio() {
      if (SDL.audio) {
        _SDL_PauseAudio(1);
        _free(SDL.audio.buffer);
        SDL.audio = null;
      }
    }
  function _SDL_WasInit() {
      if (SDL.startTime === null) {
        _SDL_Init();
      }
      return 1;
    }
  function _SDL_InitSubSystem(flags) { return 0 }
  function _SDL_GetError() {
      if (!SDL.errorMessage) {
        SDL.errorMessage = allocate(intArrayFromString("unknown SDL-emscripten error"), 'i8', ALLOC_NORMAL);
      }
      return SDL.errorMessage;
    }
  function _SDL_OpenAudio(desired, obtained) {
      SDL.allocateChannels(32);
      SDL.audio = {
        freq: HEAPU32[(((desired)+(SDL.structs.AudioSpec.freq))>>2)],
        format: HEAPU16[(((desired)+(SDL.structs.AudioSpec.format))>>1)],
        channels: HEAPU8[(((desired)+(SDL.structs.AudioSpec.channels))|0)],
        samples: HEAPU16[(((desired)+(SDL.structs.AudioSpec.samples))>>1)],
        callback: HEAPU32[(((desired)+(SDL.structs.AudioSpec.callback))>>2)],
        userdata: HEAPU32[(((desired)+(SDL.structs.AudioSpec.userdata))>>2)],
        paused: true,
        timer: null
      };
      if (obtained) {
        HEAP32[(((obtained)+(SDL.structs.AudioSpec.freq))>>2)]=SDL.audio.freq; // no good way for us to know if the browser can really handle this
        HEAP16[(((obtained)+(SDL.structs.AudioSpec.format))>>1)]=33040; // float, signed, 16-bit
        HEAP8[(((obtained)+(SDL.structs.AudioSpec.channels))|0)]=SDL.audio.channels;
        HEAP8[(((obtained)+(SDL.structs.AudioSpec.silence))|0)]=HEAPU8[(((desired)+(SDL.structs.AudioSpec.silence))|0)]; // unclear if browsers can provide this
        HEAP16[(((obtained)+(SDL.structs.AudioSpec.samples))>>1)]=SDL.audio.samples;
        HEAP32[(((obtained)+(SDL.structs.AudioSpec.callback))>>2)]=SDL.audio.callback;
        HEAP32[(((obtained)+(SDL.structs.AudioSpec.userdata))>>2)]=SDL.audio.userdata;
      }
      var totalSamples = SDL.audio.samples*SDL.audio.channels;
      SDL.audio.bufferSize = totalSamples*2; // hardcoded 16-bit audio
      SDL.audio.buffer = _malloc(SDL.audio.bufferSize);
      SDL.audio.caller = function() {
        Runtime.dynCall('viii', SDL.audio.callback, [SDL.audio.userdata, SDL.audio.buffer, SDL.audio.bufferSize]);
        SDL.audio.pushAudio(SDL.audio.buffer, SDL.audio.bufferSize);
      };
      // Mozilla Audio API. TODO: Other audio APIs
      try {
        SDL.audio.mozOutput = new Audio();
        SDL.audio.mozOutput['mozSetup'](SDL.audio.channels, SDL.audio.freq); // use string attributes on mozOutput for closure compiler
        SDL.audio.mozBuffer = new Float32Array(totalSamples);
        SDL.audio.pushAudio = function(ptr, size) {
          var mozBuffer = SDL.audio.mozBuffer;
          for (var i = 0; i < totalSamples; i++) {
            mozBuffer[i] = (HEAP16[(((ptr)+(i*2))>>1)]) / 0x8000; // hardcoded 16-bit audio, signed (TODO: reSign if not ta2?)
          }
          SDL.audio.mozOutput['mozWriteAudio'](mozBuffer);
        }
      } catch(e) {
        SDL.audio = null;
      }
      if (!SDL.audio) return -1;
      return 0;
    }
  function _SDL_LockAudio() {}
  function _SDL_UnlockAudio() {}
  function _isspace(chr) {
      return chr in { 32: 0, 9: 0, 10: 0, 11: 0, 12: 0, 13: 0 };
    }function __parseInt(str, endptr, base, min, max, bits, unsign) {
      // Skip space.
      while (_isspace(HEAP8[(str)])) str++;
      // Check for a plus/minus sign.
      var multiplier = 1;
      if (HEAP8[(str)] == 45) {
        multiplier = -1;
        str++;
      } else if (HEAP8[(str)] == 43) {
        str++;
      }
      // Find base.
      var finalBase = base;
      if (!finalBase) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            finalBase = 16;
            str += 2;
          } else {
            finalBase = 8;
            str++;
          }
        }
      } else if (finalBase==16) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            str += 2;
          }
        }
      }
      if (!finalBase) finalBase = 10;
      // Get digits.
      var chr;
      var ret = 0;
      while ((chr = HEAP8[(str)]) != 0) {
        var digit = parseInt(String.fromCharCode(chr), finalBase);
        if (isNaN(digit)) {
          break;
        } else {
          ret = ret * finalBase + digit;
          str++;
        }
      }
      // Apply sign.
      ret *= multiplier;
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str
      }
      // Unsign if needed.
      if (unsign) {
        if (Math.abs(ret) > max) {
          ret = max;
          ___setErrNo(ERRNO_CODES.ERANGE);
        } else {
          ret = unSign(ret, bits);
        }
      }
      // Validate range.
      if (ret > max || ret < min) {
        ret = ret > max ? max : min;
        ___setErrNo(ERRNO_CODES.ERANGE);
      }
      if (bits == 64) {
        return ((asm["setTempRet0"](((Math.min((+(Math.floor((ret)/(+(4294967296))))), (+(4294967295))))|0)>>>0),ret>>>0)|0);
      }
      return ret;
    }function _strtoul(str, endptr, base) {
      return __parseInt(str, endptr, base, 0, 4294967295, 32, true);  // ULONG_MAX.
    }
  function _strtol(str, endptr, base) {
      return __parseInt(str, endptr, base, -2147483648, 2147483647, 32);  // LONG_MIN, LONG_MAX.
    }
  function _printf(format, varargs) {
      // int printf(const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var stdout = HEAP32[((_stdout)>>2)];
      return _fprintf(stdout, format, varargs);
    }
  function _fputs(s, stream) {
      // int fputs(const char *restrict s, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputs.html
      return _write(stream, s, _strlen(s));
    }
  function _vfprintf(s, f, va_arg) {
      return _fprintf(s, f, HEAP32[((va_arg)>>2)]);
    }
  function _puts(s) {
      // int puts(const char *s);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/puts.html
      // NOTE: puts() always writes an extra newline.
      var stdout = HEAP32[((_stdout)>>2)];
      var ret = _fputs(s, stdout);
      if (ret < 0) {
        return ret;
      } else {
        var newlineRet = _fputc(10, stdout);
        return (newlineRet < 0) ? -1 : ret + 1;
      }
    }
  function _strchr(ptr, chr) {
      ptr--;
      do {
        ptr++;
        var val = HEAP8[(ptr)];
        if (val == chr) return ptr;
      } while (val);
      return 0;
    }
  function _usleep(useconds) {
      // int usleep(useconds_t useconds);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/usleep.html
      // We're single-threaded, so use a busy loop. Super-ugly.
      var msec = useconds / 1000;
      var start = Date.now();
      while (Date.now() - start < msec) {
        // Do nothing.
      }
      return 0;
    }
  var ___timespec_struct_layout={__size__:8,tv_sec:0,tv_nsec:4};function _nanosleep(rqtp, rmtp) {
      // int nanosleep(const struct timespec  *rqtp, struct timespec *rmtp);
      var seconds = HEAP32[(((rqtp)+(___timespec_struct_layout.tv_sec))>>2)];
      var nanoseconds = HEAP32[(((rqtp)+(___timespec_struct_layout.tv_nsec))>>2)];
      HEAP32[(((rmtp)+(___timespec_struct_layout.tv_sec))>>2)]=0
      HEAP32[(((rmtp)+(___timespec_struct_layout.tv_nsec))>>2)]=0
      return _usleep((seconds * 1e6) + (nanoseconds / 1000));
    }
  function _SDL_PollEvent(ptr) {
      if (SDL.events.length === 0) return 0;
      if (ptr) {
        SDL.makeCEvent(SDL.events.shift(), ptr);
      }
      return 1;
    }
  function _SDL_ShowCursor(toggle) {
      switch (toggle) {
        case 0: // SDL_DISABLE
          if (Browser.isFullScreen) { // only try to lock the pointer when in full screen mode
            Module['canvas'].requestPointerLock();
            return 0;
          } else { // else return SDL_ENABLE to indicate the failure
            return 1;
          }
          break;
        case 1: // SDL_ENABLE
          Module['canvas'].exitPointerLock();
          return 1;
          break;
        case -1: // SDL_QUERY
          return !Browser.pointerLock;
          break;
        default:
          console.log( "SDL_ShowCursor called with unknown toggle parameter value: " + toggle + "." );
          break;
      }
    }
  function _SDL_WM_GrabInput() {}
  function _SDL_GetMouseState(x, y) {
      if (x) HEAP32[((x)>>2)]=Browser.mouseX;
      if (y) HEAP32[((y)>>2)]=Browser.mouseY;
      return SDL.buttonState;
    }
  function _SDL_WM_ToggleFullScreen(surf) {
      if (Browser.isFullScreen) {
        Module['canvas'].cancelFullScreen();
        return 1;
      } else {
        return 0;
      }
    }
  function _SDL_CreateRGBSurfaceFrom(pixels, width, height, depth, pitch, rmask, gmask, bmask, amask) {
      // TODO: Take into account depth and pitch parameters.
      var surface = SDL.makeSurface(width, height, 0, false, 'CreateRGBSurfaceFrom', rmask, gmask, bmask, amask);
      var surfaceData = SDL.surfaces[surface];
      var surfaceImageData = surfaceData.ctx.getImageData(0, 0, width, height);
      var surfacePixelData = surfaceImageData.data;
      // Fill pixel data to created surface.
      // Supports SDL_PIXELFORMAT_RGBA8888 and SDL_PIXELFORMAT_RGB888
      var channels = amask ? 4 : 3; // RGBA8888 or RGB888
      for (var pixelOffset = 0; pixelOffset < width*height; pixelOffset++) {
        surfacePixelData[pixelOffset*4+0] = HEAPU8[pixels + (pixelOffset*channels+0)]; // R
        surfacePixelData[pixelOffset*4+1] = HEAPU8[pixels + (pixelOffset*channels+1)]; // G
        surfacePixelData[pixelOffset*4+2] = HEAPU8[pixels + (pixelOffset*channels+2)]; // B
        surfacePixelData[pixelOffset*4+3] = amask ? HEAPU8[pixels + (pixelOffset*channels+3)] : 0xff; // A
      };
      surfaceData.ctx.putImageData(surfaceImageData, 0, 0);
      return surface;
    }
  function _SDL_UpperBlit(src, srcrect, dst, dstrect) {
      var srcData = SDL.surfaces[src];
      var dstData = SDL.surfaces[dst];
      var sr, dr;
      if (srcrect) {
        sr = SDL.loadRect(srcrect);
      } else {
        sr = { x: 0, y: 0, w: srcData.width, h: srcData.height };
      }
      if (dstrect) {
        dr = SDL.loadRect(dstrect);
      } else {
        dr = { x: 0, y: 0, w: -1, h: -1 };
      }
      dstData.ctx.drawImage(srcData.canvas, sr.x, sr.y, sr.w, sr.h, dr.x, dr.y, sr.w, sr.h);
      if (dst != SDL.screen) {
        // XXX As in IMG_Load, for compatibility we write out |pixels|
        console.log('WARNING: copying canvas data to memory for compatibility');
        _SDL_LockSurface(dst);
        dstData.locked--; // The surface is not actually locked in this hack
      }
      return 0;
    }
  function _SDL_FreeSurface(surf) {
      if (surf) SDL.freeSurface(surf);
    }
  function _SDL_Flip(surf) {
      // We actually do this in Unlock, since the screen surface has as its canvas
      // backing the page canvas element
    }
  function _SDL_SetVideoMode(width, height, depth, flags) {
      ['mousedown', 'mouseup', 'mousemove', 'DOMMouseScroll', 'mousewheel', 'mouseout'].forEach(function(event) {
        if (Module["canvasFront"]) {
          Module['canvasFront'].addEventListener(event, SDL.receiveEvent, true);
        } else {
          Module['canvas'].addEventListener(event, SDL.receiveEvent, true);
        }
      });
      Browser.setCanvasSize(width, height, true);
      // Free the old surface first.
      if (SDL.screen) {
        SDL.freeSurface(SDL.screen);
        SDL.screen = null;
      }
      SDL.screen = SDL.makeSurface(width, height, flags, true, 'screen');
      if (!SDL.addedResizeListener) {
        SDL.addedResizeListener = true;
        Browser.resizeListeners.push(function(w, h) {
          SDL.receiveEvent({
            type: 'resize',
            w: w,
            h: h
          });
        });
      }
      return SDL.screen;
    }
  function _SDL_WM_SetCaption(title, icon) {
      title = title && Pointer_stringify(title);
      icon = icon && Pointer_stringify(icon);
    }
  function _SDL_GetVideoInfo() {
      // %struct.SDL_VideoInfo = type { i32, i32, %struct.SDL_PixelFormat*, i32, i32 } - 5 fields of quantum size
      var ret = _malloc(5*Runtime.QUANTUM_SIZE);
      HEAP32[((ret+Runtime.QUANTUM_SIZE*0)>>2)]=0 // TODO
      HEAP32[((ret+Runtime.QUANTUM_SIZE*1)>>2)]=0 // TODO
      HEAP32[((ret+Runtime.QUANTUM_SIZE*2)>>2)]=0
      HEAP32[((ret+Runtime.QUANTUM_SIZE*3)>>2)]=Module["canvas"].width
      HEAP32[((ret+Runtime.QUANTUM_SIZE*4)>>2)]=Module["canvas"].height
      return ret;
    }
  function _SDL_EnableKeyRepeat(delay, interval) {
      // TODO
    }
  function _SDL_EventState() {}
  function _abort() {
      ABORT = true;
      throw 'abort() at ' + (new Error().stack);
    }
  function ___errno_location() {
      return ___errno_state;
    }var ___errno=___errno_location;
  function _sysconf(name) {
      // long sysconf(int name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/sysconf.html
      switch(name) {
        case 8: return PAGE_SIZE;
        case 54:
        case 56:
        case 21:
        case 61:
        case 63:
        case 22:
        case 67:
        case 23:
        case 24:
        case 25:
        case 26:
        case 27:
        case 69:
        case 28:
        case 101:
        case 70:
        case 71:
        case 29:
        case 30:
        case 199:
        case 75:
        case 76:
        case 32:
        case 43:
        case 44:
        case 80:
        case 46:
        case 47:
        case 45:
        case 48:
        case 49:
        case 42:
        case 82:
        case 33:
        case 7:
        case 108:
        case 109:
        case 107:
        case 112:
        case 119:
        case 121:
          return 200809;
        case 13:
        case 104:
        case 94:
        case 95:
        case 34:
        case 35:
        case 77:
        case 81:
        case 83:
        case 84:
        case 85:
        case 86:
        case 87:
        case 88:
        case 89:
        case 90:
        case 91:
        case 94:
        case 95:
        case 110:
        case 111:
        case 113:
        case 114:
        case 115:
        case 116:
        case 117:
        case 118:
        case 120:
        case 40:
        case 16:
        case 79:
        case 19:
          return -1;
        case 92:
        case 93:
        case 5:
        case 72:
        case 6:
        case 74:
        case 92:
        case 93:
        case 96:
        case 97:
        case 98:
        case 99:
        case 102:
        case 103:
        case 105:
          return 1;
        case 38:
        case 66:
        case 50:
        case 51:
        case 4:
          return 1024;
        case 15:
        case 64:
        case 41:
          return 32;
        case 55:
        case 37:
        case 17:
          return 2147483647;
        case 18:
        case 1:
          return 47839;
        case 59:
        case 57:
          return 99;
        case 68:
        case 58:
          return 2048;
        case 0: return 2097152;
        case 3: return 65536;
        case 14: return 32768;
        case 73: return 32767;
        case 39: return 16384;
        case 60: return 1000;
        case 106: return 700;
        case 52: return 256;
        case 62: return 255;
        case 2: return 100;
        case 65: return 64;
        case 36: return 20;
        case 100: return 16;
        case 20: return 6;
        case 53: return 4;
        case 10: return 1;
      }
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    }
  function _sbrk(bytes) {
      // Implement a Linux-like 'memory area' for our 'process'.
      // Changes the size of the memory area by |bytes|; returns the
      // address of the previous top ('break') of the memory area
      // We control the "dynamic" memory - DYNAMIC_BASE to DYNAMICTOP
      var self = _sbrk;
      if (!self.called) {
        DYNAMICTOP = alignMemoryPage(DYNAMICTOP); // make sure we start out aligned
        self.called = true;
        assert(Runtime.dynamicAlloc);
        self.alloc = Runtime.dynamicAlloc;
        Runtime.dynamicAlloc = function() { abort('cannot dynamically allocate, sbrk now has control') };
      }
      var ret = DYNAMICTOP;
      if (bytes != 0) self.alloc(bytes);
      return ret;  // Previous break location.
    }
__ATINIT__.unshift({ func: function() { if (!Module["noFSInit"] && !FS.init.initialized) FS.init() } });__ATMAIN__.push({ func: function() { FS.ignorePermissions = false } });__ATEXIT__.push({ func: function() { FS.quit() } });Module["FS_createFolder"] = FS.createFolder;Module["FS_createPath"] = FS.createPath;Module["FS_createDataFile"] = FS.createDataFile;Module["FS_createPreloadedFile"] = FS.createPreloadedFile;Module["FS_createLazyFile"] = FS.createLazyFile;Module["FS_createLink"] = FS.createLink;Module["FS_createDevice"] = FS.createDevice;
___errno_state = Runtime.staticAlloc(4); HEAP32[((___errno_state)>>2)]=0;
_fgetc.ret = allocate([0], "i8", ALLOC_STATIC);
_fputc.ret = allocate([0], "i8", ALLOC_STATIC);
Module["requestFullScreen"] = function(lockPointer, resizeCanvas) { Browser.requestFullScreen(lockPointer, resizeCanvas) };
  Module["requestAnimationFrame"] = function(func) { Browser.requestAnimationFrame(func) };
  Module["pauseMainLoop"] = function() { Browser.mainLoop.pause() };
  Module["resumeMainLoop"] = function() { Browser.mainLoop.resume() };
  Module["getUserMedia"] = function() { Browser.getUserMedia() }
STACK_BASE = STACKTOP = Runtime.alignMemory(STATICTOP);
staticSealed = true; // seal the static portion of memory
STACK_MAX = STACK_BASE + 5242880;
DYNAMIC_BASE = DYNAMICTOP = Runtime.alignMemory(STACK_MAX);
assert(DYNAMIC_BASE < TOTAL_MEMORY); // Stack must fit in TOTAL_MEMORY; allocations from here on may enlarge TOTAL_MEMORY
 var ctlz_i8 = allocate([8,7,6,6,5,5,5,5,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_DYNAMIC);
 var cttz_i8 = allocate([8,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,7,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0], "i8", ALLOC_DYNAMIC);
var Math_min = Math.min;
function invoke_ii(index,a1) {
  try {
    return Module["dynCall_ii"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vi(index,a1) {
  try {
    Module["dynCall_vi"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vii(index,a1,a2) {
  try {
    Module["dynCall_vii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiii(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viii(index,a1,a2,a3) {
  try {
    Module["dynCall_viii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_v(index) {
  try {
    Module["dynCall_v"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiii(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iiiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iii(index,a1,a2) {
  try {
    return Module["dynCall_iii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiiii(index,a1,a2,a3,a4,a5) {
  try {
    return Module["dynCall_iiiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiii(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function asmPrintInt(x, y) {
  Module.print('int ' + x + ',' + y);// + ' ' + new Error().stack);
}
function asmPrintFloat(x, y) {
  Module.print('float ' + x + ',' + y);// + ' ' + new Error().stack);
}
// EMSCRIPTEN_START_ASM
var asm=(function(global,env,buffer){"use asm";var a=new global.Int8Array(buffer);var b=new global.Int16Array(buffer);var c=new global.Int32Array(buffer);var d=new global.Uint8Array(buffer);var e=new global.Uint16Array(buffer);var f=new global.Uint32Array(buffer);var g=new global.Float32Array(buffer);var h=new global.Float64Array(buffer);var i=env.STACKTOP|0;var j=env.STACK_MAX|0;var k=env.tempDoublePtr|0;var l=env.ABORT|0;var m=env.cttz_i8|0;var n=env.ctlz_i8|0;var o=env._stdout|0;var p=env._stdin|0;var q=env._stderr|0;var r=+env.NaN;var s=+env.Infinity;var t=0;var u=0;var v=0;var w=0;var x=0,y=0,z=0,A=0,B=0.0,C=0,D=0,E=0,F=0.0;var G=0;var H=0;var I=0;var J=0;var K=0;var L=0;var M=0;var N=0;var O=0;var P=0;var Q=global.Math.floor;var R=global.Math.abs;var S=global.Math.sqrt;var T=global.Math.pow;var U=global.Math.cos;var V=global.Math.sin;var W=global.Math.tan;var X=global.Math.acos;var Y=global.Math.asin;var Z=global.Math.atan;var _=global.Math.atan2;var $=global.Math.exp;var aa=global.Math.log;var ab=global.Math.ceil;var ac=global.Math.imul;var ad=env.abort;var ae=env.assert;var af=env.asmPrintInt;var ag=env.asmPrintFloat;var ah=env.min;var ai=env.invoke_ii;var aj=env.invoke_vi;var ak=env.invoke_vii;var al=env.invoke_iiii;var am=env.invoke_viii;var an=env.invoke_v;var ao=env.invoke_iiiii;var ap=env.invoke_iii;var aq=env.invoke_iiiiii;var ar=env.invoke_viiii;var as=env._llvm_lifetime_end;var at=env._lseek;var au=env._fclose;var av=env._SDL_EventState;var aw=env._strtoul;var ax=env._fflush;var ay=env._SDL_GetMouseState;var az=env._strtol;var aA=env._fputc;var aB=env._fwrite;var aC=env._ptsname;var aD=env._send;var aE=env._tcflush;var aF=env._fputs;var aG=env._emscripten_cancel_main_loop;var aH=env._localtime;var aI=env._SDL_WasInit;var aJ=env._read;var aK=env._fileno;var aL=env._fsync;var aM=env._signal;var aN=env._SDL_PauseAudio;var aO=env._SDL_LockAudio;var aP=env._strcmp;var aQ=env._strncmp;var aR=env._snprintf;var aS=env._fgetc;var aT=env._atexit;var aU=env._close;var aV=env._tcsetattr;var aW=env._strchr;var aX=env._tcgetattr;var aY=env._poll;var aZ=env.___setErrNo;var a_=env._grantpt;var a$=env._ftell;var a0=env._exit;var a1=env._sprintf;var a2=env._fcntl;var a3=env._SDL_ShowCursor;var a4=env._gmtime;var a5=env._localtime_r;var a6=env._symlink;var a7=env._ftruncate;var a8=env._recv;var a9=env._cos;var ba=env._SDL_PollEvent;var bb=env._SDL_Init;var bc=env.__exit;var bd=env._SDL_WM_GrabInput;var be=env._llvm_va_end;var bf=env._tzset;var bg=env._SDL_CreateRGBSurfaceFrom;var bh=env._printf;var bi=env._unlockpt;var bj=env._pread;var bk=env._SDL_SetVideoMode;var bl=env._fopen;var bm=env._open;var bn=env._usleep;var bo=env._SDL_EnableKeyRepeat;var bp=env._puts;var bq=env._SDL_GetVideoInfo;var br=env._nanosleep;var bs=env._SDL_Flip;var bt=env._SDL_InitSubSystem;var bu=env._strdup;var bv=env._SDL_GetError;var bw=env.__formatString;var bx=env._gettimeofday;var by=env._vfprintf;var bz=env._SDL_WM_SetCaption;var bA=env._sbrk;var bB=env.___errno_location;var bC=env._SDL_CloseAudio;var bD=env._isspace;var bE=env._llvm_lifetime_start;var bF=env.__parseInt;var bG=env._SDL_OpenAudio;var bH=env._SDL_UnlockAudio;var bI=env._gmtime_r;var bJ=env._sysconf;var bK=env._fread;var bL=env._SDL_WM_ToggleFullScreen;var bM=env._abort;var bN=env._fprintf;var bO=env._tan;var bP=env.__reallyNegative;var bQ=env._posix_openpt;var bR=env._feof;var bS=env._fseek;var bT=env._write;var bU=env._SDL_UpperBlit;var bV=env._rewind;var bW=env._sin;var bX=env._truncate;var bY=env._emscripten_set_main_loop;var bZ=env._unlink;var b_=env._pwrite;var b$=env._SDL_FreeSurface;var b0=env._time;
// EMSCRIPTEN_START_FUNCS
function cb(a){a=a|0;var b=0;b=i;i=i+a|0;i=i+7>>3<<3;return b|0}function cc(){return i|0}function cd(a){a=a|0;i=a}function ce(a,b){a=a|0;b=b|0;if((t|0)==0){t=a;u=b}}function cf(b){b=b|0;a[k]=a[b];a[k+1|0]=a[b+1|0];a[k+2|0]=a[b+2|0];a[k+3|0]=a[b+3|0]}function cg(b){b=b|0;a[k]=a[b];a[k+1|0]=a[b+1|0];a[k+2|0]=a[b+2|0];a[k+3|0]=a[b+3|0];a[k+4|0]=a[b+4|0];a[k+5|0]=a[b+5|0];a[k+6|0]=a[b+6|0];a[k+7|0]=a[b+7|0]}function ch(a){a=a|0;G=a}function ci(a){a=a|0;H=a}function cj(a){a=a|0;I=a}function ck(a){a=a|0;J=a}function cl(a){a=a|0;K=a}function cm(a){a=a|0;L=a}function cn(a){a=a|0;M=a}function co(a){a=a|0;N=a}function cp(a){a=a|0;O=a}function cq(a){a=a|0;P=a}function cr(){}function cs(b){b=b|0;return a[b+17|0]|0}function ct(){var a=0,b=0;a=zH(168)|0;if((a|0)==0){b=0;return b|0}zP(a|0,0,18);c[a+20>>2]=64;c[a+160>>2]=0;c[a+164>>2]=0;c[a+24>>2]=0;zP(a+124|0,0,5);zP(a+132|0,0,6);zP(a+140|0,0,17);c[a+28>>2]=569;c[a+32>>2]=1139;c[a+36>>2]=569;c[a+40>>2]=16384;c[a+44>>2]=-23060;c[a+48>>2]=8956;zP(a+52|0,0,24);c[a+76>>2]=569;c[a+80>>2]=1139;c[a+84>>2]=569;c[a+88>>2]=16384;c[a+92>>2]=-23060;c[a+96>>2]=8956;zP(a+100|0,0,24);b=a;return b|0}function cu(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;e=b+156|0;f=b+164|0;if((a[e]|0)!=0){g=c[f>>2]|0;au(g|0)|0}a[e]=0;c[f>>2]=0;g=b+160|0;zI(c[g>>2]|0);c[g>>2]=0;h=b+4|0;c[h>>2]=0;i=b+8|0;c[i>>2]=0;c[b+12>>2]=0;if((d|0)==0){j=0;return j|0}k=bl(d|0,41872)|0;c[f>>2]=k;do{if((k|0)==0){l=bl(d|0,41864)|0;c[f>>2]=l;if((l|0)==0){j=1}else{m=l;break}return j|0}else{m=k}}while(0);a[e]=1;bS(m|0,0,2)|0;m=a$(c[f>>2]|0)|0;c[h>>2]=m;e=b+144|0;c[e>>2]=0;k=b+140|0;l=b+148|0;c[l>>2]=c[k>>2];n=b+152|0;c[n>>2]=0;o=b+24|0;c[o>>2]=0;p=b+124|0;c[p>>2]=0;q=b+128|0;a[q]=0;r=b+132|0;c[r>>2]=0;s=b+136|0;a[s]=0;t=b+137|0;a[t]=0;u=b+28|0;c[u>>2]=569;v=b+32|0;c[v>>2]=1139;w=b+36|0;c[w>>2]=569;x=b+40|0;c[x>>2]=16384;y=b+44|0;c[y>>2]=-23060;z=b+48|0;c[z>>2]=8956;A=b+52|0;zP(A|0,0,24);B=b+76|0;c[B>>2]=569;C=b+80|0;c[C>>2]=1139;D=b+84|0;c[D>>2]=569;E=b+88|0;c[E>>2]=16384;F=b+92|0;c[F>>2]=-23060;G=b+96|0;c[G>>2]=8956;H=b+100|0;zP(H|0,0,24);c[i>>2]=m;do{if((a[b|0]|0)==0){m=c[f>>2]|0;if((m|0)==0){break}if((bS(m|0,0,0)|0)!=0){break}c[h>>2]=0;c[e>>2]=0;c[l>>2]=c[k>>2];c[n>>2]=0;c[o>>2]=0;c[p>>2]=0;a[q]=0;c[r>>2]=0;a[s]=0;a[t]=0;c[u>>2]=569;c[v>>2]=1139;c[w>>2]=569;c[x>>2]=16384;c[y>>2]=-23060;c[z>>2]=8956;zP(A|0,0,24);c[B>>2]=569;c[C>>2]=1139;c[D>>2]=569;c[E>>2]=16384;c[F>>2]=-23060;c[G>>2]=8956;zP(H|0,0,24)}}while(0);h=zN(d|0)|0;f=h+1|0;m=zH(f)|0;c[g>>2]=m;if((m|0)!=0){zO(m|0,d|0,f)|0}if(h>>>0<=4){j=0;return j|0}f=d+(h-4)|0;if((aP(f|0,33672)|0)==0){a[b+1|0]=1;c[e>>2]=0;c[l>>2]=c[k>>2];c[n>>2]=0;c[o>>2]=0;c[p>>2]=0;a[q]=0;c[r>>2]=0;a[s]=0;a[t]=0;c[u>>2]=569;c[v>>2]=1139;c[w>>2]=569;c[x>>2]=16384;c[y>>2]=-23060;c[z>>2]=8956;zP(A|0,0,24);c[B>>2]=569;c[C>>2]=1139;c[D>>2]=569;c[E>>2]=16384;c[F>>2]=-23060;c[G>>2]=8956;zP(H|0,0,24);j=0;return j|0}if((aP(f|0,31288)|0)==0){a[b+1|0]=1;c[e>>2]=0;c[l>>2]=c[k>>2];c[n>>2]=0;c[o>>2]=0;c[p>>2]=0;a[q]=0;c[r>>2]=0;a[s]=0;a[t]=0;c[u>>2]=569;c[v>>2]=1139;c[w>>2]=569;c[x>>2]=16384;c[y>>2]=-23060;c[z>>2]=8956;zP(A|0,0,24);c[B>>2]=569;c[C>>2]=1139;c[D>>2]=569;c[E>>2]=16384;c[F>>2]=-23060;c[G>>2]=8956;zP(H|0,0,24);j=0;return j|0}if((aP(f|0,29232)|0)!=0){j=0;return j|0}a[b+1|0]=0;c[e>>2]=0;c[l>>2]=c[k>>2];c[n>>2]=0;c[o>>2]=0;c[p>>2]=0;a[q]=0;c[r>>2]=0;a[s]=0;a[t]=0;c[u>>2]=569;c[v>>2]=1139;c[w>>2]=569;c[x>>2]=16384;c[y>>2]=-23060;c[z>>2]=8956;zP(A|0,0,24);c[B>>2]=569;c[C>>2]=1139;c[D>>2]=569;c[E>>2]=16384;c[F>>2]=-23060;c[G>>2]=8956;zP(H|0,0,24);j=0;return j|0}function cv(b){b=b|0;var d=0,e=0;d=b+164|0;e=c[d>>2]|0;if((e|0)!=0){bS(e|0,0,2)|0;c[b+4>>2]=a$(c[d>>2]|0)|0}c[b+144>>2]=0;c[b+148>>2]=c[b+140>>2];c[b+152>>2]=0;c[b+24>>2]=0;c[b+124>>2]=0;a[b+128|0]=0;c[b+132>>2]=0;a[b+136|0]=0;a[b+137|0]=0;c[b+28>>2]=569;c[b+32>>2]=1139;c[b+36>>2]=569;c[b+40>>2]=16384;c[b+44>>2]=-23060;c[b+48>>2]=8956;zP(b+52|0,0,24);c[b+76>>2]=569;c[b+80>>2]=1139;c[b+84>>2]=569;c[b+88>>2]=16384;c[b+92>>2]=-23060;c[b+96>>2]=8956;zP(b+100|0,0,24);return}function cw(b,d){b=b|0;d=d|0;var e=0,f=0;e=c[b+164>>2]|0;if((e|0)==0){f=1;return f|0}if((bS(e|0,d|0,0)|0)!=0){f=1;return f|0}c[b+4>>2]=d;c[b+144>>2]=0;c[b+148>>2]=c[b+140>>2];c[b+152>>2]=0;c[b+24>>2]=0;c[b+124>>2]=0;a[b+128|0]=0;c[b+132>>2]=0;a[b+136|0]=0;a[b+137|0]=0;c[b+28>>2]=569;c[b+32>>2]=1139;c[b+36>>2]=569;c[b+40>>2]=16384;c[b+44>>2]=-23060;c[b+48>>2]=8956;zP(b+52|0,0,24);c[b+76>>2]=569;c[b+80>>2]=1139;c[b+84>>2]=569;c[b+88>>2]=16384;c[b+92>>2]=-23060;c[b+96>>2]=8956;zP(b+100|0,0,24);f=0;return f|0}function cx(b,d){b=b|0;d=d|0;a[b+1|0]=(d|0)!=0|0;c[b+144>>2]=0;c[b+148>>2]=c[b+140>>2];c[b+152>>2]=0;c[b+24>>2]=0;c[b+124>>2]=0;a[b+128|0]=0;c[b+132>>2]=0;a[b+136|0]=0;a[b+137|0]=0;c[b+28>>2]=569;c[b+32>>2]=1139;c[b+36>>2]=569;c[b+40>>2]=16384;c[b+44>>2]=-23060;c[b+48>>2]=8956;zP(b+52|0,0,24);c[b+76>>2]=569;c[b+80>>2]=1139;c[b+84>>2]=569;c[b+88>>2]=16384;c[b+92>>2]=-23060;c[b+96>>2]=8956;zP(b+100|0,0,24);return}function cy(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=(d|0)!=0;d=b|0;f=a[d]|0;if((f<<24>>24|0)==(e&1|0)){return}g=b+4|0;h=c[g>>2]|0;if(f<<24>>24==0){c[b+12>>2]=h;i=b+8|0}else{c[b+8>>2]=h;i=b+12|0}c[g>>2]=c[i>>2];a[d]=e&1;e=b+164|0;d=c[e>>2]|0;do{if((d|0)!=0){ax(d|0)|0;i=c[g>>2]|0;h=c[e>>2]|0;if((h|0)==0){break}if((bS(h|0,i|0,0)|0)!=0){break}c[g>>2]=i;c[b+144>>2]=0;c[b+148>>2]=c[b+140>>2];c[b+152>>2]=0;c[b+24>>2]=0;c[b+124>>2]=0;a[b+128|0]=0;c[b+132>>2]=0;a[b+136|0]=0;a[b+137|0]=0;c[b+28>>2]=569;c[b+32>>2]=1139;c[b+36>>2]=569;c[b+40>>2]=16384;c[b+44>>2]=-23060;c[b+48>>2]=8956;zP(b+52|0,0,24);c[b+76>>2]=569;c[b+80>>2]=1139;c[b+84>>2]=569;c[b+88>>2]=16384;c[b+92>>2]=-23060;c[b+96>>2]=8956;zP(b+100|0,0,24)}}while(0);c[b+144>>2]=0;c[b+148>>2]=c[b+140>>2];c[b+152>>2]=0;c[b+24>>2]=0;c[b+124>>2]=0;a[b+128|0]=0;c[b+132>>2]=0;a[b+136|0]=0;a[b+137|0]=0;c[b+28>>2]=569;c[b+32>>2]=1139;c[b+36>>2]=569;c[b+40>>2]=16384;c[b+44>>2]=-23060;c[b+48>>2]=8956;zP(b+52|0,0,24);c[b+76>>2]=569;c[b+80>>2]=1139;c[b+84>>2]=569;c[b+88>>2]=16384;c[b+92>>2]=-23060;c[b+96>>2]=8956;zP(b+100|0,0,24);return}function cz(b,d){b=b|0;d=d|0;var e=0;e=(d|0)!=0;a[b+2|0]=e&1;c[b+20>>2]=e?128:64;c[b+144>>2]=0;c[b+148>>2]=c[b+140>>2];c[b+152>>2]=0;c[b+24>>2]=0;c[b+124>>2]=0;a[b+128|0]=0;c[b+132>>2]=0;a[b+136|0]=0;a[b+137|0]=0;c[b+28>>2]=569;c[b+32>>2]=1139;c[b+36>>2]=569;c[b+40>>2]=16384;c[b+44>>2]=-23060;c[b+48>>2]=8956;zP(b+52|0,0,24);c[b+76>>2]=569;c[b+80>>2]=1139;c[b+84>>2]=569;c[b+88>>2]=16384;c[b+92>>2]=-23060;c[b+96>>2]=8956;zP(b+100|0,0,24);return}function cA(b){b=b|0;var d=0;d=c[b+164>>2]|0;if((d|0)!=0){bV(d|0);c[b+4>>2]=0}c[b+144>>2]=0;c[b+148>>2]=c[b+140>>2];c[b+152>>2]=0;c[b+24>>2]=0;c[b+124>>2]=0;a[b+128|0]=0;c[b+132>>2]=0;a[b+136|0]=0;a[b+137|0]=0;c[b+28>>2]=569;c[b+32>>2]=1139;c[b+36>>2]=569;c[b+40>>2]=16384;c[b+44>>2]=-23060;c[b+48>>2]=8956;zP(b+52|0,0,24);c[b+76>>2]=569;c[b+80>>2]=1139;c[b+84>>2]=569;c[b+88>>2]=16384;c[b+92>>2]=-23060;c[b+96>>2]=8956;zP(b+100|0,0,24);return}function cB(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;g=e<<24>>24!=0;e=b+3|0;if((g&1|0)==(d[e]|0|0)){i=f;return}h=b+4|0;j=c[h>>2]|0;k=c[b+160>>2]|0;w2(27504,(x=i,i=i+24|0,c[x>>2]=g?25888:24680,c[x+8>>2]=j,c[x+16>>2]=(k|0)==0?23120:k,x)|0);a[e]=g&1;g=b+164|0;e=c[g>>2]|0;do{if((e|0)!=0){ax(e|0)|0;k=c[h>>2]|0;j=c[g>>2]|0;if((j|0)==0){break}if((bS(j|0,k|0,0)|0)!=0){break}c[h>>2]=k;c[b+144>>2]=0;c[b+148>>2]=c[b+140>>2];c[b+152>>2]=0;c[b+24>>2]=0;c[b+124>>2]=0;a[b+128|0]=0;c[b+132>>2]=0;a[b+136|0]=0;a[b+137|0]=0;c[b+28>>2]=569;c[b+32>>2]=1139;c[b+36>>2]=569;c[b+40>>2]=16384;c[b+44>>2]=-23060;c[b+48>>2]=8956;zP(b+52|0,0,24);c[b+76>>2]=569;c[b+80>>2]=1139;c[b+84>>2]=569;c[b+88>>2]=16384;c[b+92>>2]=-23060;c[b+96>>2]=8956;zP(b+100|0,0,24)}}while(0);c[b+144>>2]=0;c[b+148>>2]=c[b+140>>2];c[b+152>>2]=0;c[b+24>>2]=0;c[b+124>>2]=0;a[b+128|0]=0;c[b+132>>2]=0;a[b+136|0]=0;a[b+137|0]=0;c[b+28>>2]=569;c[b+32>>2]=1139;c[b+36>>2]=569;c[b+40>>2]=16384;c[b+44>>2]=-23060;c[b+48>>2]=8956;zP(b+52|0,0,24);c[b+76>>2]=569;c[b+80>>2]=1139;c[b+84>>2]=569;c[b+88>>2]=16384;c[b+92>>2]=-23060;c[b+96>>2]=8956;zP(b+100|0,0,24);i=f;return}function cC(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0;f=e<<24>>24!=0;e=f&1;if((a[b+3|0]|0)==0){a[b+17|0]=e;return}g=b+16|0;if((d[g]|0)==(f&1|0)){return}a[g]=e;if((a[b+1|0]|0)!=0){e=c[b+20>>2]|0;c[b+24>>2]=f?-e|0:e;return}if((a[b|0]|0)==0|f^1){return}f=c[b+140>>2]|0;e=b+148|0;g=f-(c[e>>2]|0)|0;c[e>>2]=f;if(g>>>0<298){return}if(g>>>0<894){f=b+124|0;e=(c[f>>2]|0)+1|0;c[f>>2]=e;if(e>>>0<=7){return}e=c[b+164>>2]|0;h=b+128|0;if((e|0)!=0){i=d[h]|0;aA(i|0,e|0)|0;e=b+4|0;c[e>>2]=(c[e>>2]|0)+1}a[h]=0;c[f>>2]=0;return}if(g>>>0>=1491){return}g=b+124|0;f=c[g>>2]|0;h=b+128|0;e=d[h]|128>>>(f>>>0);a[h]=e&255;i=f+1|0;c[g>>2]=i;if(i>>>0<=7){return}i=c[b+164>>2]|0;if((i|0)!=0){f=e&255;aA(f|0,i|0)|0;i=b+4|0;c[i>>2]=(c[i>>2]|0)+1}a[h]=0;c[g>>2]=0;return}function cD(b){b=b|0;var d=0,e=0,f=0,g=0;d=i;if((a[b+1|0]|0)==0){e=40800}else{e=(a[b+2|0]|0)!=0?21824:41856}f=c[b+4>>2]|0;g=c[b+160>>2]|0;w2(39200,(x=i,i=i+32|0,c[x>>2]=(a[b|0]|0)!=0?38176:37192,c[x+8>>2]=e,c[x+16>>2]=f,c[x+24>>2]=(g|0)==0?23120:g,x)|0);i=d;return}function cE(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;f=b+140|0;c[f>>2]=(c[f>>2]|0)+d;if((a[b+3|0]|0)==0){i=e;return}if((a[b+1|0]|0)==0){if((a[b|0]|0)!=0){i=e;return}f=b+152|0;g=c[f>>2]|0;if(g>>>0>d>>>0){c[f>>2]=g-d;i=e;return}h=d-g|0;g=b+17|0;j=(a[g]|0)==0;a[g]=j&1;L137:do{if(j){g=b+132|0;k=c[g>>2]|0;do{if((k|0)==0){l=b+164|0;m=c[l>>2]|0;if((m|0)==0){break L137}if((bR(m|0)|0)!=0){break L137}m=aS(c[l>>2]|0)|0;l=b+4|0;n=c[l>>2]|0;if((m|0)==-1){w2(35248,(x=i,i=i+8|0,c[x>>2]=n,x)|0);break L137}else{c[l>>2]=n+1;c[g>>2]=8;n=m&255;a[b+136|0]=n;o=7;p=n;break}}else{o=k-1|0;p=a[b+136|0]|0}}while(0);a[b+137|0]=(p&255)>>>7;a[b+136|0]=p<<1;c[g>>2]=o}}while(0);o=(a[b+137|0]|0)==0?298:596;c[f>>2]=o;if(o>>>0<=h>>>0){i=e;return}c[f>>2]=o-h;i=e;return}h=b+144|0;o=(c[h>>2]|0)+(d*44100|0)|0;c[h>>2]=(o>>>0)%1193182|0;h=(o>>>0)/1193182|0;if(o>>>0<1193182){i=e;return}if((a[b|0]|0)==0){o=b+164|0;d=b+4|0;f=b+104|0;p=b+108|0;j=b+100|0;k=b+116|0;n=b+120|0;m=b+112|0;l=b+76|0;q=b+80|0;r=b+84|0;s=b+92|0;t=b+96|0;u=0;do{do{if((bR(c[o>>2]|0)|0)==0){v=aS(c[o>>2]|0)|0;w=c[d>>2]|0;if((v|0)==-1){w2(35248,(x=i,i=i+8|0,c[x>>2]=w,x)|0);y=1;break}else{c[d>>2]=w+1;w=c[f>>2]|0;c[p>>2]=w;z=c[j>>2]|0;c[f>>2]=z;A=((v&128|0)!=0?v-256|0:v)<<5;c[j>>2]=A;v=c[k>>2]|0;c[n>>2]=v;B=c[m>>2]|0;c[k>>2]=B;C=ac(c[l>>2]|0,A)|0;A=ac(c[q>>2]|0,z)|0;z=A+C+(ac(c[r>>2]|0,w)|0)|0;w=ac(c[s>>2]|0,B)|0;B=z-w-(ac(c[t>>2]|0,v)|0)|0;c[m>>2]=(B|0)/16384|0;y=((B|0)/524288|0)>>>31&255^1;break}}else{y=1}}while(0);u=u+1|0;}while(u>>>0<h>>>0);a[b+17|0]=y;i=e;return}y=b+24|0;u=b+2|0;m=b+164|0;t=b+4|0;s=b+56|0;r=b+60|0;q=b+52|0;l=b+68|0;k=b+72|0;n=b+64|0;j=b+28|0;f=b+32|0;p=b+36|0;d=b+44|0;o=b+48|0;b=1;g=a[u]|0;while(1){B=c[y>>2]|0;if(g<<24>>24==0){D=B}else{v=c[s>>2]|0;c[r>>2]=v;w=c[q>>2]|0;c[s>>2]=w;z=B<<5;c[q>>2]=z;B=c[l>>2]|0;c[k>>2]=B;C=c[n>>2]|0;c[l>>2]=C;A=ac(c[j>>2]|0,z)|0;z=ac(c[f>>2]|0,w)|0;w=z+A+(ac(c[p>>2]|0,v)|0)|0;v=ac(c[d>>2]|0,C)|0;C=w-v-(ac(c[o>>2]|0,B)|0)|0;c[n>>2]=(C|0)/16384|0;D=(C|0)/524288|0}if((D|0)<0){E=(D|0)<-127?-128:D&255}else{E=(D|0)>127?127:D&255}aA(E&255|0,c[m>>2]|0)|0;c[t>>2]=(c[t>>2]|0)+1;C=a[u]|0;if(C<<24>>24!=0){c[y>>2]=((c[y>>2]|0)*15|0|0)/16|0}if(b>>>0>=h>>>0){break}b=b+1|0;g=C}i=e;return}function cF(b){b=b|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;w3(34760);f=e[b+10>>1]|0;g=e[b+6>>1]|0;h=e[b+8>>1]|0;j=e[b+12>>1]|0;k=e[b+14>>1]|0;l=e[b+16>>1]|0;m=e[b+18>>1]|0;n=c[(c[10742]|0)+3140>>2]|0;w2(39520,(x=i,i=i+80|0,c[x>>2]=e[b+4>>1]|0,c[x+8>>2]=f,c[x+16>>2]=g,c[x+24>>2]=h,c[x+32>>2]=j,c[x+40>>2]=k,c[x+48>>2]=l,c[x+56>>2]=m,c[x+64>>2]=n&255,c[x+72>>2]=(n&256|0)!=0?42:32,x)|0);n=e[b+26>>1]|0;m=e[b+20>>1]|0;l=e[b+24>>1]|0;k=e[b+28>>1]|0;j=b+30|0;h=e[j>>1]|0;w2(32592,(x=i,i=i+48|0,c[x>>2]=e[b+22>>1]|0,c[x+8>>2]=n,c[x+16>>2]=m,c[x+24>>2]=l,c[x+32>>2]=k,c[x+40>>2]=h,x)|0);h=e[j>>1]|0;j=a[768+(h>>>10&1)|0]|0;k=a[768+(h>>>11&1)|0]|0;l=a[768+(h>>>7&1)|0]|0;m=a[768+(h>>>6&1)|0]|0;n=a[768+(h>>>4&1)|0]|0;g=a[768+(h>>>2&1)|0]|0;f=a[768+(h&1)|0]|0;w2(30616,(x=i,i=i+64|0,c[x>>2]=a[768+(h>>>9&1)|0]|0,c[x+8>>2]=j,c[x+16>>2]=k,c[x+24>>2]=l,c[x+32>>2]=m,c[x+40>>2]=n,c[x+48>>2]=g,c[x+56>>2]=f,x)|0);if((c[b+152>>2]|0)==0){i=d;return}w2(28528,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);i=d;return}function cG(b){b=b|0;var d=0,e=0,f=0,g=0;d=b+3168|0;xM(d);dh(b);if((c[d>>2]|0)==0){e=b+3172|0;f=b+3128|0;g=b+3028|0;do{if((a[e]|0)==0){di(b,c[f>>2]<<2)}else{xU(1e5)|0;zt(c[g>>2]|0)}}while((c[d>>2]|0)==0)}d=b+3140|0;c[d>>2]=c[d>>2]&255;xL();return}function cH(a){a=a|0;var b=0;c[11094]=a;xM(a+3168|0);dh(a);bY(4,100,1)|0;b=a+3140|0;c[b>>2]=c[b>>2]&255;return}function cI(){var a=0,b=0,d=0;a=0;while(1){if((a|0)>=1e4){b=163;break}d=c[11094]|0;di(d,c[d+3128>>2]<<2);if((c[(c[11094]|0)+3168>>2]|0)==0){a=a+1|0}else{break}}if((b|0)==163){return}xL();aG()|0;return}function cJ(f,g){f=f|0;g=g|0;var j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0.0,aj=0,ak=0,al=0.0;j=i;i=i+2496|0;k=j|0;l=j+8|0;m=j+16|0;n=j+24|0;p=j+32|0;q=j+264|0;r=j+496|0;s=j+504|0;t=j+736|0;u=j+744|0;v=j+976|0;w=j+984|0;y=j+1240|0;z=j+1472|0;A=j+1480|0;B=j+1712|0;C=j+1720|0;D=j+1728|0;E=j+1736|0;F=j+1744|0;H=j+1976|0;I=j+1984|0;J=j+1992|0;K=j+2224|0;L=j+2480|0;M=j+2488|0;N=c[f+3028>>2]|0;if((N|0)!=0){zt(N)}if((wM(g,26872)|0)!=0){if((wL(g)|0)!=0){N=c7(f)|0;w2(35752,(x=i,i=i+8|0,c[x>>2]=N,x)|0);O=0;i=j;return O|0}if((wS(g,M)|0)==0){wK(g,35712);O=0;i=j;return O|0}if((wP(g)|0)==0){O=0;i=j;return O|0}c6(f,e[M>>1]|0);O=0;i=j;return O|0}if((wM(g,25336)|0)!=0){wI(g,f+3068|0);O=0;i=j;return O|0}if((wM(g,24088)|0)!=0){c[L>>2]=1;wT(g,L)|0;if((wP(g)|0)==0){O=0;i=j;return O|0}dh(f);if((c[L>>2]|0)!=0){do{di(f,1);M=(c[L>>2]|0)-1|0;c[L>>2]=M;}while((M|0)!=0)}L=K|0;M=f|0;eI(c[M>>2]|0,J);cP(L,J);cF(c[M>>2]|0);J=c[M>>2]|0;M=e[J+28>>1]|0;w2(26496,(x=i,i=i+24|0,c[x>>2]=e[J+22>>1]|0,c[x+8>>2]=M,c[x+16>>2]=L,x)|0);O=0;i=j;return O|0}if((wM(g,22512)|0)!=0){if((wM(g,25336)|0)==0){L=(wM(g,31280)|0)==0;M=(wP(g)|0)==0;if(L){if(M){O=0;i=j;return O|0}cG(f);O=0;i=j;return O|0}if(M){O=0;i=j;return O|0}M=f|0;L=b[(c[M>>2]|0)+22>>1]|0;J=f+3168|0;xM(J);dh(f);N=f+3140|0;P=f+3068|0;Q=L&65535;do{c[N>>2]=c[N>>2]&255;R=hX(c[M>>2]|0)|0;S=G;do{T=hX(c[M>>2]|0)|0;if(!((T|0)==(R|0)&(G|0)==(S|0))){break}di(f,1);}while((c[J>>2]|0)==0);U=c[M>>2]|0;if((b[U+22>>1]|0)!=L<<16>>16){V=205;break}if((wH(P,Q,e[U+28>>1]|0,c[o>>2]|0)|0)!=0){break}}while((c[J>>2]|0)==0);if((V|0)==205){J=K|0;eI(U,F);cP(J,F);cF(c[M>>2]|0);F=c[M>>2]|0;M=e[F+28>>1]|0;w2(26496,(x=i,i=i+24|0,c[x>>2]=e[F+22>>1]|0,c[x+8>>2]=M,c[x+16>>2]=J,x)|0)}xL();O=0;i=j;return O|0}L269:do{if((wT(g,H)|0)!=0){J=f+3068|0;while(1){if((wM(g,35904)|0)==0){W=wx(c[H>>2]|0)|0}else{if((wT(g,I)|0)==0){break}W=wA(c[H>>2]&65535,c[I>>2]&65535)|0}wG(J,W)|0;if((wT(g,H)|0)==0){break L269}}wK(g,35792);O=0;i=j;return O|0}}while(0);if((wP(g)|0)==0){O=0;i=j;return O|0}H=f+3168|0;xM(H);dh(f);W=f+3140|0;I=f|0;J=f+3068|0;do{c[W>>2]=c[W>>2]&255;M=hX(c[I>>2]|0)|0;F=G;do{U=hX(c[I>>2]|0)|0;if(!((U|0)==(M|0)&(G|0)==(F|0))){break}di(f,1);}while((c[H>>2]|0)==0);F=c[I>>2]|0;if((wH(J,e[F+22>>1]|0,e[F+28>>1]|0,c[o>>2]|0)|0)!=0){break}}while((c[H>>2]|0)==0);xL();O=0;i=j;return O|0}if((wM(g,21352)|0)!=0){w1(35960);O=0;i=j;return O|0}if((wM(g,41432)|0)!=0){if((wM(g,38440)|0)==0){wM(g,25336)|0;X=0}else{X=1}if((wS(g,E)|0)==0){wK(g,38384);O=0;i=j;return O|0}if((wP(g)|0)==0){O=0;i=j;return O|0}H=e[E>>1]|0;E=c[f>>2]|0;if((X|0)==0){X=(b8[c[E+56>>2]&255](c[E+52>>2]|0,H)|0)&255;w2(36928,(x=i,i=i+16|0,c[x>>2]=H,c[x+8>>2]=X,x)|0);O=0;i=j;return O|0}else{X=(b8[c[E+64>>2]&255](c[E+52>>2]|0,H)|0)&65535;w2(37136,(x=i,i=i+16|0,c[x>>2]=H,c[x+8>>2]=X,x)|0);O=0;i=j;return O|0}}if((wM(g,40304)|0)!=0){X=K|0;if((wO(g,X,256)|0)!=0){H=f+564|0;do{E=a[X]|0;if(E<<24>>24==43){Y=1;Z=1}else{J=E<<24>>24==45;Y=J&1;Z=J?2:1}J=K+Y|0;E=zg(J)|0;if((E|0)==0){w2(37440,(x=i,i=i+8|0,c[x>>2]=X,x)|0)}else{w2(37384,(x=i,i=i+16|0,c[x>>2]=(Z|0)==1?37336:37184,c[x+8>>2]=J,x)|0);dL(H,Z,E)}}while((wO(g,X,256)|0)!=0)}wP(g)|0;O=0;i=j;return O|0}if((wM(g,38776)|0)!=0){if((wM(g,38168)|0)==0){wK(g,38104);O=0;i=j;return O|0}X=K|0;if((wL(g)|0)!=0){Z=0;while(1){H=c4(f,Z)|0;if((H|0)!=0){w2(37504,(x=i,i=i+16|0,c[x>>2]=Z,c[x+8>>2]=H,x)|0)}H=Z+1|0;if(H>>>0<256){Z=H}else{O=0;break}}i=j;return O|0}if((wM(g,37912)|0)!=0){Z=0;while(1){H=c4(f,Z)|0;if((H|0)!=0){w2(37504,(x=i,i=i+16|0,c[x>>2]=Z,c[x+8>>2]=H,x)|0)}H=Z+1|0;if(H>>>0<256){Z=H}else{O=0;break}}i=j;return O|0}if((wS(g,D)|0)==0){wK(g,37776);O=0;i=j;return O|0}if((wL(g)|0)!=0){dc(f,e[D>>1]|0,0);w2(37680,(x=i,i=i+8|0,c[x>>2]=e[D>>1]|0,x)|0);O=0;i=j;return O|0}if((wO(g,X,256)|0)==0){wK(g,37616);O=0;i=j;return O|0}else{w2(37504,(x=i,i=i+16|0,c[x>>2]=e[D>>1]|0,c[x+8>>2]=X,x)|0);dc(f,e[D>>1]|0,X);O=0;i=j;return O|0}}if((wM(g,37808)|0)!=0){if((wM(g,38440)|0)==0){wM(g,25336)|0;_=0}else{_=1}if((wS(g,B)|0)==0){wK(g,38384);O=0;i=j;return O|0}if((wS(g,C)|0)==0){wK(g,38336);O=0;i=j;return O|0}if((wP(g)|0)==0){O=0;i=j;return O|0}X=c[f>>2]|0;if((_|0)==0){b5[c[X+60>>2]&255](c[X+52>>2]|0,e[B>>1]|0,b[C>>1]&255);O=0;i=j;return O|0}else{b5[c[X+68>>2]&255](c[X+52>>2]|0,e[B>>1]|0,b[C>>1]|0);O=0;i=j;return O|0}}if((wM(g,35952)|0)!=0){if((wM(g,24088)|0)!=0){if((wP(g)|0)==0){O=0;i=j;return O|0}mj(c[f>>2]|0);O=0;i=j;return O|0}if((wM(g,38696)|0)!=0){if((wP(g)|0)==0){O=0;i=j;return O|0}mH(c[f>>2]|0);O=0;i=j;return O|0}if((wM(g,34496)|0)!=0){if((wP(g)|0)==0){O=0;i=j;return O|0}w1(38480);C=f|0;B=c[C>>2]|0;if((c[B+124>>2]|0)!=0){X=0;_=B;do{w2(26280,(x=i,i=i+8|0,c[x>>2]=d[_+128+X|0]|0,x)|0);X=X+1|0;_=c[C>>2]|0;}while(X>>>0<(c[_+124>>2]|0)>>>0)}w1(22064);O=0;i=j;return O|0}if((wL(g)|0)==0){wK(g,38560);O=0;i=j;return O|0}if((wP(g)|0)==0){O=0;i=j;return O|0}w1(38480);_=f|0;X=c[_>>2]|0;if((c[X+124>>2]|0)!=0){C=0;B=X;do{w2(26280,(x=i,i=i+8|0,c[x>>2]=d[B+128+C|0]|0,x)|0);C=C+1|0;B=c[_>>2]|0;}while(C>>>0<(c[B+124>>2]|0)>>>0)}w1(22064);O=0;i=j;return O|0}if((wM(g,34992)|0)!=0){c[z>>2]=1;wT(g,z)|0;if((wP(g)|0)==0){O=0;i=j;return O|0}B=f+3168|0;xM(B);C=f+3140|0;c[C>>2]=c[C>>2]&255;dh(f);C=f|0;_=f+3068|0;X=A|0;D=A+12|0;Z=0;L435:while(1){if(Z>>>0>=(c[z>>2]|0)>>>0){break}eI(c[C>>2]|0,A);H=c[C>>2]|0;Y=b[H+22>>1]|0;E=b[H+28>>1]|0;J=H;H=E;while(1){if(H<<16>>16!=E<<16>>16){$=Y;aa=J;break}di(f,1);I=c[C>>2]|0;if((wH(_,e[I+22>>1]|0,e[I+28>>1]|0,c[o>>2]|0)|0)!=0){break L435}if((c[B>>2]|0)!=0){break L435}I=c[C>>2]|0;W=b[I+22>>1]|0;if(W<<16>>16!=Y<<16>>16){$=W;aa=I;break}J=I;H=b[I+28>>1]|0}L445:do{if((c[X>>2]&768|0)==0){ab=$;ac=b[aa+28>>1]|0}else{H=(c[D>>2]|0)+(E&65535)&65535;J=aa;I=$;while(1){if(I<<16>>16==Y<<16>>16){if((b[J+28>>1]|0)==H<<16>>16){ab=Y;ac=H;break L445}}di(f,1);W=c[C>>2]|0;if((wH(_,e[W+22>>1]|0,e[W+28>>1]|0,c[o>>2]|0)|0)!=0){break L435}if((c[B>>2]|0)!=0){break L435}W=c[C>>2]|0;J=W;I=b[W+22>>1]|0}}}while(0);if((wH(_,ab&65535,ac&65535,c[o>>2]|0)|0)!=0){break}if((c[B>>2]|0)==0){Z=Z+1|0}else{break}}xL();Z=K|0;eI(c[C>>2]|0,y);cP(Z,y);cF(c[C>>2]|0);y=c[C>>2]|0;C=e[y+28>>1]|0;w2(26496,(x=i,i=i+24|0,c[x>>2]=e[y+22>>1]|0,c[x+8>>2]=C,c[x+16>>2]=Z,x)|0);O=0;i=j;return O|0}if((wM(g,34608)|0)!=0){Z=w|0;if((wL(g)|0)!=0){cF(c[f>>2]|0);O=0;i=j;return O|0}if((wN(g,Z,256)|0)==0){w2(39176,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);O=0;i=j;return O|0}w=f|0;if((hV(c[w>>2]|0,Z,v)|0)!=0){w2(39112,(x=i,i=i+8|0,c[x>>2]=Z,x)|0);O=0;i=j;return O|0}if((wL(g)|0)!=0){w2(38872,(x=i,i=i+8|0,c[x>>2]=c[v>>2],x)|0);O=0;i=j;return O|0}if((wT(g,v)|0)==0){w2(38752,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);O=0;i=j;return O|0}if((wP(g)|0)==0){O=0;i=j;return O|0}C=c[w>>2]|0;y=c[v>>2]|0;ic(C,Z,y)|0;y=K|0;eI(c[w>>2]|0,u);cP(y,u);cF(c[w>>2]|0);u=c[w>>2]|0;w=e[u+28>>1]|0;w2(26496,(x=i,i=i+24|0,c[x>>2]=e[u+22>>1]|0,c[x+8>>2]=w,c[x+16>>2]=y,x)|0);O=0;i=j;return O|0}if((wM(g,34496)|0)==0){if((wM(g,34240)|0)!=0){c[r>>2]=1;wT(g,r)|0;if((wP(g)|0)==0){O=0;i=j;return O|0}y=f+3168|0;xM(y);dh(f);w=f+3140|0;u=f|0;Z=f+3068|0;C=0;while(1){if(C>>>0>=(c[r>>2]|0)>>>0){break}c[w>>2]=c[w>>2]&255;v=hX(c[u>>2]|0)|0;B=G;do{ac=hX(c[u>>2]|0)|0;if(!((ac|0)==(v|0)&(G|0)==(B|0))){break}di(f,1);}while((c[y>>2]|0)==0);B=c[u>>2]|0;if((wH(Z,e[B+22>>1]|0,e[B+28>>1]|0,c[o>>2]|0)|0)!=0){break}if((c[y>>2]|0)==0){C=C+1|0}else{break}}xL();C=K|0;eI(c[u>>2]|0,q);cP(C,q);cF(c[u>>2]|0);q=c[u>>2]|0;u=e[q+28>>1]|0;w2(26496,(x=i,i=i+24|0,c[x>>2]=e[q+22>>1]|0,c[x+8>>2]=u,c[x+16>>2]=C,x)|0);O=0;i=j;return O|0}if((wM(g,34024)|0)==0){O=1;i=j;return O|0}C=K|0;if(a[864]|0){ad=b[21468]|0;ae=b[21472]|0}else{a[864]=1;u=c[f>>2]|0;q=b[u+22>>1]|0;b[21468]=q;y=b[u+28>>1]|0;b[21472]=y;ad=q;ae=y}b[k>>1]=ad;b[l>>1]=ae;b[m>>1]=16;b[n>>1]=0;if((wU(g,k,l)|0)!=0){wS(g,m)|0}wS(g,n)|0;if((wP(g)|0)==0){O=0;i=j;return O|0}L518:do{if((b[m>>1]|0)==0){af=b[l>>1]|0}else{ae=f|0;ad=p+12|0;y=b[l>>1]|0;while(1){eH(c[ae>>2]|0,p,b[k>>1]|0,y);cP(C,p);q=e[l>>1]|0;w2(26496,(x=i,i=i+24|0,c[x>>2]=e[k>>1]|0,c[x+8>>2]=q,c[x+16>>2]=C,x)|0);q=c[ad>>2]|0;ag=(e[l>>1]|0)+q&65535;b[l>>1]=ag;u=b[m>>1]|0;Z=u&65535;if((b[n>>1]|0)==0){ah=u-1&65535}else{if(Z>>>0<q>>>0){break}ah=Z-q&65535}b[m>>1]=ah;if(ah<<16>>16==0){af=ag;break L518}else{y=ag}}b[m>>1]=0;af=ag}}while(0);b[21468]=b[k>>1]|0;b[21472]=af;O=0;i=j;return O|0}if((wL(g)|0)!=0){af=K|0;K=f|0;eI(c[K>>2]|0,s);cP(af,s);cF(c[K>>2]|0);s=c[K>>2]|0;K=e[s+28>>1]|0;w2(26496,(x=i,i=i+24|0,c[x>>2]=e[s+22>>1]|0,c[x+8>>2]=K,c[x+16>>2]=af,x)|0);O=0;i=j;return O|0}if((wL(g)|0)!=0){O=0;i=j;return O|0}af=f+3024|0;K=f+3020|0;s=f+4|0;k=f+24|0;ag=f+16|0;m=f+32|0;ah=f+488|0;n=f+424|0;l=f+340|0;C=f|0;L539:while(1){do{if((wM(g,25384)|0)==0){if((wM(g,25280)|0)!=0){cF(c[C>>2]|0);break}if((wM(g,25184)|0)!=0){p=c[C>>2]|0;w3(39672);y=p+1216|0;ad=c[y>>2]|0;ae=c[y+4>>2]|0;q=p+1208|0;Z=c[q>>2]|0;u=c[q+4>>2]|0;if((ad|0)==0&(ae|0)==0){ai=0.0}else{ai=(+(Z>>>0)+ +(u>>>0)*4294967296.0)/(+(ad>>>0)+ +(ae>>>0)*4294967296.0)}ae=c[p+1200>>2]|0;w2(39448,(x=i,i=i+24|0,c[x>>2]=Z,c[x+8>>2]=u,c[x+16>>2]=ae,x)|0);ae=c[y+4>>2]|0;w2(39408,(x=i,i=i+16|0,c[x>>2]=c[y>>2],c[x+8>>2]=ae,x)|0);w2(39352,(x=i,i=i+8|0,h[x>>3]=ai,x)|0);break}if((wM(g,25080)|0)!=0){cQ(l);break}if((wM(g,25016)|0)!=0){cR(n);break}if((wM(g,24896)|0)!=0){cS(ah);break}if((wM(g,24840)|0)!=0){cT(m);break}if((wM(g,24784)|0)!=0){w3(23072);r6(c[ag>>2]|0,c[o>>2]|0);break}if((wM(g,24672)|0)!=0){w3(23104);r6(c[k>>2]|0,c[o>>2]|0);break}if((wM(g,24608)|0)==0){if((wM(g,24192)|0)!=0){ae=c[s>>2]|0;w3(24192);qM(ae,w$()|0);y=w_()|0;if((y|0)==0){break}qM(ae,y);break}if((wM(g,24048)|0)!=0){y=c[K>>2]|0;w3(23592);c_(y);break}if((wM(g,23952)|0)==0){break L539}y=c[af>>2]|0;w3(23712);ez(y);break}if((wS(g,t)|0)==0){b[t>>1]=0;aj=0}else{y=b[t>>1]|0;if((y&65535)<4){aj=y}else{break}}y=c[f+3032+((aj&65535)<<2)>>2]|0;if((y|0)==0){break}ae=y+48|0;u=c[y+688>>2]|0;Z=ne(ae)|0;p=nf(ae)|0;ad=m1(ae)|0;if((ad|0)==3){ak=69}else if((ad|0)==1){ak=79}else if((ad|0)==5){ak=77}else if((ad|0)==7){ak=83}else if((ad|0)==0){ak=78}else{ak=63}w3(23528);ad=m_(ae)|0;q=m$(ae)|0;w=m0(ae)|0;r=m2(ae)|0;B=m3(ae)|0;ae=p&255;p=d[y+588|0]|0;v=Z&255;Z=d[y+589|0]|0;ac=d[y+596|0]|0;ab=e[y+642>>1]|0;_=d[y+590|0]|0;$=d[y+591|0]|0;aa=d[y+592|0]|0;D=d[y+594|0]|0;w2(23312,(x=i,i=i+184|0,c[x>>2]=u,c[x+8>>2]=ad,c[x+16>>2]=q,c[x+24>>2]=ak,c[x+32>>2]=w,c[x+40>>2]=r,c[x+48>>2]=B,c[x+56>>2]=ae>>>5&1,c[x+64>>2]=ae>>>4&1,c[x+72>>2]=ae>>>7,c[x+80>>2]=ae>>>6&1,c[x+88>>2]=p,c[x+96>>2]=(v&32|0)!=0?32:42,c[x+104>>2]=Z,c[x+112>>2]=(v&1|0)!=0?42:32,c[x+120>>2]=ac,c[x+128>>2]=ab,c[x+136>>2]=_,c[x+144>>2]=$,c[x+152>>2]=aa,c[x+160>>2]=v,c[x+168>>2]=D,c[x+176>>2]=ae,x)|0)}else{ae=c[s>>2]|0;w3(24192);qM(ae,w$()|0);D=w_()|0;if((D|0)!=0){qM(ae,D)}cR(n);cQ(l);cS(ah);cT(m);D=c[C>>2]|0;w3(39672);ae=D+1216|0;v=c[ae>>2]|0;aa=c[ae+4>>2]|0;$=D+1208|0;_=c[$>>2]|0;ab=c[$+4>>2]|0;if((v|0)==0&(aa|0)==0){al=0.0}else{al=(+(_>>>0)+ +(ab>>>0)*4294967296.0)/(+(v>>>0)+ +(aa>>>0)*4294967296.0)}aa=c[D+1200>>2]|0;w2(39448,(x=i,i=i+24|0,c[x>>2]=_,c[x+8>>2]=ab,c[x+16>>2]=aa,x)|0);aa=c[ae+4>>2]|0;w2(39408,(x=i,i=i+16|0,c[x>>2]=c[ae>>2],c[x+8>>2]=aa,x)|0);w2(39352,(x=i,i=i+8|0,h[x>>3]=al,x)|0);cF(c[C>>2]|0)}}while(0);if((wL(g)|0)!=0){O=0;V=443;break}}if((V|0)==443){i=j;return O|0}wK(g,23776);O=0;i=j;return O|0}function cK(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;if(d>>>0>65535){e=-1;return e|0}f=d>>>14;g=c[b+1032+(f<<2)>>2]|0;if((g|0)==0){e=-1;return e|0}e=a[(c[g+8>>2]|0)+(c[b+1048+(f<<2)>>2]<<14|d&16383)|0]|0;return e|0}function cL(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0;do{if(b>>>0>65535){e=255}else{f=b>>>14;g=c[a+1032+(f<<2)>>2]|0;if((g|0)==0){e=255;break}e=d[(c[g+8>>2]|0)+(c[a+1048+(f<<2)>>2]<<14|b&16383)|0]|0}}while(0);f=b+1|0;if(f>>>0>65535){h=-256;i=h|e;return i|0}b=f>>>14;g=c[a+1032+(b<<2)>>2]|0;if((g|0)==0){h=-256;i=h|e;return i|0}h=(d[(c[g+8>>2]|0)+(c[a+1048+(b<<2)>>2]<<14|f&16383)|0]|0)<<8;i=h|e;return i|0}function cM(a,b){a=a|0;b=b|0;xx(b,1336,17)|0;xy(b)|0;b=a|0;c[(c[b>>2]|0)+108>>2]=466;c[(c[b>>2]|0)+104>>2]=136;return}function cN(d,f){d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;h=d;j=f&255;c[d+3140>>2]=j|256;if((dd(h,j)|0)!=0){k=c[d>>2]|0;l=e[k+112>>1]|0;m=e[k+4>>1]|0;n=e[k+10>>1]|0;o=e[k+6>>1]|0;p=e[k+8>>1]|0;q=e[k+26>>1]|0;r=e[k+20>>1]|0;w2(33232,(x=i,i=i+72|0,c[x>>2]=e[k+22>>1]|0,c[x+8>>2]=l,c[x+16>>2]=j,c[x+24>>2]=m,c[x+32>>2]=n,c[x+40>>2]=o,c[x+48>>2]=p,c[x+56>>2]=q,c[x+64>>2]=r,x)|0)}if((f<<24>>24|0)==19){r=d+12|0;q=c[r>>2]|0;if((q|0)==0){i=g;return}p=c[d>>2]|0;if((b[p+4>>1]&-256)<<16>>16!=512){i=g;return}if((b[p+8>>1]&255)==0){i=g;return}p=c[d+8>>2]|0;ty(p,q)|0;c[r>>2]=0;i=g;return}else if((f<<24>>24|0)==25){do{if((c[d+3076>>2]|0)!=0){f=d+12|0;if((c[f>>2]|0)!=0){break}r=d+8|0;q=ts(c[r>>2]|0,0)|0;c[f>>2]=q;f=c[r>>2]|0;tr(f,q)|0}}while(0);if((a[d+3099|0]|0)==0){i=g;return}if((a[d+3098|0]|0)!=0){i=g;return}q=de(h)|0;if((q|0)==0){i=g;return}dP(32504,(x=i,i=i+8|0,c[x>>2]=q,x)|0);h=d;d=c[h>>2]|0;f=c[d+80>>2]&100;r=f|1;if(r>>>0<(c[d+76>>2]|0)>>>0){p=d+72|0;a[(c[p>>2]|0)+f|0]=16;a[(c[p>>2]|0)+r|0]=0}else{b5[c[d+48>>2]&255](c[d+32>>2]|0,f,16)}f=c[h>>2]|0;h=q&65535;d=c[f+80>>2]&102;r=d|1;if(r>>>0<(c[f+76>>2]|0)>>>0){p=f+72|0;a[(c[p>>2]|0)+d|0]=q&255;a[(c[p>>2]|0)+r|0]=(h&65535)>>>8&255;i=g;return}else{b5[c[f+48>>2]&255](c[f+32>>2]|0,d,h);i=g;return}}else{i=g;return}}function cO(a,b,d){a=a|0;b=b|0;d=d|0;var f=0,g=0,h=0;f=i;g=c[a>>2]|0;h=e[g+28>>1]|0;xt(3,33624,(x=i,i=i+32|0,c[x>>2]=e[g+22>>1]|0,c[x+8>>2]=h,c[x+16>>2]=b&255,c[x+24>>2]=d&255,x)|0);xU(1e5)|0;zt(c[a+3028>>2]|0);i=f;return}function cP(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=i;a1(b|0,26432,(x=i,i=i+8|0,c[x>>2]=d[e+16|0]|0,x)|0)|0;g=e+12|0;h=b+2|0;if((c[g>>2]|0)>>>0>1){j=1;k=2;l=h;while(1){a1(l|0,26280,(x=i,i=i+8|0,c[x>>2]=d[e+16+j|0]|0,x)|0)|0;m=k+3|0;n=j+1|0;o=b+m|0;if(n>>>0<(c[g>>2]|0)>>>0){j=n;k=m;l=o}else{break}}a[o]=32;o=k+4|0;if(o>>>0<20){p=m;q=o;r=503}else{s=m;t=o}}else{a[h]=32;p=2;q=3;r=503}if((r|0)==503){zP(b+q|0,32,19-p|0);s=19;t=20}p=e|0;q=c[p>>2]|0;if((q&-769|0)==0){u=t}else{r=s+2|0;a[b+t|0]=91;if((q&1|0)==0){v=q;w=r}else{t=b+r|0;y=3553329;a[t]=y&255;y=y>>8;a[t+1|0]=y&255;y=y>>8;a[t+2|0]=y&255;y=y>>8;a[t+3|0]=y&255;v=q&-2;w=s+5|0}if((v|0)==0){z=w}else{if((v|0)==(c[p>>2]|0)){A=w}else{a[b+w|0]=32;A=w+1|0}z=(a1(b+A|0,26120,(x=i,i=i+8|0,c[x>>2]=v,x)|0)|0)+A|0}a[b+z|0]=93;a[b+(z+1)|0]=32;u=z+2|0}zQ(b+u|0,e+32|0)|0;z=u;A=0;while(1){B=b+z|0;C=z+1|0;if((a[B]|0)==0){break}else{z=C;A=A+1|0}}v=e+96|0;if((c[v>>2]|0)==0){D=z;E=b+D|0;a[E]=0;i=f;return}a[B]=32;if(C>>>0<26){zP(b+(u+1+A)|0,32,25-u-A|0);F=26}else{F=C}C=c[v>>2]|0;if((C|0)==1){v=b+F|0;A=e+100|0;u=zN(A|0)|0;B=u+1|0;zO(v|0,A|0,B)|0;D=u+F|0;E=b+D|0;a[E]=0;i=f;return}else if((C|0)==2){D=(a1(b+F|0,25832,(x=i,i=i+16|0,c[x>>2]=e+100,c[x+8>>2]=e+164,x)|0)|0)+F|0;E=b+D|0;a[E]=0;i=f;return}else{D=F;E=b+D|0;a[E]=0;i=f;return}}function cQ(a){a=a|0;var b=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;w3(41152);f=0;do{g=d[a+(f*28|0)+7|0]|0;h=d[a+(f*28|0)+9|0]|0;j=d[a+(f*28|0)+8|0]|0;k=e[a+(f*28|0)+26>>1]|0;l=d[a+(f*28|0)+2|0]|0;m=d[a+(f*28|0)+1|0]|0;n=d[a+(f*28|0)|0]|0;o=d[a+(f*28|0)+5|0]|0;p=d[a+(f*28|0)+4|0]|0;q=d[a+(f*28|0)+3|0]|0;r=d[a+(f*28|0)+12|0]|0;s=d[a+(f*28|0)+24|0]|0;t=d[a+(f*28|0)+11|0]|0;w2(40984,(x=i,i=i+128|0,c[x>>2]=f,c[x+8>>2]=g,c[x+16>>2]=h,c[x+24>>2]=j,c[x+32>>2]=k,c[x+40>>2]=(l&2|0)!=0?40928:40896,c[x+48>>2]=m,c[x+56>>2]=(l&1|0)!=0?40792:40672,c[x+64>>2]=n,c[x+72>>2]=(o&2|0)!=0?40416:40224,c[x+80>>2]=p,c[x+88>>2]=(o&1|0)!=0?40096:39880,c[x+96>>2]=q,c[x+104>>2]=r,c[x+112>>2]=s,c[x+120>>2]=t,x)|0);f=f+1|0;}while(f>>>0<3);i=b;return}function cR(b){b=b|0;var e=0,f=0,g=0,h=0;e=i;w3(21072);f=d[b|0]|0;g=d[b+1|0]|0;w2(20960,(x=i,i=i+24|0,c[x>>2]=d[b+2|0]|0,c[x+8>>2]=f,c[x+16>>2]=g,x)|0);if((a[b+6|0]|0)==0){g=(nw(b,0)|0)&255;w2(20800,(x=i,i=i+8|0,c[x>>2]=g,x)|0)}else{g=(nI(b,0)|0)&255;w2(20864,(x=i,i=i+8|0,c[x>>2]=g,x)|0)}if((a[b+26|0]|0)==0){g=(nw(b,1)|0)&255;w2(41784,(x=i,i=i+8|0,c[x>>2]=g,x)|0)}else{g=(nI(b,1)|0)&255;w2(41840,(x=i,i=i+8|0,c[x>>2]=g,x)|0)}g=d[b+46|0]|0;if((g|0)==240){f=((nI(b,2)|0)&255)>>>4;h=(nw(b,2)|0)&15;w2(41200,(x=i,i=i+16|0,c[x>>2]=f,c[x+8>>2]=h,x)|0);w1(22064);i=e;return}else if((g|0)==255){h=(nI(b,2)|0)&255;w2(41520,(x=i,i=i+8|0,c[x>>2]=h,x)|0);w1(22064);i=e;return}else if((g|0)==0){h=(nw(b,2)|0)&255;w2(41416,(x=i,i=i+8|0,c[x>>2]=h,x)|0);w1(22064);i=e;return}else if((g|0)==15){g=((nw(b,2)|0)&255)>>>4;h=(nI(b,2)|0)&15;w2(41360,(x=i,i=i+16|0,c[x>>2]=g,c[x+8>>2]=h,x)|0);w1(22064);i=e;return}else{w1(22064);i=e;return}}function cS(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+16|0;e=d|0;w3(22232);w1(22144);f=a[b+10|0]|0;g=e|0;a[g]=(f&255)>>>7|48;h=e+1|0;a[h]=(f&255)>>>6&1|48;j=e+2|0;a[j]=(f&255)>>>5&1|48;k=e+3|0;a[k]=(f&255)>>>4&1|48;l=e+4|0;a[l]=(f&255)>>>3&1|48;m=e+5|0;a[m]=(f&255)>>>2&1|48;n=e+6|0;a[n]=(f&255)>>>1&1|48;o=e+7|0;a[o]=f&1|48;f=e+8|0;a[f]=0;w1(g);w1(22064);w1(22024);e=nO(b)|0;a[g]=(e&255)>>>7|48;a[h]=(e&255)>>>6&1|48;a[j]=(e&255)>>>5&1|48;a[k]=(e&255)>>>4&1|48;a[l]=(e&255)>>>3&1|48;a[m]=(e&255)>>>2&1|48;a[n]=(e&255)>>>1&1|48;a[o]=e&1|48;a[f]=0;w1(g);w2(21960,(x=i,i=i+8|0,c[x>>2]=c[b+24>>2],x)|0);w1(21816);e=nP(b)|0;a[g]=(e&255)>>>7|48;a[h]=(e&255)>>>6&1|48;a[j]=(e&255)>>>5&1|48;a[k]=(e&255)>>>4&1|48;a[l]=(e&255)>>>3&1|48;a[m]=(e&255)>>>2&1|48;a[n]=(e&255)>>>1&1|48;a[o]=e&1|48;a[f]=0;w1(g);w2(21760,(x=i,i=i+8|0,c[x>>2]=(a[b+72|0]|0)!=0,x)|0);w1(21416);e=nQ(b)|0;a[g]=(e&255)>>>7|48;a[h]=(e&255)>>>6&1|48;a[j]=(e&255)>>>5&1|48;a[k]=(e&255)>>>4&1|48;a[l]=(e&255)>>>3&1|48;a[m]=(e&255)>>>2&1|48;a[n]=(e&255)>>>1&1|48;a[o]=e&1|48;a[f]=0;w1(g);w1(22064);g=(nR(b,0)|0)&255;f=(nR(b,1)|0)&255;e=(nR(b,2)|0)&255;o=(nR(b,3)|0)&255;n=(nS(b,0)|0)&255;m=(nS(b,1)|0)&255;l=(nS(b,2)|0)&255;w2(21280,(x=i,i=i+56|0,c[x>>2]=g,c[x+8>>2]=f,c[x+16>>2]=e,c[x+24>>2]=o,c[x+32>>2]=n,c[x+40>>2]=m,c[x+48>>2]=l,x)|0);w2(21216,(x=i,i=i+8|0,c[x>>2]=c[b+32>>2],x)|0);l=c[b+36>>2]|0;w2(21136,(x=i,i=i+16|0,c[x>>2]=1,c[x+8>>2]=l,x)|0);l=c[b+40>>2]|0;w2(21136,(x=i,i=i+16|0,c[x>>2]=2,c[x+8>>2]=l,x)|0);l=c[b+44>>2]|0;w2(21136,(x=i,i=i+16|0,c[x>>2]=3,c[x+8>>2]=l,x)|0);l=c[b+48>>2]|0;w2(21136,(x=i,i=i+16|0,c[x>>2]=4,c[x+8>>2]=l,x)|0);l=c[b+52>>2]|0;w2(21136,(x=i,i=i+16|0,c[x>>2]=5,c[x+8>>2]=l,x)|0);l=c[b+56>>2]|0;w2(21136,(x=i,i=i+16|0,c[x>>2]=6,c[x+8>>2]=l,x)|0);l=c[b+60>>2]|0;w2(21136,(x=i,i=i+16|0,c[x>>2]=7,c[x+8>>2]=l,x)|0);w1(22064);i=d;return}function cT(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;w3(22592);e=(mn(b)|0)&255;f=(mo(b)|0)&255;g=(a[b+288|0]|0)!=0|0;w2(22472,(x=i,i=i+24|0,c[x>>2]=e,c[x+8>>2]=f,c[x+16>>2]=g,x)|0);g=0;do{f=mq(b,g)|0;e=(mp(b,g)|0)&252;h=(mr(b,g)|0)&65535;j=(ms(b,g)|0)&65535;k=(mt(b,g)|0)&65535;l=(mu(b,g)|0)&65535;m=f&65535;w2(22360,(x=i,i=i+72|0,c[x>>2]=g,c[x+8>>2]=e,c[x+16>>2]=h,c[x+24>>2]=j,c[x+32>>2]=k,c[x+40>>2]=l,c[x+48>>2]=m&1,c[x+56>>2]=m>>>1&1,c[x+64>>2]=m>>>4&1,x)|0);g=g+1|0;}while(g>>>0<4);i=d;return}function cU(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+16|0;f=e|0;g=e+8|0;if((yi(d,26200,f,0)|0)==0){h=c[f>>2]<<10;c[f>>2]=h;j=h}else{yi(d,34856,f,0)|0;j=c[f>>2]|0}c[f>>2]=(j+16383|0)>>>14;yj(d,31768,g,57344)|0;d=zH(1068)|0;j=d;if((d|0)==0){k=0;i=e;return k|0}zP(d|0,0,1024);h=zH(48)|0;l=h;do{if((h|0)==0){m=0}else{b[h>>1]=0;c[h+4>>2]=4;n=zH(65536)|0;c[h+8>>2]=n;if((n|0)==0){zI(h);m=0;break}else{c[h+12>>2]=0;n=h+40|0;o=n|0;y=0;a[o]=y&255;y=y>>8;a[o+1|0]=y&255;y=y>>8;a[o+2|0]=y&255;y=y>>8;a[o+3|0]=y&255;o=n+4|0;y=0;a[o]=y&255;y=y>>8;a[o+1|0]=y&255;y=y>>8;a[o+2|0]=y&255;y=y>>8;a[o+3|0]=y&255;m=l;break}}}while(0);c[d>>2]=m;m=d+1024|0;c[m>>2]=c[f>>2];c[d+1028>>2]=0;c[d+1032>>2]=0;c[d+1048>>2]=0;c[d+1036>>2]=0;c[d+1052>>2]=0;c[d+1040>>2]=0;c[d+1056>>2]=0;c[d+1044>>2]=0;c[d+1060>>2]=0;l=r0(c[g>>2]<<4,65536,0)|0;c[d+1064>>2]=l;rJ(l,d,106,14,0,14,90,0);d=c[m>>2]|0;m=c[g>>2]|0;xv(2,29840,27936,(x=i,i=i+24|0,c[x>>2]=c[f>>2]<<4,c[x+8>>2]=d,c[x+16>>2]=m,x)|0);k=j;i=e;return k|0}function cV(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0;if(d>>>0>65535){return}f=d>>>14;g=c[b+1032+(f<<2)>>2]|0;if((g|0)==0){return}a[(c[g+8>>2]|0)+(c[b+1048+(f<<2)>>2]<<14|d&16383)|0]=e;return}function cW(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=e&255;do{if(d>>>0<=65535){g=d>>>14;h=c[b+1032+(g<<2)>>2]|0;if((h|0)==0){break}a[(c[h+8>>2]|0)+(c[b+1048+(g<<2)>>2]<<14|d&16383)|0]=f}}while(0);f=d+1|0;if(f>>>0>65535){return}d=f>>>14;g=c[b+1032+(d<<2)>>2]|0;if((g|0)==0){return}a[(c[g+8>>2]|0)+(c[b+1048+(d<<2)>>2]<<14|f&16383)|0]=(e&65535)>>>8&255;return}function cX(a){a=a|0;return c[a+1064>>2]|0}function cY(a,d){a=a|0;d=d|0;var e=0;e=d+4|0;if((a|0)==0){b[e>>1]=0;b[d+8>>1]=0;return}else{b[e>>1]=1;b[d+8>>1]=c[a+1024>>2]<<4&65535;return}}function cZ(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;dP(26336,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);d=1;do{e=a+(d<<2)|0;f=c[e>>2]|0;if((f|0)!=0){zI(c[f+8>>2]|0);zI(f)}c[e>>2]=0;d=d+1|0;}while(d>>>0<256);zP(a+1028|0,0,36);i=b;return}function c_(a){a=a|0;var b=0,d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;d=1;f=0;do{f=((c[a+(d<<2)>>2]|0)!=0)+f|0;d=d+1|0;}while(d>>>0<255);d=c[a+1028>>2]|0;g=c[a+1024>>2]|0;w2(24920,(x=i,i=i+40|0,c[x>>2]=d,c[x+8>>2]=g,c[x+16>>2]=d<<4,c[x+24>>2]=g<<4,c[x+32>>2]=f,x)|0);f=c[a+1032>>2]|0;if((f|0)==0){h=4095}else{h=e[f>>1]|0}f=c[a+1048>>2]|0;g=c[a+1036>>2]|0;if((g|0)==0){j=4095}else{j=e[g>>1]|0}g=c[a+1052>>2]|0;d=c[a+1040>>2]|0;if((d|0)==0){k=4095}else{k=e[d>>1]|0}d=c[a+1056>>2]|0;l=c[a+1044>>2]|0;if((l|0)==0){m=4095}else{m=e[l>>1]|0}l=c[a+1060>>2]|0;w2(23608,(x=i,i=i+64|0,c[x>>2]=h,c[x+8>>2]=f,c[x+16>>2]=j,c[x+24>>2]=g,c[x+32>>2]=k,c[x+40>>2]=d,c[x+48>>2]=m,c[x+56>>2]=l,x)|0);l=0;do{m=c[a+(l<<2)>>2]|0;if((m|0)!=0){d=c[m+4>>2]|0;w2(22072,(x=i,i=i+16|0,c[x>>2]=l,c[x+8>>2]=d,x)|0)}l=l+1|0;}while(l>>>0<256);i=b;return}function c$(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;h=i;if((f|0)==0){i=h;return}j=g+4|0;k=b[j>>1]|0;l=k&65535;m=l>>>8;if((m|0)==64){b[j>>1]=k&255;i=h;return}else if((m|0)==78){n=l&255;if((n|0)==2){o=(e[g+20>>1]|0)<<4;p=g+80|0;q=g+76|0;r=g+72|0;s=g+48|0;t=g+32|0;u=e[g+18>>1]|0;v=0;while(1){w=c[f+1032+(v<<2)>>2]|0;if((w|0)==0){z=-1;A=0}else{z=c[f+1048+(v<<2)>>2]&65535;A=b[w>>1]|0}w=c[p>>2]&(u&65535)+o;B=w+1|0;if(B>>>0<(c[q>>2]|0)>>>0){a[(c[r>>2]|0)+w|0]=A&255;a[(c[r>>2]|0)+B|0]=(A&65535)>>>8&255}else{b5[c[s>>2]&255](c[t>>2]|0,w,A)}w=c[p>>2]&(u+2&65535)+o;B=w+1|0;if(B>>>0<(c[q>>2]|0)>>>0){a[(c[r>>2]|0)+w|0]=z&255;a[(c[r>>2]|0)+B|0]=(z&65535)>>>8&255}else{b5[c[s>>2]&255](c[t>>2]|0,w,z)}w=v+1|0;if(w>>>0<4){u=u+4|0;v=w}else{break}}v=g+4|0;u=(e[g+26>>1]|0)<<4;z=g+44|0;s=e[g+16>>1]|0;o=0;while(1){A=c[p>>2]|0;w=(s&65535)+u&A;B=w+1|0;C=c[q>>2]|0;if(B>>>0<C>>>0){D=c[r>>2]|0;E=(d[D+B|0]|0)<<8|(d[D+w|0]|0);F=A;G=C}else{C=b8[c[z>>2]&255](c[t>>2]|0,w)|0;E=C;F=c[p>>2]|0;G=c[q>>2]|0}C=F&(s+2&65535)+u;w=C+1|0;if(w>>>0<G>>>0){A=c[r>>2]|0;H=(d[A+w|0]|0)<<8|(d[A+C|0]|0)}else{H=b8[c[z>>2]&255](c[t>>2]|0,C)|0}C=H&65535;A=f+1032+(o<<2)|0;c[A>>2]=0;w=f+1048+(o<<2)|0;c[w>>2]=0;D=E&65535;if(!(E<<16>>16==0|H<<16>>16==-1)){if((E&65535)>255){I=754;break}B=c[f+(D<<2)>>2]|0;if((B|0)==0){I=754;break}if((c[B+4>>2]|0)>>>0<=C>>>0){I=754;break}c[A>>2]=B;c[w>>2]=C}C=o+1|0;if(C>>>0<4){s=s+4|0;o=C}else{I=756;break}}if((I|0)==754){o=v|0;b[o>>1]=b[o>>1]&255|-23808;i=h;return}else if((I|0)==756){o=v|0;b[o>>1]=b[o>>1]&255;i=h;return}}else if((n|0)==0){o=(e[g+20>>1]|0)<<4;v=g+80|0;s=g+76|0;E=g+72|0;H=g+48|0;t=g+32|0;z=e[g+18>>1]|0;r=0;while(1){G=c[f+1032+(r<<2)>>2]|0;if((G|0)==0){J=-1;K=0}else{J=c[f+1048+(r<<2)>>2]&65535;K=b[G>>1]|0}G=c[v>>2]&(z&65535)+o;u=G+1|0;if(u>>>0<(c[s>>2]|0)>>>0){a[(c[E>>2]|0)+G|0]=K&255;a[(c[E>>2]|0)+u|0]=(K&65535)>>>8&255}else{b5[c[H>>2]&255](c[t>>2]|0,G,K)}G=c[v>>2]&(z+2&65535)+o;u=G+1|0;if(u>>>0<(c[s>>2]|0)>>>0){a[(c[E>>2]|0)+G|0]=J&255;a[(c[E>>2]|0)+u|0]=(J&65535)>>>8&255}else{b5[c[H>>2]&255](c[t>>2]|0,G,J)}G=r+1|0;if(G>>>0<4){z=z+4|0;r=G}else{break}}b[j>>1]=b[j>>1]&255;i=h;return}else if((n|0)==3){b[j>>1]=16;i=h;return}else if((n|0)==1){n=g+4|0;r=(e[g+26>>1]|0)<<4;z=g+80|0;J=g+76|0;t=g+72|0;H=g+44|0;E=g+32|0;s=e[g+16>>1]|0;o=0;while(1){v=c[z>>2]|0;K=(s&65535)+r&v;G=K+1|0;u=c[J>>2]|0;if(G>>>0<u>>>0){F=c[t>>2]|0;L=(d[F+G|0]|0)<<8|(d[F+K|0]|0);M=v;N=u}else{u=b8[c[H>>2]&255](c[E>>2]|0,K)|0;L=u;M=c[z>>2]|0;N=c[J>>2]|0}u=M&(s+2&65535)+r;K=u+1|0;if(K>>>0<N>>>0){v=c[t>>2]|0;O=(d[v+K|0]|0)<<8|(d[v+u|0]|0)}else{O=b8[c[H>>2]&255](c[E>>2]|0,u)|0}u=O&65535;v=f+1032+(o<<2)|0;c[v>>2]=0;K=f+1048+(o<<2)|0;c[K>>2]=0;F=L&65535;if(!(L<<16>>16==0|O<<16>>16==-1)){if((L&65535)>255){I=729;break}G=c[f+(F<<2)>>2]|0;if((G|0)==0){I=729;break}if((c[G+4>>2]|0)>>>0<=u>>>0){I=729;break}c[v>>2]=G;c[K>>2]=u}u=o+1|0;if(u>>>0<4){s=s+4|0;o=u}else{I=731;break}}if((I|0)==729){o=n|0;b[o>>1]=b[o>>1]&255|-23808;i=h;return}else if((I|0)==731){o=n|0;b[o>>1]=b[o>>1]&255;i=h;return}}else{xt(1,41072,(x=i,i=i+8|0,c[x>>2]=l,x)|0);b[j>>1]=b[j>>1]&255|-28928;i=h;return}}else if((m|0)==72){o=g+4|0;n=b[g+8>>1]|0;do{if((n&65535)<=255){s=c[f+((n&65535)<<2)>>2]|0;if((s|0)==0){break}L=s+12|0;if((c[L>>2]|0)==0){b[o>>1]=k&255|-29184;i=h;return}O=b[s+16>>1]|0;E=c[s+24>>2]|0;H=f+1032|0;c[H>>2]=0;t=f+1048|0;c[t>>2]=0;do{if(!(O<<16>>16==0|(E|0)==65535|(O&65535)>255)){N=c[f+((O&65535)<<2)>>2]|0;if((N|0)==0){break}if((c[N+4>>2]|0)>>>0<=E>>>0){break}c[H>>2]=N;c[t>>2]=E}}while(0);E=b[s+18>>1]|0;t=c[s+28>>2]|0;H=f+1036|0;c[H>>2]=0;O=f+1052|0;c[O>>2]=0;do{if(!(E<<16>>16==0|(t|0)==65535|(E&65535)>255)){N=c[f+((E&65535)<<2)>>2]|0;if((N|0)==0){break}if((c[N+4>>2]|0)>>>0<=t>>>0){break}c[H>>2]=N;c[O>>2]=t}}while(0);t=b[s+20>>1]|0;O=c[s+32>>2]|0;H=f+1040|0;c[H>>2]=0;E=f+1056|0;c[E>>2]=0;do{if(!(t<<16>>16==0|(O|0)==65535|(t&65535)>255)){N=c[f+((t&65535)<<2)>>2]|0;if((N|0)==0){break}if((c[N+4>>2]|0)>>>0<=O>>>0){break}c[H>>2]=N;c[E>>2]=O}}while(0);O=b[s+22>>1]|0;E=c[s+36>>2]|0;H=f+1044|0;c[H>>2]=0;t=f+1060|0;c[t>>2]=0;do{if(!(O<<16>>16==0|(E|0)==65535|(O&65535)>255)){N=c[f+((O&65535)<<2)>>2]|0;if((N|0)==0){break}if((c[N+4>>2]|0)>>>0<=E>>>0){break}c[H>>2]=N;c[t>>2]=E}}while(0);c[L>>2]=0;E=o|0;b[E>>1]=b[E>>1]&255;i=h;return}}while(0);b[o>>1]=k&255|-32e3;i=h;return}else if((m|0)==75){o=0;n=0;do{o=((c[f+(n<<2)>>2]|0)!=0)+o|0;n=n+1|0;}while(n>>>0<255);b[j>>1]=k&255;b[g+10>>1]=o&65535;i=h;return}else if((m|0)==81){o=g+4|0;n=b[g+8>>1]|0;E=g+10|0;t=b[E>>1]|0;H=t&65535;do{if((n&65535)<=255){O=c[f+((n&65535)<<2)>>2]|0;if((O|0)==0){break}s=c[f+1024>>2]|0;if(H>>>0>s>>>0){b[o>>1]=k&255|-30976;i=h;return}N=f+1028|0;r=O+4|0;if(((c[N>>2]|0)+H-(c[r>>2]|0)|0)>>>0>s>>>0){b[o>>1]=k&255|-30720;i=h;return}s=O+8|0;M=c[s>>2]|0;do{if(t<<16>>16==0){zI(M);P=0}else{J=zJ(M,H<<14)|0;if((J|0)!=0){P=J;break}J=o|0;b[J>>1]=b[J>>1]&255|-30720;i=h;return}}while(0);c[N>>2]=H-(c[r>>2]|0)+(c[N>>2]|0);c[s>>2]=P;c[r>>2]=H;M=f+1032|0;do{if((c[M>>2]|0)==(O|0)){L=f+1048|0;if((c[L>>2]|0)>>>0<H>>>0){break}c[M>>2]=0;c[L>>2]=0}}while(0);M=f+1036|0;do{if((c[M>>2]|0)==(O|0)){s=f+1052|0;if((c[s>>2]|0)>>>0<(c[r>>2]|0)>>>0){break}c[M>>2]=0;c[s>>2]=0}}while(0);M=f+1040|0;do{if((c[M>>2]|0)==(O|0)){s=f+1056|0;if((c[s>>2]|0)>>>0<(c[r>>2]|0)>>>0){break}c[M>>2]=0;c[s>>2]=0}}while(0);M=f+1044|0;do{if((c[M>>2]|0)==(O|0)){s=f+1060|0;if((c[s>>2]|0)>>>0<(c[r>>2]|0)>>>0){break}c[M>>2]=0;c[s>>2]=0}}while(0);M=o|0;b[M>>1]=b[M>>1]&255;b[E>>1]=t;i=h;return}}while(0);b[o>>1]=k&255|-32e3;i=h;return}else if((m|0)==83){o=l&255;if((o|0)==0){t=g+4|0;E=b[g+8>>1]|0;do{if((E&65535)<=255){H=c[f+((E&65535)<<2)>>2]|0;if((H|0)==0){break}P=e[g+18>>1]|0;n=(e[g+20>>1]|0)<<4;M=g+80|0;r=g+76|0;O=g+72|0;s=g+40|0;N=g+32|0;L=0;do{J=a[H+40+L|0]|0;z=(L+P&65535)+n&c[M>>2];if(z>>>0<(c[r>>2]|0)>>>0){a[(c[O>>2]|0)+z|0]=J}else{b5[c[s>>2]&255](c[N>>2]|0,z,J)}L=L+1|0;}while(L>>>0<8);L=t|0;b[L>>1]=b[L>>1]&255;i=h;return}}while(0);b[t>>1]=k&255|-32e3;i=h;return}else if((o|0)==1){o=g+4|0;t=b[g+8>>1]|0;do{if((t&65535)<=255){E=c[f+((t&65535)<<2)>>2]|0;if((E|0)==0){break}L=e[g+16>>1]|0;N=(e[g+20>>1]|0)<<4;s=g+80|0;O=g+76|0;r=g+72|0;M=g+36|0;n=g+32|0;P=0;do{H=(P+L&65535)+N&c[s>>2];if(H>>>0<(c[O>>2]|0)>>>0){Q=a[(c[r>>2]|0)+H|0]|0}else{Q=b8[c[M>>2]&255](c[n>>2]|0,H)|0}a[E+40+P|0]=Q;P=P+1|0;}while(P>>>0<8);P=o|0;b[P>>1]=b[P>>1]&255;i=h;return}}while(0);b[o>>1]=k&255|-32e3;i=h;return}else{xt(1,41072,(x=i,i=i+8|0,c[x>>2]=l,x)|0);b[j>>1]=b[j>>1]&255|-28928;i=h;return}}else if((m|0)==69){o=g+4|0;Q=b[g+8>>1]|0;do{if((Q&65535)<=255){t=f+((Q&65535)<<2)|0;P=c[t>>2]|0;if((P|0)==0){break}if((c[P+12>>2]|0)!=0){b[o>>1]=k&255|-31232;i=h;return}E=f+1032|0;if((c[E>>2]|0)==(P|0)){c[E>>2]=0;c[f+1048>>2]=0}E=f+1036|0;if((c[E>>2]|0)==(P|0)){c[E>>2]=0;c[f+1052>>2]=0}E=f+1040|0;if((c[E>>2]|0)==(P|0)){c[E>>2]=0;c[f+1056>>2]=0}E=f+1044|0;if((c[E>>2]|0)==(P|0)){c[E>>2]=0;c[f+1060>>2]=0}E=f+1028|0;c[E>>2]=(c[E>>2]|0)-(c[P+4>>2]|0);c[t>>2]=0;zI(c[P+8>>2]|0);zI(P);P=o|0;b[P>>1]=b[P>>1]&255;i=h;return}}while(0);b[o>>1]=k&255|-32e3;i=h;return}else if((m|0)==70){b[j>>1]=50;i=h;return}else if((m|0)==71){o=g+4|0;Q=b[g+8>>1]|0;do{if((Q&65535)<=255){P=c[f+((Q&65535)<<2)>>2]|0;if((P|0)==0){break}t=P+12|0;if((c[t>>2]|0)!=0){b[o>>1]=k&255|-29440;i=h;return}E=P+16|0;n=c[f+1032>>2]|0;if((n|0)==0){b[E>>1]=0;R=65535}else{b[E>>1]=b[n>>1]|0;R=c[f+1048>>2]|0}c[P+24>>2]=R;n=P+18|0;E=c[f+1036>>2]|0;if((E|0)==0){b[n>>1]=0;S=65535}else{b[n>>1]=b[E>>1]|0;S=c[f+1052>>2]|0}c[P+28>>2]=S;E=P+20|0;n=c[f+1040>>2]|0;if((n|0)==0){b[E>>1]=0;T=65535}else{b[E>>1]=b[n>>1]|0;T=c[f+1056>>2]|0}c[P+32>>2]=T;n=P+22|0;E=c[f+1044>>2]|0;if((E|0)==0){b[n>>1]=0;U=65535}else{b[n>>1]=b[E>>1]|0;U=c[f+1060>>2]|0}c[P+36>>2]=U;c[t>>2]=1;t=o|0;b[t>>1]=b[t>>1]&255;i=h;return}}while(0);b[o>>1]=k&255|-32e3;i=h;return}else if((m|0)==68){o=l&255;U=b[g+10>>1]|0;T=U&65535;S=b[g+8>>1]|0;if(o>>>0>3){b[j>>1]=k&255|-29952;i=h;return}do{if((S&65535)<=255){R=c[f+((S&65535)<<2)>>2]|0;if((R|0)==0){break}if(U<<16>>16==-1){c[f+1032+(o<<2)>>2]=0;c[f+1048+(o<<2)>>2]=0;b[j>>1]=b[j>>1]&255;i=h;return}if(T>>>0<(c[R+4>>2]|0)>>>0){c[f+1032+(o<<2)>>2]=R;c[f+1048+(o<<2)>>2]=T;b[j>>1]=b[j>>1]&255;i=h;return}else{b[j>>1]=k&255|-22528;i=h;return}}}while(0);b[j>>1]=k&255|-32e3;i=h;return}else if((m|0)==65){b[j>>1]=k&255;b[g+10>>1]=(rL(c[f+1064>>2]|0)|0)>>>4&65535;i=h;return}else if((m|0)==67){T=g+4|0;o=b[g+10>>1]|0;U=o&65535;if(o<<16>>16==0){b[T>>1]=k&255|-30464;i=h;return}o=c[f+1024>>2]|0;if(U>>>0>o>>>0){b[T>>1]=k&255|-30976;i=h;return}S=f+1028|0;if(((c[S>>2]|0)+U|0)>>>0>o>>>0){b[T>>1]=k&255|-30720;i=h;return}else{V=1}while(1){if(V>>>0>=255){I=623;break}W=f+(V<<2)|0;if((c[W>>2]|0)==0){break}else{V=V+1|0}}if((I|0)==623){b[T>>1]=k&255|-31488;i=h;return}I=zH(48)|0;o=I;R=V&65535;do{if((I|0)==0){X=0}else{b[I>>1]=R;c[I+4>>2]=U;V=zH(U<<14)|0;c[I+8>>2]=V;if((V|0)==0){zI(I);X=0;break}else{c[I+12>>2]=0;V=I+40|0;Q=V|0;y=0;a[Q]=y&255;y=y>>8;a[Q+1|0]=y&255;y=y>>8;a[Q+2|0]=y&255;y=y>>8;a[Q+3|0]=y&255;Q=V+4|0;y=0;a[Q]=y&255;y=y>>8;a[Q+1|0]=y&255;y=y>>8;a[Q+2|0]=y&255;y=y>>8;a[Q+3|0]=y&255;X=o;break}}}while(0);c[W>>2]=X;c[S>>2]=(c[S>>2]|0)+U;U=T|0;b[U>>1]=b[U>>1]&255;b[g+8>>1]=R;i=h;return}else if((m|0)==66){b[j>>1]=k&255;R=f+1024|0;b[g+10>>1]=(c[R>>2]|0)-(c[f+1028>>2]|0)&65535;b[g+8>>1]=c[R>>2]&65535;i=h;return}else if((m|0)==76){R=g+4|0;U=b[g+8>>1]|0;do{if((U&65535)<=255){T=f+((U&65535)<<2)|0;if((c[T>>2]|0)==0){break}b[R>>1]=k&255;b[g+10>>1]=c[(c[T>>2]|0)+4>>2]&65535;i=h;return}}while(0);b[R>>1]=k&255|-32e3;i=h;return}else if((m|0)==77){m=e[g+18>>1]|0;k=(e[g+20>>1]|0)<<4;R=g+80|0;U=g+76|0;T=g+72|0;S=g+48|0;X=g+32|0;W=0;o=0;while(1){I=f+(o<<2)|0;do{if((c[I>>2]|0)==0){Y=W}else{Q=W+1|0;V=(o<<2)+m|0;t=o&65535;P=c[R>>2]&(V&65535)+k;E=P+1|0;if(E>>>0<(c[U>>2]|0)>>>0){a[(c[T>>2]|0)+P|0]=o&255;a[(c[T>>2]|0)+E|0]=(t&65535)>>>8&255}else{b5[c[S>>2]&255](c[X>>2]|0,P,t)}t=c[(c[I>>2]|0)+4>>2]|0;P=t&65535;E=c[R>>2]&(V+2&65535)+k;V=E+1|0;if(V>>>0<(c[U>>2]|0)>>>0){a[(c[T>>2]|0)+E|0]=t&255;a[(c[T>>2]|0)+V|0]=(P&65535)>>>8&255;Y=Q;break}else{b5[c[S>>2]&255](c[X>>2]|0,E,P);Y=Q;break}}}while(0);I=o+1|0;if(I>>>0<255){W=Y;o=I}else{break}}b[j>>1]=b[j>>1]&255;b[g+10>>1]=Y&65535;i=h;return}else{xt(1,20992,(x=i,i=i+8|0,c[x>>2]=l,x)|0);b[j>>1]=b[j>>1]&255|-31744;i=h;return}}function c0(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=i;h=f|0;f=c[h>>2]|0;j=f+4|0;k=b[j>>1]|0;l=(k&65535)>>>8;if((l|0)==136){m=f+30|0;b[m>>1]=b[m>>1]&-2;b[(c[h>>2]|0)+4>>1]=0;m=(c[h>>2]|0)+30|0;b[m>>1]=b[m>>1]|1;i=g;return}else if((l|0)==135){l=b[f+16>>1]|0;m=(e[f+6>>1]|0)<<1;n=(e[f+20>>1]|0)<<4;o=c[f+80>>2]|0;p=(l+18&65535)+n&o;q=p+1|0;r=c[f+76>>2]|0;if(q>>>0<r>>>0){s=c[f+72>>2]|0;t=(d[s+q|0]|0)<<8|(d[s+p|0]|0);u=f;v=o;w=r}else{r=b8[c[f+44>>2]&255](c[f+32>>2]|0,p)|0;p=c[h>>2]|0;t=r;u=p;v=c[p+80>>2]|0;w=c[p+76>>2]|0}p=v&(l+20&65535)+n;if(p>>>0<w>>>0){y=a[(c[u+72>>2]|0)+p|0]|0;z=u;A=v;B=w}else{w=b8[c[u+36>>2]&255](c[u+32>>2]|0,p)|0;p=c[h>>2]|0;y=w;z=p;A=c[p+80>>2]|0;B=c[p+76>>2]|0}p=A&(l+26&65535)+n;w=p+1|0;if(w>>>0<B>>>0){u=c[z+72>>2]|0;C=(d[u+w|0]|0)<<8|(d[u+p|0]|0);D=z;E=A;F=B}else{B=b8[c[z+44>>2]&255](c[z+32>>2]|0,p)|0;p=c[h>>2]|0;C=B;D=p;E=c[p+80>>2]|0;F=c[p+76>>2]|0}p=E&(l+28&65535)+n;if(p>>>0<F>>>0){G=a[(c[D+72>>2]|0)+p|0]|0}else{G=b8[c[D+36>>2]&255](c[D+32>>2]|0,p)|0}xt(3,35656,(x=i,i=i+24|0,c[x>>2]=(y&255)<<16|t&65535,c[x+8>>2]=(G&255)<<16|C&65535,c[x+16>>2]=m,x)|0);m=(c[h>>2]|0)+30|0;b[m>>1]=b[m>>1]|1;m=(c[h>>2]|0)+4|0;b[m>>1]=b[m>>1]&255;m=(c[h>>2]|0)+4|0;b[m>>1]=b[m>>1]|-31232;i=g;return}else{b[j>>1]=k&255;k=(c[h>>2]|0)+4|0;b[k>>1]=b[k>>1]|-31232;k=(c[h>>2]|0)+30|0;b[k>>1]=b[k>>1]|1;i=g;return}}function c1(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+8|0;h=g|0;j=f|0;k=c[j>>2]|0;l=(e[k+4>>1]|0)>>>8;m=k+30|0;b[m>>1]=b[m>>1]|1;if((l|0)==0){m=c[j>>2]|0;k=c[m+80>>2]&1132;n=k|1;if(n>>>0<(c[m+76>>2]|0)>>>0){o=c[m+72>>2]|0;p=(d[o+n|0]|0)<<8|(d[o+k|0]|0);q=m}else{o=b8[c[m+44>>2]&255](c[m+32>>2]|0,k)|0;p=o;q=c[j>>2]|0}b[q+8>>1]=p;p=c[j>>2]|0;q=c[p+80>>2]&1134;o=q|1;if(o>>>0<(c[p+76>>2]|0)>>>0){k=c[p+72>>2]|0;r=(d[k+o|0]|0)<<8|(d[k+q|0]|0);s=p}else{k=b8[c[p+44>>2]&255](c[p+32>>2]|0,q)|0;r=k;s=c[j>>2]|0}b[s+6>>1]=r;r=c[j>>2]|0;s=c[r+80>>2]&1136;if(s>>>0<(c[r+76>>2]|0)>>>0){t=a[(c[r+72>>2]|0)+s|0]|0;u=r}else{k=b8[c[r+36>>2]&255](c[r+32>>2]|0,s)|0;t=k;u=c[j>>2]|0}k=u+4|0;b[k>>1]=b[k>>1]&-256;k=(c[j>>2]|0)+4|0;b[k>>1]=b[k>>1]|t&255;t=c[j>>2]|0;k=c[t+80>>2]&1136;if(k>>>0<(c[t+76>>2]|0)>>>0){a[(c[t+72>>2]|0)+k|0]=0}else{b5[c[t+40>>2]&255](c[t+32>>2]|0,k,0)}k=(c[j>>2]|0)+30|0;b[k>>1]=b[k>>1]&-2;i=g;return}else if((l|0)==1){k=c[j>>2]|0;t=b[k+8>>1]|0;u=c[k+80>>2]&1132;s=u|1;if(s>>>0<(c[k+76>>2]|0)>>>0){r=k+72|0;a[(c[r>>2]|0)+u|0]=t&255;a[(c[r>>2]|0)+s|0]=(t&65535)>>>8&255}else{b5[c[k+48>>2]&255](c[k+32>>2]|0,u,t)}t=c[j>>2]|0;u=b[t+6>>1]|0;k=c[t+80>>2]&1134;s=k|1;if(s>>>0<(c[t+76>>2]|0)>>>0){r=t+72|0;a[(c[r>>2]|0)+k|0]=u&255;a[(c[r>>2]|0)+s|0]=(u&65535)>>>8&255}else{b5[c[t+48>>2]&255](c[t+32>>2]|0,k,u)}u=(c[j>>2]|0)+30|0;b[u>>1]=b[u>>1]&-2;i=g;return}else{if((c[f+3104>>2]|0)==0){i=g;return}if((l|0)==4){c[h>>2]=b0(0)|0;f=aH(h|0)|0;u=f+20|0;k=((c[u>>2]|0)+1900|0)/100|0;t=(c[j>>2]|0)+6|0;b[t>>1]=b[t>>1]&255;t=(c[j>>2]|0)+6|0;b[t>>1]=(e[t>>1]|0|(((((k>>>0)/10|0)>>>0)%10|0)<<4|((k>>>0)%10|0))<<8)&65535;k=(c[u>>2]|0)+1900|0;u=(c[j>>2]|0)+6|0;b[u>>1]=b[u>>1]&-256;u=(c[j>>2]|0)+6|0;b[u>>1]=(((((k>>>0)/10|0)>>>0)%10|0)<<4|((k>>>0)%10|0)&15|(e[u>>1]|0))&65535;u=(c[f+16>>2]|0)+1|0;k=(c[j>>2]|0)+8|0;b[k>>1]=b[k>>1]&255;k=(c[j>>2]|0)+8|0;b[k>>1]=(e[k>>1]|0|(((((u>>>0)/10|0)>>>0)%10|0)<<4|((u>>>0)%10|0))<<8)&65535;u=c[f+12>>2]|0;f=(c[j>>2]|0)+8|0;b[f>>1]=b[f>>1]&-256;f=(c[j>>2]|0)+8|0;b[f>>1]=(((((u>>>0)/10|0)>>>0)%10|0)<<4|((u>>>0)%10|0)&15|(e[f>>1]|0))&65535;f=(c[j>>2]|0)+30|0;b[f>>1]=b[f>>1]&-2;i=g;return}else if((l|0)==5){f=(c[j>>2]|0)+30|0;b[f>>1]=b[f>>1]&-2;i=g;return}else if((l|0)==2){c[h>>2]=b0(0)|0;f=aH(h|0)|0;h=c[f+8>>2]|0;u=(c[j>>2]|0)+6|0;b[u>>1]=b[u>>1]&255;u=(c[j>>2]|0)+6|0;b[u>>1]=(e[u>>1]|0|(((((h>>>0)/10|0)>>>0)%10|0)<<4|((h>>>0)%10|0))<<8)&65535;h=c[f+4>>2]|0;u=(c[j>>2]|0)+6|0;b[u>>1]=b[u>>1]&-256;u=(c[j>>2]|0)+6|0;b[u>>1]=(((((h>>>0)/10|0)>>>0)%10|0)<<4|((h>>>0)%10|0)&15|(e[u>>1]|0))&65535;u=c[f>>2]|0;f=(c[j>>2]|0)+8|0;b[f>>1]=b[f>>1]&255;f=(c[j>>2]|0)+8|0;b[f>>1]=(e[f>>1]|0|(((((u>>>0)/10|0)>>>0)%10|0)<<4|((u>>>0)%10|0))<<8)&65535;u=(c[j>>2]|0)+30|0;b[u>>1]=b[u>>1]&-2;i=g;return}else if((l|0)==3){l=(c[j>>2]|0)+30|0;b[l>>1]=b[l>>1]&-2;i=g;return}else{i=g;return}}}function c2(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0;h=i;i=i+512|0;j=h|0;k=h+256|0;l=d;m=f&255;if((m|0)==6){b[(c[d>>2]|0)+4>>1]=0;if(g<<24>>24!=19){i=h;return}dB(l);i=h;return}else if((m|0)==205){n=908}do{if((n|0)==908){if((g<<24>>24|0)==21){c0(l);i=h;return}else if((g<<24>>24|0)==26){c1(l);i=h;return}else if((g<<24>>24|0)==19){dC(c[d+8>>2]|0,c[d>>2]|0);i=h;return}else{break}}}while(0);f=d;o=(c[f>>2]|0)+30|0;b[o>>1]=b[o>>1]&-2;o=g&255;g=o<<8|m;if((g|0)==1538){p=hJ(c[f>>2]|0)|0;b[(c[f>>2]|0)+4>>1]=p&65535;b[(c[f>>2]|0)+8>>1]=p>>>16&65535;i=h;return}else if((g|0)==2306){b[(c[f>>2]|0)+4>>1]=c[d+3108>>2]&65535;i=h;return}else if((g|0)==2050){b[(c[f>>2]|0)+4>>1]=c[d+3112>>2]&65535;i=h;return}else if((g|0)==1537){p=c[f>>2]|0;hI(p,(e[p+8>>1]|0)<<16|(e[p+4>>1]|0));i=h;return}else if((g|0)==514){p=c[d+3048>>2]|0;if((p|0)==0){q=0}else{q=c[p+48>>2]&65535}b[(c[f>>2]|0)+4>>1]=q;q=c[d+3052>>2]|0;if((q|0)==0){r=0}else{r=c[q+48>>2]&65535}b[(c[f>>2]|0)+10>>1]=r;r=c[d+3056>>2]|0;if((r|0)==0){s=0}else{s=c[r+48>>2]&65535}b[(c[f>>2]|0)+6>>1]=s;s=c[d+3060>>2]|0;if((s|0)==0){t=0}else{t=c[s+48>>2]&65535}b[(c[f>>2]|0)+8>>1]=t;i=h;return}else if((g|0)==4){c$(c[d+3020>>2]|0,c[f>>2]|0);i=h;return}else if((g|0)==770){b[(c[f>>2]|0)+4>>1]=0;i=h;return}else if((g|0)==260){cY(c[d+3020>>2]|0,c[f>>2]|0);i=h;return}else if((g|0)==3){eG(c[d+3024>>2]|0,c[f>>2]|0);i=h;return}else if((g|0)==259){eC(c[d+3024>>2]|0,c[f>>2]|0);i=h;return}else if((g|0)==5){t=j|0;s=k|0;r=(c[f>>2]|0)+30|0;b[r>>1]=b[r>>1]|1;r=c[f>>2]|0;q=(e[r+26>>1]|0)<<4;p=e[r+16>>1]|0;u=0;v=r;while(1){r=(p&65535)+q&c[v+80>>2];if((r+1|0)>>>0<(c[v+76>>2]|0)>>>0){w=a[(c[v+72>>2]|0)+r|0]|0}else{w=(b8[c[v+44>>2]&255](c[v+32>>2]|0,r)|0)&255}a[j+u|0]=w;if(w<<24>>24==0){break}r=u+1|0;if(r>>>0>=256){n=991;break}p=p+1|0;u=r;v=c[f>>2]|0}if((n|0)==991){i=h;return}if(u>>>0>255){i=h;return}u=c[f>>2]|0;v=e[u+18>>1]|0;p=0;w=u;while(1){u=(v&65535)+q&c[w+80>>2];if((u+1|0)>>>0<(c[w+76>>2]|0)>>>0){y=a[(c[w+72>>2]|0)+u|0]|0}else{y=(b8[c[w+44>>2]&255](c[w+32>>2]|0,u)|0)&255}a[k+p|0]=y;if(y<<24>>24==0){break}u=p+1|0;if(u>>>0>=256){n=997;break}v=v+1|0;p=u;w=c[f>>2]|0}if((n|0)==997){i=h;return}if(p>>>0>255){i=h;return}p=(dV(l,t,s)|0)==0;s=(c[f>>2]|0)+30|0;t=b[s>>1]|0;if(p){b[s>>1]=t&-2;b[(c[f>>2]|0)+4>>1]=0;i=h;return}else{b[s>>1]=t|1;b[(c[f>>2]|0)+4>>1]=1;i=h;return}}else if((g|0)==1025|(g|0)==1281){i=h;return}else if((g|0)==1026){b[(c[f>>2]|0)+4>>1]=0;i=h;return}else if((g|0)==1794){t=c[f>>2]|0;s=b[t+20>>1]|0;p=b[t+18>>1]|0;b[t+4>>1]=2;b[(c[f>>2]|0)+8>>1]=512;if((p|s)<<16>>16==0){i=h;return}t=c[f>>2]|0;n=(s&65535)<<4;s=c[t+80>>2]&(p&65535)+n;w=p;p=32864;v=50;y=t;k=s;q=s>>>0<(c[t+76>>2]|0)>>>0;do{if(q){a[(c[y+72>>2]|0)+k|0]=v}else{b5[c[y+40>>2]&255](c[y+32>>2]|0,k,v)}w=w+1&65535;p=p+1|0;v=a[p]|0;y=c[f>>2]|0;k=c[y+80>>2]&(w&65535)+n;q=k>>>0<(c[y+76>>2]|0)>>>0}while(v<<24>>24!=0);if(q){a[(c[y+72>>2]|0)+k|0]=0;i=h;return}else{b5[c[y+40>>2]&255](c[y+32>>2]|0,k,0);i=h;return}}else if((g|0)==2){k=c7(l)|0;y=(c[f>>2]|0)+4|0;b[y>>1]=b[y>>1]&-256;y=(c[f>>2]|0)+4|0;b[y>>1]=(e[y>>1]|0|k&255)&65535;i=h;return}else if((g|0)==0){c[d+3168>>2]=1;i=h;return}else if((g|0)==256){c[d+3168>>2]=2;i=h;return}else if((g|0)==1282){b[(c[f>>2]|0)+4>>1]=0;i=h;return}else if((g|0)==1){c6(l,b[(c[f>>2]|0)+4>>1]&255);i=h;return}else if((g|0)==258){g=c[d+3032>>2]|0;if((g|0)==0){z=0}else{z=c[g+688>>2]&65535}b[(c[f>>2]|0)+4>>1]=z;z=c[d+3036>>2]|0;if((z|0)==0){A=0}else{A=c[z+688>>2]&65535}b[(c[f>>2]|0)+10>>1]=A;A=c[d+3040>>2]|0;if((A|0)==0){B=0}else{B=c[A+688>>2]&65535}b[(c[f>>2]|0)+6>>1]=B;B=c[d+3044>>2]|0;if((B|0)==0){C=0}else{C=c[B+688>>2]&65535}b[(c[f>>2]|0)+8>>1]=C;i=h;return}else{C=(c[f>>2]|0)+30|0;b[C>>1]=b[C>>1]|1;C=c[f>>2]|0;f=e[C+4>>1]|0;B=e[C+10>>1]|0;d=e[C+6>>1]|0;A=e[C+8>>1]|0;xt(3,39888,(x=i,i=i+48|0,c[x>>2]=m,c[x+8>>2]=o,c[x+16>>2]=f,c[x+24>>2]=B,c[x+32>>2]=d,c[x+40>>2]=A,x)|0);i=h;return}}function c3(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0;d=i;i=i+424|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;l=d+48|0;m=d+56|0;n=d+64|0;o=d+72|0;p=d+80|0;q=d+88|0;r=d+96|0;s=d+104|0;t=d+112|0;u=d+120|0;v=d+128|0;w=d+136|0;y=d+144|0;z=d+152|0;A=d+160|0;B=d+176|0;C=d+184|0;D=d+192|0;E=d+200|0;F=d+208|0;G=d+216|0;H=d+224|0;I=d+232|0;J=d+240|0;K=d+248|0;L=d+256|0;M=d+264|0;N=d+272|0;O=d+280|0;P=d+288|0;Q=d+296|0;R=d+304|0;S=d+312|0;T=d+320|0;U=d+328|0;V=d+336|0;W=d+344|0;X=d+352|0;Y=d+360|0;Z=d+368|0;_=d+376|0;$=d+384|0;aa=d+392|0;ab=d+400|0;ac=d+408|0;ad=d+416|0;ae=zH(3176)|0;af=ae;if((ae|0)==0){ag=0;i=d;return ag|0}c[ae+3064>>2]=b;wt(ae+3068|0);ah=ae+3108|0;c[ah>>2]=0;ai=ae+3112|0;c[ai>>2]=0;c[ae+3140>>2]=0;c[ae+3168>>2]=0;a[ae+3172|0]=0;aj=yc(b,0,38464)|0;ak=(aj|0)==0?b:aj;ym(ak,40056,ad,38424)|0;yj(ak,38368,ae+3076|0,128)|0;yj(ak,38256,$,2)|0;yl(ak,38152,ae+3104|0,1)|0;yl(ak,38016,aa,1)|0;yl(ak,37856,ab,1)|0;yl(ak,37744,ac,1)|0;ak=c[$>>2]|0;aj=c[aa>>2]|0;al=c[ab>>2]|0;xv(2,37648,37528,(x=i,i=i+32|0,c[x>>2]=c[ad>>2],c[x+8>>2]=ak,c[x+16>>2]=aj,c[x+24>>2]=al,x)|0);al=c[ad>>2]|0;do{if((aP(al|0,38424)|0)==0){c[ae+3e3>>2]=1;am=1}else{if((aP(al|0,37488)|0)==0){c[ae+3e3>>2]=2;am=2;break}if((aP(al|0,37416)|0)==0){c[ae+3e3>>2]=6;am=6;break}else{xt(0,37352,(x=i,i=i+8|0,c[x>>2]=al,x)|0);c[ae+3e3>>2]=1;am=1;break}}}while(0);a[ae+3098|0]=(c[aa>>2]|0)!=0|0;a[ae+3099|0]=(c[ab>>2]|0)!=0|0;ab=ae+3100|0;a[ab]=(c[ac>>2]|0)!=0|0;ac=ae+3004|0;a[ac]=60;a[ae+3005|0]=0;a[ae+3006|0]=8;aa=ae+3007|0;a[aa]=0;al=ae+3008|0;a[al]=0;ad=(am&2|0)==0;if(!ad){a[aa]=1}aj=c[$>>2]|0;c[ah>>2]=aj;do{if((am&1|0)==0){if(ad){break}a[al]=0;if((aj|0)==0){break}a[al]=(aj<<2)+12&12}else{a[ac]=60;if((aj|0)==0){break}a[ac]=((aj<<6)+192|61)&255}}while(0);dO(af,b);aj=r5()|0;ad=ae+16|0;c[ad>>2]=aj;am=ae+20|0;w9(aj,b,am)|0;xa(c[ad>>2]|0,b)|0;aj=c[am>>2]|0;if((aj|0)==0){an=65536}else{an=rM(aj)|0}aj=ae+3e3|0;ah=c[aj>>2]|0;do{if((ah&1|0)==0){if((ah&2|0)==0){break}$=an>>>16;if(($|0)==0){ao=0}else{ak=$-1|0;ao=ak>>>0>3?12:ak<<2&12}a[aa]=(a[aa]&-13&255|ao)&255}else{if(an>>>0<65536){ap=0}else{ap=(an-65536|0)>>>15}ak=a[al]&-2;a[aa]=(a[aa]&-16&255|ap&15)&255;a[al]=(ak&255|ap>>>4&1)&255}}while(0);do{if((c[am>>2]|0)!=0){if((a[ab]|0)!=0){break}se(c[ad>>2]|0,1138,4660)}}while(0);ab=r5()|0;ap=ae+24|0;c[ap>>2]=ab;rY(ab,ae,34,70,0,66,46,0);ab=ae+28|0;c[ab>>2]=0;aa=yc(b,0,39384)|0;do{if((aa|0)!=0){ym(aa,21928,Y,0)|0;yi(aa,39312,Z,0)|0;yi(aa,39160,_,65536)|0;an=c[_>>2]|0;ao=c[Y>>2]|0;xv(2,39056,38816,(x=i,i=i+24|0,c[x>>2]=c[Z>>2],c[x+8>>2]=an,c[x+16>>2]=(ao|0)==0?38736:ao,x)|0);ao=sf(c[Z>>2]|0,c[_>>2]|0)|0;c[ab>>2]=ao;if((ao|0)==0){xt(0,38632,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);break}r9(ao,0);ao=c[ad>>2]|0;r7(ao,sm(c[ab>>2]|0)|0,0);ao=c[Y>>2]|0;if((ao|0)==0){break}if((sy(c[ab>>2]|0,ao)|0)==0){break}xt(0,38496,(x=i,i=i+8|0,c[x>>2]=c[Y>>2],x)|0)}}while(0);Y=yc(b,0,40176)|0;ym(Y,40056,W,25488)|0;yj(Y,39736,X,0)|0;Y=c[X>>2]|0;xv(2,38968,39624,(x=i,i=i+16|0,c[x>>2]=c[W>>2],c[x+8>>2]=Y,x)|0);Y=ae;c[Y>>2]=hU()|0;if((dj(af,c[W>>2]|0)|0)!=0){xt(0,39464,(x=i,i=i+8|0,c[x>>2]=c[W>>2],x)|0)}hM(c[Y>>2]|0,c[ad>>2]|0,80,54,130,134);hN(c[Y>>2]|0,c[ap>>2]|0,80,54,130,134);W=c[am>>2]|0;ab=c[Y>>2]|0;if((W|0)==0){hL(ab,0,0)}else{hL(ab,c[W+44>>2]|0,c[W+40>>2]|0)}c[(c[Y>>2]|0)+92>>2]=ae;c[(c[Y>>2]|0)+96>>2]=18;W=c[X>>2]|0;c[ae+3128>>2]=W;c[ae+3132>>2]=W;W=ae+3136|0;c[W>>2]=0;yi(yc(b,0,40760)|0,34200,V,0)|0;xv(2,40632,41288,(x=i,i=i+16|0,c[x>>2]=c[V>>2],c[x+8>>2]=16,x)|0);a[ae+3097|0]=0;X=ae+32|0;ab=X;zP(ae+3080|0,0,16);mI(ab);_=r0(c[V>>2]|0,16,0)|0;if((_|0)==0){xt(0,40352,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0)}else{rJ(_,X,16,92,50,68,32,108);r7(c[ap>>2]|0,_,1);mv(ab,1);ml(ab,0,ae,382)}yi(yc(b,0,40912)|0,34200,U,32)|0;xv(2,40840,41288,(x=i,i=i+16|0,c[x>>2]=c[U>>2],c[x+8>>2]=2,x)|0);_=ae+488|0;V=_;nW(V);Z=r0(c[U>>2]|0,2,0)|0;if((Z|0)!=0){rJ(Z,_,74,38,112,102,88,2);r7(c[ap>>2]|0,Z,1);nN(V,c[Y>>2]|0,160);hK(c[Y>>2]|0,_,4)}yi(yc(b,0,41176)|0,34200,T,64)|0;xv(2,41120,40944,(x=i,i=i+16|0,c[x>>2]=c[T>>2],c[x+8>>2]=4,x)|0);a[ae+3096|0]=0;Y=ae+340|0;Z=Y;nq(Z);U=r0(c[T>>2]|0,4,0)|0;if((U|0)!=0){rJ(U,Y,40,126,44,138,124,4);r7(c[ap>>2]|0,U,1);nr(Z,0,1);nr(Z,1,1);nr(Z,2,1);nk(Z,0,_,112);nk(Z,1,ae,32);nk(Z,2,ae,174)}yi(yc(b,0,41472)|0,34200,S,96)|0;xv(2,41400,41288,(x=i,i=i+16|0,c[x>>2]=c[S>>2],c[x+8>>2]=4,x)|0);Z=ae+424|0;U=Z;nH(U);c[ae+432>>2]=ae;c[ae+436>>2]=252;c[ae+460>>2]=ae;c[ae+464>>2]=262;c[ae+472>>2]=ae;c[ae+476>>2]=192;Y=r0(c[S>>2]|0,4,0)|0;if((Y|0)!=0){rJ(Y,Z,56,68,18,98,36,112);r7(c[ap>>2]|0,Y,1);nJ(U,3,-103)}U=ae+564|0;Y=U;dH(Y);dE(Y,_,110);Y=ae+844|0;c[Y>>2]=0;do{if((c[aj>>2]&1|0)!=0){Z=yc(b,0,22032)|0;if((Z|0)==0){break}yl(Z,22008,O,1)|0;if((c[O>>2]|0)==0){break}ym(Z,21928,L,0)|0;ym(Z,21792,M,21624)|0;yi(Z,21376,N,0)|0;yl(Z,21264,P,0)|0;yl(Z,21184,R,1)|0;if((yl(Z,21096,Q,0)|0)==0){aq=c[Q>>2]|0}else{c[Q>>2]=-1;aq=-1}Z=c[L>>2]|0;S=c[M>>2]|0;T=c[R>>2]|0;aa=c[N>>2]|0;ao=c[P>>2]|0;xv(2,21040,20880,(x=i,i=i+48|0,c[x>>2]=(Z|0)!=0?Z:32456,c[x+8>>2]=S,c[x+16>>2]=aq,c[x+24>>2]=T,c[x+32>>2]=aa,c[x+40>>2]=ao,x)|0);ao=ct()|0;c[Y>>2]=ao;if((ao|0)==0){xt(0,20824,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);break}if((cu(ao,c[L>>2]|0)|0)!=0){xt(0,20712,(x=i,i=i+8|0,c[x>>2]=c[L>>2],x)|0)}ao=c[M>>2]|0;do{if((aP(ao|0,21624)|0)==0){cy(c[Y>>2]|0,0)}else{if((aP(ao|0,41816)|0)==0){cy(c[Y>>2]|0,1);break}else{xt(0,41688,(x=i,i=i+8|0,c[x>>2]=ao,x)|0);break}}}while(0);ao=c[Y>>2]|0;if((c[P>>2]|0)==0){aa=c[N>>2]|0;cw(ao,aa)|0}else{cv(ao)}ao=c[Q>>2]|0;if((ao|0)>-1){cx(c[Y>>2]|0,ao)}cz(c[Y>>2]|0,c[R>>2]|0)}}while(0);R=ae+848|0;eq(R);d2(R,ae,460);Y=yc(b,0,23088)|0;if((Y|0)!=0){ym(Y,33992,H,0)|0;yj(Y,22784,I,500)|0;yi(Y,22552,J,44100)|0;yi(Y,22456,K,0)|0;Y=c[J>>2]|0;Q=c[K>>2]|0;N=c[H>>2]|0;xv(2,22320,22160,(x=i,i=i+32|0,c[x>>2]=c[I>>2],c[x+8>>2]=Y,c[x+16>>2]=Q,c[x+24>>2]=(N|0)!=0?N:32456,x)|0);N=c[H>>2]|0;do{if((N|0)!=0){if((er(R,N,c[J>>2]|0)|0)==0){break}xt(0,22096,(x=i,i=i+8|0,c[x>>2]=c[H>>2],x)|0)}}while(0);es(R,c[K>>2]|0);d1(R,c[I>>2]|0)}I=xb(b,c[10740]|0)|0;R=ae+3028|0;c[R>>2]=I;if((I|0)!=0){y4(I,U,70);y5(c[R>>2]|0,ae,2);y3(c[R>>2]|0,ae,112)}U=ae+4|0;c[U>>2]=0;I=yc(b,0,25880)|0;ym(I,25608,G,25328)|0;K=c[10738]|0;L1424:do{if((K|0)==0){ar=I;as=c[G>>2]|0}else{if((I|0)==0){at=K}else{H=I;J=K;while(1){N=c[G>>2]|0;if((aP(J|0,N|0)|0)==0){ar=H;as=N;break L1424}N=yc(b,H,25880)|0;ym(N,25608,G,25328)|0;Q=c[10738]|0;if((N|0)==0){at=Q;break}else{H=N;J=Q}}}c[G>>2]=at;ar=0;as=at}}while(0);xv(2,25232,25128,(x=i,i=i+8|0,c[x>>2]=as,x)|0);as=c[G>>2]|0;L1433:do{if((aP(as|0,25040)|0)==0){G=qF(ar)|0;c[U>>2]=G;if((G|0)==0){au=1157;break}yl(ar,23728,E,0)|0;yj(ar,31664,F,2)|0;G=(c[E>>2]|0)!=0?23560:23488;xv(2,25232,23216,(x=i,i=i+16|0,c[x>>2]=c[F>>2],c[x+8>>2]=G,x)|0);if((c[E>>2]|0)!=0){G=c[(c[U>>2]|0)+32>>2]|0;qd(G,_,nM(V,c[F>>2]|0)|0)}G=c[ad>>2]|0;r7(G,qK(c[U>>2]|0)|0,0);G=c[ap>>2]|0;r7(G,qL(c[U>>2]|0)|0,0);G=c[aj>>2]|0;do{if((G&1|0)==0){if((G&2|0)==0){break}a[al]=a[al]&-4}else{a[ac]=a[ac]&-49}}while(0);dG(af,0);au=1156}else{if((aP(as|0,24984)|0)==0){G=py(ar)|0;c[U>>2]=G;if((G|0)==0){au=1157;break}yl(ar,23728,C,0)|0;yj(ar,31664,D,2)|0;G=(c[C>>2]|0)!=0?23560:23488;xv(2,25232,23656,(x=i,i=i+16|0,c[x>>2]=c[D>>2],c[x+8>>2]=G,x)|0);if((c[C>>2]|0)!=0){G=c[(c[U>>2]|0)+32>>2]|0;pe(G,_,nM(V,c[D>>2]|0)|0)}G=c[ad>>2]|0;r7(G,qK(c[U>>2]|0)|0,0);G=c[ap>>2]|0;r7(G,qL(c[U>>2]|0)|0,0);G=c[aj>>2]|0;do{if((G&1|0)==0){if((G&2|0)==0){break}a[al]=a[al]&-4}else{a[ac]=a[ac]&-49}}while(0);dG(af,0);au=1156;break}if((aP(as|0,25328)|0)==0){G=pi(ar)|0;c[U>>2]=G;if((G|0)==0){au=1157;break}at=c[ad>>2]|0;r7(at,qK(G)|0,0);G=c[ap>>2]|0;r7(G,qL(c[U>>2]|0)|0,0);G=c[aj>>2]|0;do{if((G&1|0)==0){if((G&2|0)==0){break}a[al]=a[al]&-4|2}else{a[ac]=a[ac]&-49|32}}while(0);dG(af,2);au=1156;break}if((aP(as|0,24864)|0)==0){G=pQ(ar)|0;c[U>>2]=G;if((G|0)==0){au=1157;break}at=c[ad>>2]|0;r7(at,qK(G)|0,0);G=c[ap>>2]|0;r7(G,qL(c[U>>2]|0)|0,0);G=c[aj>>2]|0;do{if((G&1|0)==0){if((G&2|0)==0){break}a[al]=a[al]|3}else{a[ac]=a[ac]|48}}while(0);dG(af,3);au=1156;break}if((aP(as|0,24816)|0)==0){G=p7(ar)|0;c[U>>2]=G;if((G|0)==0){au=1157;break}at=c[ad>>2]|0;r7(at,qK(G)|0,0);G=c[ap>>2]|0;r7(G,qL(c[U>>2]|0)|0,0);G=c[aj>>2]|0;do{if((G&1|0)==0){if((G&2|0)==0){break}a[al]=a[al]|3}else{a[ac]=a[ac]|48}}while(0);dG(af,3);au=1156;break}if((aP(as|0,24736)|0)==0){G=qg(ar)|0;c[U>>2]=G;if((G|0)==0){au=1157;break}at=c[ad>>2]|0;r7(at,qK(G)|0,0);G=c[ap>>2]|0;r7(G,qL(c[U>>2]|0)|0,0);G=c[aj>>2]|0;do{if((G&1|0)==0){if((G&2|0)==0){break}a[al]=a[al]&-4|2}else{a[ac]=a[ac]&-49|32}}while(0);dG(af,2);au=1156;break}if((aP(as|0,24632)|0)==0){G=qn(ar)|0;c[U>>2]=G;if((G|0)==0){au=1157;break}at=c[ad>>2]|0;r7(at,qK(G)|0,0);G=c[ap>>2]|0;r7(G,qL(c[U>>2]|0)|0,0);G=c[aj>>2]|0;do{if((G&1|0)==0){if((G&2|0)==0){break}a[al]=a[al]&-4|2}else{a[ac]=a[ac]&-49|32}}while(0);dG(af,2);au=1156;break}do{if((aP(as|0,24384)|0)!=0){if((aP(as|0,24112)|0)==0){break}xt(0,24e3,(x=i,i=i+8|0,c[x>>2]=as,x)|0);au=1156;break L1433}}while(0);G=q0(ar)|0;c[U>>2]=G;if((G|0)==0){au=1157;break}at=c[ad>>2]|0;r7(at,qK(G)|0,0);G=c[ap>>2]|0;r7(G,qL(c[U>>2]|0)|0,0);G=c[aj>>2]|0;do{if((G&1|0)==0){if((G&2|0)==0){break}a[al]=a[al]&-4|2}else{a[ac]=a[ac]&-49|32}}while(0);dG(af,2);au=1156}}while(0);if((au|0)==1156){if((c[U>>2]|0)==0){au=1157}else{au=1158}}if((au|0)==1157){xt(0,23864,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);if((c[U>>2]|0)!=0){au=1158}}do{if((au|0)==1158){ac=c[ad>>2]|0;w9(ac,ar,am)|0;ac=c[ad>>2]|0;xa(ac,ar)|0;ac=c[ad>>2]|0;xk(ac,ar)|0;ac=c[R>>2]|0;if((ac|0)==0){break}qJ(c[U>>2]|0,ac)}}while(0);U=c[R>>2]|0;if((U|0)!=0){zl(U,640,480)|0;U=c[R>>2]|0;zn(U,35224,39752)|0}c[ae+12>>2]=0;U=ae+8|0;c[U>>2]=tx()|0;R=yc(b,0,26144)|0;if((R|0)!=0){ar=R;do{do{if((w8(ar,B)|0)==0){R=c[B>>2]|0;if((R|0)==0){break}am=c[U>>2]|0;ty(am,R)|0;if((tg(c[B>>2]|0)|0)>>>0<=127){break}c[ai>>2]=(c[ai>>2]|0)+1}else{xt(0,26072,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0)}}while(0);ar=yc(b,ar,26144)|0;}while((ar|0)!=0)}ar=ae+3012|0;c[ar>>2]=0;ai=yc(b,0,27488)|0;do{if((ai|0)!=0){yi(ai,34200,y,1008)|0;yj(ai,31664,z,6)|0;yl(ai,27216,v,0)|0;yl(ai,26840,w,0)|0;B=A|0;yj(ai,28968,B,65535)|0;R=A+4|0;yj(ai,28480,R,65535)|0;am=A+8|0;yj(ai,26712,am,65535)|0;au=A+12|0;yj(ai,26600,au,65535)|0;ac=c[z>>2]|0;al=c[v>>2]|0;aj=(c[w>>2]|0)==0|0;as=c[B>>2]|0;D=c[R>>2]|0;C=c[am>>2]|0;F=c[au>>2]|0;xv(2,26456,26360,(x=i,i=i+64|0,c[x>>2]=c[y>>2],c[x+8>>2]=ac,c[x+16>>2]=al,c[x+24>>2]=aj,c[x+32>>2]=as,c[x+40>>2]=D,c[x+48>>2]=C,c[x+56>>2]=F,x)|0);F=q1(c[y>>2]|0)|0;c[ar>>2]=F;if((F|0)==0){xt(0,26224,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);break}else{q5(F,c[ap>>2]|0);qZ(c[ar>>2]|0,c[U>>2]|0);q_(c[ar>>2]|0,0,c[B>>2]|0);q_(c[ar>>2]|0,1,c[R>>2]|0);q_(c[ar>>2]|0,2,c[am>>2]|0);q_(c[ar>>2]|0,3,c[au>>2]|0);oc((c[ar>>2]|0)+28|0,1193182);od((c[ar>>2]|0)+28|0,(c[v>>2]|0)!=0|0);oe((c[ar>>2]|0)+28|0,(c[w>>2]|0)!=0|0);au=(c[ar>>2]|0)+28|0;n9(au,_,nM(V,c[z>>2]|0)|0);oa((c[ar>>2]|0)+28|0,X,284);mm(ab,2,(c[ar>>2]|0)+28|0,76);au=(c[ar>>2]|0)+28|0;c[ae+240>>2]=au;c[ae+244>>2]=298;c[ae+232>>2]=au;c[ae+236>>2]=428;c[ae+224>>2]=ae;c[ae+228>>2]=82;c[ae+216>>2]=ae;c[ae+220>>2]=132;break}}}while(0);ar=ae+3016|0;c[ar>>2]=0;ab=yc(b,0,29192)|0;do{if((ab|0)!=0){yi(ab,34200,q,800)|0;yj(ab,31664,p,5)|0;z=r|0;yj(ab,28968,z,65535)|0;w=r+4|0;yj(ab,28480,w,65535)|0;yj(ab,28336,t,17)|0;ym(ab,28152,u,44448)|0;yj(ab,27976,s,0)|0;v=c[p>>2]|0;y=c[z>>2]|0;ai=c[w>>2]|0;A=c[t>>2]|0;au=c[s>>2]|0;am=c[u>>2]|0;xv(2,27800,27688,(x=i,i=i+56|0,c[x>>2]=c[q>>2],c[x+8>>2]=v,c[x+16>>2]=y,c[x+24>>2]=ai,c[x+32>>2]=A,c[x+40>>2]=au,c[x+48>>2]=am,x)|0);am=rh(c[q>>2]|0)|0;c[ar>>2]=am;if((am|0)==0){xt(0,27592,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);break}else{rk(am,c[ap>>2]|0);rf(c[ar>>2]|0,c[U>>2]|0);rg(c[ar>>2]|0,0,c[z>>2]|0);rg(c[ar>>2]|0,1,c[w>>2]|0);w=c[ar>>2]|0;z=c[u>>2]|0;rl(w,z,zN(z|0)|0);rd(c[ar>>2]|0,c[s>>2]|0);re(c[ar>>2]|0,c[t>>2]|0);z=c[ar>>2]|0;rb(z,_,nM(V,c[p>>2]|0)|0);rc(c[ar>>2]|0,X,286);z=c[ar>>2]|0;c[ae+312>>2]=z;c[ae+316>>2]=550;c[ae+304>>2]=z;c[ae+308>>2]=184;c[ae+296>>2]=ae;c[ae+300>>2]=90;c[ae+288>>2]=ae;c[ae+292>>2]=10;break}}}while(0);zP(ae+3032|0,0,16);ar=yc(b,0,31848)|0;L1545:do{if((ar|0)!=0){X=0;p=ar;while(1){t=c[832+(X<<2)>>2]|0;s=c[816+(X<<2)>>2]|0;u=X+1|0;U=af+3032+(X<<2)|0;q=p;while(1){if((yi(q,34200,g,t)|0)!=0){yi(q,31752,g,t)|0}yj(q,31664,h,s)|0;ym(q,31512,o,31376)|0;yj(q,31256,j,1)|0;yj(q,31e3,k,c[j>>2]|0)|0;yj(q,30544,l,c[j>>2]|0)|0;ym(q,33992,m,0)|0;ym(q,30408,n,0)|0;ab=c[g>>2]|0;r=c[h>>2]|0;z=c[k>>2]|0;w=c[l>>2]|0;am=c[o>>2]|0;xv(2,30200,29944,(x=i,i=i+48|0,c[x>>2]=u,c[x+8>>2]=ab,c[x+16>>2]=r,c[x+24>>2]=z,c[x+32>>2]=w,c[x+40>>2]=am,x)|0);am=c[m>>2]|0;if((am|0)!=0){xv(2,30200,29808,(x=i,i=i+16|0,c[x>>2]=u,c[x+8>>2]=am,x)|0)}av=sM(c[g>>2]|0,0)|0;c[U>>2]=av;if((av|0)!=0){break}am=c[h>>2]|0;w=c[m>>2]|0;xt(0,29656,(x=i,i=i+24|0,c[x>>2]=c[g>>2],c[x+8>>2]=am,c[x+16>>2]=(w|0)==0?32456:w,x)|0);w=yc(b,q,31848)|0;if((w|0)==0){break L1545}else{q=w}}s=c[m>>2]|0;do{if((s|0)!=0){if((sN(av,s)|0)==0){break}xt(0,31992,(x=i,i=i+8|0,c[x>>2]=c[m>>2],x)|0)}}while(0);s=c[n>>2]|0;do{if((s|0)!=0){if((sO(c[U>>2]|0,s)|0)==0){break}xt(0,29528,(x=i,i=i+8|0,c[x>>2]=c[n>>2],x)|0)}}while(0);if((m9((c[U>>2]|0)+48|0,c[o>>2]|0)|0)!=0){xt(0,29336,(x=i,i=i+8|0,c[x>>2]=c[o>>2],x)|0)}mY((c[U>>2]|0)+48|0,c[k>>2]|0,c[l>>2]|0);s=(c[U>>2]|0)+48|0;mT(s,_,nM(V,c[h>>2]|0)|0);s=c[ap>>2]|0;r7(s,ss(c[U>>2]|0)|0,0);s=yc(b,q,31848)|0;if((s|0)==0|u>>>0>3){break}else{X=u;p=s}}}}while(0);zP(ae+3048|0,0,16);h=yc(b,0,34464)|0;L1570:do{if((h|0)!=0){V=0;_=h;while(1){l=c[848+(V<<2)>>2]|0;k=V+1|0;o=af+3048+(V<<2)|0;n=_;while(1){yi(n,34200,e,l)|0;ym(n,33992,f,0)|0;m=c[e>>2]|0;av=c[f>>2]|0;xv(2,33592,33160,(x=i,i=i+24|0,c[x>>2]=k,c[x+8>>2]=m,c[x+16>>2]=(av|0)==0?32456:av,x)|0);aw=sB(c[e>>2]|0)|0;c[o>>2]=aw;if((aw|0)!=0){break}xt(0,32184,(x=i,i=i+8|0,c[x>>2]=k,x)|0);av=yc(b,n,34464)|0;if((av|0)==0){break L1570}else{n=av}}l=c[f>>2]|0;do{if((l|0)!=0){if((sC(aw,l)|0)==0){break}xt(0,31992,(x=i,i=i+8|0,c[x>>2]=c[f>>2],x)|0)}}while(0);l=c[ap>>2]|0;r7(l,sp(c[o>>2]|0)|0,0);l=yc(b,n,34464)|0;if((l|0)==0|k>>>0>3){break}else{V=k;_=l}}}}while(0);ap=ae+3020|0;c[ap>>2]=0;f=yc(b,0,34720)|0;do{if((f|0)!=0){aw=cU(f)|0;c[ap>>2]=aw;if((aw|0)==0){break}e=cX(aw)|0;if((e|0)==0){break}r7(c[ad>>2]|0,e,0)}}while(0);ap=ae+3024|0;c[ap>>2]=0;f=yc(b,0,35144)|0;do{if((f|0)!=0){e=ex(f)|0;c[ap>>2]=e;if((e|0)==0){break}aw=d3(e)|0;if((aw|0)!=0){r7(c[ad>>2]|0,aw,0)}aw=d4(c[ap>>2]|0)|0;if((aw|0)==0){break}r7(c[ad>>2]|0,aw,0)}}while(0);xk(c[ad>>2]|0,b)|0;r8(c[ad>>2]|0,1040384);zP(ae+3144|0,0,16);c[ae+3116>>2]=0;c[ae+3120>>2]=0;xV(ae+3124|0)|0;c[W>>2]=0;c[ae+3160>>2]=0;c[ae+3164>>2]=0;ag=af;i=d;return ag|0}function c4(a,b){a=a|0;b=b|0;return c[43256+((b&255)<<2)>>2]|0}function c5(a){a=a|0;return c[a+3164>>2]|0}function c6(a,b){a=a|0;b=b|0;c[a+3076>>2]=b;return}function c7(a){a=a|0;return c[a+3076>>2]|0}function c8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;do{if(b>>>0>3){e=1}else{f=c[a+3032+(b<<2)>>2]|0;if((f|0)==0){e=1;break}e=(sN(f,d)|0)!=0|0}}while(0);return e|0}function c9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=xP(32768,d)|0;do{if(b>>>0>3){f=1}else{d=c[a+3032+(b<<2)>>2]|0;if((d|0)==0){f=1;break}f=(sN(d,e)|0)!=0|0}}while(0);zI(e);return f|0}function da(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;do{if(b>>>0>3){e=1}else{f=c[a+3048+(b<<2)>>2]|0;if((f|0)==0){e=1;break}e=(sC(f,d)|0)!=0|0}}while(0);return e|0}function db(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=xP(32768,d)|0;do{if(b>>>0>3){f=1}else{d=c[a+3048+(b<<2)>>2]|0;if((d|0)==0){f=1;break}f=(sC(d,e)|0)!=0|0}}while(0);zI(e);return f|0}function dc(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;b=43256+((d&255)<<2)|0;zI(c[b>>2]|0);do{if((e|0)==0){f=0}else{if((a[e]|0)==0){f=0;break}f=xQ(e)|0}}while(0);c[b>>2]=f;return}function dd(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;a=i;i=i+272|0;d=a|0;e=a+8|0;f=c[43256+((b&255)<<2)>>2]|0;if((f|0)==0){g=0;i=a;return g|0}wu(e,f);f=(wT(e,d)|0)!=0;g=f&(c[d>>2]|0)!=0&1;i=a;return g|0}function de(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=a|0;a=0;while(1){if(a>>>0>=32){e=0;f=1256;break}g=(a>>>0<16?61440:49152)|a<<8&3840;h=c[b>>2]|0;i=g<<4;j=c[h+80>>2]|0;k=j&(i|4);l=k|1;m=c[h+76>>2]|0;if(l>>>0<m>>>0){n=c[h+72>>2]|0;o=(d[n+l|0]|0)<<8|(d[n+k|0]|0);p=h;q=j;r=m}else{m=b8[c[h+44>>2]&255](c[h+32>>2]|0,k)|0;k=c[b>>2]|0;o=m;p=k;q=c[k+80>>2]|0;r=c[k+76>>2]|0}k=q&(i|6);i=k|1;if(i>>>0<r>>>0){m=c[p+72>>2]|0;s=(d[m+i|0]|0)<<8|(d[m+k|0]|0)}else{s=b8[c[p+44>>2]&255](c[p+32>>2]|0,k)|0}if(o<<16>>16==17232&s<<16>>16==22597){e=g;f=1255;break}else{a=a+1|0}}if((f|0)==1255){return e|0}else if((f|0)==1256){return e|0}return 0}function df(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;if((a[b+3098|0]|0)==0){i=e;return}f=b|0;g=c[f>>2]|0;h=c[g+80>>2]&1048560;if(h>>>0<(c[g+76>>2]|0)>>>0){j=a[(c[g+72>>2]|0)+h|0]|0}else{j=b8[c[g+36>>2]&255](c[g+32>>2]|0,h)|0}if(j<<24>>24!=-22){i=e;return}j=c[f>>2]|0;f=c[j+80>>2]&1048563;h=f+1|0;if(h>>>0<(c[j+76>>2]|0)>>>0){g=c[j+72>>2]|0;k=d[g+h|0]<<8|d[g+f|0]}else{k=b8[c[j+44>>2]&255](c[j+32>>2]|0,f)|0}if(k<<16>>16!=-4096){i=e;return}k=de(b)|0;if((k|0)==0){i=e;return}dP(30792,(x=i,i=i+8|0,c[x>>2]=k,x)|0);f=b+16|0;sc(c[f>>2]|0,1048561,12);sc(c[f>>2]|0,1048562,0);sc(c[f>>2]|0,1048563,k&255);sc(c[f>>2]|0,1048564,k>>>8&255);i=e;return}function dg(a){a=a|0;var b=0,d=0;b=i;dP(28752,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);df(a);ig(c[a>>2]|0);mS(a+32|0);nx(a+340|0);oi(a+488|0);dI(a+564|0);d=c[a+3032>>2]|0;if((d|0)!=0){sP(d)}d=c[a+3036>>2]|0;if((d|0)!=0){sP(d)}d=c[a+3040>>2]|0;if((d|0)!=0){sP(d)}d=c[a+3044>>2]|0;if((d|0)!=0){sP(d)}d=c[a+3012>>2]|0;if((d|0)!=0){q6(d)}d=c[a+3016>>2]|0;if((d|0)!=0){rm(d)}d=c[a+3024>>2]|0;if((d|0)!=0){ey(d)}d=c[a+3020>>2]|0;if((d|0)==0){i=b;return}cZ(d);i=b;return}function dh(a){a=a|0;c[a+3120>>2]=c[a+3116>>2];xV(a+3124|0)|0;c[a+3136>>2]=0;return}function di(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=(b|0)==0?4:b;b=a+3128|0;f=c[a>>2]|0;if((c[b>>2]|0)==0){ii(f,(c[a+3136>>2]|0)+e|0);g=4}else{ii(f,e);g=c[b>>2]<<2}b=a+3160|0;f=(c[b>>2]|0)+e|0;c[b>>2]=f;if(f>>>0<g>>>0){i=d;return}c[b>>2]=f-g;g=a+3116|0;c[g>>2]=(c[g>>2]|0)+1;f=a+3164|0;c[f>>2]=(c[f>>2]|0)+1;f=a+4|0;b=c[f>>2]|0;e=b+36|0;c[e>>2]=(c[b+40>>2]|0)+1+(c[e>>2]|0);c[(c[f>>2]|0)+40>>2]=0;ny(a+340|0,1);e=a+3144|0;b=(c[e>>2]|0)+1|0;c[e>>2]=b;if(b>>>0<=7){i=d;return}h=b&-8;j=a+3148|0;c[j>>2]=(c[j>>2]|0)+h;c[e>>2]=b&7;dM(a+564|0,h);b=c[a+844>>2]|0;if((b|0)!=0){cE(b,h)}m7(a+32|0,h);qN(c[f>>2]|0,0);f=a+3032|0;b=c[f>>2]|0;if((b|0)!=0){no(b+48|0,h)}b=a+3036|0;e=c[b>>2]|0;if((e|0)!=0){no(e+48|0,h)}e=a+3040|0;k=c[e>>2]|0;if((k|0)!=0){no(k+48|0,h)}k=a+3044|0;l=c[k>>2]|0;if((l|0)!=0){no(l+48|0,h)}h=c[j>>2]|0;if(h>>>0<=1023){i=d;return}l=h&-1024;c[j>>2]=h&1023;h=a+3152|0;c[h>>2]=(c[h>>2]|0)+l;j=c[a+3028>>2]|0;if((j|0)!=0){zt(j)}j=c[a+3012>>2]|0;if((j|0)!=0){os(j+28|0,l)}j=c[a+3016>>2]|0;if((j|0)!=0){rn(j,l)}ew(a+848|0,l);j=c[f>>2]|0;if((j|0)!=0){sQ(j,l)}j=c[b>>2]|0;if((j|0)!=0){sQ(j,l)}j=c[e>>2]|0;if((j|0)!=0){sQ(j,l)}j=c[k>>2]|0;if((j|0)!=0){sQ(j,l)}l=c[h>>2]|0;if(l>>>0<=16383){i=d;return}c[h>>2]=l&16383;l=c[g>>2]|0;h=z4(xV(a+3124|0)|0,0,1193182,0)|0;j=z5(h,G,1e6,0)|0;h=a+3120|0;k=j+(c[h>>2]|0)|0;if(l>>>0>=k>>>0){j=a+3136|0;c[j>>2]=(c[j>>2]|0)+1;j=l-k|0;c[g>>2]=j;c[h>>2]=0;e=z4(j,0,1e6,0)|0;j=z5(e,G,1193182,0)|0;e=j;if(e>>>0<=25e3){i=d;return}xU(e)|0;i=d;return}c[g>>2]=0;g=k-l|0;c[h>>2]=g;l=a+3136|0;a=c[l>>2]|0;if((a|0)!=0){c[l>>2]=a-1}if(g>>>0<=1193182){i=d;return}c[h>>2]=0;xt(2,37056,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);i=d;return}function dj(a,b){a=a|0;b=b|0;var d=0;if((aP(b|0,27064)|0)==0){hD(c[a>>2]|0);d=0;return d|0}if((aP(b|0,25488)|0)==0){hF(c[a>>2]|0);d=0;return d|0}if((aP(b|0,24272)|0)==0){hm(c[a>>2]|0);d=0;return d|0}if((aP(b|0,22688)|0)==0){hR(c[a>>2]|0);d=0;return d|0}if((aP(b|0,21536)|0)==0){hG(c[a>>2]|0);d=0;return d|0}if((aP(b|0,41616)|0)==0){hH(c[a>>2]|0);d=0;return d|0}if((aP(b|0,40552)|0)!=0){d=1;return d|0}hS(c[a>>2]|0);d=0;return d|0}function dk(a,b){a=a|0;b=b|0;var d=0;d=i;c[a+3128>>2]=b;c[a+3136>>2]=0;xv(2,38968,37976,(x=i,i=i+8|0,c[x>>2]=b,x)|0);i=d;return}function dl(a,b){a=a|0;b=b|0;return sa(c[a+16>>2]|0,(c[a+3092>>2]|0)+b|0)|0}function dm(a,b,d){a=a|0;b=b|0;d=d|0;sd(c[a+16>>2]|0,(c[a+3092>>2]|0)+b|0,d);return}function dn(a,b){a=a|0;b=b|0;return sa(c[a+16>>2]|0,(c[a+3088>>2]|0)+b|0)|0}function dp(a,b,d){a=a|0;b=b|0;d=d|0;sd(c[a+16>>2]|0,(c[a+3088>>2]|0)+b|0,d);return}function dq(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;t6(b,c,d);return}function dr(b){b=b|0;var c=0,d=0;if((a[b+3006|0]|0)<0){c=a[b+3004|0]|0;return c|0}else{d=dF(b+564|0)|0;a[b+3005|0]=d;c=d;return c|0}return 0}function ds(b,d){b=b|0;d=d|0;var e=0,f=0;e=b+3006|0;f=a[e]|0;a[e]=d;e=b+564|0;dJ(e,d&64);dK(e,(d&255)>>>7^1);nr(b+340|0,2,d&1);e=(f^d)&255;if((e&2|0)!=0){et(b+848|0,d&2)}if((c[b+3e3>>2]&1|0)==0){return}if((e&8|0)==0){return}e=c[b+844>>2]|0;if((e|0)==0){return}f=d&8;cB(e,(f>>>3^1)&255);if((f|0)==0){f=b+3128|0;c[b+3132>>2]=c[f>>2];c[f>>2]=1;c[b+3136>>2]=0;return}else{c[b+3128>>2]=c[b+3132>>2];c[b+3136>>2]=0;return}}function dt(a,b){a=a|0;b=b|0;return-1|0}function du(a,b,c){a=a|0;b=b|0;c=c|0;return}function dv(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;if((c[b+3e3>>2]&2|0)!=0){if((a[b+3006|0]&8)==0){d=b+3007|0;e=a[d]|0;return e|0}else{d=b+3008|0;e=a[d]|0;return e|0}}f=c[b+844>>2]|0;do{if((f|0)!=0){g=(cs(f)|0)<<24>>24==0;h=b+3007|0;i=a[h]|0;if(g){a[h]=i&-17;g=b+3008|0;a[g]=a[g]&-17;break}else{a[h]=i|16;i=b+3008|0;a[i]=a[i]|16;break}}}while(0);if((a[b+3006|0]&4)==0){d=b+3008|0;e=a[d]|0;return e|0}else{d=b+3007|0;e=a[d]|0;return e|0}return 0}function dw(b,c){b=b|0;c=c|0;var d=0;d=b+3096|0;do{if((a[b+3097|0]|0)==0){if((a[d]|0)!=0|c<<24>>24==0){break}mJ(b+32|0,1)}}while(0);a[d]=c<<24>>24!=0|0;return}function dx(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;do{if((c[b+3e3>>2]&1|0)!=0){e=b+3007|0;f=a[e]|0;if(d<<24>>24==0){a[e]=f&-33;g=b+3008|0;a[g]=a[g]&-33}else{a[e]=f|32;f=b+3008|0;a[f]=a[f]|32}f=c[b+844>>2]|0;if((f|0)==0){break}cC(f,d)}}while(0);ev(b+848|0,d);return}function dy(b,c){b=b|0;c=c|0;var d=0;d=c<<24>>24!=0;a[b+3097|0]=d&1;if(!d){return}mJ(b+32|0,0);return}function dz(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+8|0;f=e|0;do{if((dN(b,d,f)|0)==0){g=a[f]|0}else{a[f]=-1;if((d|0)==130){h=(c[b+3092>>2]|0)>>>16&255;a[f]=h;g=h;break}else if((d|0)==129){h=(c[b+3088>>2]|0)>>>16&255;a[f]=h;g=h;break}else if((d|0)==131){h=(c[b+3084>>2]|0)>>>16&255;a[f]=h;g=h;break}else if((d|0)==135){h=(c[b+3080>>2]|0)>>>16&255;a[f]=h;g=h;break}else{g=-1;break}}}while(0);i=e;return g|0}function dA(a,b,d){a=a|0;b=b|0;d=d|0;if((dD(a,b,d)|0)==0){return}if((b|0)==129){c[a+3088>>2]=(d&255)<<16&983040;return}else if((b|0)==130){c[a+3092>>2]=(d&255)<<16&983040;return}else if((b|0)==131){c[a+3084>>2]=(d&255)<<16&983040;return}else if((b|0)==135){c[a+3080>>2]=(d&255)<<16&983040;return}else{return}}function dB(a){a=a|0;var d=0,e=0,f=0;d=c[a+3012>>2]|0;e=a|0;a=c[e>>2]|0;if((d|0)==0){b[a+4>>1]=1;return}f=(q$(d,b[a+8>>1]&255)|0)==65535;a=(c[e>>2]|0)+4|0;if(f){b[a>>1]=1;return}else{b[a>>1]=0;return}}function dC(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0;h=i;i=i+4632|0;j=h|0;k=h+512|0;l=h+520|0;m=h+528|0;n=h+536|0;o=g+4|0;p=b[o>>1]|0;q=(p&65535)>>>8;if((q|0)==8){r=g+8|0;s=e[r>>1]|0;t=ts(f,s&255)|0;if((t|0)==0){b[o>>1]=b[o>>1]&255|256;u=c[g+80>>2]&1089;if(u>>>0<(c[g+76>>2]|0)>>>0){a[(c[g+72>>2]|0)+u|0]=1}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,u,1)}u=g+30|0;b[u>>1]=b[u>>1]|1;i=h;return}do{if((s&128|0)==0){if((c[t+44>>2]|0)>>>0<50){break}u=c[t+52>>2]|0;if(u>>>0<12){v=3}else{v=u>>>0<17?2:4}b[g+10>>1]=v}}while(0);v=c[f>>2]|0;if((v|0)==0){w=0}else{s=c[f+4>>2]|0;u=0;x=0;do{x=((c[(c[s+(u<<2)>>2]|0)+24>>2]|0)>>>7&1)+x|0;u=u+1|0;}while(u>>>0<v>>>0);w=x&255}b[r>>1]=(b[r>>1]&-256&65535|w)&65535;b[r>>1]=((c[t+48>>2]<<8)+65280|w)&65535;w=t+44|0;r=g+6|0;x=(c[w>>2]<<8)+65280|0;b[r>>1]=(b[r>>1]&255|x)&65535;b[r>>1]=(c[t+52>>2]&255|x|((c[w>>2]|0)+1023|0)>>>2&192)&65535;b[o>>1]=b[o>>1]&255;w=c[g+80>>2]&1089;if(w>>>0<(c[g+76>>2]|0)>>>0){a[(c[g+72>>2]|0)+w|0]=0}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,w,0)}w=g+30|0;b[w>>1]=b[w>>1]&-2;i=h;return}else if((q|0)==5){w=j|0;j=g+8|0;x=b[j>>1]&255;t=ts(f,x)|0;if((t|0)==0){b[o>>1]=b[o>>1]&255|256;r=c[g+80>>2]&1089;if(r>>>0<(c[g+76>>2]|0)>>>0){a[(c[g+72>>2]|0)+r|0]=1}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,r,1)}r=g+30|0;b[r>>1]=b[r>>1]|1;i=h;return}r=b[o>>1]|0;if((a[t+56|0]|0)!=0){b[o>>1]=r&255|768;v=c[g+80>>2]&1089;if(v>>>0<(c[g+76>>2]|0)>>>0){a[(c[g+72>>2]|0)+v|0]=3}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,v,3)}v=g+30|0;b[v>>1]=b[v>>1]|1;i=h;return}v=r&255;r=e[g+6>>1]|0;u=r>>>8;if(x>>>0>4){y=r<<2&768|u}else{y=u}u=(e[j>>1]|0)>>>8;do{if(x>>>0<4){j=g+80|0;r=c[j>>2]|0;s=r&120;z=s|1;A=g+76|0;B=c[A>>2]|0;if(z>>>0<B>>>0){C=c[g+72>>2]|0;D=d[C+z|0]<<8|d[C+s|0];E=r;F=B}else{B=b8[c[g+44>>2]&255](c[g+32>>2]|0,s)|0;D=B;E=c[j>>2]|0;F=c[A>>2]|0}B=E&122;s=B|1;if(s>>>0<F>>>0){r=c[g+72>>2]|0;G=d[r+s|0]<<8|d[r+B|0];H=E;I=F}else{r=b8[c[g+44>>2]&255](c[g+32>>2]|0,B)|0;G=r;H=c[j>>2]|0;I=c[A>>2]|0}A=((G&65535)<<4)+(D+8&65535)&H;if(A>>>0<I>>>0){J=a[(c[g+72>>2]|0)+A|0]|0;break}else{J=b8[c[g+36>>2]&255](c[g+32>>2]|0,A)|0;break}}else{J=-10}}while(0);if(u>>>0>=(c[t+36>>2]|0)>>>0){b[o>>1]=b[o>>1]&255;I=c[g+80>>2]&1089;if(I>>>0<(c[g+76>>2]|0)>>>0){a[(c[g+72>>2]|0)+I|0]=0}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,I,0)}I=g+30|0;b[I>>1]=b[I>>1]&-2;i=h;return}zP(w|0,J|0,512);J=0;while(1){if(J>>>0>=v>>>0){K=1589;break}I=J+1|0;if((tw(t,w,y,u,I,1)|0)==0){J=I}else{K=1585;break}}if((K|0)==1589){b[o>>1]=b[o>>1]&255;J=c[g+80>>2]&1089;if(J>>>0<(c[g+76>>2]|0)>>>0){a[(c[g+72>>2]|0)+J|0]=0}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,J,0)}J=g+30|0;b[J>>1]=b[J>>1]&-2;i=h;return}else if((K|0)==1585){b[o>>1]=b[o>>1]&255|1024;K=c[g+80>>2]&1089;if(K>>>0<(c[g+76>>2]|0)>>>0){a[(c[g+72>>2]|0)+K|0]=4}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,K,4)}K=g+30|0;b[K>>1]=b[K>>1]|1;i=h;return}}else if((q|0)==3){K=n|0;J=g+8|0;u=ts(f,b[J>>1]&255)|0;if((u|0)==0){b[o>>1]=b[o>>1]&255|256;y=c[g+80>>2]&1089;if(y>>>0<(c[g+76>>2]|0)>>>0){a[(c[g+72>>2]|0)+y|0]=1}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,y,1)}y=g+30|0;b[y>>1]=b[y>>1]|1;i=h;return}y=b[o>>1]|0;if((a[u+56|0]|0)!=0){b[o>>1]=y&255|768;w=c[g+80>>2]&1089;if(w>>>0<(c[g+76>>2]|0)>>>0){a[(c[g+72>>2]|0)+w|0]=3}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,w,3)}w=g+30|0;b[w>>1]=b[w>>1]|1;i=h;return}w=y&255;y=e[g+6>>1]|0;t=(e[g+20>>1]<<4)+(e[g+10>>1]|0)|0;if((tq(u,y<<2&768|y>>>8,(e[J>>1]|0)>>>8,y&63,l)|0)!=0){b[o>>1]=b[o>>1]&255|1024;y=c[g+80>>2]&1089;if(y>>>0<(c[g+76>>2]|0)>>>0){a[(c[g+72>>2]|0)+y|0]=4}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,y,4)}y=g+30|0;b[y>>1]=b[y>>1]|1;i=h;return}L2007:do{if((w|0)==0){L=g+80|0;M=g+76|0}else{y=g+76|0;J=g+72|0;v=g+80|0;I=g+44|0;H=g+32|0;D=t;G=w;while(1){F=G>>>0<8?G:8;E=F<<9;x=E+D|0;A=c[y>>2]|0;L2012:do{if(x>>>0<A>>>0){j=(c[J>>2]|0)+D|0;zO(K|0,j|0,E)|0;N=x}else{if((E|0)==0){N=D;break}else{O=D;P=0;Q=A}while(1){j=O&1048575&c[v>>2];r=j+1|0;if(r>>>0<Q>>>0){B=c[J>>2]|0;R=a[B+r|0]|0;S=a[B+j|0]|0}else{B=b8[c[I>>2]&255](c[H>>2]|0,j)|0;R=(B&65535)>>>8&255;S=B&255}a[n+P|0]=S;a[n+(P|1)|0]=R;B=O+2|0;j=P+2|0;if(j>>>0>=E>>>0){N=B;break L2012}O=B;P=j;Q=c[y>>2]|0}}}while(0);if((tv(u,K,c[l>>2]|0,F)|0)!=0){break}c[l>>2]=(c[l>>2]|0)+F;if((G|0)==(F|0)){L=v;M=y;break L2007}else{D=N;G=G-F|0}}b[o>>1]=b[o>>1]&255|256;G=c[v>>2]&1089;if(G>>>0<(c[y>>2]|0)>>>0){a[(c[J>>2]|0)+G|0]=1}else{b5[c[g+40>>2]&255](c[H>>2]|0,G,1)}G=g+30|0;b[G>>1]=b[G>>1]|1;i=h;return}}while(0);b[o>>1]=b[o>>1]&255;N=c[L>>2]&1089;if(N>>>0<(c[M>>2]|0)>>>0){a[(c[g+72>>2]|0)+N|0]=0}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,N,0)}N=g+30|0;b[N>>1]=b[N>>1]&-2;i=h;return}else if((q|0)==23){b[o>>1]=p&255;N=c[g+80>>2]&1089;if(N>>>0<(c[g+76>>2]|0)>>>0){a[(c[g+72>>2]|0)+N|0]=0}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,N,0)}N=g+30|0;b[N>>1]=b[N>>1]&-2}else if((q|0)==4){N=n|0;M=g+8|0;L=ts(f,b[M>>1]&255)|0;l=b[o>>1]|0;if((L|0)==0){b[o>>1]=l&255|256;K=c[g+80>>2]&1089;if(K>>>0<(c[g+76>>2]|0)>>>0){a[(c[g+72>>2]|0)+K|0]=1}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,K,1)}K=g+30|0;b[K>>1]=b[K>>1]|1;i=h;return}K=l&255;l=e[g+6>>1]|0;if((tq(L,l<<2&768|l>>>8,(e[M>>1]|0)>>>8,l&63,k)|0)!=0){b[o>>1]=b[o>>1]&255|1024;l=c[g+80>>2]&1089;if(l>>>0<(c[g+76>>2]|0)>>>0){a[(c[g+72>>2]|0)+l|0]=4}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,l,4)}l=g+30|0;b[l>>1]=b[l>>1]|1;i=h;return}L2058:do{if((K|0)!=0){l=K;M=c[k>>2]|0;while(1){u=l>>>0<8?l:8;if((tt(L,N,M,u)|0)!=0){break}Q=(c[k>>2]|0)+u|0;c[k>>2]=Q;if((l|0)==(u|0)){break L2058}else{l=l-u|0;M=Q}}b[o>>1]=b[o>>1]&255|256;M=c[g+80>>2]&1089;if(M>>>0<(c[g+76>>2]|0)>>>0){a[(c[g+72>>2]|0)+M|0]=1}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,M,1)}M=g+30|0;b[M>>1]=b[M>>1]|1;i=h;return}}while(0);b[o>>1]=b[o>>1]&255;k=c[g+80>>2]&1089;if(k>>>0<(c[g+76>>2]|0)>>>0){a[(c[g+72>>2]|0)+k|0]=0}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,k,0)}k=g+30|0;b[k>>1]=b[k>>1]&-2;i=h;return}else if((q|0)==2){k=n|0;N=g+8|0;L=ts(f,b[N>>1]&255)|0;K=b[o>>1]|0;if((L|0)==0){b[o>>1]=K&255|256;M=c[g+80>>2]&1089;if(M>>>0<(c[g+76>>2]|0)>>>0){a[(c[g+72>>2]|0)+M|0]=1}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,M,1)}M=g+30|0;b[M>>1]=b[M>>1]|1;i=h;return}M=K&255;K=e[g+6>>1]|0;l=(e[g+20>>1]<<4)+(e[g+10>>1]|0)|0;if((tq(L,K<<2&768|K>>>8,(e[N>>1]|0)>>>8,K&63,m)|0)!=0){b[o>>1]=b[o>>1]&255|1024;K=c[g+80>>2]&1089;if(K>>>0<(c[g+76>>2]|0)>>>0){a[(c[g+72>>2]|0)+K|0]=4}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,K,4)}K=g+30|0;b[K>>1]=b[K>>1]|1;i=h;return}L2092:do{if((M|0)==0){T=g+80|0;U=g+76|0}else{K=g+76|0;N=g+72|0;H=g+80|0;J=g+48|0;y=g+32|0;v=M;Q=l;while(1){u=v>>>0<8?v:8;if((tt(L,k,c[m>>2]|0,u)|0)!=0){break}P=v-u|0;c[m>>2]=(c[m>>2]|0)+u;O=u<<9;R=O+Q|0;S=c[K>>2]|0;L2098:do{if(R>>>0>S>>>0){if((O|0)==0){V=Q;break}else{W=Q;X=0;Y=S}while(1){w=a[n+X|0]|0;t=a[n+(X|1)|0]|0;G=W&1048575&c[H>>2];D=G+1|0;if(D>>>0<Y>>>0){a[(c[N>>2]|0)+G|0]=w;a[(c[N>>2]|0)+D|0]=t}else{b5[c[J>>2]&255](c[y>>2]|0,G,(t&255)<<8|w&255)}w=W+2|0;t=X+2|0;if(t>>>0>=O>>>0){V=w;break L2098}W=w;X=t;Y=c[K>>2]|0}}else{t=(c[N>>2]|0)+Q|0;zO(t|0,k|0,O)|0;V=R}}while(0);if((v|0)==(u|0)){T=H;U=K;break L2092}else{v=P;Q=V}}b[o>>1]=b[o>>1]&255|256;Q=c[H>>2]&1089;if(Q>>>0<(c[K>>2]|0)>>>0){a[(c[N>>2]|0)+Q|0]=1}else{b5[c[g+40>>2]&255](c[y>>2]|0,Q,1)}Q=g+30|0;b[Q>>1]=b[Q>>1]|1;i=h;return}}while(0);b[o>>1]=b[o>>1]&255;V=c[T>>2]&1089;if(V>>>0<(c[U>>2]|0)>>>0){a[(c[g+72>>2]|0)+V|0]=0}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,V,0)}V=g+30|0;b[V>>1]=b[V>>1]&-2;i=h;return}else if((q|0)==12){b[o>>1]=p&255;V=c[g+80>>2]&1089;if(V>>>0<(c[g+76>>2]|0)>>>0){a[(c[g+72>>2]|0)+V|0]=0}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,V,0)}V=g+30|0;b[V>>1]=b[V>>1]&-2;i=h;return}else if((q|0)==16){V=(ts(f,b[g+8>>1]&255)|0)==0;U=b[o>>1]&255;if(V){b[o>>1]=U|8192;V=c[g+80>>2]&1089;if(V>>>0<(c[g+76>>2]|0)>>>0){a[(c[g+72>>2]|0)+V|0]=32}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,V,32)}V=g+30|0;b[V>>1]=b[V>>1]|1;i=h;return}else{b[o>>1]=U;U=c[g+80>>2]&1089;if(U>>>0<(c[g+76>>2]|0)>>>0){a[(c[g+72>>2]|0)+U|0]=0}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,U,0)}U=g+30|0;b[U>>1]=b[U>>1]&-2;i=h;return}}else if((q|0)==0){b[o>>1]=p&255;U=c[g+80>>2]&1089;if(U>>>0<(c[g+76>>2]|0)>>>0){a[(c[g+72>>2]|0)+U|0]=0}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,U,0)}U=g+30|0;b[U>>1]=b[U>>1]&-2;i=h;return}else if((q|0)==1){U=g+80|0;V=c[U>>2]|0;T=V&1089;k=g+76|0;Y=c[k>>2]|0;if(T>>>0<Y>>>0){Z=a[(c[g+72>>2]|0)+T|0]|0;_=p;$=V;aa=Y}else{Y=b8[c[g+36>>2]&255](c[g+32>>2]|0,T)|0;Z=Y;_=b[o>>1]|0;$=c[U>>2]|0;aa=c[k>>2]|0}b[o>>1]=_&255|(Z&255)<<8;_=$&1089;if(_>>>0<aa>>>0){a[(c[g+72>>2]|0)+_|0]=Z}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,_,Z)}_=g+30|0;aa=b[_>>1]|0;b[_>>1]=Z<<24>>24==0?aa&-2:aa|1;i=h;return}else if((q|0)!=24){b[o>>1]=p&255|256;p=c[g+80>>2]&1089;if(p>>>0<(c[g+76>>2]|0)>>>0){a[(c[g+72>>2]|0)+p|0]=1}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,p,1)}p=g+30|0;b[p>>1]=b[p>>1]|1;i=h;return}p=ts(f,b[g+8>>1]&255)|0;if((p|0)==0){b[o>>1]=b[o>>1]&255|256;f=c[g+80>>2]&1089;if(f>>>0<(c[g+76>>2]|0)>>>0){a[(c[g+72>>2]|0)+f|0]=1}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,f,1)}f=g+30|0;b[f>>1]=b[f>>1]|1;i=h;return}f=e[g+6>>1]|0;do{if((f<<2&768|f>>>8)>>>0<=(c[p+44>>2]|0)>>>0){if((f&63)>>>0>(c[p+52>>2]|0)>>>0){break}q=g+80|0;aa=c[q>>2]|0;Z=aa&122;_=Z|1;$=g+76|0;k=c[$>>2]|0;if(_>>>0<k>>>0){U=c[g+72>>2]|0;ab=d[U+_|0]<<8|d[U+Z|0];ac=aa;ad=k}else{k=b8[c[g+44>>2]&255](c[g+32>>2]|0,Z)|0;ab=k;ac=c[q>>2]|0;ad=c[$>>2]|0}b[g+20>>1]=ab;k=ac&120;Z=k|1;if(Z>>>0<ad>>>0){aa=c[g+72>>2]|0;ae=d[aa+Z|0]<<8|d[aa+k|0];af=ac;ag=ad}else{aa=b8[c[g+44>>2]&255](c[g+32>>2]|0,k)|0;ae=aa;af=c[q>>2]|0;ag=c[$>>2]|0}b[g+18>>1]=ae;b[o>>1]=b[o>>1]&255;$=af&1089;if($>>>0<ag>>>0){a[(c[g+72>>2]|0)+$|0]=0}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,$,0)}$=g+30|0;b[$>>1]=b[$>>1]&-2;i=h;return}}while(0);b[o>>1]=b[o>>1]&255|3072;o=c[g+80>>2]&1089;if(o>>>0<(c[g+76>>2]|0)>>>0){a[(c[g+72>>2]|0)+o|0]=12}else{b5[c[g+40>>2]&255](c[g+32>>2]|0,o,12)}o=g+30|0;b[o>>1]=b[o>>1]|1;i=h;return}function dD(a,b,c){a=a|0;b=b|0;c=c|0;return 1}function dE(a,b,d){a=a|0;b=b|0;d=d|0;c[a+272>>2]=b;c[a+276>>2]=d;return}function dF(b){b=b|0;return a[b+4|0]|0}function dG(b,d){b=b|0;d=d|0;var e=0;if((c[b+3e3>>2]&4|0)==0){return}e=b+3010|0;a[e]=(a[e]&-49&255|d<<4&48)&255;return}function dH(a){a=a|0;c[a>>2]=381;c[a+272>>2]=0;c[a+276>>2]=0;zP(a+4|0,0,12);return}function dI(b){b=b|0;var d=0,e=0;d=i;dP(31152,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);if((c[1862]|0)!=0){e=7448;do{a[e+16|0]=0;e=e+20|0;}while((c[e>>2]|0)!=0)}c[b>>2]=381;a[b+4|0]=85;c[b+8>>2]=0;c[b+12>>2]=1;a[b+16|0]=-86;i=d;return}function dJ(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=e<<24>>24!=0;e=b+7|0;if((d[e]|0|0)==(g&1|0)){i=f;return}a[e]=g&1;if(!g){i=f;return}dP(31152,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);if((c[1862]|0)!=0){g=7448;do{a[g+16|0]=0;g=g+20|0;}while((c[g>>2]|0)!=0)}c[b>>2]=381;a[b+4|0]=85;c[b+8>>2]=0;c[b+12>>2]=1;a[b+16|0]=-86;i=f;return}function dK(b,e){b=b|0;e=e|0;var f=0;f=e<<24>>24!=0;e=b+6|0;if((d[e]|0|0)==(f&1|0)){return}a[e]=f&1;if(f){c[b>>2]=381;return}a[b+4|0]=0;a[b+5|0]=0;f=c[b+276>>2]|0;if((f|0)==0){return}b3[f&511](c[b+272>>2]|0,0);return}function dL(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;if((e|0)==3){xt(2,38072,(x=i,i=i+8|0,c[x>>2]=f,x)|0);i=g;return}else{h=7448}while(1){j=c[h>>2]|0;k=(j|0)==0;if(k|(j|0)==(f|0)){break}else{h=h+20|0}}if(k){i=g;return}if((e|0)==2){k=h+16|0;if((a[k]|0)==0){i=g;return}a[k]=0;k=b[h+10>>1]|0;f=k&65535;if(k<<16>>16==0){i=g;return}k=d+12|0;j=d+8|0;l=0;m=c[k>>2]|0;while(1){n=m+1&255;if((n|0)==(c[j>>2]|0)){break}a[d+16+m|0]=a[h+12+l|0]|0;c[k>>2]=n;o=l+1|0;if(o>>>0<f>>>0){l=o;m=n}else{p=1734;break}}if((p|0)==1734){i=g;return}xt(0,32232,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);i=g;return}else if((e|0)==1){a[h+16|0]=1;e=b[h+4>>1]|0;m=e&65535;if(e<<16>>16==0){i=g;return}e=d+12|0;l=d+8|0;f=0;k=c[e>>2]|0;while(1){j=k+1&255;if((j|0)==(c[l>>2]|0)){break}a[d+16+k|0]=a[h+6+f|0]|0;c[e>>2]=j;n=f+1|0;if(n>>>0<m>>>0){f=n;k=j}else{p=1731;break}}if((p|0)==1731){i=g;return}xt(0,32232,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);i=g;return}else{i=g;return}}function dM(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b+8|0;f=c[e>>2]|0;if((f|0)==(c[b+12>>2]|0)){return}if((a[b+7|0]|0)==0){return}if((a[b+6|0]|0)==0){return}g=b+5|0;if((a[g]|0)!=0){return}h=b|0;i=c[h>>2]|0;if(i>>>0>d>>>0){c[h>>2]=i-d;return}c[h>>2]=381;a[b+4|0]=a[b+16+f|0]|0;a[g]=1;c[e>>2]=f+1&255;f=c[b+276>>2]|0;if((f|0)==0){return}b3[f&511](c[b+272>>2]|0,1);return}function dN(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+16|0;g=f|0;h=f+8|0;if((c[b+3e3>>2]&4|0)==0){j=1;i=f;return j|0}if((d-112|0)>>>0>=16){if((d|0)==100){a[e]=1;j=0;i=f;return j|0}else if((d|0)==102){a[e]=a[b+3009|0]|0;j=0;i=f;return j|0}else if((d|0)==103){a[e]=a[b+3010|0]|0;j=0;i=f;return j|0}else{j=1;i=f;return j|0}}if((c[b+3104>>2]|0)==0){k=0;l=0;m=0;n=0;o=0;p=1;q=1980}else{if((bx(h|0,0)|0)==0){c[g>>2]=c[h>>2];r=(c[h+4>>2]|0)/1e5|0}else{c[g>>2]=b0(0)|0;r=0}h=aH(g|0)|0;k=r;l=c[h>>2]|0;m=c[h+4>>2]|0;n=c[h+8>>2]|0;o=c[h+12>>2]|0;p=(c[h+16>>2]|0)+1|0;q=(c[h+20>>2]|0)+1900|0}do{if((d|0)==116){s=((m>>>0)%10|0)&255}else if((d|0)==117){s=((m>>>0)/10|0)&255}else if((d|0)==114){s=((l>>>0)%10|0)&255}else if((d|0)==115){s=((l>>>0)/10|0)&255}else if((d|0)==124){s=((p>>>0)/10|0)&255}else if((d|0)==127){if(q>>>0<1980){s=0;break}s=q+4&7}else if((d|0)==123){s=((p>>>0)%10|0)&255}else if((d|0)==113){s=((k>>>0)%10|0)&255}else if((d|0)==121){s=((o>>>0)/10|0)&255}else if((d|0)==118){s=((n>>>0)%10|0)&255}else if((d|0)==120){s=((o>>>0)%10|0)&255}else if((d|0)==119){s=((n>>>0)/10|0)&255}else{dP(26672,(x=i,i=i+8|0,c[x>>2]=d,x)|0);s=-1}}while(0);a[e]=s;j=0;i=f;return j|0}function dO(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+16|0;f=e|0;g=e+8|0;h=b+3009|0;a[h]=0;j=b+3010|0;a[j]=0;if((c[b+3e3>>2]&4|0)==0){i=e;return}b=yc(d,0,30440)|0;if((b|0)==0){i=e;return}yj(b,37760,f,0)|0;yj(b,32136,g,100)|0;b=c[g>>2]|0;xv(2,30392,28288,(x=i,i=i+16|0,c[x>>2]=c[f>>2],c[x+8>>2]=b,x)|0);a[h]=c[f>>2]&255;a[j]=c[g>>2]&255;i=e;return}function dP(a,b){a=a|0;b=b|0;var d=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+16|0;f=d|0;g=c[10742]|0;if((g|0)==0){h=0;j=0}else{k=c[g>>2]|0;h=e[k+28>>1]|0;j=e[k+22>>1]|0}xt(3,30080,(x=i,i=i+16|0,c[x>>2]=j,c[x+8>>2]=h,x)|0);h=f;c[h>>2]=b;c[h+4>>2]=0;xu(3,a,f|0);i=d;return}function dQ(){xK(0,1);return}function dR(a){a=a|0;aB(34968,18,1,c[q>>2]|0)|0;ax(c[q>>2]|0)|0;a=(c[10742]|0)+3168|0;c[a>>2]=(c[a>>2]|0)==0?1:2;return}function dS(a){a=a|0;aB(35920,19,1,c[q>>2]|0)|0;ax(c[q>>2]|0)|0;c[(c[10742]|0)+3168>>2]=2;return}function dT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((hV(c[a>>2]|0,b,d)|0)==0){e=0;return e|0}if((aP(b|0,38712)|0)!=0){e=1;return e|0}c[d>>2]=c[a+3140>>2];e=0;return e|0}function dU(a,b,d){a=a|0;b=b|0;d=d|0;return(ic(c[a>>2]|0,b,d)|0)!=0|0}function dV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=(a|0)==0?c[10742]|0:a;if((b|0)==0){f=1;return f|0}a=(d|0)==0?44456:d;d=552;while(1){g=c[d>>2]|0;if((g|0)==0){break}if((xz(g,b)|0)==0){d=d+8|0}else{h=1816;break}}if((h|0)==1816){f=b4[c[d+4>>2]&127](e,b,a)|0;return f|0}d=c[e+3028>>2]|0;do{if((d|0)!=0){h=zn(d,b,a)|0;if((h|0)>-1){f=h}else{break}return f|0}}while(0);d=c[e+4>>2]|0;do{if((d|0)!=0){e=qI(d,b,a)|0;if((e|0)>-1){f=e}else{break}return f|0}}while(0);f=1;return f|0}function dW(a,b,d){a=a|0;b=b|0;d=d|0;return(yD(d,c[a+3064>>2]|0)|0)!=0|0}function dX(a,b,c){a=a|0;b=b|0;c=c|0;return(dj(a,c)|0)!=0|0}function dY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;b=i;i=i+8|0;e=b|0;if((xB(d,e)|0)==0){dk(a,c[e>>2]|0);f=0}else{f=1}i=b;return f|0}function dZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;i=i+8|0;e=b|0;if((xC(d,e)|0)!=0){f=1;i=b;return f|0}d=(c[e>>2]|0)+(c[a+3128>>2]|0)|0;g=(d|0)<1?1:d;c[e>>2]=g;dk(a,g);f=0;i=b;return f|0}function d_(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+8|0;e=d|0;xc();xd(c[q>>2]|0,0,2)|0;f=ya(0)|0;c[11076]=f;if((f|0)==0){g=1;i=d;return g|0}yg(44280);f=w5(a,b,e,1544)|0;L2388:do{if((f|0)!=-1){h=f;while(1){if((h|0)<0){g=1;j=1870;break}if((h|0)==100){k=c[c[e>>2]>>2]|0;xH(k)|0}else if((h|0)==113){xm(c[q>>2]|0,0)}else if((h|0)==73){yn(44280,c[c[e>>2]>>2]|0,32088,0)|0}else if((h|0)==0){j=1857;break}else if((h|0)==115){yn(44280,25208,c[c[e>>2]>>2]|0,32088)|0}else if((h|0)==118){xm(c[q>>2]|0,3)}else if((h|0)==103){c[10738]=c[c[e>>2]>>2]}else if((h|0)==116){c[10740]=c[c[e>>2]>>2]}else if((h|0)==108){xl(c[c[e>>2]>>2]|0,3)|0}else if((h|0)==86){j=1843;break}else if((h|0)==112){yn(44280,28264,c[c[e>>2]>>2]|0,26656)|0}else if((h|0)==63){j=1842;break}else if((h|0)==98){yn(44280,37600,c[c[e>>2]>>2]|0,32088)|0}else if((h|0)==105){if((xW(c[11076]|0,c[c[e>>2]>>2]|0)|0)!=0){j=1848;break}}else if(!((h|0)==99|(h|0)==114|(h|0)==82)){g=1;j=1866;break}h=w5(a,b,e,1544)|0;if((h|0)==-1){break L2388}}if((j|0)==1848){h=c[q>>2]|0;k=c[b>>2]|0;l=c[c[e>>2]>>2]|0;bN(h|0,30304,(x=i,i=i+16|0,c[x>>2]=k,c[x+8>>2]=l,x)|0)|0;g=1;i=d;return g|0}else if((j|0)==1857){l=c[c[e>>2]>>2]|0;bN(c[q>>2]|0,23968,(x=i,i=i+16|0,c[x>>2]=c[b>>2],c[x+8>>2]=l,x)|0)|0;g=1;i=d;return g|0}else if((j|0)==1866){i=d;return g|0}else if((j|0)==1843){aB(33424,87,1,c[o>>2]|0)|0;ax(c[o>>2]|0)|0;g=0;i=d;return g|0}else if((j|0)==1870){i=d;return g|0}else if((j|0)==1842){w4(32976,32328,1544);ax(c[o>>2]|0)|0;g=0;i=d;return g|0}}}while(0);xm(c[q>>2]|0,3);c[10738]=22440;xt(1,33808,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);xv(2,34600,34344,(x=i,i=i+8|0,c[x>>2]=21232,x)|0);if((x_(c[11076]|0,21232)|0)!=0){xt(0,34112,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);g=1;i=d;return g|0}j=yc(c[11076]|0,0,41384)|0;b=(j|0)==0?c[11076]|0:j;if((yo(44280,b,1)|0)==0){aT(2)|0;bb(0)|0;xJ(b)|0;c[10742]=c3(b)|0;aM(2,66)|0;aM(15,168)|0;aM(11,170)|0;wZ(c[p>>2]|0,c[o>>2]|0);xw(42992);xn(42992,30,c[10742]|0);xo(42992,112,c[10742]|0);xp(42992,c[(c[10742]|0)+16>>2]|0,80);xq(42992,c[(c[10742]|0)+16>>2]|0,54);xr(42992,1);wQ(c[10742]|0,110,76);cM(c[10742]|0,42992);dg(c[10742]|0);cH(c[10742]|0);a0(1);return 0}else{g=1;i=d;return g|0}return 0}function d$(a){a=a|0;var b=0;aB(37712,30,1,c[q>>2]|0)|0;ax(c[q>>2]|0)|0;a=c[10742]|0;do{if((a|0)!=0){b=c[a>>2]|0;if((b|0)==0){break}cF(b)}}while(0);xK(0,1);a0(1)}function d0(a,b,d){a=a|0;b=b|0;d=d|0;c[a+3168>>2]=1;return 0}function d1(a,c){a=a|0;c=c|0;var d=0;d=c>>>0>1e3?32767:((c*32767|0)>>>0)/1e3|0;b[a+2136>>1]=0;b[a+2138>>1]=d+32768&65535;b[a+2140>>1]=32768-d&65535;return}function d2(a,b,d){a=a|0;b=b|0;d=d|0;c[a+2144>>2]=b;c[a+2148>>2]=d;return}function d3(a){a=a|0;return c[a+32>>2]|0}function d4(a){a=a|0;return c[a+36>>2]|0}function d5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;b=i;i=i+8|0;e=b|0;if((xB(d,e)|0)==0){c[a+3076>>2]=c[e>>2];f=0}else{f=1}i=b;return f|0}function d6(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;d=i;i=i+16|0;f=d|0;g=d+8|0;c[f>>2]=e;if((aP(e|0,29736)|0)==0){xt(2,29608,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);if((tz(c[b+8>>2]|0)|0)==0){h=0;i=d;return h|0}xt(0,29432,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);h=1;i=d;return h|0}e=b+8|0;b=0;L2446:while(1){do{if((a[c[f>>2]|0]|0)==0){h=b;j=1895;break L2446}if((xF(f,g,31480,31328)|0)!=0){break L2446}xt(2,29128,(x=i,i=i+8|0,c[x>>2]=c[g>>2],x)|0);}while((tA(c[e>>2]|0,c[g>>2]|0,28824,0)|0)==0);xt(0,28384,(x=i,i=i+8|0,c[x>>2]=c[g>>2],x)|0);b=1}if((j|0)==1895){i=d;return h|0}xt(0,29272,(x=i,i=i+8|0,c[x>>2]=c[f>>2],x)|0);h=1;i=d;return h|0}function d7(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;d=i;i=i+16|0;f=d|0;g=d+8|0;c[f>>2]=e;if((a[e]|0)==0){h=0;i=d;return h|0}e=b+8|0;while(1){if((xF(f,g,31480,31328)|0)!=0){break}b=ts(c[e>>2]|0,c[g>>2]|0)|0;j=c[g>>2]|0;if((b|0)==0){xt(0,30112,(x=i,i=i+8|0,c[x>>2]=j,x)|0)}else{xt(2,29896,(x=i,i=i+8|0,c[x>>2]=j,x)|0);j=c[e>>2]|0;tr(j,b)|0;tl(b)}if((a[c[f>>2]|0]|0)==0){h=0;k=1910;break}}if((k|0)==1910){i=d;return h|0}xt(0,30344,(x=i,i=i+8|0,c[x>>2]=c[f>>2],x)|0);h=1;i=d;return h|0}function d8(a,b,d){a=a|0;b=b|0;d=d|0;return(w6(c[a+8>>2]|0,d,1)|0)!=0|0}function d9(a,b,d){a=a|0;b=b|0;d=d|0;c[a+3168>>2]=2;xs(42992,1);return 0}function ea(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;b=i;i=i+8|0;e=b|0;if((xD(d,e)|0)!=0){f=1;i=b;return f|0}d=a+3012|0;if((c[d>>2]|0)==0){f=0;i=b;return f|0}xt(2,31176,(x=i,i=i+8|0,c[x>>2]=(c[e>>2]|0)!=0?30896:30456,x)|0);od((c[d>>2]|0)+28|0,c[e>>2]|0);f=0;i=b;return f|0}function eb(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;i=i+16|0;e=b|0;f=b+8|0;c[e>>2]=d;if((xF(e,f,31480,31328)|0)!=0){g=1;i=b;return g|0}g=(da(a,c[f>>2]|0,c[e>>2]|0)|0)!=0|0;i=b;return g|0}function ec(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;i=i+16|0;e=b|0;f=b+8|0;c[e>>2]=d;if((xF(e,f,31480,31328)|0)!=0){g=1;i=b;return g|0}g=(db(a,c[f>>2]|0,c[e>>2]|0)|0)!=0|0;i=b;return g|0}function ed(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0;d=i;i=i+8|0;f=d|0;if((xD(e,f)|0)!=0){g=1;i=d;return g|0}a[b+3172|0]=c[f>>2]&255;dh(b);g=0;i=d;return g|0}function ee(b,c,d){b=b|0;c=c|0;d=d|0;d=b+3172|0;a[d]=(a[d]|0)==0|0;dh(b);return 0}function ef(a,b,c){a=a|0;b=b|0;c=c|0;dg(a);return 0}function eg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;i=i+16|0;e=b|0;f=b+8|0;c[e>>2]=d;if((xF(e,f,31480,31328)|0)!=0){g=1;i=b;return g|0}g=(c8(a,c[f>>2]|0,c[e>>2]|0)|0)!=0|0;i=b;return g|0}function eh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;i=i+16|0;e=b|0;f=b+8|0;c[e>>2]=d;if((xF(e,f,31480,31328)|0)!=0){g=1;i=b;return g|0}g=(c9(a,c[f>>2]|0,c[e>>2]|0)|0)!=0|0;i=b;return g|0}function ei(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;d=a+844|0;a=c[d>>2]|0;if((a|0)==0){e=1;return e|0}cv(a);cD(c[d>>2]|0);e=0;return e|0}function ej(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;i=i+8|0;e=b|0;f=a+844|0;do{if((c[f>>2]|0)==0){g=1}else{if((xD(d,e)|0)!=0){g=1;break}cz(c[f>>2]|0,c[e>>2]|0);cD(c[f>>2]|0);g=0}}while(0);i=b;return g|0}function ek(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;d=b+844|0;b=c[d>>2]|0;if((b|0)==0){f=1;return f|0}if((cu(b,(a[e]|0)==0?0:e)|0)!=0){f=1;return f|0}cD(c[d>>2]|0);f=0;return f|0}function el(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;d=i;i=i+8|0;f=d|0;g=b+844|0;b=c[g>>2]|0;if((b|0)==0){h=1;i=d;return h|0}cy(b,0);do{if((a[e]|0)!=0){if((aP(e|0,31616)|0)==0){cv(c[g>>2]|0);break}if((xA(e,f)|0)!=0){h=1;i=d;return h|0}if((cw(c[g>>2]|0,c[f>>2]|0)|0)==0){break}else{h=1}i=d;return h|0}}while(0);cD(c[g>>2]|0);h=0;i=d;return h|0}function em(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;i=i+8|0;e=b|0;f=a+844|0;do{if((c[f>>2]|0)==0){g=1}else{if((xD(d,e)|0)!=0){g=1;break}cx(c[f>>2]|0,c[e>>2]|0);cD(c[f>>2]|0);g=0}}while(0);i=b;return g|0}function en(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;d=a+844|0;a=c[d>>2]|0;if((a|0)==0){e=1;return e|0}cA(a);cD(c[d>>2]|0);e=0;return e|0}function eo(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;d=i;i=i+8|0;f=d|0;g=b+844|0;b=c[g>>2]|0;if((b|0)==0){h=1;i=d;return h|0}cy(b,1);do{if((a[e]|0)!=0){if((aP(e|0,31616)|0)==0){cv(c[g>>2]|0);break}if((xA(e,f)|0)!=0){h=1;i=d;return h|0}if((cw(c[g>>2]|0,c[f>>2]|0)|0)==0){break}else{h=1}i=d;return h|0}}while(0);cD(c[g>>2]|0);h=0;i=d;return h|0}function ep(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;d=c[a+844>>2]|0;if((d|0)==0){e=1;return e|0}cD(d);e=0;return e|0}function eq(a){a=a|0;c[a+12>>2]=0;zP(a|0,0,7);b[a+8>>1]=-32768;c[a+16>>2]=0;c[a+20>>2]=0;c[a+24>>2]=32768;c[a+28>>2]=44100;c[a+32>>2]=0;v2(a+36|0);c[a+84>>2]=0;b[a+2136>>1]=0;b[a+2138>>1]=-16385;b[a+2140>>1]=16385;return}function er(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=a|0;f=c[e>>2]|0;if((f|0)!=0){v7(f)}f=wa(b)|0;c[e>>2]=f;if((f|0)==0){g=1;return g|0}c[a+28>>2]=d;if((v9(f,1,d,1)|0)==0){g=0;return g|0}v7(c[e>>2]|0);c[e>>2]=0;g=1;return g|0}function es(a,b){a=a|0;b=b|0;c[a+32>>2]=b;v4(a+36|0,b,c[a+28>>2]|0);return}function et(b,c){b=b|0;c=c|0;eu(b);a[b+5|0]=c<<24>>24!=0|0;return}function eu(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((a[d+5|0]|0)==0){e=-32768}else{e=b[((a[d+6|0]|0)==0?d+2140|0:d+2138|0)>>1]|0}f=b1[c[d+2148>>2]&1023](c[d+2144>>2]|0)|0;g=d+16|0;h=c[g>>2]|0;i=f-h|0;c[g>>2]=f;g=d+4|0;j=d+8|0;k=e&65535;l=(b[j>>1]|0)==e<<16>>16;if((a[g]|0)==0){if(l){return}a[g]=1;b[j>>1]=-32768;c[d+12>>2]=0;c[d+24>>2]=32768;c[d+20>>2]=0;m=(c[d+28>>2]|0)>>>3;n=d|0;if((c[n>>2]|0)==0){return}o=d+84|0;p=c[o>>2]|0;if((m|0)==0){q=p}else{r=d+88|0;s=d+32|0;t=d+36|0;u=m;m=p;while(1){p=m+1|0;b[d+88+(m<<1)>>1]=0;if(p>>>0>1023){if((c[s>>2]|0)!=0){vV(t,r,r,p,1,1)}v=c[n>>2]|0;v8(v,r,p)|0;w=0}else{w=p}p=u-1|0;if((p|0)==0){q=w;break}else{u=p;m=w}}}c[o>>2]=q;return}do{if(l){q=d+12|0;o=(c[q>>2]|0)+i|0;c[q>>2]=o;if(o>>>0<=2386364){break}a[g]=0;o=d+84|0;q=c[o>>2]|0;if((q|0)==0){return}w=d+88|0;m=d+36|0;if((c[d+32>>2]|0)!=0){vV(m,w,w,q,1,1)}u=c[d>>2]|0;v8(u,w,q)|0;v3(m);c[o>>2]=0;return}else{b[j>>1]=e;c[d+12>>2]=i}}while(0);e=d+24|0;j=c[e>>2]|0;if((f|0)==(h|0)){x=j}else{h=d+28|0;f=d+20|0;g=d|0;l=d+84|0;o=d+88|0;m=d+32|0;q=d+36|0;w=i;i=j;j=c[f>>2]|0;while(1){u=((i*63|0)+k|0)>>>6;r=j+(c[h>>2]|0)|0;c[f>>2]=r;if(r>>>0>1193181){if((c[g>>2]|0)==0){y=r}else{n=c[l>>2]|0;t=n+1|0;b[d+88+(n<<1)>>1]=(u^32768)&65535;if(t>>>0>1023){if((c[m>>2]|0)!=0){vV(q,o,o,t,1,1)}n=c[g>>2]|0;v8(n,o,t)|0;z=0}else{z=t}c[l>>2]=z;y=c[f>>2]|0}t=y-1193182|0;c[f>>2]=t;A=t}else{A=r}r=w-1|0;if((r|0)==0){x=u;break}else{w=r;i=u;j=A}}}c[e>>2]=x;return}function ev(b,c){b=b|0;c=c|0;eu(b);a[b+6|0]=c<<24>>24!=0|0;return}function ew(a,b){a=a|0;b=b|0;eu(a);return}function ex(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;i=i+32|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;yi(d,27808,f,0)|0;if((c[f>>2]|0)>>>0>67108863){c[f>>2]=67108863}yi(d,35696,g,0)|0;yi(d,31896,h,53248)|0;yl(d,30096,j,0)|0;d=(c[g>>2]|0)>>>4;c[g>>2]=d;k=(c[h>>2]|0)+15&-16;c[h>>2]=k;l=zH(44)|0;if((l|0)==0){m=0;i=e;return m|0}c[l>>2]=0;c[l+4>>2]=0;c[l+8>>2]=0;c[l+12>>2]=c[f>>2];n=l+32|0;c[n>>2]=0;o=l+16|0;zP(o|0,0,14);if((d|0)!=0){p=r0(k<<4,d<<4,1)|0;c[n>>2]=p;c[p+24>>2]=l;r3(c[n>>2]|0,0);n=c[h>>2]&65535;b[l+24>>1]=n;p=c[g>>2]&65535;b[l+28>>1]=p;d=zH(6)|0;c[l+20>>2]=d;c[o>>2]=1;b[d>>1]=n;b[d+2>>1]=p;a[d+4|0]=0}if((c[j>>2]|0)==0){c[l+36>>2]=0;q=0}else{c[l+36>>2]=r0(1048576,65520,1)|0;q=(c[j>>2]|0)!=0|0}c[l+40>>2]=0;j=c[f>>2]|0;f=c[g>>2]|0;g=c[h>>2]|0;xv(2,28096,26512,(x=i,i=i+48|0,c[x>>2]=j,c[x+8>>2]=j>>>20,c[x+16>>2]=f<<4,c[x+24>>2]=f>>>6,c[x+32>>2]=g,c[x+40>>2]=q,x)|0);m=l;i=e;return m|0}function ey(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;dP(25088,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);f=d|0;g=c[f>>2]|0;if((g|0)!=0){h=d+4|0;j=0;k=g;while(1){g=c[(c[h>>2]|0)+(j<<2)>>2]|0;if((g|0)==0){l=k}else{zI(c[g+8>>2]|0);zI(g);l=c[f>>2]|0}g=j+1|0;if(g>>>0<l>>>0){j=g;k=l}else{break}}}l=d+28|0;if((b[l>>1]|0)!=0){r3(c[d+32>>2]|0,0);b[d+26>>1]=0;c[d+16>>2]=1;k=d+20|0;b[c[k>>2]>>1]=b[d+24>>1]|0;b[(c[k>>2]|0)+2>>1]=b[l>>1]|0;a[(c[k>>2]|0)+4|0]=0}k=c[d+36>>2]|0;if((k|0)==0){c[f>>2]=0;m=d+8|0;c[m>>2]=0;n=d+40|0;c[n>>2]=0;i=e;return}r3(k,0);c[f>>2]=0;m=d+8|0;c[m>>2]=0;n=d+40|0;c[n>>2]=0;i=e;return}function ez(b){b=b|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;f=b+8|0;g=b+12|0;h=(c[g>>2]|0)>>>10;j=b+26|0;k=(e[j>>1]|0)>>>6;l=b+28|0;m=(e[l>>1]|0)>>>6;n=(c[b+36>>2]|0)!=0?63:0;w2(23800,(x=i,i=i+48|0,c[x>>2]=(c[f>>2]|0)>>>10,c[x+8>>2]=h,c[x+16>>2]=k,c[x+24>>2]=m,c[x+32>>2]=n,c[x+40>>2]=n,x)|0);n=b|0;m=c[f>>2]|0;f=c[g>>2]|0;w2(22248,(x=i,i=i+24|0,c[x>>2]=c[n>>2],c[x+8>>2]=m,c[x+16>>2]=f,x)|0);if((c[n>>2]|0)!=0){f=b+4|0;m=0;do{g=c[(c[f>>2]|0)+(m<<2)>>2]|0;k=(c[g>>2]|0)>>>10;h=(c[g+4>>2]|0)!=0|0;w2(21152,(x=i,i=i+24|0,c[x>>2]=m,c[x+8>>2]=k,c[x+16>>2]=h,x)|0);m=m+1|0;}while(m>>>0<(c[n>>2]|0)>>>0)}n=b+16|0;m=e[j>>1]<<4;j=e[l>>1]<<4;w2(41224,(x=i,i=i+24|0,c[x>>2]=c[n>>2],c[x+8>>2]=m,c[x+16>>2]=j,x)|0);if((c[n>>2]|0)==0){i=d;return}j=b+20|0;b=0;do{m=c[j>>2]|0;l=e[m+(b*6|0)>>1]|0;f=e[m+(b*6|0)+2>>1]<<4;h=(a[m+(b*6|0)+4|0]|0)!=0|0;w2(39944,(x=i,i=i+32|0,c[x>>2]=b,c[x+8>>2]=l,c[x+16>>2]=f,c[x+24>>2]=h,x)|0);b=b+1|0;}while(b>>>0<(c[n>>2]|0)>>>0);i=d;return}function eA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=a+8|0;if(((c[a+12>>2]|0)-(c[e>>2]|0)|0)>>>0<b>>>0){f=1;return f|0}g=a|0;h=c[g>>2]|0;i=a+4|0;a=0;while(1){if(a>>>0>=h>>>0){j=2091;break}k=a+1|0;if((c[(c[i>>2]|0)+(a<<2)>>2]|0)==0){l=k;break}else{a=k}}if((j|0)==2091){l=a+1|0}c[d>>2]=l;d=zH(12)|0;a=d;L2696:do{if((d|0)==0){m=0}else{do{if((b|0)==0){c[d+8>>2]=0}else{j=zH(b)|0;c[d+8>>2]=j;if((j|0)!=0){break}zI(d);m=0;break L2696}}while(0);c[d>>2]=b;c[d+4>>2]=0;m=a}}while(0);if((l|0)!=0){a=c[g>>2]|0;L2706:do{if(a>>>0<l>>>0){c[g>>2]=l;d=zJ(c[i>>2]|0,l*12|0)|0;c[i>>2]=d;j=c[g>>2]|0;if(a>>>0>=j>>>0){break}c[d+(a<<2)>>2]=0;h=a+1|0;if(h>>>0<j>>>0){n=h;o=d}else{break}while(1){c[o+(n<<2)>>2]=0;d=n+1|0;if(d>>>0>=(c[g>>2]|0)>>>0){break L2706}n=d;o=c[i>>2]|0}}}while(0);c[(c[i>>2]|0)+(l-1<<2)>>2]=m}c[e>>2]=(c[e>>2]|0)+b;f=0;return f|0}function eB(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=d+16|0;h=c[g>>2]|0;if((h|0)==0){i=1;return i|0}j=d+20|0;k=c[j>>2]|0;l=0;while(1){if((a[k+(l*6|0)+4|0]|0)==0){m=b[k+(l*6|0)+2>>1]|0;if((m&65535)>=(e&65535)){break}}n=l+1|0;if(n>>>0<h>>>0){l=n}else{i=1;o=2120;break}}if((o|0)==2120){return i|0}if((m&65535)>(e&65535)){m=h+1|0;c[g>>2]=m;h=zJ(k,m*6|0)|0;c[j>>2]=h;m=c[g>>2]|0;g=m-1|0;if(g>>>0>l>>>0){o=m;m=g;g=h;while(1){n=g+(m*6|0)|0;p=g+((o-2|0)*6|0)|0;b[n>>1]=b[p>>1]|0;b[n+2>>1]=b[p+2>>1]|0;b[n+4>>1]=b[p+4>>1]|0;p=m-1|0;n=c[j>>2]|0;if(p>>>0>l>>>0){o=m;m=p;g=n}else{q=n;break}}}else{q=h}h=l+1|0;b[q+(h*6|0)>>1]=(b[q+(l*6|0)>>1]|0)+e&65535;q=c[j>>2]|0;b[q+(h*6|0)+2>>1]=(b[q+(l*6|0)+2>>1]|0)-e&65535;a[(c[j>>2]|0)+(h*6|0)+4|0]=0;b[(c[j>>2]|0)+(l*6|0)+2>>1]=e;r=c[j>>2]|0}else{r=k}a[r+(l*6|0)+4|0]=1;r=d+26|0;b[r>>1]=(b[r>>1]|0)+(b[(c[j>>2]|0)+(l*6|0)+2>>1]|0)&65535;c[f>>2]=l;i=0;return i|0}function eC(a,d){a=a|0;d=d|0;var e=0,f=0,g=0;if((a|0)==0){e=0;f=d+4|0;b[f>>1]=e;return}g=(c[a+36>>2]|0)==0?1:3;b[d+6>>1]=b[a+28>>1]|0;b[d+8>>1]=(c[a+12>>2]|0)>>>10&65535;e=g;f=d+4|0;b[f>>1]=e;return}function eD(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;h=g+4|0;i=b[g+16>>1]|0;j=(e[g+26>>1]|0)<<4;k=g+80|0;l=c[k>>2]|0;m=j+(i&65535)&l;n=m+1|0;o=g+76|0;p=c[o>>2]|0;if(n>>>0<p>>>0){q=c[g+72>>2]|0;r=(d[q+n|0]|0)<<8|(d[q+m|0]|0);s=l;t=p}else{p=b8[c[g+44>>2]&255](c[g+32>>2]|0,m)|0;r=p;s=c[k>>2]|0;t=c[o>>2]|0}p=s&(i+2&65535)+j;m=p+1|0;if(m>>>0<t>>>0){l=c[g+72>>2]|0;u=(d[l+m|0]|0)<<8|(d[l+p|0]|0);v=s;w=t}else{t=b8[c[g+44>>2]&255](c[g+32>>2]|0,p)|0;u=t;v=c[k>>2]|0;w=c[o>>2]|0}t=(u&65535)<<16|r&65535;r=v&(i+4&65535)+j;u=r+1|0;if(u>>>0<w>>>0){p=c[g+72>>2]|0;x=(d[p+u|0]|0)<<8|(d[p+r|0]|0);y=v;z=w}else{w=b8[c[g+44>>2]&255](c[g+32>>2]|0,r)|0;x=w;y=c[k>>2]|0;z=c[o>>2]|0}w=x&65535;r=y&(i+6&65535)+j;v=r+1|0;if(v>>>0<z>>>0){p=c[g+72>>2]|0;A=(d[p+v|0]|0)<<8|(d[p+r|0]|0);B=y;C=z}else{z=b8[c[g+44>>2]&255](c[g+32>>2]|0,r)|0;A=z;B=c[k>>2]|0;C=c[o>>2]|0}z=B&(i+8&65535)+j;r=z+1|0;if(r>>>0<C>>>0){y=c[g+72>>2]|0;D=(d[y+r|0]|0)<<8|(d[y+z|0]|0);E=B;F=C}else{C=b8[c[g+44>>2]&255](c[g+32>>2]|0,z)|0;D=C;E=c[k>>2]|0;F=c[o>>2]|0}C=(D&65535)<<16|A&65535;z=E&(i+10&65535)+j;B=z+1|0;if(B>>>0<F>>>0){y=c[g+72>>2]|0;G=(d[y+B|0]|0)<<8|(d[y+z|0]|0);H=E;I=F}else{F=b8[c[g+44>>2]&255](c[g+32>>2]|0,z)|0;G=F;H=c[k>>2]|0;I=c[o>>2]|0}F=G&65535;z=H&(i+12&65535)+j;E=z+1|0;if(E>>>0<I>>>0){y=c[g+72>>2]|0;J=(d[y+E|0]|0)<<8|(d[y+z|0]|0);K=H;L=I}else{I=b8[c[g+44>>2]&255](c[g+32>>2]|0,z)|0;J=I;K=c[k>>2]|0;L=c[o>>2]|0}I=K&(i+14&65535)+j;j=I+1|0;if(j>>>0<L>>>0){L=c[g+72>>2]|0;M=(d[L+j|0]|0)<<8|(d[L+I|0]|0)}else{M=b8[c[g+44>>2]&255](c[g+32>>2]|0,I)|0}I=(M&65535)<<16|J&65535;L=G<<16>>16==0;L2773:do{if((G|x)<<16>>16==0){if((t|0)==0){break}j=g+72|0;i=g+40|0;K=g+32|0;z=g+36|0;H=D;y=A;E=M;B=J;r=1;while(1){p=c[k>>2]|0;v=p&((H&65535)<<4)+(y&65535);u=c[o>>2]|0;if(v>>>0<u>>>0){N=a[(c[j>>2]|0)+v|0]|0;O=p;P=u}else{u=b8[c[z>>2]&255](c[K>>2]|0,v)|0;N=u;O=c[k>>2]|0;P=c[o>>2]|0}u=O&((E&65535)<<4)+(B&65535);if(u>>>0<P>>>0){a[(c[j>>2]|0)+u|0]=N}else{b5[c[i>>2]&255](c[K>>2]|0,u,N)}u=y+1&65535;v=B+1&65535;if(r>>>0>=t>>>0){break L2773}H=((u&65535)>>>4)+H&65535;y=u&15;E=((v&65535)>>>4)+E&65535;B=v&15;r=r+1|0}}else{r=x<<16>>16!=0;if(r&L){do{if((c[f>>2]|0)>>>0>=w>>>0){B=c[(c[f+4>>2]|0)+(w-1<<2)>>2]|0;if((B|0)==0){break}E=c[B>>2]|0;if(C>>>0>=E>>>0){b[h>>1]=0;y=g+10|0;b[y>>1]=b[y>>1]&-256|164;return}if((C+t|0)>>>0>E>>>0){b[h>>1]=0;E=g+10|0;b[E>>1]=b[E>>1]&-256|167}if((t|0)==0){break L2773}E=B+8|0;B=g+72|0;y=g+40|0;H=g+32|0;K=M;i=J;j=0;while(1){z=a[(c[E>>2]|0)+(j+C)|0]|0;v=c[k>>2]&((K&65535)<<4)+(i&65535);if(v>>>0<(c[o>>2]|0)>>>0){a[(c[B>>2]|0)+v|0]=z}else{b5[c[y>>2]&255](c[H>>2]|0,v,z)}z=i+1&65535;v=j+1|0;if(v>>>0>=t>>>0){break L2773}K=((z&65535)>>>4)+K&65535;i=z&15;j=v}}}while(0);b[h>>1]=0;j=g+10|0;b[j>>1]=b[j>>1]&-256|163;return}if(!(r|L)){do{if((c[f>>2]|0)>>>0>=F>>>0){j=c[(c[f+4>>2]|0)+(F-1<<2)>>2]|0;if((j|0)==0){break}i=c[j>>2]|0;if(I>>>0>=i>>>0){b[h>>1]=0;K=g+10|0;b[K>>1]=b[K>>1]&-256|166;return}if((I+t|0)>>>0>i>>>0){b[h>>1]=0;i=g+10|0;b[i>>1]=b[i>>1]&-256|167;return}if((t|0)==0){break L2773}i=g+72|0;K=j+8|0;j=g+36|0;H=g+32|0;y=D;B=A;E=0;while(1){v=c[k>>2]&((y&65535)<<4)+(B&65535);if(v>>>0<(c[o>>2]|0)>>>0){Q=a[(c[i>>2]|0)+v|0]|0}else{Q=b8[c[j>>2]&255](c[H>>2]|0,v)|0}a[(c[K>>2]|0)+(E+I)|0]=Q;v=B+1&65535;z=E+1|0;if(z>>>0>=t>>>0){break L2773}y=((v&65535)>>>4)+y&65535;B=v&15;E=z}}}while(0);b[h>>1]=0;r=g+10|0;b[r>>1]=b[r>>1]&-256|165;return}do{if(x<<16>>16!=0){r=f|0;if((c[r>>2]|0)>>>0<w>>>0){break}E=f+4|0;B=c[(c[E>>2]|0)+(w-1<<2)>>2]|0;if((B|0)==0){break}y=c[B>>2]|0;if(C>>>0>=y>>>0){b[h>>1]=0;K=g+10|0;b[K>>1]=b[K>>1]&-256|164;return}if((C+t|0)>>>0>y>>>0){b[h>>1]=0;y=g+10|0;b[y>>1]=b[y>>1]&-256|167}do{if(!L){if((c[r>>2]|0)>>>0<F>>>0){break}y=c[(c[E>>2]|0)+(F-1<<2)>>2]|0;if((y|0)==0){break}K=c[y>>2]|0;if(I>>>0>=K>>>0){b[h>>1]=0;H=g+10|0;b[H>>1]=b[H>>1]&-256|166;return}if((I+t|0)>>>0>K>>>0){b[h>>1]=0;K=g+10|0;b[K>>1]=b[K>>1]&-256|167}K=c[y+8>>2]|0;y=c[B+8>>2]|0;zO(K|0,y|0,t)|0;break L2773}}while(0);b[h>>1]=0;B=g+10|0;b[B>>1]=b[B>>1]&-256|165;return}}while(0);b[h>>1]=0;B=g+10|0;b[B>>1]=b[B>>1]&-256|163;return}}while(0);b[h>>1]=1;h=g+10|0;b[h>>1]=b[h>>1]&-256;return}function eE(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=d+4|0;f=d+10|0;g=b[f>>1]|0;h=(g&65535)<<10;i=a+8|0;if(h>>>0>((c[a+12>>2]|0)-(c[i>>2]|0)|0)>>>0){b[e>>1]=0;b[f>>1]=g&-256|160;return}j=b[d+8>>1]|0;d=j&65535;do{if(j<<16>>16!=0){if((c[a>>2]|0)>>>0<d>>>0){break}k=c[(c[a+4>>2]|0)+(d-1<<2)>>2]|0;if((k|0)==0){break}l=k+8|0;m=zJ(c[l>>2]|0,h)|0;if((m|0)==0){b[e>>1]=0;b[f>>1]=b[f>>1]&-256|160;return}else{n=(c[i>>2]|0)+h|0;c[i>>2]=n;o=k|0;c[i>>2]=n-(c[o>>2]|0);c[l>>2]=m;c[o>>2]=h;b[e>>1]=1;return}}}while(0);b[e>>1]=0;b[f>>1]=g&-256|162;return}function eF(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=e+4|0;g=b[e+8>>1]|0;h=d+16|0;i=c[h>>2]|0;j=d+20|0;k=0;while(1){if(k>>>0>=i>>>0){break}l=c[j>>2]|0;if((b[l+(k*6|0)>>1]|0)==g<<16>>16){m=2239;break}else{k=k+1|0}}do{if((m|0)==2239){g=l+(k*6|0)+4|0;if((a[g]|0)==0){break}a[g]=0;g=c[j>>2]|0;i=d+26|0;b[i>>1]=(b[i>>1]|0)-(b[g+(k*6|0)+2>>1]|0)&65535;i=c[h>>2]|0;L2886:do{if((i|0)==0){n=0}else{o=0;p=0;q=i;r=g;while(1){s=o+1|0;L2889:do{if((a[r+(o*6|0)+4|0]|0)==0&s>>>0<q>>>0){if((a[r+(s*6|0)+4|0]|0)==0){t=r;u=s}else{v=s;w=q;break}while(1){x=t+(o*6|0)+2|0;b[x>>1]=(b[x>>1]|0)+(b[t+(u*6|0)+2>>1]|0)&65535;x=u+1|0;y=c[h>>2]|0;if(x>>>0>=y>>>0){v=x;w=y;break L2889}z=c[j>>2]|0;if((a[z+(x*6|0)+4|0]|0)==0){t=z;u=x}else{v=x;w=y;break}}}else{v=s;w=q}}while(0);if((o|0)==(p|0)){A=w}else{s=c[j>>2]|0;y=s+(p*6|0)|0;x=s+(o*6|0)|0;b[y>>1]=b[x>>1]|0;b[y+2>>1]=b[x+2>>1]|0;b[y+4>>1]=b[x+4>>1]|0;A=c[h>>2]|0}x=p+1|0;if(v>>>0>=A>>>0){n=x;break L2886}o=v;p=x;q=A;r=c[j>>2]|0}}}while(0);c[h>>2]=n;B=f|0;b[B>>1]=1;return}}while(0);n=f|0;b[n>>1]=1;f=e+10|0;b[f>>1]=b[f>>1]&-256|178;B=n;b[B>>1]=1;return}function eG(d,f){d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=f+4|0;do{if((d|0)==0){b[k>>1]=0;l=f+10|0;b[l>>1]=b[l>>1]&-256|128;m=f+4|0}else{l=(e[k>>1]|0)>>>8;n=f+4|0;if((l|0)==0){m=n;break}else if((l|0)==13){o=f+4|0;p=b[f+8>>1]|0;q=p&65535;do{if(p<<16>>16!=0){if((c[d>>2]|0)>>>0<q>>>0){break}r=c[(c[d+4>>2]|0)+(q-1<<2)>>2]|0;if((r|0)==0){break}s=r+4|0;r=c[s>>2]|0;if((r|0)==0){b[o>>1]=0;t=f+10|0;b[t>>1]=b[t>>1]&-256|170;i=g;return}else{c[s>>2]=r-1;b[o>>1]=1;i=g;return}}}while(0);b[o>>1]=0;q=f+10|0;b[q>>1]=b[q>>1]&-256|162;i=g;return}else if((l|0)==1){if((c[d+36>>2]|0)==0){b[n>>1]=0;q=f+10|0;b[q>>1]=b[q>>1]&-256|144;i=g;return}q=d+40|0;if((c[q>>2]|0)==0){c[q>>2]=1;b[n>>1]=1;q=f+10|0;b[q>>1]=b[q>>1]&-256;i=g;return}else{b[n>>1]=0;q=f+10|0;b[q>>1]=b[q>>1]&-256|145;i=g;return}}else if((l|0)==17){eF(d,f);i=g;return}else if((l|0)==6){hI(f,1048575);b[n>>1]=1;q=f+10|0;b[q>>1]=b[q>>1]&-256;i=g;return}else if((l|0)==7){b[n>>1]=(hJ(f)|0)>>>20&1;q=f+10|0;b[q>>1]=b[q>>1]&-256;i=g;return}else if((l|0)==12){q=f+4|0;p=f+8|0;r=b[p>>1]|0;s=r&65535;do{if(r<<16>>16!=0){if((c[d>>2]|0)>>>0<s>>>0){break}t=c[(c[d+4>>2]|0)+(s-1<<2)>>2]|0;if((t|0)==0){break}u=t+4|0;c[u>>2]=(c[u>>2]|0)+1;b[q>>1]=1;b[f+10>>1]=0;b[p>>1]=1;i=g;return}}while(0);b[q>>1]=0;p=f+10|0;b[p>>1]=b[p>>1]&-256|162;i=g;return}else if((l|0)==3){hI(f,-1);b[n>>1]=1;p=f+10|0;b[p>>1]=b[p>>1]&-256;i=g;return}else if((l|0)==11){eD(d,f);i=g;return}else if((l|0)==10){p=b[f+8>>1]|0;s=p&65535;do{if(p<<16>>16!=0){if((c[d>>2]|0)>>>0<s>>>0){break}r=s-1|0;o=d+4|0;u=c[o>>2]|0;t=u+(r<<2)|0;v=c[t>>2]|0;do{if((v|0)==0){w=u}else{y=d+8|0;c[y>>2]=(c[y>>2]|0)-(c[v>>2]|0);y=c[t>>2]|0;if((y|0)==0){w=u;break}zI(c[y+8>>2]|0);zI(y);w=c[o>>2]|0}}while(0);c[w+(r<<2)>>2]=0;b[n>>1]=1;o=f+10|0;b[o>>1]=b[o>>1]&-256;i=g;return}}while(0);b[n>>1]=0;s=f+10|0;b[s>>1]=b[s>>1]&-256|162;i=g;return}else if((l|0)==4){hI(f,1048575);b[n>>1]=1;s=f+10|0;b[s>>1]=b[s>>1]&-256;i=g;return}else if((l|0)==5){hI(f,-1);b[n>>1]=1;s=f+10|0;b[s>>1]=b[s>>1]&-256;i=g;return}else if((l|0)==15){eE(d,f);i=g;return}else if((l|0)==16){s=f+8|0;if((eB(d,b[s>>1]|0,j)|0)==0){b[n>>1]=1;p=c[j>>2]|0;q=d+20|0;b[s>>1]=b[(c[q>>2]|0)+(p*6|0)+2>>1]|0;b[f+10>>1]=b[(c[q>>2]|0)+(p*6|0)>>1]|0;i=g;return}b[n>>1]=0;p=c[d+16>>2]|0;if((p|0)==0){z=0}else{q=c[d+20>>2]|0;o=0;u=0;while(1){if((a[q+(o*6|0)+4|0]|0)==0){t=b[q+(o*6|0)+2>>1]|0;A=(t&65535)>(u&65535)?t:u}else{A=u}t=o+1|0;if(t>>>0<p>>>0){o=t;u=A}else{z=A;break}}}b[s>>1]=z;u=f+10|0;b[u>>1]=b[u>>1]&-256|(z<<16>>16==0?177:176);i=g;return}else if((l|0)==2){if((c[d+36>>2]|0)==0){b[n>>1]=0;u=f+10|0;b[u>>1]=b[u>>1]&-256|144;i=g;return}u=d+40|0;if((c[u>>2]|0)==0){b[n>>1]=0;o=f+10|0;b[o>>1]=b[o>>1]&-256|147;i=g;return}else{c[u>>2]=0;b[n>>1]=1;u=f+10|0;b[u>>1]=b[u>>1]&-256;i=g;return}}else if((l|0)==8){u=d+12|0;o=d+8|0;b[n>>1]=((c[u>>2]|0)-(c[o>>2]|0)|0)>>>10&65535;b[f+8>>1]=((c[u>>2]|0)-(c[o>>2]|0)|0)>>>10&65535;o=f+10|0;b[o>>1]=b[o>>1]&-256;i=g;return}else if((l|0)==9){o=f+4|0;u=f+8|0;p=e[u>>1]<<10;if(p>>>0>((c[d+12>>2]|0)-(c[d+8>>2]|0)|0)>>>0){b[o>>1]=0;q=f+10|0;b[q>>1]=b[q>>1]&-256|160;i=g;return}q=o|0;if((eA(d,p,h)|0)==0){b[q>>1]=1;b[u>>1]=c[h>>2]&65535;u=f+10|0;b[u>>1]=b[u>>1]&-256;i=g;return}else{b[q>>1]=0;q=f+10|0;b[q>>1]=b[q>>1]&-256|161;i=g;return}}else if((l|0)==14){q=f+8|0;u=b[q>>1]|0;p=u&65535;do{if(u<<16>>16!=0){if((c[d>>2]|0)>>>0<p>>>0){break}o=c[(c[d+4>>2]|0)+(p-1<<2)>>2]|0;if((o|0)==0){break}b[n>>1]=1;b[f+10>>1]=c[o+4>>2]<<8&65535|255;b[q>>1]=(c[o>>2]|0)>>>10&65535;i=g;return}}while(0);b[n>>1]=0;q=f+10|0;b[q>>1]=b[q>>1]&-256|162;i=g;return}else{xt(3,38592,(x=i,i=i+8|0,c[x>>2]=l,x)|0);b[n>>1]=0;q=f+10|0;b[q>>1]=b[q>>1]&-256|128;i=g;return}}}while(0);b[m>>1]=768;b[f+10>>1]=768;b[f+8>>1]=(c[d+36>>2]|0)!=0|0;i=g;return}function eH(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;i=i+16|0;j=h|0;k=g&65535;l=(f&65535)<<4;f=d+80|0;m=d+76|0;n=d+72|0;o=d+36|0;p=d+32|0;d=0;do{q=c[f>>2]&(d+k&65535)+l;if(q>>>0<(c[m>>2]|0)>>>0){r=a[(c[n>>2]|0)+q|0]|0}else{r=b8[c[o>>2]&255](c[p>>2]|0,q)|0}a[j+d|0]=r;d=d+1|0;}while(d>>>0<16);d=j|0;c[e>>2]=0;c[e+4>>2]=0;b[e+8>>1]=g;b3[c[14528+((a[d]&255)<<2)>>2]&511](e,d);d=e+12|0;if((c[d>>2]|0)==0){i=h;return}else{s=0}do{a[e+16+s|0]=a[j+s|0]|0;s=s+1|0;}while(s>>>0<(c[d>>2]|0)>>>0);i=h;return}function eI(d,f){d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+16|0;h=g|0;j=b[d+28>>1]|0;k=h|0;l=j&65535;m=(e[d+22>>1]|0)<<4;n=d+80|0;o=d+76|0;p=d+72|0;q=d+36|0;r=d+32|0;d=0;do{s=(d+l&65535)+m&c[n>>2];if(s>>>0<(c[o>>2]|0)>>>0){t=a[(c[p>>2]|0)+s|0]|0}else{t=b8[c[q>>2]&255](c[r>>2]|0,s)|0}a[h+d|0]=t;d=d+1|0;}while(d>>>0<16);c[f>>2]=0;c[f+4>>2]=0;b[f+8>>1]=j;b3[c[14528+((a[k]&255)<<2)>>2]&511](f,k);k=f+12|0;if((c[k>>2]|0)==0){i=g;return}else{u=0}do{a[f+16+u|0]=a[h+u|0]|0;u=u+1|0;}while(u>>>0<(c[k>>2]|0)>>>0);i=g;return}function eJ(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=4473921;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;e=hl(b,b+100|0,f,0)|0;zQ(b+164|0,c[15904+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function eK(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=4473921;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;e=hl(b,b+100|0,f,1)|0;zQ(b+164|0,c[15936+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function eL(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=4473921;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;zQ(b+100|0,c[15904+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=(hl(b,b+164|0,f,0)|0)+1;c[b+96>>2]=2;return}function eM(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=4473921;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;zQ(b+100|0,c[15936+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=(hl(b,b+164|0,f,1)|0)+1;c[b+96>>2]=2;return}function eN(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=2;c[b+96>>2]=2;g=b+32|0;y=4473921;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;g=b+100|0;a[g]=a[31608]|0;a[g+1|0]=a[31609|0]|0;a[g+2|0]=a[31610|0]|0;a1(b+164|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e+1|0]|0,x)|0)|0;i=f;return}function eO(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=3;c[b+96>>2]=2;g=b+32|0;y=4473921;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;g=b+100|0;a[g]=a[29888]|0;a[g+1|0]=a[29889|0]|0;a[g+2|0]=a[29890|0]|0;a1(b+164|0,26776,(x=i,i=i+8|0,c[x>>2]=(d[e+2|0]|0)<<8|(d[e+1|0]|0),x)|0)|0;i=f;return}function eP(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=1;d=b+32|0;a[d]=a[25072]|0;a[d+1|0]=a[25073|0]|0;a[d+2|0]=a[25074|0]|0;a[d+3|0]=a[25075|0]|0;a[d+4|0]=a[25076|0]|0;d=b+100|0;a[d]=a[40560]|0;a[d+1|0]=a[40561|0]|0;a[d+2|0]=a[40562|0]|0;return}function eQ(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=1;d=b+32|0;y=5263184;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;d=b+100|0;a[d]=a[40560]|0;a[d+1|0]=a[40561|0]|0;a[d+2|0]=a[40562|0]|0;return}function eR(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;a[f]=a[39280]|0;a[f+1|0]=a[39281|0]|0;a[f+2|0]=a[39282|0]|0;f=e+1|0;e=hl(b,b+100|0,f,0)|0;zQ(b+164|0,c[15904+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function eS(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;a[f]=a[39280]|0;a[f+1|0]=a[39281|0]|0;a[f+2|0]=a[39282|0]|0;f=e+1|0;e=hl(b,b+100|0,f,1)|0;zQ(b+164|0,c[15936+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function eT(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;a[f]=a[39280]|0;a[f+1|0]=a[39281|0]|0;a[f+2|0]=a[39282|0]|0;f=e+1|0;zQ(b+100|0,c[15904+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=(hl(b,b+164|0,f,0)|0)+1;c[b+96>>2]=2;return}function eU(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;a[f]=a[39280]|0;a[f+1|0]=a[39281|0]|0;a[f+2|0]=a[39282|0]|0;f=e+1|0;zQ(b+100|0,c[15936+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=(hl(b,b+164|0,f,1)|0)+1;c[b+96>>2]=2;return}function eV(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=2;c[b+96>>2]=2;g=b+32|0;a[g]=a[39280]|0;a[g+1|0]=a[39281|0]|0;a[g+2|0]=a[39282|0]|0;g=b+100|0;a[g]=a[31608]|0;a[g+1|0]=a[31609|0]|0;a[g+2|0]=a[31610|0]|0;a1(b+164|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e+1|0]|0,x)|0)|0;i=f;return}function eW(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=3;c[b+96>>2]=2;g=b+32|0;a[g]=a[39280]|0;a[g+1|0]=a[39281|0]|0;a[g+2|0]=a[39282|0]|0;g=b+100|0;a[g]=a[29888]|0;a[g+1|0]=a[29889|0]|0;a[g+2|0]=a[29890|0]|0;a1(b+164|0,26776,(x=i,i=i+8|0,c[x>>2]=(d[e+2|0]|0)<<8|(d[e+1|0]|0),x)|0)|0;i=f;return}function eX(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=1;d=b+32|0;a[d]=a[25072]|0;a[d+1|0]=a[25073|0]|0;a[d+2|0]=a[25074|0]|0;a[d+3|0]=a[25075|0]|0;a[d+4|0]=a[25076|0]|0;d=b+100|0;a[d]=a[40312]|0;a[d+1|0]=a[40313|0]|0;a[d+2|0]=a[40314|0]|0;return}function eY(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;y=4276548;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;return}function eZ(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;y=5456196;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;return}function e_(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;y=4276545;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;return}function e$(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;y=5456193;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;return}function e0(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=1;d=b+32|0;y=5263184;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;d=b+100|0;a[d]=a[40312]|0;a[d+1|0]=a[40313|0]|0;a[d+2|0]=a[40314|0]|0;return}function e1(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=4408385;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;e=hl(b,b+100|0,f,0)|0;zQ(b+164|0,c[15904+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function e2(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=4408385;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;e=hl(b,b+100|0,f,1)|0;zQ(b+164|0,c[15936+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function e3(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=4408385;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;zQ(b+100|0,c[15904+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=(hl(b,b+164|0,f,0)|0)+1;c[b+96>>2]=2;return}function e4(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=4408385;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;zQ(b+100|0,c[15936+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=(hl(b,b+164|0,f,1)|0)+1;c[b+96>>2]=2;return}function e5(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=2;c[b+96>>2]=2;g=b+32|0;y=4408385;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;g=b+100|0;a[g]=a[31608]|0;a[g+1|0]=a[31609|0]|0;a[g+2|0]=a[31610|0]|0;a1(b+164|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e+1|0]|0,x)|0)|0;i=f;return}function e6(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=3;c[b+96>>2]=2;g=b+32|0;y=4408385;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;g=b+100|0;a[g]=a[29888]|0;a[g+1|0]=a[29889|0]|0;a[g+2|0]=a[29890|0]|0;a1(b+164|0,26776,(x=i,i=i+8|0,c[x>>2]=(d[e+2|0]|0)<<8|(d[e+1|0]|0),x)|0)|0;i=f;return}function e7(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=1;d=b+32|0;a[d]=a[25072]|0;a[d+1|0]=a[25073|0]|0;a[d+2|0]=a[25074|0]|0;a[d+3|0]=a[25075|0]|0;a[d+4|0]=a[25076|0]|0;d=b+100|0;a[d]=a[40168]|0;a[d+1|0]=a[40169|0]|0;a[d+2|0]=a[40170|0]|0;return}function e8(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=1;d=b+32|0;y=5263184;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;d=b+100|0;a[d]=a[40168]|0;a[d+1|0]=a[40169|0]|0;a[d+2|0]=a[40170|0]|0;return}function e9(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=4342355;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;e=hl(b,b+100|0,f,0)|0;zQ(b+164|0,c[15904+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function fa(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=4342355;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;e=hl(b,b+100|0,f,1)|0;zQ(b+164|0,c[15936+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function fb(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=4342355;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;zQ(b+100|0,c[15904+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=(hl(b,b+164|0,f,0)|0)+1;c[b+96>>2]=2;return}function fc(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=4342355;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;zQ(b+100|0,c[15936+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=(hl(b,b+164|0,f,1)|0)+1;c[b+96>>2]=2;return}function fd(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=2;c[b+96>>2]=2;g=b+32|0;y=4342355;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;g=b+100|0;a[g]=a[31608]|0;a[g+1|0]=a[31609|0]|0;a[g+2|0]=a[31610|0]|0;a1(b+164|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e+1|0]|0,x)|0)|0;i=f;return}function fe(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=3;c[b+96>>2]=2;g=b+32|0;y=4342355;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;g=b+100|0;a[g]=a[29888]|0;a[g+1|0]=a[29889|0]|0;a[g+2|0]=a[29890|0]|0;a1(b+164|0,26776,(x=i,i=i+8|0,c[x>>2]=(d[e+2|0]|0)<<8|(d[e+1|0]|0),x)|0)|0;i=f;return}function ff(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=1;d=b+32|0;a[d]=a[25072]|0;a[d+1|0]=a[25073|0]|0;a[d+2|0]=a[25074|0]|0;a[d+3|0]=a[25075|0]|0;a[d+4|0]=a[25076|0]|0;d=b+100|0;a[d]=a[40032]|0;a[d+1|0]=a[40033|0]|0;a[d+2|0]=a[40034|0]|0;return}function fg(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=1;d=b+32|0;y=5263184;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;d=b+100|0;a[d]=a[40032]|0;a[d+1|0]=a[40033|0]|0;a[d+2|0]=a[40034|0]|0;return}function fh(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=4476481;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;e=hl(b,b+100|0,f,0)|0;zQ(b+164|0,c[15904+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function fi(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=4476481;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;e=hl(b,b+100|0,f,1)|0;zQ(b+164|0,c[15936+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function fj(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=4476481;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;zQ(b+100|0,c[15904+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=(hl(b,b+164|0,f,0)|0)+1;c[b+96>>2]=2;return}function fk(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=4476481;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;zQ(b+100|0,c[15936+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=(hl(b,b+164|0,f,1)|0)+1;c[b+96>>2]=2;return}function fl(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=2;c[b+96>>2]=2;g=b+32|0;y=4476481;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;g=b+100|0;a[g]=a[31608]|0;a[g+1|0]=a[31609|0]|0;a[g+2|0]=a[31610|0]|0;a1(b+164|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e+1|0]|0,x)|0)|0;i=f;return}function fm(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=3;c[b+96>>2]=2;g=b+32|0;y=4476481;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;g=b+100|0;a[g]=a[29888]|0;a[g+1|0]=a[29889|0]|0;a[g+2|0]=a[29890|0]|0;a1(b+164|0,26776,(x=i,i=i+8|0,c[x>>2]=(d[e+2|0]|0)<<8|(d[e+1|0]|0),x)|0)|0;i=f;return}function fn(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b+4|0;f=c[e>>2]|0;c[e>>2]=1;g=d+1|0;b3[c[14528+((a[g]&255)<<2)>>2]&511](b,g);g=b+12|0;if((c[e>>2]|0)==0){c[g>>2]=(c[g>>2]|0)+1;c[e>>2]=f;return}else{c[g>>2]=1;c[b+96>>2]=0;g=b+32|0;y=3822405;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;c[e>>2]=f;return}}function fo(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=4347219;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;e=hl(b,b+100|0,f,0)|0;zQ(b+164|0,c[15904+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function fp(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=4347219;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;e=hl(b,b+100|0,f,1)|0;zQ(b+164|0,c[15936+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function fq(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=4347219;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;zQ(b+100|0,c[15904+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=(hl(b,b+164|0,f,0)|0)+1;c[b+96>>2]=2;return}function fr(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=4347219;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;zQ(b+100|0,c[15936+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=(hl(b,b+164|0,f,1)|0)+1;c[b+96>>2]=2;return}function fs(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=2;c[b+96>>2]=2;g=b+32|0;y=4347219;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;g=b+100|0;a[g]=a[31608]|0;a[g+1|0]=a[31609|0]|0;a[g+2|0]=a[31610|0]|0;a1(b+164|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e+1|0]|0,x)|0)|0;i=f;return}function ft(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=3;c[b+96>>2]=2;g=b+32|0;y=4347219;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;g=b+100|0;a[g]=a[29888]|0;a[g+1|0]=a[29889|0]|0;a[g+2|0]=a[29890|0]|0;a1(b+164|0,26776,(x=i,i=i+8|0,c[x>>2]=(d[e+2|0]|0)<<8|(d[e+1|0]|0),x)|0)|0;i=f;return}function fu(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b+4|0;f=c[e>>2]|0;c[e>>2]=2;g=d+1|0;b3[c[14528+((a[g]&255)<<2)>>2]&511](b,g);g=b+12|0;if((c[e>>2]|0)==0){c[g>>2]=(c[g>>2]|0)+1;c[e>>2]=f;return}else{c[g>>2]=1;c[b+96>>2]=0;g=b+32|0;y=3822403;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;c[e>>2]=f;return}}function fv(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=5394264;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;e=hl(b,b+100|0,f,0)|0;zQ(b+164|0,c[15904+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function fw(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=5394264;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;e=hl(b,b+100|0,f,1)|0;zQ(b+164|0,c[15936+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function fx(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=5394264;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;zQ(b+100|0,c[15904+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=(hl(b,b+164|0,f,0)|0)+1;c[b+96>>2]=2;return}function fy(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=5394264;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;zQ(b+100|0,c[15936+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=(hl(b,b+164|0,f,1)|0)+1;c[b+96>>2]=2;return}function fz(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=2;c[b+96>>2]=2;g=b+32|0;y=5394264;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;g=b+100|0;a[g]=a[31608]|0;a[g+1|0]=a[31609|0]|0;a[g+2|0]=a[31610|0]|0;a1(b+164|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e+1|0]|0,x)|0)|0;i=f;return}function fA(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=3;c[b+96>>2]=2;g=b+32|0;y=5394264;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;g=b+100|0;a[g]=a[29888]|0;a[g+1|0]=a[29889|0]|0;a[g+2|0]=a[29890|0]|0;a1(b+164|0,26776,(x=i,i=i+8|0,c[x>>2]=(d[e+2|0]|0)<<8|(d[e+1|0]|0),x)|0)|0;i=f;return}function fB(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b+4|0;f=c[e>>2]|0;c[e>>2]=3;g=d+1|0;b3[c[14528+((a[g]&255)<<2)>>2]&511](b,g);g=b+12|0;if((c[e>>2]|0)==0){c[g>>2]=(c[g>>2]|0)+1;c[e>>2]=f;return}else{c[g>>2]=1;c[b+96>>2]=0;g=b+32|0;y=3822419;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;c[e>>2]=f;return}}function fC(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=5262659;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;e=hl(b,b+100|0,f,0)|0;zQ(b+164|0,c[15904+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function fD(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=5262659;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;e=hl(b,b+100|0,f,1)|0;zQ(b+164|0,c[15936+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function fE(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=5262659;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;zQ(b+100|0,c[15904+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=(hl(b,b+164|0,f,0)|0)+1;c[b+96>>2]=2;return}function fF(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=5262659;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;zQ(b+100|0,c[15936+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=(hl(b,b+164|0,f,1)|0)+1;c[b+96>>2]=2;return}function fG(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=2;c[b+96>>2]=2;g=b+32|0;y=5262659;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;g=b+100|0;a[g]=a[31608]|0;a[g+1|0]=a[31609|0]|0;a[g+2|0]=a[31610|0]|0;a1(b+164|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e+1|0]|0,x)|0)|0;i=f;return}function fH(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=3;c[b+96>>2]=2;g=b+32|0;y=5262659;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;g=b+100|0;a[g]=a[29888]|0;a[g+1|0]=a[29889|0]|0;a[g+2|0]=a[29890|0]|0;a1(b+164|0,26776,(x=i,i=i+8|0,c[x>>2]=(d[e+2|0]|0)<<8|(d[e+1|0]|0),x)|0)|0;i=f;return}function fI(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b+4|0;f=c[e>>2]|0;c[e>>2]=4;g=d+1|0;b3[c[14528+((a[g]&255)<<2)>>2]&511](b,g);g=b+12|0;if((c[e>>2]|0)==0){c[g>>2]=(c[g>>2]|0)+1;c[e>>2]=f;return}else{c[g>>2]=1;c[b+96>>2]=0;g=b+32|0;y=3822404;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;c[e>>2]=f;return}}function fJ(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;y=5263182;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;return}function fK(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;y=5718595;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;return}function fL(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;y=4478787;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;return}function fM(b,d){b=b|0;d=d|0;var e=0;c[b+12>>2]=1;c[b+96>>2]=1;e=b+32|0;y=4410953;a[e]=y&255;y=y>>8;a[e+1|0]=y&255;y=y>>8;a[e+2|0]=y&255;y=y>>8;a[e+3|0]=y&255;zQ(b+100|0,c[15936+((a[d]&7)<<2)>>2]|0)|0;return}function fN(b,d){b=b|0;d=d|0;var e=0;c[b+12>>2]=1;c[b+96>>2]=1;e=b+32|0;y=4408644;a[e]=y&255;y=y>>8;a[e+1|0]=y&255;y=y>>8;a[e+2|0]=y&255;y=y>>8;a[e+3|0]=y&255;zQ(b+100|0,c[15936+((a[d]&7)<<2)>>2]|0)|0;return}function fO(b,d){b=b|0;d=d|0;var e=0;c[b+12>>2]=1;c[b+96>>2]=1;e=b+32|0;a[e]=a[25072]|0;a[e+1|0]=a[25073|0]|0;a[e+2|0]=a[25074|0]|0;a[e+3|0]=a[25075|0]|0;a[e+4|0]=a[25076|0]|0;zQ(b+100|0,c[15936+((a[d]&7)<<2)>>2]|0)|0;return}function fP(b,d){b=b|0;d=d|0;var e=0;c[b+12>>2]=1;c[b+96>>2]=1;e=b+32|0;y=5263184;a[e]=y&255;y=y>>8;a[e+1|0]=y&255;y=y>>8;a[e+2|0]=y&255;y=y>>8;a[e+3|0]=y&255;zQ(b+100|0,c[15936+((a[d]&7)<<2)>>2]|0)|0;return}function fQ(b,d){b=b|0;d=d|0;d=b|0;c[d>>2]=c[d>>2]|1;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;a[d]=a[35240]|0;a[d+1|0]=a[35241|0]|0;a[d+2|0]=a[35242|0]|0;a[d+3|0]=a[35243|0]|0;a[d+4|0]=a[35244|0]|0;a[d+5|0]=a[35245|0]|0;return}function fR(b,d){b=b|0;d=d|0;d=b|0;c[d>>2]=c[d>>2]|1;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;a[d]=a[35528]|0;a[d+1|0]=a[35529|0]|0;a[d+2|0]=a[35530|0]|0;a[d+3|0]=a[35531|0]|0;a[d+4|0]=a[35532|0]|0;return}function fS(b,e){b=b|0;e=e|0;var f=0;f=b|0;c[f>>2]=c[f>>2]|1;f=b+32|0;a[f]=a[35592]|0;a[f+1|0]=a[35593|0]|0;a[f+2|0]=a[35594|0]|0;a[f+3|0]=a[35595|0]|0;a[f+4|0]=a[35596|0]|0;a[f+5|0]=a[35597|0]|0;f=e+1|0;zQ(b+100|0,c[15936+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=(hl(b,b+164|0,f,1)|0)+1;c[b+96>>2]=2;return}function fT(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=1;c[b+96>>2]=1;g=b+32|0;a[g]=a[35688]|0;a[g+1|0]=a[35689|0]|0;a[g+2|0]=a[35690|0]|0;a1(b+100|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e]|0,x)|0)|0;i=f;return}function fU(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=b+12|0;if((a[e+1|0]|0)==102){c[g>>2]=4;c[b+96>>2]=2;h=b+32|0;a[h]=a[35736]|0;a[h+1|0]=a[35737|0]|0;a[h+2|0]=a[35738|0]|0;a[h+3|0]=a[35739|0]|0;a[h+4|0]=a[35740|0]|0;h=b+100|0;j=d[e+2|0]|0;a1(h|0,26648,(x=i,i=i+8|0,c[x>>2]=j,x)|0)|0;j=b+164|0;h=d[e+3|0]|0;a1(j|0,26648,(x=i,i=i+8|0,c[x>>2]=h,x)|0)|0;i=f;return}else{c[g>>2]=1;c[b+96>>2]=1;g=b+32|0;a[g]=a[35688]|0;a[g+1|0]=a[35689|0]|0;a[g+2|0]=a[35690|0]|0;g=b+100|0;b=d[e]|0;a1(g|0,26648,(x=i,i=i+8|0,c[x>>2]=b,x)|0)|0;i=f;return}}function fV(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b|0;c[g>>2]=c[g>>2]|1;c[b+12>>2]=3;c[b+96>>2]=1;g=b+32|0;a[g]=a[25072]|0;a[g+1|0]=a[25073|0]|0;a[g+2|0]=a[25074|0]|0;a[g+3|0]=a[25075|0]|0;a[g+4|0]=a[25076|0]|0;a1(b+100|0,26776,(x=i,i=i+8|0,c[x>>2]=(d[e+2|0]|0)<<8|(d[e+1|0]|0),x)|0)|0;i=f;return}function fW(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b|0;c[f>>2]=c[f>>2]|1;c[b+12>>2]=2;c[b+96>>2]=1;f=b+32|0;a[f]=a[25072]|0;a[f+1|0]=a[25073|0]|0;a[f+2|0]=a[25074|0]|0;a[f+3|0]=a[25075|0]|0;a[f+4|0]=a[25076|0]|0;f=b+100|0;b=a[d+1|0]|0;d=b&255;if(b<<24>>24>-1){a1(f|0,39608,(x=i,i=i+8|0,c[x>>2]=d,x)|0)|0;i=e;return}else{b=-d&255;a1(f|0,39432,(x=i,i=i+8|0,c[x>>2]=b,x)|0)|0;i=e;return}}function fX(b,d){b=b|0;d=d|0;d=b|0;c[d>>2]=c[d>>2]|1;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;a[d]=a[35776]|0;a[d+1|0]=a[35777|0]|0;a[d+2|0]=a[35778|0]|0;a[d+3|0]=a[35779|0]|0;a[d+4|0]=a[35780|0]|0;return}function fY(b,d){b=b|0;d=d|0;d=b|0;c[d>>2]=c[d>>2]|1;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;a[d]=a[35816]|0;a[d+1|0]=a[35817|0]|0;a[d+2|0]=a[35818|0]|0;a[d+3|0]=a[35819|0]|0;a[d+4|0]=a[35820|0]|0;return}function fZ(b,d){b=b|0;d=d|0;d=b|0;c[d>>2]=c[d>>2]|1;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;a[d]=a[35912]|0;a[d+1|0]=a[35913|0]|0;a[d+2|0]=a[35914|0]|0;a[d+3|0]=a[35915|0]|0;a[d+4|0]=a[35916|0]|0;a[d+5|0]=a[35917|0]|0;return}function f_(b,d){b=b|0;d=d|0;d=b|0;c[d>>2]=c[d>>2]|1;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;a[d]=a[36864]|0;a[d+1|0]=a[36865|0]|0;a[d+2|0]=a[36866|0]|0;a[d+3|0]=a[36867|0]|0;a[d+4|0]=a[36868|0]|0;a[d+5|0]=a[36869|0]|0;return}function f$(b,f){b=b|0;f=f|0;var g=0,h=0,j=0;g=i;c[b+12>>2]=2;c[b+96>>2]=1;h=d[f+1|0]|0;j=(e[b+8>>1]|0)+2+((h&128|0)!=0?h|65280:h)|0;zQ(b+32|0,c[16296+((a[f]&15)<<2)>>2]|0)|0;a1(b+100|0,26776,(x=i,i=i+8|0,c[x>>2]=j&65535,x)|0)|0;i=g;return}function f0(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;e=i;f=b+1|0;zQ(a+32|0,c[16232+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;g=hl(a,a+100|0,f,0)|0;a1(a+164|0,26648,(x=i,i=i+8|0,c[x>>2]=d[b+(g+1)|0]|0,x)|0)|0;c[a+12>>2]=g+2;c[a+96>>2]=2;i=e;return}function f1(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;e=i;f=b+1|0;zQ(a+32|0,c[16232+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;g=hl(a,a+100|0,f,1)|0;a1(a+164|0,26776,(x=i,i=i+8|0,c[x>>2]=(d[b+(g+2)|0]|0)<<8|(d[b+(g+1)|0]|0),x)|0)|0;c[a+12>>2]=g+3;c[a+96>>2]=2;i=e;return}function f2(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;g=e+1|0;zQ(b+32|0,c[16232+(((d[g]|0)>>>3&7)<<2)>>2]|0)|0;h=hl(b,b+100|0,g,1)|0;g=b+164|0;j=a[e+(h+1)|0]|0;e=j&255;if(j<<24>>24>-1){a1(g|0,39608,(x=i,i=i+8|0,c[x>>2]=e,x)|0)|0;k=h+2|0;l=b+12|0;c[l>>2]=k;m=b+96|0;c[m>>2]=2;i=f;return}else{j=-e&255;a1(g|0,39432,(x=i,i=i+8|0,c[x>>2]=j,x)|0)|0;k=h+2|0;l=b+12|0;c[l>>2]=k;m=b+96|0;c[m>>2]=2;i=f;return}}function f3(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;a[f]=a[28048]|0;a[f+1|0]=a[28049|0]|0;a[f+2|0]=a[28050|0]|0;a[f+3|0]=a[28051|0]|0;a[f+4|0]=a[28052|0]|0;f=e+1|0;e=hl(b,b+100|0,f,0)|0;zQ(b+164|0,c[15904+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function f4(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;a[f]=a[28048]|0;a[f+1|0]=a[28049|0]|0;a[f+2|0]=a[28050|0]|0;a[f+3|0]=a[28051|0]|0;a[f+4|0]=a[28052|0]|0;f=e+1|0;e=hl(b,b+100|0,f,1)|0;zQ(b+164|0,c[15936+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function f5(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;a[f]=a[40904]|0;a[f+1|0]=a[40905|0]|0;a[f+2|0]=a[40906|0]|0;a[f+3|0]=a[40907|0]|0;a[f+4|0]=a[40908|0]|0;f=e+1|0;e=hl(b,b+100|0,f,0)|0;zQ(b+164|0,c[15904+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function f6(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;a[f]=a[40904]|0;a[f+1|0]=a[40905|0]|0;a[f+2|0]=a[40906|0]|0;a[f+3|0]=a[40907|0]|0;a[f+4|0]=a[40908|0]|0;f=e+1|0;e=hl(b,b+100|0,f,1)|0;zQ(b+164|0,c[15936+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function f7(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=5656397;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;e=hl(b,b+100|0,f,0)|0;zQ(b+164|0,c[15904+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function f8(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=5656397;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;e=hl(b,b+100|0,f,1)|0;zQ(b+164|0,c[15936+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function f9(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=5656397;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;zQ(b+100|0,c[15904+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=(hl(b,b+164|0,f,0)|0)+1;c[b+96>>2]=2;return}function ga(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=5656397;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;zQ(b+100|0,c[15936+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=(hl(b,b+164|0,f,1)|0)+1;c[b+96>>2]=2;return}function gb(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=5656397;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;e=hl(b,b+100|0,f,1)|0;zQ(b+164|0,c[15864+(((d[f]|0)>>>3&3)<<2)>>2]|0)|0;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function gc(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=4277580;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;zQ(b+100|0,c[15936+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=(hl(b,b+164|0,f,1)|0)+1;c[b+96>>2]=2;return}function gd(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=5656397;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;zQ(b+100|0,c[15864+(((d[f]|0)>>>3&3)<<2)>>2]|0)|0;c[b+12>>2]=(hl(b,b+164|0,f,1)|0)+1;c[b+96>>2]=2;return}function ge(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;y=5263184;a[e]=y&255;y=y>>8;a[e+1|0]=y&255;y=y>>8;a[e+2|0]=y&255;y=y>>8;a[e+3|0]=y&255;c[b+12>>2]=(hl(b,b+100|0,d+1|0,1)|0)+1;c[b+96>>2]=1;return}function gf(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[40904]|0;a[e+1|0]=a[40905|0]|0;a[e+2|0]=a[40906|0]|0;a[e+3|0]=a[40907|0]|0;a[e+4|0]=a[40908|0]|0;e=b+100|0;a[e]=a[29888]|0;a[e+1|0]=a[29889|0]|0;a[e+2|0]=a[29890|0]|0;zQ(b+164|0,c[15936+((a[d]&7)<<2)>>2]|0)|0;c[b+12>>2]=1;c[b+96>>2]=2;return}function gg(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b|0;c[g>>2]=c[g>>2]|256;c[b+12>>2]=5;c[b+96>>2]=1;g=b+32|0;a[g]=a[31888]|0;a[g+1|0]=a[31889|0]|0;a[g+2|0]=a[31890|0]|0;a[g+3|0]=a[31891|0]|0;a[g+4|0]=a[31892|0]|0;g=(d[e+2|0]|0)<<8|(d[e+1|0]|0);a1(b+100|0,25288,(x=i,i=i+16|0,c[x>>2]=(d[e+4|0]|0)<<8|(d[e+3|0]|0),c[x+8>>2]=g,x)|0)|0;i=f;return}function gh(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;a[d]=a[41168]|0;a[d+1|0]=a[41169|0]|0;a[d+2|0]=a[41170|0]|0;a[d+3|0]=a[41171|0]|0;a[d+4|0]=a[41172|0]|0;return}function gi(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;a[d]=a[41256]|0;a[d+1|0]=a[41257|0]|0;a[d+2|0]=a[41258|0]|0;a[d+3|0]=a[41259|0]|0;a[d+4|0]=a[41260|0]|0;a[d+5|0]=a[41261|0]|0;return}function gj(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;a[d]=a[41392]|0;a[d+1|0]=a[41393|0]|0;a[d+2|0]=a[41394|0]|0;a[d+3|0]=a[41395|0]|0;a[d+4|0]=a[41396|0]|0;return}function gk(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;a[d]=a[41440]|0;a[d+1|0]=a[41441|0]|0;a[d+2|0]=a[41442|0]|0;a[d+3|0]=a[41443|0]|0;a[d+4|0]=a[41444|0]|0;return}function gl(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;a[d]=a[41624]|0;a[d+1|0]=a[41625|0]|0;a[d+2|0]=a[41626|0]|0;a[d+3|0]=a[41627|0]|0;a[d+4|0]=a[41628|0]|0;return}function gm(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;c[b+12>>2]=3;c[b+96>>2]=2;g=b+32|0;y=5656397;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;g=b+100|0;a[g]=a[31608]|0;a[g+1|0]=a[31609|0]|0;a[g+2|0]=a[31610|0]|0;g=b+4|0;h=(d[e+2|0]|0)<<8|(d[e+1|0]|0);a1(b+164|0,21112,(x=i,i=i+16|0,c[x>>2]=c[15880+(c[g>>2]<<2)>>2],c[x+8>>2]=h,x)|0)|0;c[g>>2]=0;i=f;return}function gn(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;c[b+12>>2]=3;c[b+96>>2]=2;g=b+32|0;y=5656397;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;g=b+100|0;a[g]=a[29888]|0;a[g+1|0]=a[29889|0]|0;a[g+2|0]=a[29890|0]|0;g=b+4|0;h=(d[e+2|0]|0)<<8|(d[e+1|0]|0);a1(b+164|0,21112,(x=i,i=i+16|0,c[x>>2]=c[15880+(c[g>>2]<<2)>>2],c[x+8>>2]=h,x)|0)|0;c[g>>2]=0;i=f;return}function go(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;c[b+12>>2]=3;c[b+96>>2]=2;g=b+32|0;y=5656397;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;g=b+4|0;h=(d[e+2|0]|0)<<8|(d[e+1|0]|0);a1(b+100|0,21112,(x=i,i=i+16|0,c[x>>2]=c[15880+(c[g>>2]<<2)>>2],c[x+8>>2]=h,x)|0)|0;c[g>>2]=0;g=b+164|0;a[g]=a[31608]|0;a[g+1|0]=a[31609|0]|0;a[g+2|0]=a[31610|0]|0;i=f;return}function gp(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;c[b+12>>2]=3;c[b+96>>2]=2;g=b+32|0;y=5656397;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;g=b+4|0;h=(d[e+2|0]|0)<<8|(d[e+1|0]|0);a1(b+100|0,21112,(x=i,i=i+16|0,c[x>>2]=c[15880+(c[g>>2]<<2)>>2],c[x+8>>2]=h,x)|0)|0;c[g>>2]=0;g=b+164|0;a[g]=a[29888]|0;a[g+1|0]=a[29889|0]|0;a[g+2|0]=a[29890|0]|0;i=f;return}function gq(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;d=i;c[b+12>>2]=1;e=b+96|0;c[e>>2]=0;f=b+32|0;a[f]=a[41808]|0;a[f+1|0]=a[41809|0]|0;a[f+2|0]=a[41810|0]|0;a[f+3|0]=a[41811|0]|0;a[f+4|0]=a[41812|0]|0;a[f+5|0]=a[41813|0]|0;f=b+4|0;g=c[f>>2]|0;if((g|0)==0){i=d;return}h=b+100|0;j=h|0;y=978535771;a[j]=y&255;y=y>>8;a[j+1|0]=y&255;y=y>>8;a[j+2|0]=y&255;y=y>>8;a[j+3|0]=y&255;j=h+4|0;y=6113604;a[j]=y&255;y=y>>8;a[j+1|0]=y&255;y=y>>8;a[j+2|0]=y&255;y=y>>8;a[j+3|0]=y&255;a1(b+164|0,41192,(x=i,i=i+16|0,c[x>>2]=c[15880+(g<<2)>>2],c[x+8>>2]=32080,x)|0)|0;c[e>>2]=2;c[f>>2]=0;i=d;return}function gr(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;d=i;c[b+12>>2]=1;e=b+96|0;c[e>>2]=0;f=b+32|0;a[f]=a[20664]|0;a[f+1|0]=a[20665|0]|0;a[f+2|0]=a[20666|0]|0;a[f+3|0]=a[20667|0]|0;a[f+4|0]=a[20668|0]|0;a[f+5|0]=a[20669|0]|0;f=b+4|0;g=c[f>>2]|0;if((g|0)==0){i=d;return}h=b+100|0;j=h|0;y=978535771;a[j]=y&255;y=y>>8;a[j+1|0]=y&255;y=y>>8;a[j+2|0]=y&255;y=y>>8;a[j+3|0]=y&255;j=h+4|0;y=6113604;a[j]=y&255;y=y>>8;a[j+1|0]=y&255;y=y>>8;a[j+2|0]=y&255;y=y>>8;a[j+3|0]=y&255;a1(b+164|0,41192,(x=i,i=i+16|0,c[x>>2]=c[15880+(g<<2)>>2],c[x+8>>2]=32080,x)|0)|0;c[e>>2]=2;c[f>>2]=0;i=d;return}function gs(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;d=i;c[b+12>>2]=1;e=b+96|0;c[e>>2]=0;f=b+32|0;a[f]=a[20816]|0;a[f+1|0]=a[20817|0]|0;a[f+2|0]=a[20818|0]|0;a[f+3|0]=a[20819|0]|0;a[f+4|0]=a[20820|0]|0;a[f+5|0]=a[20821|0]|0;f=b+4|0;g=c[f>>2]|0;if((g|0)==0){i=d;return}h=b+100|0;j=h|0;y=978535771;a[j]=y&255;y=y>>8;a[j+1|0]=y&255;y=y>>8;a[j+2|0]=y&255;y=y>>8;a[j+3|0]=y&255;j=h+4|0;y=6113604;a[j]=y&255;y=y>>8;a[j+1|0]=y&255;y=y>>8;a[j+2|0]=y&255;y=y>>8;a[j+3|0]=y&255;a1(b+164|0,41192,(x=i,i=i+16|0,c[x>>2]=c[15880+(g<<2)>>2],c[x+8>>2]=32080,x)|0)|0;c[e>>2]=2;c[f>>2]=0;i=d;return}function gt(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;d=i;c[b+12>>2]=1;e=b+96|0;c[e>>2]=0;f=b+32|0;a[f]=a[21024]|0;a[f+1|0]=a[21025|0]|0;a[f+2|0]=a[21026|0]|0;a[f+3|0]=a[21027|0]|0;a[f+4|0]=a[21028|0]|0;a[f+5|0]=a[21029|0]|0;f=b+4|0;g=c[f>>2]|0;if((g|0)==0){i=d;return}h=b+100|0;j=h|0;y=978535771;a[j]=y&255;y=y>>8;a[j+1|0]=y&255;y=y>>8;a[j+2|0]=y&255;y=y>>8;a[j+3|0]=y&255;j=h+4|0;y=6113604;a[j]=y&255;y=y>>8;a[j+1|0]=y&255;y=y>>8;a[j+2|0]=y&255;y=y>>8;a[j+3|0]=y&255;a1(b+164|0,41192,(x=i,i=i+16|0,c[x>>2]=c[15880+(g<<2)>>2],c[x+8>>2]=32080,x)|0)|0;c[e>>2]=2;c[f>>2]=0;i=d;return}function gu(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;y=5524552;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;return}function gv(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;y=4410691;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;return}function gw(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=2;c[b+96>>2]=2;g=b+32|0;a[g]=a[28048]|0;a[g+1|0]=a[28049|0]|0;a[g+2|0]=a[28050|0]|0;a[g+3|0]=a[28051|0]|0;a[g+4|0]=a[28052|0]|0;g=b+100|0;a[g]=a[31608]|0;a[g+1|0]=a[31609|0]|0;a[g+2|0]=a[31610|0]|0;a1(b+164|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e+1|0]|0,x)|0)|0;i=f;return}function gx(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=3;c[b+96>>2]=2;g=b+32|0;a[g]=a[28048]|0;a[g+1|0]=a[28049|0]|0;a[g+2|0]=a[28050|0]|0;a[g+3|0]=a[28051|0]|0;a[g+4|0]=a[28052|0]|0;g=b+100|0;a[g]=a[29888]|0;a[g+1|0]=a[29889|0]|0;a[g+2|0]=a[29890|0]|0;a1(b+164|0,26776,(x=i,i=i+8|0,c[x>>2]=(d[e+2|0]|0)<<8|(d[e+1|0]|0),x)|0)|0;i=f;return}function gy(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;a[d]=a[21088]|0;a[d+1|0]=a[21089|0]|0;a[d+2|0]=a[21090|0]|0;a[d+3|0]=a[21091|0]|0;a[d+4|0]=a[21092|0]|0;a[d+5|0]=a[21093|0]|0;return}function gz(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;a[d]=a[21176]|0;a[d+1|0]=a[21177|0]|0;a[d+2|0]=a[21178|0]|0;a[d+3|0]=a[21179|0]|0;a[d+4|0]=a[21180|0]|0;a[d+5|0]=a[21181|0]|0;return}function gA(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;d=i;c[b+12>>2]=1;e=b+96|0;c[e>>2]=0;f=b+32|0;a[f]=a[21256]|0;a[f+1|0]=a[21257|0]|0;a[f+2|0]=a[21258|0]|0;a[f+3|0]=a[21259|0]|0;a[f+4|0]=a[21260|0]|0;a[f+5|0]=a[21261|0]|0;f=b+4|0;g=c[f>>2]|0;if((g|0)==0){i=d;return}a1(b+100|0,41192,(x=i,i=i+16|0,c[x>>2]=c[15880+(g<<2)>>2],c[x+8>>2]=32080,x)|0)|0;c[e>>2]=1;c[f>>2]=0;i=d;return}function gB(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;d=i;c[b+12>>2]=1;e=b+96|0;c[e>>2]=0;f=b+32|0;a[f]=a[21344]|0;a[f+1|0]=a[21345|0]|0;a[f+2|0]=a[21346|0]|0;a[f+3|0]=a[21347|0]|0;a[f+4|0]=a[21348|0]|0;a[f+5|0]=a[21349|0]|0;f=b+4|0;g=c[f>>2]|0;if((g|0)==0){i=d;return}a1(b+100|0,41192,(x=i,i=i+16|0,c[x>>2]=c[15880+(g<<2)>>2],c[x+8>>2]=32080,x)|0)|0;c[e>>2]=1;c[f>>2]=0;i=d;return}function gC(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;a[d]=a[21544]|0;a[d+1|0]=a[21545|0]|0;a[d+2|0]=a[21546|0]|0;a[d+3|0]=a[21547|0]|0;a[d+4|0]=a[21548|0]|0;a[d+5|0]=a[21549|0]|0;return}function gD(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;a[d]=a[21784]|0;a[d+1|0]=a[21785|0]|0;a[d+2|0]=a[21786|0]|0;a[d+3|0]=a[21787|0]|0;a[d+4|0]=a[21788|0]|0;a[d+5|0]=a[21789|0]|0;return}function gE(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=2;c[b+96>>2]=2;g=b+32|0;y=5656397;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;zQ(b+100|0,c[15904+((a[e]&7)<<2)>>2]|0)|0;a1(b+164|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e+1|0]|0,x)|0)|0;i=f;return}function gF(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=3;c[b+96>>2]=2;g=b+32|0;y=5656397;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;zQ(b+100|0,c[15936+((a[e]&7)<<2)>>2]|0)|0;a1(b+164|0,26776,(x=i,i=i+8|0,c[x>>2]=(d[e+2|0]|0)<<8|(d[e+1|0]|0),x)|0)|0;i=f;return}function gG(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;e=i;f=a|0;c[f>>2]=c[f>>2]|1;f=b+1|0;zQ(a+32|0,c[16200+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;g=hl(a,a+100|0,f,0)|0;a1(a+164|0,26648,(x=i,i=i+8|0,c[x>>2]=d[b+(g+1)|0]|0,x)|0)|0;c[a+12>>2]=g+2;c[a+96>>2]=2;i=e;return}function gH(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;e=i;f=a|0;c[f>>2]=c[f>>2]|1;f=b+1|0;zQ(a+32|0,c[16200+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;g=hl(a,a+100|0,f,1)|0;a1(a+164|0,26648,(x=i,i=i+8|0,c[x>>2]=d[b+(g+1)|0]|0,x)|0)|0;c[a+12>>2]=g+2;c[a+96>>2]=2;i=e;return}function gI(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=3;c[b+96>>2]=1;g=b+32|0;a[g]=a[21872]|0;a[g+1|0]=a[21873|0]|0;a[g+2|0]=a[21874|0]|0;a[g+3|0]=a[21875|0]|0;a[g+4|0]=a[21876|0]|0;a1(b+100|0,26776,(x=i,i=i+8|0,c[x>>2]=(d[e+2|0]|0)<<8|(d[e+1|0]|0),x)|0)|0;i=f;return}function gJ(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;a[d]=a[21872]|0;a[d+1|0]=a[21873|0]|0;a[d+2|0]=a[21874|0]|0;a[d+3|0]=a[21875|0]|0;a[d+4|0]=a[21876|0]|0;return}function gK(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=5457228;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;zQ(b+100|0,c[15936+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=(hl(b,b+164|0,f,1)|0)+1;c[b+96>>2]=2;return}function gL(b,e){b=b|0;e=e|0;var f=0;f=b+32|0;y=5456972;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;f=e+1|0;zQ(b+100|0,c[15936+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;c[b+12>>2]=(hl(b,b+164|0,f,1)|0)+1;c[b+96>>2]=2;return}function gM(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;g=b+32|0;y=5656397;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;g=hl(b,b+100|0,e+1|0,0)|0;h=b+12|0;c[h>>2]=g;a1(b+164|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e+(g+1)|0]|0,x)|0)|0;c[h>>2]=(c[h>>2]|0)+2;c[b+96>>2]=2;i=f;return}function gN(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;g=b+32|0;y=5656397;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;g=hl(b,b+100|0,e+1|0,1)|0;h=b+12|0;c[h>>2]=g;a1(b+164|0,26776,(x=i,i=i+8|0,c[x>>2]=(d[e+(g+2)|0]|0)<<8|(d[e+(g+1)|0]|0),x)|0)|0;c[h>>2]=(c[h>>2]|0)+3;c[b+96>>2]=2;i=f;return}function gO(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b|0;c[g>>2]=c[g>>2]|1;g=b+32|0;a[g]=a[22152]|0;a[g+1|0]=a[22153|0]|0;a[g+2|0]=a[22154|0]|0;a[g+3|0]=a[22155|0]|0;a[g+4|0]=a[22156|0]|0;a[g+5|0]=a[22157|0]|0;a1(b+100|0,26776,(x=i,i=i+8|0,c[x>>2]=(d[e+2|0]|0)<<8|(d[e+1|0]|0),x)|0)|0;a1(b+164|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e+3|0]|0,x)|0)|0;c[b+12>>2]=4;c[b+96>>2]=2;i=f;return}function gP(b,d){b=b|0;d=d|0;d=b|0;c[d>>2]=c[d>>2]|1;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;a[d]=a[22312]|0;a[d+1|0]=a[22313|0]|0;a[d+2|0]=a[22314|0]|0;a[d+3|0]=a[22315|0]|0;a[d+4|0]=a[22316|0]|0;a[d+5|0]=a[22317|0]|0;return}function gQ(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=3;c[b+96>>2]=1;g=b+32|0;a[g]=a[22448]|0;a[g+1|0]=a[22449|0]|0;a[g+2|0]=a[22450|0]|0;a[g+3|0]=a[22451|0]|0;a[g+4|0]=a[22452|0]|0;a1(b+100|0,26776,(x=i,i=i+8|0,c[x>>2]=(d[e+2|0]|0)<<8|(d[e+1|0]|0),x)|0)|0;i=f;return}function gR(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;a[d]=a[22448]|0;a[d+1|0]=a[22449|0]|0;a[d+2|0]=a[22450|0]|0;a[d+3|0]=a[22451|0]|0;a[d+4|0]=a[22452|0]|0;return}function gS(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;a[d]=a[22504]|0;a[d+1|0]=a[22505|0]|0;a[d+2|0]=a[22506|0]|0;a[d+3|0]=a[22507|0]|0;a[d+4|0]=a[22508|0]|0;d=b|0;c[d>>2]=c[d>>2]|256;return}function gT(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b|0;c[g>>2]=c[g>>2]|256;c[b+12>>2]=2;c[b+96>>2]=1;g=b+32|0;y=5525065;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;a1(b+100|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e+1|0]|0,x)|0)|0;i=f;return}function gU(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;a[d]=a[23080]|0;a[d+1|0]=a[23081|0]|0;a[d+2|0]=a[23082|0]|0;a[d+3|0]=a[23083|0]|0;a[d+4|0]=a[23084|0]|0;d=b|0;c[d>>2]=c[d>>2]|256;return}function gV(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;a[d]=a[23152]|0;a[d+1|0]=a[23153|0]|0;a[d+2|0]=a[23154|0]|0;a[d+3|0]=a[23155|0]|0;a[d+4|0]=a[23156|0]|0;return}function gW(b,e){b=b|0;e=e|0;var f=0;f=e+1|0;zQ(b+32|0,c[16200+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;e=hl(b,b+100|0,f,0)|0;f=b+164|0;y=49;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function gX(b,e){b=b|0;e=e|0;var f=0;f=e+1|0;zQ(b+32|0,c[16200+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;e=hl(b,b+100|0,f,1)|0;f=b+164|0;y=49;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function gY(b,e){b=b|0;e=e|0;var f=0;f=e+1|0;zQ(b+32|0,c[16200+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;e=hl(b,b+100|0,f,0)|0;f=b+164|0;a[f]=a[31432]|0;a[f+1|0]=a[31433|0]|0;a[f+2|0]=a[31434|0]|0;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function gZ(b,e){b=b|0;e=e|0;var f=0;f=e+1|0;zQ(b+32|0,c[16200+(((d[f]|0)>>>3&7)<<2)>>2]|0)|0;e=hl(b,b+100|0,f,1)|0;f=b+164|0;a[f]=a[31432]|0;a[f+1|0]=a[31433|0]|0;a[f+2|0]=a[31434|0]|0;c[b+12>>2]=e+1;c[b+96>>2]=2;return}function g_(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;y=5062977;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;a1(b+100|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e+1|0]|0,x)|0)|0;c[b+12>>2]=2;c[b+96>>2]=1;i=f;return}function g$(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=0;d=b+32|0;a[d]=a[24792]|0;a[d+1|0]=a[24793|0]|0;a[d+2|0]=a[24794|0]|0;a[d+3|0]=a[24795|0]|0;a[d+4|0]=a[24796|0]|0;return}function g0(a,b){a=a|0;b=b|0;var f=0,g=0,h=0;f=i;g=a|0;c[g>>2]=c[g>>2]|512;c[a+12>>2]=2;c[a+96>>2]=1;g=d[b+1|0]|0;h=(e[a+8>>1]|0)+2+((g&128|0)!=0?g|65280:g)|0;zQ(a+32|0,c[16184+((d[b]|0)-224<<2)>>2]|0)|0;a1(a+100|0,26776,(x=i,i=i+8|0,c[x>>2]=h&65535,x)|0)|0;i=f;return}function g1(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=2;c[b+96>>2]=2;g=b+32|0;a[g]=a[25840]|0;a[g+1|0]=a[25841|0]|0;a[g+2|0]=a[25842|0]|0;g=b+100|0;a[g]=a[31608]|0;a[g+1|0]=a[31609|0]|0;a[g+2|0]=a[31610|0]|0;a1(b+164|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e+1|0]|0,x)|0)|0;i=f;return}function g2(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=2;c[b+96>>2]=2;g=b+32|0;a[g]=a[25840]|0;a[g+1|0]=a[25841|0]|0;a[g+2|0]=a[25842|0]|0;g=b+100|0;a[g]=a[29888]|0;a[g+1|0]=a[29889|0]|0;a[g+2|0]=a[29890|0]|0;a1(b+164|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e+1|0]|0,x)|0)|0;i=f;return}function g3(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=2;c[b+96>>2]=2;g=b+32|0;y=5526863;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;a1(b+100|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e+1|0]|0,x)|0)|0;e=b+164|0;a[e]=a[31608]|0;a[e+1|0]=a[31609|0]|0;a[e+2|0]=a[31610|0]|0;i=f;return}function g4(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=2;c[b+96>>2]=2;g=b+32|0;y=5526863;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;a1(b+100|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e+1|0]|0,x)|0)|0;e=b+164|0;a[e]=a[29888]|0;a[e+1|0]=a[29889|0]|0;a[e+2|0]=a[29890|0]|0;i=f;return}function g5(e,f){e=e|0;f=f|0;var g=0,h=0;g=i;h=e|0;c[h>>2]=c[h>>2]|256;c[e+12>>2]=3;c[e+96>>2]=1;h=((b[e+8>>1]|0)+3&65535)+((d[f+2|0]|0)<<8|(d[f+1|0]|0))&65535;f=e+32|0;a[f]=a[31888]|0;a[f+1|0]=a[31889|0]|0;a[f+2|0]=a[31890|0]|0;a[f+3|0]=a[31891|0]|0;a[f+4|0]=a[31892|0]|0;a1(e+100|0,26776,(x=i,i=i+8|0,c[x>>2]=h&65535,x)|0)|0;i=g;return}function g6(e,f){e=e|0;f=f|0;var g=0,h=0;g=i;c[e+12>>2]=3;c[e+96>>2]=1;h=((b[e+8>>1]|0)+3&65535)+((d[f+2|0]|0)<<8|(d[f+1|0]|0))&65535;f=e+32|0;a[f]=a[25200]|0;a[f+1|0]=a[25201|0]|0;a[f+2|0]=a[25202|0]|0;a[f+3|0]=a[25203|0]|0;a[f+4|0]=a[25204|0]|0;a1(e+100|0,26776,(x=i,i=i+8|0,c[x>>2]=h&65535,x)|0)|0;i=g;return}function g7(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;c[b+12>>2]=5;c[b+96>>2]=1;g=b+32|0;a[g]=a[26488]|0;a[g+1|0]=a[26489|0]|0;a[g+2|0]=a[26490|0]|0;a[g+3|0]=a[26491|0]|0;a[g+4|0]=a[26492|0]|0;g=(d[e+2|0]|0)<<8|(d[e+1|0]|0);a1(b+100|0,25288,(x=i,i=i+16|0,c[x>>2]=(d[e+4|0]|0)<<8|(d[e+3|0]|0),c[x+8>>2]=g,x)|0)|0;i=f;return}function g8(b,f){b=b|0;f=f|0;var g=0,h=0;g=i;c[b+12>>2]=2;c[b+96>>2]=1;h=d[f+1|0]|0;f=(e[b+8>>1]|0)+2+((h&128|0)!=0?h|65280:h)|0;h=b+32|0;a[h]=a[25496]|0;a[h+1|0]=a[25497|0]|0;a[h+2|0]=a[25498|0]|0;a[h+3|0]=a[25499|0]|0;a[h+4|0]=a[25500|0]|0;a1(b+100|0,26776,(x=i,i=i+8|0,c[x>>2]=f&65535,x)|0)|0;i=g;return}function g9(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=2;d=b+32|0;a[d]=a[25840]|0;a[d+1|0]=a[25841|0]|0;a[d+2|0]=a[25842|0]|0;d=b+100|0;a[d]=a[31608]|0;a[d+1|0]=a[31609|0]|0;a[d+2|0]=a[31610|0]|0;d=b+164|0;a[d]=a[29600]|0;a[d+1|0]=a[29601|0]|0;a[d+2|0]=a[29602|0]|0;return}function ha(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=2;d=b+32|0;a[d]=a[25840]|0;a[d+1|0]=a[25841|0]|0;a[d+2|0]=a[25842|0]|0;d=b+100|0;a[d]=a[29888]|0;a[d+1|0]=a[29889|0]|0;a[d+2|0]=a[29890|0]|0;d=b+164|0;a[d]=a[29600]|0;a[d+1|0]=a[29601|0]|0;a[d+2|0]=a[29602|0]|0;return}function hb(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=2;d=b+32|0;y=5526863;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;d=b+100|0;a[d]=a[29600]|0;a[d+1|0]=a[29601|0]|0;a[d+2|0]=a[29602|0]|0;d=b+164|0;a[d]=a[31608]|0;a[d+1|0]=a[31609|0]|0;a[d+2|0]=a[31610|0]|0;return}function hc(b,d){b=b|0;d=d|0;c[b+12>>2]=1;c[b+96>>2]=2;d=b+32|0;y=5526863;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;d=b+100|0;a[d]=a[29600]|0;a[d+1|0]=a[29601|0]|0;a[d+2|0]=a[29602|0]|0;d=b+164|0;a[d]=a[29888]|0;a[d+1|0]=a[29889|0]|0;a[d+2|0]=a[29890|0]|0;return}function hd(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+256|0;f=e|0;g=d+1|0;c[b>>2]=0;c[b+4>>2]=0;b3[c[14528+((a[g]&255)<<2)>>2]&511](b,g);g=b+12|0;if((c[g>>2]|0)!=0){h=0;while(1){j=h+1|0;a[b+16+h|0]=a[d+j|0]|0;if(j>>>0<(c[g>>2]|0)>>>0){h=j}else{break}}}h=f|0;f=b+32|0;zQ(h|0,f|0)|0;a[f]=a[26128]|0;a[f+1|0]=a[26129|0]|0;a[f+2|0]=a[26130|0]|0;a[f+3|0]=a[26131|0]|0;a[f+4|0]=a[26132|0]|0;a[f+5|0]=a[26133|0]|0;zR(f|0,h|0)|0;c[g>>2]=(c[g>>2]|0)+1;i=e;return}function he(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+256|0;f=e|0;g=d+1|0;c[b>>2]=0;c[b+4>>2]=0;b3[c[14528+((a[g]&255)<<2)>>2]&511](b,g);g=b+12|0;if((c[g>>2]|0)!=0){h=0;while(1){j=h+1|0;a[b+16+h|0]=a[d+j|0]|0;if(j>>>0<(c[g>>2]|0)>>>0){h=j}else{break}}}h=f|0;f=b+32|0;zQ(h|0,f|0)|0;a[f]=a[26208]|0;a[f+1|0]=a[26209|0]|0;a[f+2|0]=a[26210|0]|0;a[f+3|0]=a[26211|0]|0;a[f+4|0]=a[26212|0]|0;a[f+5|0]=a[26213|0]|0;a[f+6|0]=a[26214|0]|0;zR(f|0,h|0)|0;c[g>>2]=(c[g>>2]|0)+1;i=e;return}function hf(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+256|0;f=e|0;g=d+1|0;c[b>>2]=0;c[b+4>>2]=0;b3[c[14528+((a[g]&255)<<2)>>2]&511](b,g);g=b+12|0;if((c[g>>2]|0)!=0){h=0;while(1){j=h+1|0;a[b+16+h|0]=a[d+j|0]|0;if(j>>>0<(c[g>>2]|0)>>>0){h=j}else{break}}}h=f|0;f=b+32|0;zQ(h|0,f|0)|0;a[f]=a[26288]|0;a[f+1|0]=a[26289|0]|0;a[f+2|0]=a[26290|0]|0;a[f+3|0]=a[26291|0]|0;a[f+4|0]=a[26292|0]|0;zR(f|0,h|0)|0;c[g>>2]=(c[g>>2]|0)+1;i=e;return}function hg(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=e+1|0;h=(d[g]|0)>>>3&7;if((h|0)==7){j=b+32|0;a[j]=a[27072]|0;a[j+1|0]=a[27073|0]|0;a[j+2|0]=a[27074|0]|0;a[j+3|0]=a[27075|0]|0;a[j+4|0]=a[27076|0]|0;c[b+12>>2]=(hl(b,b+100|0,g,0)|0)+1;c[b+96>>2]=1;i=f;return}else if((h|0)==6){j=b+32|0;y=5654852;a[j]=y&255;y=y>>8;a[j+1|0]=y&255;y=y>>8;a[j+2|0]=y&255;y=y>>8;a[j+3|0]=y&255;c[b+12>>2]=(hl(b,b+100|0,g,0)|0)+1;c[b+96>>2]=1;i=f;return}else if((h|0)==5){j=b+32|0;a[j]=a[27552]|0;a[j+1|0]=a[27553|0]|0;a[j+2|0]=a[27554|0]|0;a[j+3|0]=a[27555|0]|0;a[j+4|0]=a[27556|0]|0;c[b+12>>2]=(hl(b,b+100|0,g,0)|0)+1;c[b+96>>2]=1;i=f;return}else if((h|0)==3){j=b+32|0;y=4670798;a[j]=y&255;y=y>>8;a[j+1|0]=y&255;y=y>>8;a[j+2|0]=y&255;y=y>>8;a[j+3|0]=y&255;c[b+12>>2]=(hl(b,b+100|0,g,0)|0)+1;c[b+96>>2]=1;i=f;return}else if((h|0)==2){j=b+32|0;y=5525326;a[j]=y&255;y=y>>8;a[j+1|0]=y&255;y=y>>8;a[j+2|0]=y&255;y=y>>8;a[j+3|0]=y&255;c[b+12>>2]=(hl(b,b+100|0,g,0)|0)+1;c[b+96>>2]=1;i=f;return}else if((h|0)==1){c[b+12>>2]=1;c[b+96>>2]=1;j=b+32|0;a[j]=a[35688]|0;a[j+1|0]=a[35689|0]|0;a[j+2|0]=a[35690|0]|0;a1(b+100|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e]|0,x)|0)|0;i=f;return}else if((h|0)==0){j=b+32|0;a[j]=a[28048]|0;a[j+1|0]=a[28049|0]|0;a[j+2|0]=a[28050|0]|0;a[j+3|0]=a[28051|0]|0;a[j+4|0]=a[28052|0]|0;j=hl(b,b+100|0,g,0)|0;a1(b+164|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e+(j+1)|0]|0,x)|0)|0;c[b+12>>2]=j+2;c[b+96>>2]=2;i=f;return}else if((h|0)==4){h=b+32|0;y=5002573;a[h]=y&255;y=y>>8;a[h+1|0]=y&255;y=y>>8;a[h+2|0]=y&255;y=y>>8;a[h+3|0]=y&255;c[b+12>>2]=(hl(b,b+100|0,g,0)|0)+1;c[b+96>>2]=1;i=f;return}else{c[b+12>>2]=1;c[b+96>>2]=1;g=b+32|0;a[g]=a[35688]|0;a[g+1|0]=a[35689|0]|0;a[g+2|0]=a[35690|0]|0;a1(b+100|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e]|0,x)|0)|0;i=f;return}}function hh(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=e+1|0;h=(d[g]|0)>>>3&7;if((h|0)==2){j=b+32|0;y=5525326;a[j]=y&255;y=y>>8;a[j+1|0]=y&255;y=y>>8;a[j+2|0]=y&255;y=y>>8;a[j+3|0]=y&255;c[b+12>>2]=(hl(b,b+100|0,g,1)|0)+1;c[b+96>>2]=1;i=f;return}else if((h|0)==3){j=b+32|0;y=4670798;a[j]=y&255;y=y>>8;a[j+1|0]=y&255;y=y>>8;a[j+2|0]=y&255;y=y>>8;a[j+3|0]=y&255;c[b+12>>2]=(hl(b,b+100|0,g,1)|0)+1;c[b+96>>2]=1;i=f;return}else if((h|0)==1){c[b+12>>2]=1;c[b+96>>2]=1;j=b+32|0;a[j]=a[35688]|0;a[j+1|0]=a[35689|0]|0;a[j+2|0]=a[35690|0]|0;a1(b+100|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e]|0,x)|0)|0;i=f;return}else if((h|0)==4){j=b+32|0;y=5002573;a[j]=y&255;y=y>>8;a[j+1|0]=y&255;y=y>>8;a[j+2|0]=y&255;y=y>>8;a[j+3|0]=y&255;c[b+12>>2]=(hl(b,b+100|0,g,1)|0)+1;c[b+96>>2]=1;i=f;return}else if((h|0)==6){j=b+32|0;y=5654852;a[j]=y&255;y=y>>8;a[j+1|0]=y&255;y=y>>8;a[j+2|0]=y&255;y=y>>8;a[j+3|0]=y&255;c[b+12>>2]=(hl(b,b+100|0,g,1)|0)+1;c[b+96>>2]=1;i=f;return}else if((h|0)==7){j=b+32|0;a[j]=a[27072]|0;a[j+1|0]=a[27073|0]|0;a[j+2|0]=a[27074|0]|0;a[j+3|0]=a[27075|0]|0;a[j+4|0]=a[27076|0]|0;c[b+12>>2]=(hl(b,b+100|0,g,1)|0)+1;c[b+96>>2]=1;i=f;return}else if((h|0)==0){j=b+32|0;a[j]=a[28048]|0;a[j+1|0]=a[28049|0]|0;a[j+2|0]=a[28050|0]|0;a[j+3|0]=a[28051|0]|0;a[j+4|0]=a[28052|0]|0;j=hl(b,b+100|0,g,1)|0;a1(b+164|0,26776,(x=i,i=i+8|0,c[x>>2]=(d[e+(j+2)|0]|0)<<8|(d[e+(j+1)|0]|0),x)|0)|0;c[b+12>>2]=j+3;c[b+96>>2]=2;i=f;return}else if((h|0)==5){h=b+32|0;a[h]=a[27552]|0;a[h+1|0]=a[27553|0]|0;a[h+2|0]=a[27554|0]|0;a[h+3|0]=a[27555|0]|0;a[h+4|0]=a[27556|0]|0;c[b+12>>2]=(hl(b,b+100|0,g,1)|0)+1;c[b+96>>2]=1;i=f;return}else{c[b+12>>2]=1;c[b+96>>2]=1;g=b+32|0;a[g]=a[35688]|0;a[g+1|0]=a[35689|0]|0;a[g+2|0]=a[35690|0]|0;a1(b+100|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e]|0,x)|0)|0;i=f;return}}function hi(a,b){a=a|0;b=b|0;c[a+12>>2]=1;c[a+96>>2]=0;zQ(a+32|0,c[15968+((d[b]|0)-248<<2)>>2]|0)|0;return}function hj(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=e+1|0;h=(d[g]|0)>>>3&7;if((h|0)==1){j=b+32|0;y=4408644;a[j]=y&255;y=y>>8;a[j+1|0]=y&255;y=y>>8;a[j+2|0]=y&255;y=y>>8;a[j+3|0]=y&255;c[b+12>>2]=(hl(b,b+100|0,g,0)|0)+1;c[b+96>>2]=1;i=f;return}else if((h|0)==0){h=b+32|0;y=4410953;a[h]=y&255;y=y>>8;a[h+1|0]=y&255;y=y>>8;a[h+2|0]=y&255;y=y>>8;a[h+3|0]=y&255;c[b+12>>2]=(hl(b,b+100|0,g,0)|0)+1;c[b+96>>2]=1;i=f;return}else{c[b+12>>2]=1;c[b+96>>2]=1;g=b+32|0;a[g]=a[35688]|0;a[g+1|0]=a[35689|0]|0;a[g+2|0]=a[35690|0]|0;a1(b+100|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e]|0,x)|0)|0;i=f;return}}function hk(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=e+1|0;h=(d[g]|0)>>>3&7;if((h|0)==1){j=b+32|0;y=4408644;a[j]=y&255;y=y>>8;a[j+1|0]=y&255;y=y>>8;a[j+2|0]=y&255;y=y>>8;a[j+3|0]=y&255;c[b+12>>2]=(hl(b,b+100|0,g,1)|0)+1;c[b+96>>2]=1;i=f;return}else if((h|0)==2){j=b+32|0;a[j]=a[31888]|0;a[j+1|0]=a[31889|0]|0;a[j+2|0]=a[31890|0]|0;a[j+3|0]=a[31891|0]|0;a[j+4|0]=a[31892|0]|0;c[b+12>>2]=(hl(b,b+100|0,g,1)|0)+1;c[b+96>>2]=1;j=b|0;c[j>>2]=c[j>>2]|256;i=f;return}else if((h|0)==3){j=b+32|0;a[j]=a[30056]|0;a[j+1|0]=a[30057|0]|0;a[j+2|0]=a[30058|0]|0;a[j+3|0]=a[30059|0]|0;a[j+4|0]=a[30060|0]|0;a[j+5|0]=a[30061|0]|0;c[b+12>>2]=(hl(b,b+100|0,g,1)|0)+1;c[b+96>>2]=1;j=b|0;c[j>>2]=c[j>>2]|256;i=f;return}else if((h|0)==5){j=b+32|0;a[j]=a[26488]|0;a[j+1|0]=a[26489|0]|0;a[j+2|0]=a[26490|0]|0;a[j+3|0]=a[26491|0]|0;a[j+4|0]=a[26492|0]|0;c[b+12>>2]=(hl(b,b+100|0,g,1)|0)+1;c[b+96>>2]=1;i=f;return}else if((h|0)==6){j=b+32|0;a[j]=a[25072]|0;a[j+1|0]=a[25073|0]|0;a[j+2|0]=a[25074|0]|0;a[j+3|0]=a[25075|0]|0;a[j+4|0]=a[25076|0]|0;c[b+12>>2]=(hl(b,b+100|0,g,1)|0)+1;c[b+96>>2]=1;i=f;return}else if((h|0)==7){c[b+12>>2]=1;c[b+96>>2]=1;j=b+32|0;a[j]=a[35688]|0;a[j+1|0]=a[35689|0]|0;a[j+2|0]=a[35690|0]|0;a1(b+100|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e]|0,x)|0)|0;i=f;return}else if((h|0)==0){j=b+32|0;y=4410953;a[j]=y&255;y=y>>8;a[j+1|0]=y&255;y=y>>8;a[j+2|0]=y&255;y=y>>8;a[j+3|0]=y&255;c[b+12>>2]=(hl(b,b+100|0,g,1)|0)+1;c[b+96>>2]=1;i=f;return}else if((h|0)==4){h=b+32|0;y=5262666;a[h]=y&255;y=y>>8;a[h+1|0]=y&255;y=y>>8;a[h+2|0]=y&255;y=y>>8;a[h+3|0]=y&255;c[b+12>>2]=(hl(b,b+100|0,g,1)|0)+1;c[b+96>>2]=1;i=f;return}else{c[b+12>>2]=1;c[b+96>>2]=1;g=b+32|0;a[g]=a[35688]|0;a[g+1|0]=a[35689|0]|0;a[g+2|0]=a[35690|0]|0;a1(b+100|0,26648,(x=i,i=i+8|0,c[x>>2]=d[e]|0,x)|0)|0;i=f;return}}function hl(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;j=d[f]|0;k=j&192;if((k|0)==192){l=j&7;if((g|0)==0){m=c[15904+(l<<2)>>2]|0;zQ(e|0,m|0)|0;n=1;i=h;return n|0}else{m=c[15936+(l<<2)>>2]|0;zQ(e|0,m|0)|0;n=1;i=h;return n|0}}m=k>>>3|j&7;j=b+4|0;b=c[15880+(c[j>>2]<<2)>>2]|0;c[j>>2]=0;j=(g|0)!=0?23768:22224;a[e]=a[j]|0;a[e+1|0]=a[j+1|0]|0;a[e+2|0]=a[j+2|0]|0;a[e+3|0]=a[j+3|0]|0;a[e+4|0]=a[j+4|0]|0;a[e+5|0]=a[j+5|0]|0;j=e+(zN(e|0)|0)|0;e=c[15996+(m<<3)>>2]|0;if((m|0)==6){g=(d[f+2|0]|0)<<8|(d[f+1|0]|0);a1(j|0,21112,(x=i,i=i+16|0,c[x>>2]=b,c[x+8>>2]=g,x)|0)|0;n=3;i=h;return n|0}g=c[15992+(m<<3)>>2]|0;if((g|0)==0){a1(j|0,41192,(x=i,i=i+16|0,c[x>>2]=b,c[x+8>>2]=e,x)|0)|0}else if((g|0)==2){m=(d[f+2|0]|0)<<8;k=m|(d[f+1|0]|0);l=m&32768;a1(j|0,38544,(x=i,i=i+32|0,c[x>>2]=b,c[x+8>>2]=e,c[x+16>>2]=(l>>>14)+43,c[x+24>>2]=((l|0)==0?k:-k|0)&65535,x)|0)|0}else if((g|0)==1){k=d[f+1|0]|0;f=k&128;a1(j|0,39824,(x=i,i=i+32|0,c[x>>2]=b,c[x+8>>2]=e,c[x+16>>2]=(f>>>6)+43,c[x+24>>2]=((f|0)==0?k:-k|0)&255,x)|0)|0}else{a[j]=a[37592]|0;a[j+1|0]=a[37593|0]|0;a[j+2|0]=a[37594|0]|0;a[j+3|0]=a[37595|0]|0;a[j+4|0]=a[37596|0]|0;a[j+5|0]=a[37597|0]|0}n=g+1|0;i=h;return n|0}function hm(a){a=a|0;var b=0;hD(a);b=a|0;c[b>>2]=c[b>>2]&-12|10;c[a+544>>2]=408;c[a+548>>2]=190;c[a+552>>2]=194;c[a+576>>2]=196;c[a+580>>2]=450;c[a+584>>2]=170;c[a+588>>2]=174;c[a+592>>2]=172;c[a+596>>2]=166;c[a+600>>2]=164;c[a+604>>2]=168;c[a+928>>2]=352;c[a+932>>2]=354;c[a+960>>2]=336;c[a+964>>2]=448;return}function hn(a){a=a|0;var d=0;d=b[a+12>>1]|0;iK(a,b[a+4>>1]|0);iK(a,b[a+6>>1]|0);iK(a,b[a+8>>1]|0);iK(a,b[a+10>>1]|0);iK(a,d);iK(a,b[a+14>>1]|0);iK(a,b[a+16>>1]|0);iK(a,b[a+18>>1]|0);d=a+1200|0;c[d>>2]=(c[d>>2]|0)+19;return 1}function ho(a){a=a|0;var d=0;b[a+18>>1]=iL(a)|0;b[a+16>>1]=iL(a)|0;b[a+14>>1]=iL(a)|0;iL(a)|0;b[a+10>>1]=iL(a)|0;b[a+8>>1]=iL(a)|0;b[a+6>>1]=iL(a)|0;b[a+4>>1]=iL(a)|0;d=a+1200|0;c[d>>2]=(c[d>>2]|0)+19;return 1}function hp(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0;f=a+129|0;iD(a,f);g=b[a+4+(((d[f]|0)>>>3&7)<<1)>>1]|0;f=g&65535;if((c[a+1184>>2]|0)==0){h=c[q>>2]|0;aB(25256,21,1,h|0)|0;i=(e[a+1196>>1]|0)+1|0;return i|0}h=b[a+1194>>1]|0;j=(e[a+1192>>1]|0)<<4;k=a+80|0;l=c[k>>2]|0;m=j+(h&65535)&l;n=m+1|0;o=a+76|0;p=c[o>>2]|0;if(n>>>0<p>>>0){r=c[a+72>>2]|0;s=(d[r+n|0]|0)<<8|(d[r+m|0]|0);t=l;u=p}else{p=b8[c[a+44>>2]&255](c[a+32>>2]|0,m)|0;s=p;t=c[k>>2]|0;u=c[o>>2]|0}o=s&65535;k=t&(h+2&65535)+j;j=k+1|0;if(j>>>0<u>>>0){u=c[a+72>>2]|0;v=(d[u+j|0]|0)<<8|(d[u+k|0]|0)}else{v=b8[c[a+44>>2]&255](c[a+32>>2]|0,k)|0}k=v&65535;u=g<<16>>16<0?f|-65536:f;do{if((u|0)>=((s<<16>>16<0?o|-65536:o)|0)){if((u|0)>((v<<16>>16<0?k|-65536:k)+2|0)){break}f=a+1200|0;c[f>>2]=(c[f>>2]|0)+34;i=(e[a+1196>>1]|0)+1|0;return i|0}}while(0);id(a,5);i=0;return i|0}function hq(a){a=a|0;var b=0;iK(a,(d[a+130|0]|0)<<8|(d[a+129|0]|0));b=a+1200|0;c[b>>2]=(c[b>>2]|0)+3;return 3}function hr(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=a+129|0;iD(a,f);g=(iF(a)|0)&65535;h=a+1196|0;i=e[h>>1]|0;j=(d[i+2+(a+128)|0]|0)<<8;k=j|(d[i+1+(a+128)|0]|0);i=ac((j&32768|0)!=0?k|-65536:k,(g&32768|0)!=0?g|-65536:g)|0;b[a+4+(((d[f]|0)>>>3&7)<<1)>>1]=i&65535;f=i&-32768;i=a+30|0;g=b[i>>1]|0;if((f|0)==(-32768|0)|(f|0)==0){l=g&-2050}else{l=g|2049}b[i>>1]=(f|0)==0?l|64:l&-65;l=a+1200|0;c[l>>2]=((c[a+1184>>2]|0)!=0?30:23)+(c[l>>2]|0);return(e[h>>1]|0)+3|0}function hs(a){a=a|0;var b=0;b=d[a+129|0]|0;iK(a,((b&128|0)!=0?b|65280:b)&65535);b=a+1200|0;c[b>>2]=(c[b>>2]|0)+3;return 2}function ht(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=a+129|0;iD(a,f);g=(iF(a)|0)&65535;h=a+1196|0;i=d[(e[h>>1]|0)+1+(a+128)|0]|0;j=(i&128|0)!=0?i|65280:i;i=ac((j&32768|0)!=0?j|-65536:j,(g&32768|0)!=0?g|-65536:g)|0;b[a+4+(((d[f]|0)>>>3&7)<<1)>>1]=i&65535;f=i&-32768;i=a+30|0;g=b[i>>1]|0;if((f|0)==(-32768|0)|(f|0)==0){k=g&-2050}else{k=g|2049}b[i>>1]=(f|0)==0?k|64:k&-65;k=a+1200|0;c[k>>2]=((c[a+1184>>2]|0)!=0?30:23)+(c[k>>2]|0);return(e[h>>1]|0)+2|0}function hu(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=((e[d+30>>1]|0)>>>9&2^2)-1&65535;if((c[d+144>>2]&12|0)==0){g=b[d+20>>1]|0;h=d+18|0;i=b[h>>1]|0;j=b8[c[d+56>>2]&255](c[d+52>>2]|0,e[d+8>>1]|0)|0;k=c[d+80>>2]&((g&65535)<<4)+(i&65535);if(k>>>0<(c[d+76>>2]|0)>>>0){a[(c[d+72>>2]|0)+k|0]=j}else{b5[c[d+40>>2]&255](c[d+32>>2]|0,k,j)}b[h>>1]=(b[h>>1]|0)+f&65535;h=d+1200|0;c[h>>2]=(c[h>>2]|0)+8;return 1}h=d+6|0;if((b[h>>1]|0)==0){return 1}j=d+20|0;k=d+18|0;i=d+56|0;g=d+52|0;l=d+8|0;m=d+80|0;n=d+76|0;o=d+72|0;p=d+1216|0;q=d+1200|0;r=d+40|0;s=d+32|0;d=b[k>>1]|0;do{t=b[j>>1]|0;u=b8[c[i>>2]&255](c[g>>2]|0,e[l>>1]|0)|0;v=c[m>>2]&((t&65535)<<4)+(d&65535);if(v>>>0<(c[n>>2]|0)>>>0){a[(c[o>>2]|0)+v|0]=u}else{b5[c[r>>2]&255](c[s>>2]|0,v,u)}d=(b[k>>1]|0)+f&65535;b[k>>1]=d;u=(b[h>>1]|0)-1&65535;b[h>>1]=u;v=zW(c[p>>2]|0,c[p+4>>2]|0,1,0)|0;c[p>>2]=v;c[p+4>>2]=G;c[q>>2]=(c[q>>2]|0)+8;}while(u<<16>>16!=0);return 1}function hv(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=((e[d+30>>1]|0)>>>8&4^4)-2&65535;if((c[d+144>>2]&12|0)==0){g=b[d+20>>1]|0;h=d+18|0;i=b[h>>1]|0;j=b8[c[d+64>>2]&255](c[d+52>>2]|0,e[d+8>>1]|0)|0;k=c[d+80>>2]&((g&65535)<<4)+(i&65535);i=k+1|0;if(i>>>0<(c[d+76>>2]|0)>>>0){g=d+72|0;a[(c[g>>2]|0)+k|0]=j&255;a[(c[g>>2]|0)+i|0]=(j&65535)>>>8&255}else{b5[c[d+48>>2]&255](c[d+32>>2]|0,k,j)}b[h>>1]=(b[h>>1]|0)+f&65535;h=d+1200|0;c[h>>2]=(c[h>>2]|0)+8;return 1}h=d+6|0;if((b[h>>1]|0)==0){return 1}j=d+20|0;k=d+18|0;i=d+64|0;g=d+52|0;l=d+8|0;m=d+80|0;n=d+76|0;o=d+72|0;p=d+1216|0;q=d+1200|0;r=d+48|0;s=d+32|0;d=b[k>>1]|0;do{t=b[j>>1]|0;u=b8[c[i>>2]&255](c[g>>2]|0,e[l>>1]|0)|0;v=c[m>>2]&((t&65535)<<4)+(d&65535);t=v+1|0;if(t>>>0<(c[n>>2]|0)>>>0){a[(c[o>>2]|0)+v|0]=u&255;a[(c[o>>2]|0)+t|0]=(u&65535)>>>8&255}else{b5[c[r>>2]&255](c[s>>2]|0,v,u)}d=(b[k>>1]|0)+f&65535;b[k>>1]=d;u=(b[h>>1]|0)-1&65535;b[h>>1]=u;v=zW(c[p>>2]|0,c[p+4>>2]|0,1,0)|0;c[p>>2]=v;c[p+4>>2]=G;c[q>>2]=(c[q>>2]|0)+8;}while(u<<16>>16!=0);return 1}function hw(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=c[d+144>>2]|0;g=b[((f&2|0)==0?d+26|0:d+148|0)>>1]|0;h=((e[d+30>>1]|0)>>>9&2^2)-1&65535;if((f&12|0)==0){f=c[d+60>>2]|0;i=c[d+52>>2]|0;j=e[d+8>>1]|0;k=d+16|0;l=(e[k>>1]|0)+((g&65535)<<4)&c[d+80>>2];if(l>>>0<(c[d+76>>2]|0)>>>0){m=a[(c[d+72>>2]|0)+l|0]|0}else{m=b8[c[d+36>>2]&255](c[d+32>>2]|0,l)|0}b5[f&255](i,j,m);b[k>>1]=(b[k>>1]|0)+h&65535;k=d+1200|0;c[k>>2]=(c[k>>2]|0)+8;return 1}k=d+6|0;if((b[k>>1]|0)==0){return 1}m=d+60|0;j=d+52|0;i=d+8|0;f=d+16|0;l=(g&65535)<<4;g=d+80|0;n=d+76|0;o=d+72|0;p=d+1216|0;q=d+1200|0;r=d+36|0;s=d+32|0;d=b[f>>1]|0;do{t=c[m>>2]|0;u=c[j>>2]|0;v=e[i>>1]|0;w=(d&65535)+l&c[g>>2];if(w>>>0<(c[n>>2]|0)>>>0){x=a[(c[o>>2]|0)+w|0]|0}else{x=b8[c[r>>2]&255](c[s>>2]|0,w)|0}b5[t&255](u,v,x);d=(b[f>>1]|0)+h&65535;b[f>>1]=d;v=(b[k>>1]|0)-1&65535;b[k>>1]=v;u=zW(c[p>>2]|0,c[p+4>>2]|0,1,0)|0;c[p>>2]=u;c[p+4>>2]=G;c[q>>2]=(c[q>>2]|0)+8;}while(v<<16>>16!=0);return 1}function hx(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=c[a+144>>2]|0;g=b[((f&2|0)==0?a+26|0:a+148|0)>>1]|0;h=((e[a+30>>1]|0)>>>8&4^4)-2&65535;if((f&12|0)==0){f=c[a+68>>2]|0;i=c[a+52>>2]|0;j=e[a+8>>1]|0;k=a+16|0;l=(e[k>>1]|0)+((g&65535)<<4)&c[a+80>>2];m=l+1|0;if(m>>>0<(c[a+76>>2]|0)>>>0){n=c[a+72>>2]|0;o=d[n+m|0]<<8|d[n+l|0]}else{o=b8[c[a+44>>2]&255](c[a+32>>2]|0,l)|0}b5[f&255](i,j,o);b[k>>1]=(b[k>>1]|0)+h&65535;k=a+1200|0;c[k>>2]=(c[k>>2]|0)+8;return 1}k=a+6|0;if((b[k>>1]|0)==0){return 1}o=a+68|0;j=a+52|0;i=a+8|0;f=a+16|0;l=(g&65535)<<4;g=a+80|0;n=a+76|0;m=a+72|0;p=a+1216|0;q=a+1200|0;r=a+44|0;s=a+32|0;a=b[f>>1]|0;do{t=c[o>>2]|0;u=c[j>>2]|0;v=e[i>>1]|0;w=(a&65535)+l&c[g>>2];x=w+1|0;if(x>>>0<(c[n>>2]|0)>>>0){y=c[m>>2]|0;z=d[y+x|0]<<8|d[y+w|0]}else{z=b8[c[r>>2]&255](c[s>>2]|0,w)|0}b5[t&255](u,v,z);a=(b[f>>1]|0)+h&65535;b[f>>1]=a;v=(b[k>>1]|0)-1&65535;b[k>>1]=v;u=zW(c[p>>2]|0,c[p+4>>2]|0,1,0)|0;c[p>>2]=u;c[p+4>>2]=G;c[q>>2]=(c[q>>2]|0)+8;}while(v<<16>>16!=0);return 1}function hy(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=f+129|0;h=a[g]|0;iD(f,g);g=iE(f)|0;i=f+1196|0;j=(e[i>>1]|0)+1|0;k=d[f+128+j|0]|0;l=(c[f>>2]&2|0)==0?k:k&31;if((l|0)==0){m=j;return m|0}j=(h&255)>>>3&7;do{if((j|0)==7){h=g&255;k=(((h&128|0)!=0?65280:0)|h)>>>((l>>>0>7?7:l-1|0)>>>0);h=f+30|0;n=b[h>>1]|0;b[h>>1]=(k&1|0)==0?n&-2:n|1;n=k>>>1&255;it(f,n);b[h>>1]=b[h>>1]&-2049;o=n}else if((j|0)==2){n=f+30|0;h=b[n>>1]|0;k=(h<<8&256|g&255)&65535;p=(l>>>0)%9|0;q=k<<p|k>>>((9-p|0)>>>0);p=(q&256|0)==0?h&-2:h|1;b[n>>1]=p;if(((k<<1^k)&128|0)==0){b[n>>1]=p&-2049;o=q&255;break}else{b[n>>1]=p|2048;o=q&255;break}}else if((j|0)==4){q=g&255;if(l>>>0>8){r=0}else{r=q<<l&65535}p=r&255;it(f,p);n=f+30|0;k=b[n>>1]|0;h=(r&256)==0?k&-2:k|1;b[n>>1]=h;if(((q<<1^q)&128|0)==0){b[n>>1]=h&-2049;o=p;break}else{b[n>>1]=h|2048;o=p;break}}else if((j|0)==3){p=f+30|0;h=b[p>>1]|0;n=(h<<8&256|g&255)&65535;q=(l>>>0)%9|0;k=n>>>(q>>>0)|n<<9-q;q=(k&256|0)==0?h&-2:h|1;b[p>>1]=q;if(((k<<1^n)&128|0)==0){b[p>>1]=q&-2049;o=k&255;break}else{b[p>>1]=q|2048;o=k&255;break}}else if((j|0)==5){if(l>>>0>8){s=0}else{s=(g&255)>>>((l-1|0)>>>0)&65535}k=f+30|0;q=b[k>>1]|0;b[k>>1]=(s&1|0)==0?q&-2:q|1;q=s>>>1&255;it(f,q);p=b[k>>1]|0;if(g<<24>>24<0){b[k>>1]=p|2048;o=q;break}else{b[k>>1]=p&-2049;o=q;break}}else if((j|0)==0){q=g&255;p=l&7;k=q>>>((8-p|0)>>>0)|q<<p;p=f+30|0;n=b[p>>1]|0;h=(k&1|0)==0?n&-2:n|1;b[p>>1]=h;if(((q<<1^q)&128|0)==0){b[p>>1]=h&-2049;o=k&255;break}else{b[p>>1]=h|2048;o=k&255;break}}else if((j|0)==1){k=g&255;h=l&7;p=k<<8-h|k>>>(h>>>0);h=f+30|0;q=b[h>>1]|0;n=(p&128|0)==0?q&-2:q|1;b[h>>1]=n;if(((p<<1^k)&128|0)==0){b[h>>1]=n&-2049;o=p&255;break}else{b[h>>1]=n|2048;o=p&255;break}}else{o=0}}while(0);iG(f,o);o=f+1200|0;c[o>>2]=(c[o>>2]|0)+l+((c[f+1184>>2]|0)!=0?17:5);m=(e[i>>1]|0)+2|0;return m|0}function hz(a,b){a=a|0;b=b|0;return-86|0}function hA(a,b){a=a|0;b=b|0;return-21846|0}function hB(a,b,c){a=a|0;b=b|0;c=c|0;return}function hC(a,b,c){a=a|0;b=b|0;c=c|0;return}function hD(a){a=a|0;var b=0;c[a>>2]=1;b=0;do{c[a+160+(b<<2)>>2]=c[13224+(b<<2)>>2];b=b+1|0;}while(b>>>0<256);c[a+116>>2]=6;c[a+120>>2]=6;c[a+124>>2]=0;return}function hE(a,b){a=a|0;b=b|0;var d=0;d=b>>>0>16?16:b;c[a+116>>2]=d;c[a+120>>2]=d>>>0<6?6:d;c[a+124>>2]=0;return}function hF(a){a=a|0;var b=0,d=0;b=a|0;c[b>>2]=1;d=0;do{c[a+160+(d<<2)>>2]=c[13224+(d<<2)>>2];d=d+1|0;}while(d>>>0<256);c[b>>2]=c[b>>2]|64;c[a+116>>2]=4;c[a+120>>2]=6;c[a+124>>2]=0;return}function hG(a){a=a|0;var b=0,d=0;b=a|0;c[b>>2]=1;d=0;do{c[a+160+(d<<2)>>2]=c[13224+(d<<2)>>2];d=d+1|0;}while(d>>>0<256);c[a+116>>2]=6;c[a+120>>2]=6;c[a+124>>2]=0;c[b>>2]=c[b>>2]&-4;return}function hH(a){a=a|0;var b=0,d=0;b=a|0;c[b>>2]=1;d=0;do{c[a+160+(d<<2)>>2]=c[13224+(d<<2)>>2];d=d+1|0;}while(d>>>0<256);d=c[b>>2]|0;c[a+116>>2]=4;c[a+120>>2]=6;c[a+124>>2]=0;c[b>>2]=d&-68|64;return}function hI(a,b){a=a|0;b=b|0;c[a+80>>2]=b;return}function hJ(a){a=a|0;return c[a+80>>2]|0}function hK(a,b,d){a=a|0;b=b|0;d=d|0;c[a+84>>2]=b;c[a+88>>2]=d;return}function hL(a,b,d){a=a|0;b=b|0;d=d|0;c[a+72>>2]=b;c[a+76>>2]=d;return}function hM(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;c[a+32>>2]=b;c[a+36>>2]=d;c[a+40>>2]=e;c[a+44>>2]=f;c[a+48>>2]=g;return}function hN(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;c[a+52>>2]=b;c[a+56>>2]=d;c[a+60>>2]=e;c[a+64>>2]=f;c[a+68>>2]=g;return}function hO(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=f+129|0;h=a[g]|0;iD(f,g);g=(iF(f)|0)&65535;i=f+1196|0;j=(e[i>>1]|0)+1|0;k=d[f+128+j|0]|0;l=(c[f>>2]&2|0)==0?k:k&31;if((l|0)==0){m=j;return m|0}j=(h&255)>>>3&7;do{if((j|0)==4){h=l>>>0>16?0:g<<l;k=h&65535;iu(f,k);n=f+30|0;o=b[n>>1]|0;p=(h&65536|0)==0?o&-2:o|1;b[n>>1]=p;if(((g<<1^g)&32768|0)==0){b[n>>1]=p&-2049;q=k;break}else{b[n>>1]=p|2048;q=k;break}}else if((j|0)==0){k=l&15;p=g>>>((16-k|0)>>>0)|g<<k;k=f+30|0;n=b[k>>1]|0;o=(p&1|0)==0?n&-2:n|1;b[k>>1]=o;if(((g<<1^g)&32768|0)==0){b[k>>1]=o&-2049;q=p&65535;break}else{b[k>>1]=o|2048;q=p&65535;break}}else if((j|0)==1){p=l&15;o=g<<16-p|g>>>(p>>>0);p=f+30|0;k=b[p>>1]|0;n=(o&32768|0)==0?k&-2:k|1;b[p>>1]=n;if(((o<<1^g)&32768|0)==0){b[p>>1]=n&-2049;q=o&65535;break}else{b[p>>1]=n|2048;q=o&65535;break}}else if((j|0)==5){if(l>>>0>16){r=0}else{r=g>>>((l-1|0)>>>0)}o=f+30|0;n=b[o>>1]|0;b[o>>1]=(r&1|0)==0?n&-2:n|1;n=r>>>1&65535;iu(f,n);p=b[o>>1]|0;if((g&32768|0)==0){b[o>>1]=p&-2049;q=n;break}else{b[o>>1]=p|2048;q=n;break}}else if((j|0)==2){n=f+30|0;p=b[n>>1]|0;o=(p&65535)<<16&65536|g;k=(l>>>0)%17|0;h=o<<k|o>>>((17-k|0)>>>0);k=(h&65536|0)==0?p&-2:p|1;b[n>>1]=k;if(((g<<1^g)&32768|0)==0){b[n>>1]=k&-2049;q=h&65535;break}else{b[n>>1]=k|2048;q=h&65535;break}}else if((j|0)==3){h=f+30|0;k=b[h>>1]|0;n=(k&65535)<<16&65536|g;p=(l>>>0)%17|0;o=n>>>(p>>>0)|n<<17-p;p=(o&65536|0)==0?k&-2:k|1;b[h>>1]=p;if(((o<<1^g)&32768|0)==0){b[h>>1]=p&-2049;q=o&65535;break}else{b[h>>1]=p|2048;q=o&65535;break}}else if((j|0)==7){o=(((g&32768|0)!=0?-65536:0)|g)>>>((l>>>0>15?15:l-1|0)>>>0);p=f+30|0;h=b[p>>1]|0;b[p>>1]=(o&1|0)==0?h&-2:h|1;h=o>>>1&65535;iu(f,h);b[p>>1]=b[p>>1]&-2049;q=h}else{q=0}}while(0);iH(f,q);q=f+1200|0;c[q>>2]=(c[q>>2]|0)+l+((c[f+1184>>2]|0)!=0?17:5);m=(e[i>>1]|0)+2|0;return m|0}function hP(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=e+14|0;iK(e,b[f>>1]|0);g=e+12|0;h=b[g>>1]|0;i=a[e+131|0]&31;j=i&255;if(i<<24>>24!=0){if((i&255)>1){i=(h&65535)<<4;k=e+80|0;l=e+76|0;m=e+72|0;n=e+44|0;o=e+32|0;p=1;q=b[f>>1]|0;do{q=q-2&65535;r=c[k>>2]&(q&65535)+i;s=r+1|0;if(s>>>0<(c[l>>2]|0)>>>0){t=c[m>>2]|0;u=(d[t+s|0]|0)<<8|(d[t+r|0]|0)}else{u=b8[c[n>>2]&255](c[o>>2]|0,r)|0}iK(e,u);p=p+1|0;}while(p>>>0<j>>>0)}iK(e,h)}b[f>>1]=h;b[g>>1]=h-((d[e+130|0]|0)<<8|(d[e+129|0]|0))&65535;if((j|0)==1){h=e+1200|0;c[h>>2]=(c[h>>2]|0)+25;return 4}else if((j|0)==0){h=e+1200|0;c[h>>2]=(c[h>>2]|0)+15;return 4}else{h=e+1200|0;c[h>>2]=(c[h>>2]|0)+(j<<4|6);return 4}return 0}function hQ(a){a=a|0;var d=0;d=a+14|0;b[a+12>>1]=b[d>>1]|0;b[d>>1]=iL(a)|0;d=a+1200|0;c[d>>2]=(c[d>>2]|0)+8;return 1}function hR(a){a=a|0;var b=0,d=0;hD(a);b=a|0;d=c[b>>2]&-76;c[a+544>>2]=408;c[a+548>>2]=190;c[a+552>>2]=194;c[a+576>>2]=196;c[a+580>>2]=450;c[a+584>>2]=170;c[a+588>>2]=174;c[a+592>>2]=172;c[a+596>>2]=166;c[a+600>>2]=164;c[a+604>>2]=168;c[a+928>>2]=352;c[a+932>>2]=354;c[a+960>>2]=336;c[a+964>>2]=448;c[b>>2]=d|74;hE(a,4);return}function hS(a){a=a|0;var b=0;hm(a);b=a|0;c[b>>2]=c[b>>2]|40;c[a+220>>2]=478;return}function hT(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((a[b+129|0]|0)!=1){f=ie(b)|0;return f|0}g=b+130|0;h=(d[g]|0)>>>3&7;if((h|0)==4){iD(b,g);iH(b,0);i=b+1200|0;c[i>>2]=((c[b+1184>>2]|0)!=0?3:2)+(c[i>>2]|0);f=(e[b+1196>>1]|0)+2|0;return f|0}else if((h|0)==0){iD(b,g);if((c[b+1184>>2]|0)==0){f=ie(b)|0;return f|0}else{iH(b,0);i=b+1200|0;c[i>>2]=(c[i>>2]|0)+11;f=(e[b+1196>>1]|0)+2|0;return f|0}}else if((h|0)==6){iD(b,g);i=((iF(b)|0)&4)==0;j=b|0;k=c[j>>2]|0;c[j>>2]=i?k&-17:k|16;k=b+1200|0;c[k>>2]=((c[b+1184>>2]|0)!=0?6:3)+(c[k>>2]|0);f=(e[b+1196>>1]|0)+2|0;return f|0}else if((h|0)==1){iD(b,g);if((c[b+1184>>2]|0)==0){f=ie(b)|0;return f|0}else{iH(b,0);g=b+1200|0;c[g>>2]=(c[g>>2]|0)+11;f=(e[b+1196>>1]|0)+2|0;return f|0}}else{f=ie(b)|0;return f|0}return 0}function hU(){var b=0,d=0,e=0,f=0;b=zH(1224)|0;if((b|0)==0){d=0;return d|0}e=b;c[b>>2]=1;c[b+32>>2]=0;c[b+36>>2]=114;c[b+44>>2]=104;c[b+40>>2]=52;c[b+48>>2]=58;c[b+52>>2]=0;c[b+56>>2]=114;c[b+64>>2]=104;c[b+60>>2]=52;c[b+68>>2]=58;c[b+72>>2]=0;c[b+76>>2]=0;c[b+80>>2]=1048575;zP(b+84|0,0,28);c[b+116>>2]=4;c[b+120>>2]=6;a[b+156|0]=0;c[b+152>>2]=0;f=b+160|0;zO(f|0,13224,1024)|0;c[b+1200>>2]=0;zP(b+1208|0,0,16);d=e;return d|0}function hV(b,d,f){b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=(a[d]|0)==37?d+1|0:d;d=0;while(1){if(d>>>0>=8){h=0;i=2900;break}if((aP(g|0,c[14496+(d<<2)>>2]|0)|0)==0){i=2897;break}if((aP(g|0,c[14464+(d<<2)>>2]|0)|0)==0){i=2899;break}else{d=d+1|0}}if((i|0)==2897){c[f>>2]=e[b+4+((d&7)<<1)>>1]|0;j=0;return j|0}else if((i|0)==2899){k=e[b+4+((d&3)<<1)>>1]|0;c[f>>2]=((d&4|0)!=0?k>>>8:k)&255;j=0;return j|0}else if((i|0)==2900){while(1){i=0;if(h>>>0>=4){break}if((aP(g|0,c[472+(h<<2)>>2]|0)|0)==0){i=2902;break}else{h=h+1|0;i=2900}}if((i|0)==2902){c[f>>2]=e[b+20+((h&3)<<1)>>1]|0;j=0;return j|0}if((aP(g|0,25192)|0)==0){c[f>>2]=e[b+28>>1]|0;j=0;return j|0}if((aP(g|0,34592)|0)!=0){j=1;return j|0}c[f>>2]=e[b+30>>1]|0;j=0;return j|0}return 0}function hW(b,c){b=b|0;c=c|0;a[b+156|0]=c<<24>>24!=0|0;return}function hX(a){a=a|0;var b=0;b=a+1216|0;return(G=c[b+4>>2]|0,c[b>>2]|0)|0}function hY(a){a=a|0;var d=0;c[a+1184>>2]=1;b[a+1192>>1]=b[a+26>>1]|0;b[a+1194>>1]=(b[a+16>>1]|0)+(b[a+10>>1]|0)&65535;b[a+1196>>1]=1;d=a+1200|0;c[d>>2]=(c[d>>2]|0)+7;return}function hZ(a){a=a|0;var d=0;c[a+1184>>2]=1;b[a+1192>>1]=b[a+26>>1]|0;b[a+1194>>1]=(b[a+18>>1]|0)+(b[a+10>>1]|0)&65535;b[a+1196>>1]=1;d=a+1200|0;c[d>>2]=(c[d>>2]|0)+8;return}function h_(a){a=a|0;var d=0;c[a+1184>>2]=1;b[a+1192>>1]=b[a+24>>1]|0;b[a+1194>>1]=(b[a+16>>1]|0)+(b[a+14>>1]|0)&65535;b[a+1196>>1]=1;d=a+1200|0;c[d>>2]=(c[d>>2]|0)+8;return}function h$(a){a=a|0;var d=0;c[a+1184>>2]=1;b[a+1192>>1]=b[a+24>>1]|0;b[a+1194>>1]=(b[a+18>>1]|0)+(b[a+14>>1]|0)&65535;b[a+1196>>1]=1;d=a+1200|0;c[d>>2]=(c[d>>2]|0)+7;return}function h0(a){a=a|0;var d=0;c[a+1184>>2]=1;b[a+1192>>1]=b[a+26>>1]|0;b[a+1194>>1]=b[a+16>>1]|0;b[a+1196>>1]=1;d=a+1200|0;c[d>>2]=(c[d>>2]|0)+5;return}function h1(a){a=a|0;var d=0;c[a+1184>>2]=1;b[a+1192>>1]=b[a+26>>1]|0;b[a+1194>>1]=b[a+18>>1]|0;b[a+1196>>1]=1;d=a+1200|0;c[d>>2]=(c[d>>2]|0)+5;return}function h2(a){a=a|0;var e=0;c[a+1184>>2]=1;b[a+1192>>1]=b[a+26>>1]|0;e=c[a+1188>>2]|0;b[a+1194>>1]=(d[e+2|0]|0)<<8|(d[e+1|0]|0);b[a+1196>>1]=3;e=a+1200|0;c[e>>2]=(c[e>>2]|0)+6;return}function h3(a){a=a|0;var d=0;c[a+1184>>2]=1;b[a+1192>>1]=b[a+26>>1]|0;b[a+1194>>1]=b[a+10>>1]|0;b[a+1196>>1]=1;d=a+1200|0;c[d>>2]=(c[d>>2]|0)+5;return}function h4(a){a=a|0;var f=0;c[a+1184>>2]=1;b[a+1192>>1]=b[a+26>>1]|0;f=d[(c[a+1188>>2]|0)+1|0]|0;b[a+1194>>1]=(e[a+16>>1]|0)+(e[a+10>>1]|0)+((f&128|0)!=0?f|65280:f)&65535;b[a+1196>>1]=2;f=a+1200|0;c[f>>2]=(c[f>>2]|0)+11;return}function h5(a){a=a|0;var f=0;c[a+1184>>2]=1;b[a+1192>>1]=b[a+26>>1]|0;f=d[(c[a+1188>>2]|0)+1|0]|0;b[a+1194>>1]=(e[a+18>>1]|0)+(e[a+10>>1]|0)+((f&128|0)!=0?f|65280:f)&65535;b[a+1196>>1]=2;f=a+1200|0;c[f>>2]=(c[f>>2]|0)+12;return}function h6(a){a=a|0;var f=0;c[a+1184>>2]=1;b[a+1192>>1]=b[a+24>>1]|0;f=d[(c[a+1188>>2]|0)+1|0]|0;b[a+1194>>1]=(e[a+16>>1]|0)+(e[a+14>>1]|0)+((f&128|0)!=0?f|65280:f)&65535;b[a+1196>>1]=2;f=a+1200|0;c[f>>2]=(c[f>>2]|0)+12;return}function h7(a){a=a|0;var f=0;c[a+1184>>2]=1;b[a+1192>>1]=b[a+24>>1]|0;f=d[(c[a+1188>>2]|0)+1|0]|0;b[a+1194>>1]=(e[a+18>>1]|0)+(e[a+14>>1]|0)+((f&128|0)!=0?f|65280:f)&65535;b[a+1196>>1]=2;f=a+1200|0;c[f>>2]=(c[f>>2]|0)+11;return}function h8(a){a=a|0;var f=0;c[a+1184>>2]=1;b[a+1192>>1]=b[a+26>>1]|0;f=d[(c[a+1188>>2]|0)+1|0]|0;b[a+1194>>1]=((f&128|0)!=0?f|65280:f)+(e[a+16>>1]|0)&65535;b[a+1196>>1]=2;f=a+1200|0;c[f>>2]=(c[f>>2]|0)+9;return}function h9(a){a=a|0;var f=0;c[a+1184>>2]=1;b[a+1192>>1]=b[a+26>>1]|0;f=d[(c[a+1188>>2]|0)+1|0]|0;b[a+1194>>1]=((f&128|0)!=0?f|65280:f)+(e[a+18>>1]|0)&65535;b[a+1196>>1]=2;f=a+1200|0;c[f>>2]=(c[f>>2]|0)+9;return}function ia(a){a=a|0;var f=0;c[a+1184>>2]=1;b[a+1192>>1]=b[a+24>>1]|0;f=d[(c[a+1188>>2]|0)+1|0]|0;b[a+1194>>1]=((f&128|0)!=0?f|65280:f)+(e[a+14>>1]|0)&65535;b[a+1196>>1]=2;f=a+1200|0;c[f>>2]=(c[f>>2]|0)+9;return}function ib(a){a=a|0;var f=0;c[a+1184>>2]=1;b[a+1192>>1]=b[a+26>>1]|0;f=d[(c[a+1188>>2]|0)+1|0]|0;b[a+1194>>1]=((f&128|0)!=0?f|65280:f)+(e[a+10>>1]|0)&65535;b[a+1196>>1]=2;f=a+1200|0;c[f>>2]=(c[f>>2]|0)+9;return}function ic(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=(a[e]|0)==37?e+1|0:e;e=0;while(1){if(e>>>0>=8){h=0;i=2941;break}if((aP(g|0,c[14496+(e<<2)>>2]|0)|0)==0){i=2935;break}if((aP(g|0,c[14464+(e<<2)>>2]|0)|0)==0){i=2937;break}else{e=e+1|0}}if((i|0)==2935){b[d+4+((e&7)<<1)>>1]=f&65535;j=0;return j|0}else if((i|0)==2937){k=d+4+((e&3)<<1)|0;l=b[k>>1]|0;if((e&4|0)==0){m=(l&-256&65535|f&255)&65535}else{m=(l&255|f<<8)&65535}b[k>>1]=m;j=0;return j|0}else if((i|0)==2941){while(1){i=0;if(h>>>0>=4){break}if((aP(g|0,c[472+(h<<2)>>2]|0)|0)==0){i=2943;break}else{h=h+1|0;i=2941}}if((i|0)==2943){b[d+20+((h&3)<<1)>>1]=f&65535;j=0;return j|0}if((aP(g|0,25192)|0)==0){b[d+28>>1]=f&65535;j=0;return j|0}if((aP(g|0,34592)|0)!=0){j=1;return j|0}b[d+30>>1]=f&65535;j=0;return j|0}return 0}function id(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=c[a+108>>2]|0;if((f|0)!=0){b3[f&511](c[a+92>>2]|0,e&255)}f=a+144|0;g=c[f>>2]|0;if((g&32|0)==0){h=b[a+28>>1]|0}else{i=b[a+112>>1]|0;if((c[a>>2]&1|0)==0){j=i}else{j=i+(((g>>>1&1^1)&65535|(g&12|0)==0)^1)&65535}c[f>>2]=0;h=j}j=a+30|0;iK(a,b[j>>1]|0);f=a+22|0;iK(a,b[f>>1]|0);iK(a,h);h=e<<2&1020;e=a+80|0;g=c[e>>2]|0;i=g&(h&65535);k=i|1;l=a+76|0;m=c[l>>2]|0;if(k>>>0<m>>>0){n=c[a+72>>2]|0;o=(d[n+k|0]|0)<<8|(d[n+i|0]|0);p=g;q=m}else{m=b8[c[a+44>>2]&255](c[a+32>>2]|0,i)|0;o=m;p=c[e>>2]|0;q=c[l>>2]|0}b[a+28>>1]=o;o=p&((h|2)&65535);h=o|1;if(h>>>0<q>>>0){q=c[a+72>>2]|0;r=(d[q+h|0]|0)<<8|(d[q+o|0]|0);b[f>>1]=r;s=b[j>>1]|0;t=s&-769;b[j>>1]=t;mj(a);return}else{r=b8[c[a+44>>2]&255](c[a+32>>2]|0,o)|0;b[f>>1]=r;s=b[j>>1]|0;t=s&-769;b[j>>1]=t;mj(a);return}}function ie(b){b=b|0;var d=0,e=0;d=c[b+104>>2]|0;if((d|0)!=0){b5[d&255](c[b+92>>2]|0,a[b+128|0]|0,a[b+129|0]|0)}if((c[b>>2]&8|0)==0){e=1;return e|0}id(b,6);d=b+1200|0;c[d>>2]=(c[d>>2]|0)+50;e=0;return e|0}function ig(d){d=d|0;var e=0;e=d+1216|0;c[e>>2]=0;c[e+4>>2]=0;c[d+80>>2]=1048575;zP(d+4|0,0,24);b[d+22>>1]=-4096;b[d+28>>1]=-16;b[d+30>>1]=0;c[d+124>>2]=0;a[d+156|0]=0;c[d+152>>2]=0;c[d+144>>2]=0;return}function ih(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=d+152|0;if((c[f>>2]|0)!=0){g=d+1200|0;c[g>>2]=(c[g>>2]|0)+2;h=d+156|0;if((a[h]|0)==0){return}if((b[d+30>>1]&512)==0){return}a[h]=0;c[f>>2]=0;h=c[d+88>>2]|0;if((h|0)==0){return}i=b1[h&1023](c[d+84>>2]|0)|0;c[g>>2]=(c[g>>2]|0)+61;id(d,i&255);return}i=d+144|0;if((c[i>>2]&32|0)==0){c[i>>2]=0;g=d+28|0;b[d+112>>1]=b[g>>1]|0;j=g}else{j=d+28|0}g=d+30|0;h=b[g>>1]|0;k=d+156|0;l=a[k]|0;m=d+157|0;a[m]=1;n=d+100|0;o=d+128|0;p=d+1200|0;q=d+92|0;r=d+129|0;do{mH(d);c[i>>2]=c[i>>2]&-2;s=c[n>>2]|0;if((s|0)!=0){b5[s&255](c[q>>2]|0,a[o]|0,a[r]|0)}s=b1[c[d+160+((a[o]&255)<<2)>>2]&1023](d)|0;if((s|0)==0){c[p>>2]=(c[p>>2]|0)+10}else{b[j>>1]=(e[j>>1]|0)+s&65535;mk(d,s)}}while((c[i>>2]&1|0)!=0);i=d+1216|0;j=zW(c[i>>2]|0,c[i+4>>2]|0,1,0)|0;c[i>>2]=j;c[i+4>>2]=G;if((a[m]|0)==0){return}m=b[g>>1]|0;if((h&256&m)<<16>>16!=0){id(d,1);return}if(l<<24>>24==0){return}if((a[k]|0)==0){return}if((m&512)==0){return}a[k]=0;c[f>>2]=0;f=c[d+88>>2]|0;if((f|0)==0){return}k=b1[f&1023](c[d+84>>2]|0)|0;c[p>>2]=(c[p>>2]|0)+61;id(d,k&255);return}function ii(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=a+1200|0;e=c[d>>2]|0;f=a+1208|0;if(e>>>0>b>>>0){g=b;h=e}else{i=b;b=e;while(1){e=i-b|0;j=zW(c[f>>2]|0,c[f+4>>2]|0,b,0)|0;c[f>>2]=j;c[f+4>>2]=G;c[d>>2]=0;ih(a);j=c[d>>2]|0;if(e>>>0<j>>>0){g=e;h=j;break}else{i=e;b=j}}}c[d>>2]=h-g;h=zW(c[f>>2]|0,c[f+4>>2]|0,g,0)|0;c[f>>2]=h;c[f+4>>2]=G;return}function ij(a){a=a|0;var e=0,f=0,g=0;c[a+1184>>2]=1;b[a+1192>>1]=b[a+26>>1]|0;e=(b[a+16>>1]|0)+(b[a+10>>1]|0)&65535;f=a+1194|0;b[f>>1]=e;g=c[a+1188>>2]|0;b[f>>1]=((d[g+2|0]|0)<<8|(d[g+1|0]|0))+e&65535;b[a+1196>>1]=3;e=a+1200|0;c[e>>2]=(c[e>>2]|0)+11;return}function ik(a){a=a|0;var e=0,f=0,g=0;c[a+1184>>2]=1;b[a+1192>>1]=b[a+26>>1]|0;e=(b[a+18>>1]|0)+(b[a+10>>1]|0)&65535;f=a+1194|0;b[f>>1]=e;g=c[a+1188>>2]|0;b[f>>1]=((d[g+2|0]|0)<<8|(d[g+1|0]|0))+e&65535;b[a+1196>>1]=3;e=a+1200|0;c[e>>2]=(c[e>>2]|0)+12;return}function il(a){a=a|0;var e=0,f=0,g=0;c[a+1184>>2]=1;b[a+1192>>1]=b[a+24>>1]|0;e=(b[a+16>>1]|0)+(b[a+14>>1]|0)&65535;f=a+1194|0;b[f>>1]=e;g=c[a+1188>>2]|0;b[f>>1]=((d[g+2|0]|0)<<8|(d[g+1|0]|0))+e&65535;b[a+1196>>1]=3;e=a+1200|0;c[e>>2]=(c[e>>2]|0)+12;return}function im(a){a=a|0;var e=0,f=0,g=0;c[a+1184>>2]=1;b[a+1192>>1]=b[a+24>>1]|0;e=(b[a+18>>1]|0)+(b[a+14>>1]|0)&65535;f=a+1194|0;b[f>>1]=e;g=c[a+1188>>2]|0;b[f>>1]=((d[g+2|0]|0)<<8|(d[g+1|0]|0))+e&65535;b[a+1196>>1]=3;e=a+1200|0;c[e>>2]=(c[e>>2]|0)+11;return}function io(a){a=a|0;var e=0,f=0,g=0;c[a+1184>>2]=1;b[a+1192>>1]=b[a+26>>1]|0;e=b[a+16>>1]|0;f=a+1194|0;b[f>>1]=e;g=c[a+1188>>2]|0;b[f>>1]=((d[g+2|0]|0)<<8|(d[g+1|0]|0))+e&65535;b[a+1196>>1]=3;e=a+1200|0;c[e>>2]=(c[e>>2]|0)+9;return}function ip(a){a=a|0;var e=0,f=0,g=0;c[a+1184>>2]=1;b[a+1192>>1]=b[a+26>>1]|0;e=b[a+18>>1]|0;f=a+1194|0;b[f>>1]=e;g=c[a+1188>>2]|0;b[f>>1]=((d[g+2|0]|0)<<8|(d[g+1|0]|0))+e&65535;b[a+1196>>1]=3;e=a+1200|0;c[e>>2]=(c[e>>2]|0)+9;return}function iq(a){a=a|0;var e=0,f=0,g=0;c[a+1184>>2]=1;b[a+1192>>1]=b[a+24>>1]|0;e=b[a+14>>1]|0;f=a+1194|0;b[f>>1]=e;g=c[a+1188>>2]|0;b[f>>1]=((d[g+2|0]|0)<<8|(d[g+1|0]|0))+e&65535;b[a+1196>>1]=3;e=a+1200|0;c[e>>2]=(c[e>>2]|0)+9;return}function ir(a){a=a|0;var e=0,f=0,g=0;c[a+1184>>2]=1;b[a+1192>>1]=b[a+26>>1]|0;e=b[a+10>>1]|0;f=a+1194|0;b[f>>1]=e;g=c[a+1188>>2]|0;b[f>>1]=((d[g+2|0]|0)<<8|(d[g+1|0]|0))+e&65535;b[a+1196>>1]=3;e=a+1200|0;c[e>>2]=(c[e>>2]|0)+9;return}function is(d){d=d|0;c[d+1184>>2]=0;b[d+1192>>1]=0;b[d+1194>>1]=a[c[d+1188>>2]|0]&7;b[d+1196>>1]=1;c[d+1200>>2]=0;return}function it(c,d){c=c|0;d=d|0;var e=0,f=0;e=d&255;if(d<<24>>24==0){f=64}else{f=(e&128|0)==0?0:128}d=c+30|0;b[d>>1]=b[d>>1]&-197|((a[872+e|0]|0)==0?f|4:f);return}function iu(c,d){c=c|0;d=d|0;var e=0,f=0;e=d&65535;if(d<<16>>16==0){f=64}else{f=(e&32768|0)==0?0:128}d=c+30|0;b[d>>1]=b[d>>1]&-197|((a[872+(e&255)|0]|0)==0?f|4:f);return}function iv(c,d){c=c|0;d=d|0;var e=0,f=0;e=d&255;if(d<<24>>24==0){f=64}else{f=(e&128|0)==0?0:128}d=c+30|0;b[d>>1]=((a[872+e|0]|0)==0?f|4:f)&196|b[d>>1]&-2246;return}function iw(c,d){c=c|0;d=d|0;var e=0,f=0;e=d&65535;if(d<<16>>16==0){f=64}else{f=(e&32768|0)==0?0:128}d=c+30|0;b[d>>1]=((a[872+(e&255)|0]|0)==0?f|4:f)&196|b[d>>1]&-2246;return}function ix(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=e+d&255;g=f&255;if(f<<24>>24==0){h=64}else{h=(g&128|0)==0?0:128}f=c+30|0;c=(e&255)+(d&255)&65535;i=(c&65280|0)!=0|0;j=((c^e&255)&128&(c^d&255)|0)==0?i:i|2048;b[f>>1]=b[f>>1]&-2262|(((c^(e^d)&255)&16|0)==0?j:j|16)|((a[872+g|0]|0)==0?h|4:h)&196;return}function iy(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d&65535;g=e&65535;h=e+d&65535;i=h&65535;if(h<<16>>16==0){j=64}else{j=(i&32768|0)==0?0:128}h=c+30|0;c=g+f|0;k=c>>>0>65535|0;l=((c^g)&32768&(c^f)|0)==0?k:k|2048;b[h>>1]=b[h>>1]&-2262|((((e^d)&65535^c)&16|0)==0?l:l|16)|((a[872+(i&255)|0]|0)==0?j|4:j)&196;return}function iz(c,d,e,f){c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=(e+d&255)+f&255;h=g&255;if(g<<24>>24==0){i=64}else{i=(h&128|0)==0?0:128}g=c+30|0;c=((e&255)+(d&255)&65535)+(f&255)&65535;f=(c&65280|0)!=0|0;j=((c^e&255)&128&(c^d&255)|0)==0?f:f|2048;b[g>>1]=b[g>>1]&-2262|(((c^(e^d)&255)&16|0)==0?j:j|16)|((a[872+h|0]|0)==0?i|4:i)&196;return}function iA(c,d,e,f){c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=d&65535;h=e&65535;i=(e+d&65535)+f&65535;j=i&65535;if(i<<16>>16==0){k=64}else{k=(j&32768|0)==0?0:128}i=c+30|0;c=h+g+(f&65535)|0;f=c>>>0>65535|0;l=((c^h)&32768&(c^g)|0)==0?f:f|2048;b[i>>1]=b[i>>1]&-2262|(((c^(e^d)&65535)&16|0)==0?l:l|16)|((a[872+(j&255)|0]|0)==0?k|4:k)&196;return}function iB(c,d,e,f){c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=d&255;h=g-(e&255)-(f&255)|0;if((h&255)<<24>>24==0){i=64}else{i=(h&128|0)==0?0:128}f=c+30|0;c=(h&65280|0)!=0|0;j=(e^d)&255;d=(j&128&(h^g)|0)==0?c:c|2048;b[f>>1]=b[f>>1]&-2262|(((h^j)&16|0)==0?d:d|16)|((a[872+(h&255)|0]|0)==0?i|4:i)&196;return}function iC(c,d,e,f){c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=d&65535;h=d-e&65535;i=h-f&65535;if(h<<16>>16==f<<16>>16){j=64}else{j=(i&32768|0)==0?0:128}h=c+30|0;c=g-(e&65535)-(f&65535)|0;f=c>>>0>65535|0;k=(e^d)&65535;d=(k&32768&(c^g)|0)==0?f:f|2048;b[h>>1]=b[h>>1]&-2262|(((c^k)&16|0)==0?d:d|16)|((a[872+(i&255)|0]|0)==0?j|4:j)&196;return}function iD(a,e){a=a|0;e=e|0;var f=0;c[a+1188>>2]=e;f=d[e]|0;b2[c[14248+((f>>>3&24|f&7)<<2)>>2]&255](a);if((c[a+144>>2]&2|0)==0){return}b[a+1192>>1]=b[a+148>>1]|0;f=a+1200|0;c[f>>2]=(c[f>>2]|0)+2;return}function iE(b){b=b|0;var d=0,f=0,g=0;if((c[b+1184>>2]|0)==0){d=e[b+1194>>1]|0;f=e[b+4+((d&3)<<1)>>1]|0;g=((d&4|0)!=0?f>>>8:f)&255;return g|0}f=((e[b+1192>>1]|0)<<4)+(e[b+1194>>1]|0)&c[b+80>>2];if(f>>>0<(c[b+76>>2]|0)>>>0){g=a[(c[b+72>>2]|0)+f|0]|0;return g|0}else{g=b8[c[b+36>>2]&255](c[b+32>>2]|0,f)|0;return g|0}return 0}function iF(a){a=a|0;var f=0,g=0,h=0,i=0;if((c[a+1184>>2]|0)==0){f=b[a+4+((b[a+1194>>1]&7)<<1)>>1]|0;return f|0}g=b[a+1194>>1]|0;if((c[a>>2]&64|0)==0){if((g&1)!=0){h=3073}}else{h=3073}if((h|0)==3073){h=a+1200|0;c[h>>2]=(c[h>>2]|0)+4}h=((e[a+1192>>1]|0)<<4)+(g&65535)&c[a+80>>2];g=h+1|0;if(g>>>0<(c[a+76>>2]|0)>>>0){i=c[a+72>>2]|0;f=(d[i+g|0]|0)<<8|(d[i+h|0]|0);return f|0}else{f=b8[c[a+44>>2]&255](c[a+32>>2]|0,h)|0;return f|0}return 0}function iG(d,f){d=d|0;f=f|0;var g=0,h=0,i=0;if((c[d+1184>>2]|0)==0){g=e[d+1194>>1]|0;h=d+4+((g&3)<<1)|0;i=b[h>>1]|0;if((g&4|0)==0){b[h>>1]=i&-256|f&255;return}else{b[h>>1]=i&255|(f&255)<<8;return}}else{i=((e[d+1192>>1]|0)<<4)+(e[d+1194>>1]|0)&c[d+80>>2];if(i>>>0<(c[d+76>>2]|0)>>>0){a[(c[d+72>>2]|0)+i|0]=f;return}else{b5[c[d+40>>2]&255](c[d+32>>2]|0,i,f);return}}}function iH(d,f){d=d|0;f=f|0;var g=0,h=0,i=0;if((c[d+1184>>2]|0)==0){b[d+4+((b[d+1194>>1]&7)<<1)>>1]=f;return}g=b[d+1194>>1]|0;if((c[d>>2]&64|0)==0){if((g&1)!=0){h=3097}}else{h=3097}if((h|0)==3097){h=d+1200|0;c[h>>2]=(c[h>>2]|0)+4}h=((e[d+1192>>1]|0)<<4)+(g&65535)&c[d+80>>2];g=h+1|0;if(g>>>0<(c[d+76>>2]|0)>>>0){i=d+72|0;a[(c[i>>2]|0)+h|0]=f&255;a[(c[i>>2]|0)+g|0]=(f&65535)>>>8&255;return}else{b5[c[d+48>>2]&255](c[d+32>>2]|0,h,f);return}}function iI(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d&255;g=f-(e&255)|0;if((g&255)<<24>>24==0){h=64}else{h=(g&128|0)==0?0:128}i=c+30|0;c=(g&65280|0)!=0|0;j=(e^d)&255;d=(j&128&(g^f)|0)==0?c:c|2048;b[i>>1]=b[i>>1]&-2262|(((j^g)&16|0)==0?d:d|16)|((a[872+(g&255)|0]|0)==0?h|4:h)&196;return}function iJ(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=d&65535;g=d-e&65535;if(d<<16>>16==e<<16>>16){h=64}else{h=(g&32768|0)==0?0:128}i=c+30|0;c=f-(e&65535)|0;j=c>>>0>65535|0;k=(e^d)&65535;d=(k&32768&(c^f)|0)==0?j:j|2048;b[i>>1]=b[i>>1]&-2262|(((k^c)&16|0)==0?d:d|16)|((a[872+(g&255)|0]|0)==0?h|4:h)&196;return}function iK(d,f){d=d|0;f=f|0;var g=0,h=0,i=0;g=d+12|0;h=(b[g>>1]|0)-2&65535;b[g>>1]=h;g=((e[d+24>>1]|0)<<4)+(h&65535)&c[d+80>>2];h=g+1|0;if(h>>>0<(c[d+76>>2]|0)>>>0){i=d+72|0;a[(c[i>>2]|0)+g|0]=f&255;a[(c[i>>2]|0)+h|0]=(f&65535)>>>8&255;return}else{b5[c[d+48>>2]&255](c[d+32>>2]|0,g,f);return}}function iL(a){a=a|0;var f=0,g=0,h=0,i=0;f=a+12|0;g=b[f>>1]|0;b[f>>1]=g+2&65535;f=((e[a+24>>1]|0)<<4)+(g&65535)&c[a+80>>2];g=f+1|0;if(g>>>0<(c[a+76>>2]|0)>>>0){h=c[a+72>>2]|0;i=(d[h+g|0]|0)<<8|(d[h+f|0]|0);return i|0}else{i=b8[c[a+44>>2]&255](c[a+32>>2]|0,f)|0;return i|0}return 0}function iM(a){a=a|0;var f=0,g=0,h=0,i=0;f=a+129|0;iD(a,f);g=iE(a)|0;h=(d[f]|0)>>>3;f=b[a+4+((h&3)<<1)>>1]|0;i=(h&4|0)!=0?(f&65535)>>>8:f;iG(a,i+(g&255)&255);ix(a,g,i&255);i=a+1200|0;c[i>>2]=((c[a+1184>>2]|0)!=0?16:3)+(c[i>>2]|0);return(e[a+1196>>1]|0)+1|0}function iN(a){a=a|0;var f=0,g=0,h=0;f=a+129|0;iD(a,f);g=iF(a)|0;h=b[a+4+(((d[f]|0)>>>3&7)<<1)>>1]|0;iH(a,h+g&65535);iy(a,g,h);h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?16:3)+(c[h>>2]|0);return(e[a+1196>>1]|0)+1|0}function iO(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=a+129|0;g=(d[f]|0)>>>3;iD(a,f);f=(g&4|0)!=0;h=a+4+((g&3)<<1)|0;g=b[h>>1]|0;i=f?(g&65535)>>>8:g;g=iE(a)|0;j=i+(g&255)&65535;k=b[h>>1]|0;if(f){l=j<<8|k&255}else{l=j&255|k&-256}b[h>>1]=l;ix(a,i&255,g);g=a+1200|0;c[g>>2]=((c[a+1184>>2]|0)!=0?9:3)+(c[g>>2]|0);return(e[a+1196>>1]|0)+1|0}function iP(a){a=a|0;var f=0,g=0,h=0;f=a+129|0;g=(d[f]|0)>>>3&7;iD(a,f);f=a+4+(g<<1)|0;g=b[f>>1]|0;h=iF(a)|0;b[f>>1]=h+g&65535;iy(a,g,h);h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?9:3)+(c[h>>2]|0);return(e[a+1196>>1]|0)+1|0}function iQ(d){d=d|0;var e=0,f=0,g=0;e=d+4|0;f=b[e>>1]|0;g=a[d+129|0]|0;b[e>>1]=(g&255)+f&255|f&-256;ix(d,f&255,g);g=d+1200|0;c[g>>2]=(c[g>>2]|0)+4;return 2}function iR(a){a=a|0;var e=0,f=0,g=0;e=a+4|0;f=b[e>>1]|0;g=(d[a+130|0]|0)<<8|(d[a+129|0]|0);b[e>>1]=g+(f&65535)&65535;iy(a,f,g&65535);g=a+1200|0;c[g>>2]=(c[g>>2]|0)+4;return 3}function iS(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=b[d+20>>1]|0;g=d+12|0;h=(b[g>>1]|0)-2&65535;b[g>>1]=h;g=((e[d+24>>1]|0)<<4)+(h&65535)&c[d+80>>2];h=g+1|0;if(h>>>0<(c[d+76>>2]|0)>>>0){i=d+72|0;a[(c[i>>2]|0)+g|0]=f&255;a[(c[i>>2]|0)+h|0]=(f&65535)>>>8&255;j=d+1200|0;k=c[j>>2]|0;l=k+10|0;c[j>>2]=l;return 1}else{b5[c[d+48>>2]&255](c[d+32>>2]|0,g,f);j=d+1200|0;k=c[j>>2]|0;l=k+10|0;c[j>>2]=l;return 1}return 0}function iT(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a+12|0;g=b[f>>1]|0;b[f>>1]=g+2&65535;f=((e[a+24>>1]|0)<<4)+(g&65535)&c[a+80>>2];g=f+1|0;if(g>>>0<(c[a+76>>2]|0)>>>0){h=c[a+72>>2]|0;i=(d[h+g|0]|0)<<8|(d[h+f|0]|0);j=a+20|0;b[j>>1]=i;k=a+1200|0;l=c[k>>2]|0;m=l+8|0;c[k>>2]=m;return 1}else{i=b8[c[a+44>>2]&255](c[a+32>>2]|0,f)|0;j=a+20|0;b[j>>1]=i;k=a+1200|0;l=c[k>>2]|0;m=l+8|0;c[k>>2]=m;return 1}return 0}function iU(a){a=a|0;var f=0,g=0,h=0,i=0;f=a+129|0;iD(a,f);g=iE(a)|0;h=(d[f]|0)>>>3;f=b[a+4+((h&3)<<1)>>1]|0;i=(((h&4|0)!=0?(f&65535)>>>8:f)|g&255)&255;iG(a,i);iv(a,i);i=a+1200|0;c[i>>2]=((c[a+1184>>2]|0)!=0?16:3)+(c[i>>2]|0);return(e[a+1196>>1]|0)+1|0}function iV(a){a=a|0;var f=0,g=0,h=0;f=a+129|0;iD(a,f);g=iF(a)|0;h=b[a+4+(((d[f]|0)>>>3&7)<<1)>>1]|g;iH(a,h);iw(a,h);h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?16:3)+(c[h>>2]|0);return(e[a+1196>>1]|0)+1|0}function iW(a){a=a|0;var f=0,g=0,h=0,i=0,j=0;f=a+129|0;g=(d[f]|0)>>>3;iD(a,f);f=(g&4|0)!=0;h=a+4+((g&3)<<1)|0;g=b[h>>1]|0;i=(f?(g&65535)>>>8:g)&255|(iE(a)|0)&255;g=b[h>>1]|0;if(f){j=i<<8|g&255}else{j=i|g&-256}b[h>>1]=j;iv(a,i&255);i=a+1200|0;c[i>>2]=((c[a+1184>>2]|0)!=0?9:3)+(c[i>>2]|0);return(e[a+1196>>1]|0)+1|0}function iX(a){a=a|0;var f=0,g=0,h=0;f=a+129|0;g=(d[f]|0)>>>3&7;iD(a,f);f=a+4+(g<<1)|0;g=b[f>>1]|0;h=iF(a)|0|g;b[f>>1]=h;iw(a,h);h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?9:3)+(c[h>>2]|0);return(e[a+1196>>1]|0)+1|0}function iY(a){a=a|0;var e=0,f=0;e=a+4|0;f=d[a+129|0]|0|b[e>>1];b[e>>1]=f;iv(a,f&255);f=a+1200|0;c[f>>2]=(c[f>>2]|0)+4;return 2}function iZ(a){a=a|0;var e=0,f=0;e=a+4|0;f=d[a+129|0]|0|b[e>>1]|(d[a+130|0]|0)<<8;b[e>>1]=f;iw(a,f);f=a+1200|0;c[f>>2]=(c[f>>2]|0)+4;return 3}function i_(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=b[d+22>>1]|0;g=d+12|0;h=(b[g>>1]|0)-2&65535;b[g>>1]=h;g=((e[d+24>>1]|0)<<4)+(h&65535)&c[d+80>>2];h=g+1|0;if(h>>>0<(c[d+76>>2]|0)>>>0){i=d+72|0;a[(c[i>>2]|0)+g|0]=f&255;a[(c[i>>2]|0)+h|0]=(f&65535)>>>8&255;j=d+1200|0;k=c[j>>2]|0;l=k+10|0;c[j>>2]=l;return 1}else{b5[c[d+48>>2]&255](c[d+32>>2]|0,g,f);j=d+1200|0;k=c[j>>2]|0;l=k+10|0;c[j>>2]=l;return 1}return 0}function i$(a){a=a|0;var f=0,g=0,h=0,i=0,j=0;f=a+12|0;g=b[f>>1]|0;b[f>>1]=g+2&65535;f=((e[a+24>>1]|0)<<4)+(g&65535)&c[a+80>>2];g=f+1|0;if(g>>>0<(c[a+76>>2]|0)>>>0){h=c[a+72>>2]|0;i=(d[h+g|0]|0)<<8|(d[h+f|0]|0);j=a+22|0;b[j>>1]=i;mj(a);return 1}else{i=b8[c[a+44>>2]&255](c[a+32>>2]|0,f)|0;j=a+22|0;b[j>>1]=i;mj(a);return 1}return 0}function i0(a){a=a|0;var f=0,g=0,h=0,i=0;f=a+129|0;iD(a,f);g=iE(a)|0;h=(d[f]|0)>>>3;f=b[a+4+((h&3)<<1)>>1]|0;i=(h&4|0)!=0?(f&65535)>>>8:f;f=b[a+30>>1]&1;iG(a,(f+(g&255)&65535)+i&255);iz(a,g,i&255,f&255);f=a+1200|0;c[f>>2]=((c[a+1184>>2]|0)!=0?16:3)+(c[f>>2]|0);return(e[a+1196>>1]|0)+1|0}function i1(a){a=a|0;var f=0,g=0,h=0;f=a+129|0;iD(a,f);g=iF(a)|0;h=b[a+4+(((d[f]|0)>>>3&7)<<1)>>1]|0;f=b[a+30>>1]&1;iH(a,(h+g&65535)+f&65535);iA(a,g,h,f);f=a+1200|0;c[f>>2]=((c[a+1184>>2]|0)!=0?16:3)+(c[f>>2]|0);return(e[a+1196>>1]|0)+1|0}function i2(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a+129|0;g=(d[f]|0)>>>3;iD(a,f);f=(g&4|0)!=0;h=a+4+((g&3)<<1)|0;g=b[h>>1]|0;i=f?(g&65535)>>>8:g;g=iE(a)|0;j=b[a+30>>1]&1;k=(i+(g&255)&65535)+j&65535;l=b[h>>1]|0;if(f){m=k<<8|l&255}else{m=k&255|l&-256}b[h>>1]=m;iz(a,i&255,g,j&255);j=a+1200|0;c[j>>2]=((c[a+1184>>2]|0)!=0?9:3)+(c[j>>2]|0);return(e[a+1196>>1]|0)+1|0}function i3(a){a=a|0;var f=0,g=0,h=0,i=0;f=a+129|0;g=(d[f]|0)>>>3&7;iD(a,f);f=a+4+(g<<1)|0;g=b[f>>1]|0;h=iF(a)|0;i=b[a+30>>1]&1;b[f>>1]=(h+g&65535)+i&65535;iA(a,g,h,i);i=a+1200|0;c[i>>2]=((c[a+1184>>2]|0)!=0?9:3)+(c[i>>2]|0);return(e[a+1196>>1]|0)+1|0}function i4(d){d=d|0;var e=0,f=0,g=0,h=0;e=d+4|0;f=b[e>>1]|0;g=a[d+129|0]|0;h=b[d+30>>1]&1;b[e>>1]=((g&255)+f&65535)+h&255|f&-256;iz(d,f&255,g,h&255);h=d+1200|0;c[h>>2]=(c[h>>2]|0)+4;return 2}function i5(a){a=a|0;var e=0,f=0,g=0,h=0;e=a+4|0;f=b[e>>1]|0;g=(d[a+130|0]|0)<<8|(d[a+129|0]|0);h=b[a+30>>1]&1;b[e>>1]=g+(f&65535)+(h&65535)&65535;iA(a,f,g&65535,h);h=a+1200|0;c[h>>2]=(c[h>>2]|0)+4;return 3}function i6(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b[d+24>>1]|0;f=d+12|0;g=(b[f>>1]|0)-2&65535;b[f>>1]=g;f=((e&65535)<<4)+(g&65535)&c[d+80>>2];g=f+1|0;if(g>>>0<(c[d+76>>2]|0)>>>0){h=d+72|0;a[(c[h>>2]|0)+f|0]=e&255;a[(c[h>>2]|0)+g|0]=(e&65535)>>>8&255;i=d+1200|0;j=c[i>>2]|0;k=j+10|0;c[i>>2]=k;return 1}else{b5[c[d+48>>2]&255](c[d+32>>2]|0,f,e);i=d+1200|0;j=c[i>>2]|0;k=j+10|0;c[i>>2]=k;return 1}return 0}function i7(a){a=a|0;var d=0;d=a+144|0;c[d>>2]=c[d>>2]|3;b[a+148>>1]=b[a+20>>1]|0;return 1}function i8(a){a=a|0;var d=0;d=a+144|0;c[d>>2]=c[d>>2]|3;b[a+148>>1]=b[a+22>>1]|0;return 1}function i9(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f+12|0;h=b[g>>1]|0;b[g>>1]=h+2&65535;g=f+24|0;i=((e[g>>1]|0)<<4)+(h&65535)&c[f+80>>2];h=i+1|0;if(h>>>0<(c[f+76>>2]|0)>>>0){j=c[f+72>>2]|0;k=(d[j+h|0]|0)<<8|(d[j+i|0]|0);b[g>>1]=k;l=f+1200|0;m=c[l>>2]|0;n=m+8|0;c[l>>2]=n;o=f+157|0;a[o]=0;return 1}else{k=b8[c[f+44>>2]&255](c[f+32>>2]|0,i)|0;b[g>>1]=k;l=f+1200|0;m=c[l>>2]|0;n=m+8|0;c[l>>2]=n;o=f+157|0;a[o]=0;return 1}return 0}function ja(a){a=a|0;var f=0,g=0,h=0,i=0;f=a+129|0;iD(a,f);g=iE(a)|0;h=(d[f]|0)>>>3;f=b[a+4+((h&3)<<1)>>1]|0;i=(h&4|0)!=0?(f&65535)>>>8:f;f=b[a+30>>1]&1;iG(a,((g&255)-f&65535)-i&255);iB(a,g,i&255,f&255);f=a+1200|0;c[f>>2]=((c[a+1184>>2]|0)!=0?16:3)+(c[f>>2]|0);return(e[a+1196>>1]|0)+1|0}function jb(a){a=a|0;var f=0,g=0,h=0;f=a+129|0;iD(a,f);g=iF(a)|0;h=b[a+4+(((d[f]|0)>>>3&7)<<1)>>1]|0;f=b[a+30>>1]&1;iH(a,(g-h&65535)-f&65535);iC(a,g,h,f);f=a+1200|0;c[f>>2]=((c[a+1184>>2]|0)!=0?16:3)+(c[f>>2]|0);return(e[a+1196>>1]|0)+1|0}function jc(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a+129|0;g=(d[f]|0)>>>3;iD(a,f);f=(g&4|0)!=0;h=a+4+((g&3)<<1)|0;g=b[h>>1]|0;i=f?(g&65535)>>>8:g;g=iE(a)|0;j=b[a+30>>1]&1;k=(i-(g&255)&65535)-j&65535;l=b[h>>1]|0;if(f){m=k<<8|l&255}else{m=k&255|l&-256}b[h>>1]=m;iB(a,i&255,g,j&255);j=a+1200|0;c[j>>2]=((c[a+1184>>2]|0)!=0?9:3)+(c[j>>2]|0);return(e[a+1196>>1]|0)+1|0}function jd(a){a=a|0;var f=0,g=0,h=0,i=0;f=a+129|0;g=(d[f]|0)>>>3&7;iD(a,f);f=a+4+(g<<1)|0;g=b[f>>1]|0;h=iF(a)|0;i=b[a+30>>1]&1;b[f>>1]=(g-h&65535)-i&65535;iC(a,g,h,i);i=a+1200|0;c[i>>2]=((c[a+1184>>2]|0)!=0?9:3)+(c[i>>2]|0);return(e[a+1196>>1]|0)+1|0}function je(d){d=d|0;var e=0,f=0,g=0,h=0;e=d+4|0;f=b[e>>1]|0;g=a[d+129|0]|0;h=b[d+30>>1]&1;b[e>>1]=(f-(g&255)&65535)-h&255|f&-256;iB(d,f&255,g,h&255);h=d+1200|0;c[h>>2]=(c[h>>2]|0)+4;return 2}function jf(a){a=a|0;var e=0,f=0,g=0,h=0;e=a+4|0;f=b[e>>1]|0;g=(d[a+130|0]|0)<<8|(d[a+129|0]|0);h=b[a+30>>1]&1;b[e>>1]=(f&65535)-g-(h&65535)&65535;iC(a,f,g&65535,h);h=a+1200|0;c[h>>2]=(c[h>>2]|0)+4;return 3}function jg(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=b[d+26>>1]|0;g=d+12|0;h=(b[g>>1]|0)-2&65535;b[g>>1]=h;g=((e[d+24>>1]|0)<<4)+(h&65535)&c[d+80>>2];h=g+1|0;if(h>>>0<(c[d+76>>2]|0)>>>0){i=d+72|0;a[(c[i>>2]|0)+g|0]=f&255;a[(c[i>>2]|0)+h|0]=(f&65535)>>>8&255;j=d+1200|0;k=c[j>>2]|0;l=k+10|0;c[j>>2]=l;return 1}else{b5[c[d+48>>2]&255](c[d+32>>2]|0,g,f);j=d+1200|0;k=c[j>>2]|0;l=k+10|0;c[j>>2]=l;return 1}return 0}function jh(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a+12|0;g=b[f>>1]|0;b[f>>1]=g+2&65535;f=((e[a+24>>1]|0)<<4)+(g&65535)&c[a+80>>2];g=f+1|0;if(g>>>0<(c[a+76>>2]|0)>>>0){h=c[a+72>>2]|0;i=(d[h+g|0]|0)<<8|(d[h+f|0]|0);j=a+26|0;b[j>>1]=i;k=a+1200|0;l=c[k>>2]|0;m=l+8|0;c[k>>2]=m;return 1}else{i=b8[c[a+44>>2]&255](c[a+32>>2]|0,f)|0;j=a+26|0;b[j>>1]=i;k=a+1200|0;l=c[k>>2]|0;m=l+8|0;c[k>>2]=m;return 1}return 0}function ji(a){a=a|0;var f=0,g=0,h=0,i=0;f=a+129|0;iD(a,f);g=iE(a)|0;h=(d[f]|0)>>>3;f=b[a+4+((h&3)<<1)>>1]|0;i=((h&4|0)!=0?(f&65535)>>>8:f)&(g&255)&255;iG(a,i);iv(a,i);i=a+1200|0;c[i>>2]=((c[a+1184>>2]|0)!=0?16:3)+(c[i>>2]|0);return(e[a+1196>>1]|0)+1|0}function jj(a){a=a|0;var f=0,g=0,h=0;f=a+129|0;iD(a,f);g=iF(a)|0;h=b[a+4+(((d[f]|0)>>>3&7)<<1)>>1]&g;iH(a,h);iw(a,h);h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?16:3)+(c[h>>2]|0);return(e[a+1196>>1]|0)+1|0}function jk(a){a=a|0;var f=0,g=0,h=0,i=0,j=0;f=a+129|0;g=(d[f]|0)>>>3;iD(a,f);f=(g&4|0)!=0;h=a+4+((g&3)<<1)|0;g=b[h>>1]|0;i=(f?(g&65535)>>>8:g)&((iE(a)|0)&255);g=b[h>>1]|0;if(f){j=i<<8|g&255}else{j=i|g&-256}b[h>>1]=j;iv(a,i&255);i=a+1200|0;c[i>>2]=((c[a+1184>>2]|0)!=0?9:3)+(c[i>>2]|0);return(e[a+1196>>1]|0)+1|0}function jl(a){a=a|0;var f=0,g=0,h=0;f=a+129|0;g=(d[f]|0)>>>3&7;iD(a,f);f=a+4+(g<<1)|0;g=b[f>>1]|0;h=(iF(a)|0)&g;b[f>>1]=h;iw(a,h);h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?9:3)+(c[h>>2]|0);return(e[a+1196>>1]|0)+1|0}function jm(a){a=a|0;var e=0,f=0,g=0;e=a+4|0;f=b[e>>1]|0;g=(d[a+129|0]|0)&f;b[e>>1]=g|f&-256;iv(a,g&255);g=a+1200|0;c[g>>2]=(c[g>>2]|0)+4;return 2}function jn(a){a=a|0;var e=0,f=0;e=a+4|0;f=((d[a+130|0]|0)<<8|(d[a+129|0]|0))&b[e>>1];b[e>>1]=f;iw(a,f);f=a+1200|0;c[f>>2]=(c[f>>2]|0)+4;return 3}function jo(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=a+4|0;e=b[d>>1]|0;f=e&65535;g=f&255;h=a+30|0;i=b[h>>1]|0;j=i&65535;k=j&1;do{if((f&14)>>>0>9){l=3221}else{if((j&16|0)!=0){l=3221;break}m=g;n=k;o=i&-17}}while(0);if((l|0)==3221){l=g+6|0;m=l;n=(l&65280|0)!=0|k;o=i|16}b[h>>1]=o;if((m&240)>>>0<145&(n|0)==0){p=m;q=o&-2}else{p=m+96|0;q=o|1}b[h>>1]=q;b[d>>1]=(e&-256&65535|p&255)&65535;it(a,p&255);p=a+1200|0;c[p>>2]=(c[p>>2]|0)+4;return 1}function jp(a){a=a|0;var f=0,g=0,h=0,i=0;f=a+129|0;iD(a,f);g=iE(a)|0;h=(d[f]|0)>>>3;f=b[a+4+((h&3)<<1)>>1]|0;i=(h&4|0)!=0?(f&65535)>>>8:f;iG(a,(g&255)-i&255);iI(a,g,i&255);i=a+1200|0;c[i>>2]=((c[a+1184>>2]|0)!=0?16:3)+(c[i>>2]|0);return(e[a+1196>>1]|0)+1|0}function jq(a){a=a|0;var f=0,g=0,h=0;f=a+129|0;iD(a,f);g=iF(a)|0;h=b[a+4+(((d[f]|0)>>>3&7)<<1)>>1]|0;iH(a,g-h&65535);iJ(a,g,h);h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?16:3)+(c[h>>2]|0);return(e[a+1196>>1]|0)+1|0}function jr(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=a+129|0;g=(d[f]|0)>>>3;iD(a,f);f=(g&4|0)!=0;h=a+4+((g&3)<<1)|0;g=b[h>>1]|0;i=f?(g&65535)>>>8:g;g=iE(a)|0;j=i-(g&255)&65535;k=b[h>>1]|0;if(f){l=j<<8|k&255}else{l=j&255|k&-256}b[h>>1]=l;iI(a,i&255,g);g=a+1200|0;c[g>>2]=((c[a+1184>>2]|0)!=0?9:3)+(c[g>>2]|0);return(e[a+1196>>1]|0)+1|0}function js(a){a=a|0;var f=0,g=0,h=0;f=a+129|0;g=(d[f]|0)>>>3&7;iD(a,f);f=a+4+(g<<1)|0;g=b[f>>1]|0;h=iF(a)|0;b[f>>1]=g-h&65535;iJ(a,g,h);h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?9:3)+(c[h>>2]|0);return(e[a+1196>>1]|0)+1|0}function jt(d){d=d|0;var e=0,f=0,g=0;e=d+4|0;f=b[e>>1]|0;g=a[d+129|0]|0;b[e>>1]=f-(g&255)&255|f&-256;iI(d,f&255,g);g=d+1200|0;c[g>>2]=(c[g>>2]|0)+4;return 2}function ju(a){a=a|0;var e=0,f=0,g=0;e=a+4|0;f=b[e>>1]|0;g=(d[a+130|0]|0)<<8|(d[a+129|0]|0);b[e>>1]=(f&65535)-g&65535;iJ(a,f,g&65535);g=a+1200|0;c[g>>2]=(c[g>>2]|0)+4;return 3}function jv(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=a+4|0;e=b[d>>1]|0;f=e&65535;g=f&255;h=a+30|0;i=b[h>>1]|0;j=i&65535;k=j&1;do{if((f&14)>>>0>9){l=3238}else{if((j&16|0)!=0){l=3238;break}m=g;n=k;o=i&-17}}while(0);if((l|0)==3238){l=g-6|0;m=l;n=(l&65280|0)!=0|k;o=i|16}b[h>>1]=o;if((m&240)>>>0<145&(n|0)==0){p=m;q=o&-2}else{p=m-96|0;q=o|1}b[h>>1]=q;b[d>>1]=(e&-256&65535|p&255)&65535;it(a,p&255);p=a+1200|0;c[p>>2]=(c[p>>2]|0)+4;return 1}function jw(a){a=a|0;var f=0,g=0,h=0,i=0;f=a+129|0;iD(a,f);g=iE(a)|0;h=(d[f]|0)>>>3;f=b[a+4+((h&3)<<1)>>1]|0;i=(((h&4|0)!=0?(f&65535)>>>8:f)^g&255)&255;iG(a,i);iv(a,i);i=a+1200|0;c[i>>2]=((c[a+1184>>2]|0)!=0?16:3)+(c[i>>2]|0);return(e[a+1196>>1]|0)+1|0}function jx(a){a=a|0;var f=0,g=0,h=0;f=a+129|0;iD(a,f);g=iF(a)|0;h=b[a+4+(((d[f]|0)>>>3&7)<<1)>>1]^g;iH(a,h);iw(a,h);h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?16:3)+(c[h>>2]|0);return(e[a+1196>>1]|0)+1|0}function jy(a){a=a|0;var f=0,g=0,h=0,i=0,j=0;f=a+129|0;g=(d[f]|0)>>>3;iD(a,f);f=(g&4|0)!=0;h=a+4+((g&3)<<1)|0;g=b[h>>1]|0;i=(f?(g&65535)>>>8:g)&255^(iE(a)|0)&255;g=b[h>>1]|0;if(f){j=i<<8|g&255}else{j=i|g&-256}b[h>>1]=j;iv(a,i&255);i=a+1200|0;c[i>>2]=((c[a+1184>>2]|0)!=0?9:3)+(c[i>>2]|0);return(e[a+1196>>1]|0)+1|0}function jz(a){a=a|0;var d=0;d=a+144|0;c[d>>2]=c[d>>2]|3;b[a+148>>1]=b[a+24>>1]|0;return 1}function jA(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=a+4|0;f=e[d>>1]|0;g=f&255;h=f>>>8;i=a+30|0;j=b[i>>1]|0;do{if((f&14)>>>0>9){k=3253}else{if((j&16)!=0){k=3253;break}b[i>>1]=j&-18;l=g;m=h}}while(0);if((k|0)==3253){b[a+30>>1]=j|17;l=g+6|0;m=h+1|0}b[d>>1]=(l&15|m<<8)&65535;m=a+1200|0;c[m>>2]=(c[m>>2]|0)+8;return 1}function jB(a){a=a|0;var d=0;d=a+144|0;c[d>>2]=c[d>>2]|3;b[a+148>>1]=b[a+26>>1]|0;return 1}function jC(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=a+4|0;f=e[d>>1]|0;g=f&255;h=f>>>8;i=a+30|0;j=b[i>>1]|0;do{if((f&14)>>>0>9){k=3259}else{if((j&16)!=0){k=3259;break}b[i>>1]=j&-18;l=g;m=h}}while(0);if((k|0)==3259){b[a+30>>1]=j|17;l=g-6|0;m=h-1|0}b[d>>1]=(l&15|m<<8)&65535;m=a+1200|0;c[m>>2]=(c[m>>2]|0)+8;return 1}function jD(a){a=a|0;var f=0,g=0,h=0;f=a+129|0;g=(d[f]|0)>>>3&7;iD(a,f);f=a+4+(g<<1)|0;g=b[f>>1]|0;h=(iF(a)|0)^g;b[f>>1]=h;iw(a,h);h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?9:3)+(c[h>>2]|0);return(e[a+1196>>1]|0)+1|0}function jE(a){a=a|0;var e=0,f=0,g=0;e=a+4|0;f=b[e>>1]|0;g=(d[a+129|0]|0)^f&255;b[e>>1]=g|f&-256;iv(a,g&255);g=a+1200|0;c[g>>2]=(c[g>>2]|0)+4;return 2}function jF(a){a=a|0;var e=0,f=0;e=a+4|0;f=((d[a+130|0]|0)<<8|(d[a+129|0]|0))^b[e>>1];b[e>>1]=f;iw(a,f);f=a+1200|0;c[f>>2]=(c[f>>2]|0)+4;return 3}function jG(a){a=a|0;var f=0,g=0,h=0;f=a+129|0;iD(a,f);g=iE(a)|0;h=(d[f]|0)>>>3;f=b[a+4+((h&3)<<1)>>1]|0;iI(a,g,((h&4|0)!=0?(f&65535)>>>8:f)&255);f=a+1200|0;c[f>>2]=((c[a+1184>>2]|0)!=0?9:3)+(c[f>>2]|0);return(e[a+1196>>1]|0)+1|0}function jH(a){a=a|0;var f=0,g=0;f=a+129|0;iD(a,f);g=iF(a)|0;iJ(a,g,b[a+4+(((d[f]|0)>>>3&7)<<1)>>1]|0);f=a+1200|0;c[f>>2]=((c[a+1184>>2]|0)!=0?9:3)+(c[f>>2]|0);return(e[a+1196>>1]|0)+1|0}function jI(a){a=a|0;var f=0,g=0;f=a+129|0;iD(a,f);g=(d[f]|0)>>>3;f=b[a+4+((g&3)<<1)>>1]|0;iI(a,((g&4|0)!=0?(f&65535)>>>8:f)&255,iE(a)|0);f=a+1200|0;c[f>>2]=((c[a+1184>>2]|0)!=0?9:3)+(c[f>>2]|0);return(e[a+1196>>1]|0)+1|0}function jJ(a){a=a|0;var f=0,g=0;f=a+129|0;iD(a,f);g=b[a+4+(((d[f]|0)>>>3&7)<<1)>>1]|0;iJ(a,g,iF(a)|0);g=a+1200|0;c[g>>2]=((c[a+1184>>2]|0)!=0?9:3)+(c[g>>2]|0);return(e[a+1196>>1]|0)+1|0}function jK(d){d=d|0;var e=0;iI(d,b[d+4>>1]&255,a[d+129|0]|0);e=d+1200|0;c[e>>2]=(c[e>>2]|0)+4;return 2}function jL(a){a=a|0;var e=0;iJ(a,b[a+4>>1]|0,(d[a+130|0]|0)<<8|(d[a+129|0]|0));e=a+1200|0;c[e>>2]=(c[e>>2]|0)+4;return 3}function jM(d){d=d|0;var e=0,f=0,g=0;e=d+4+((a[d+128|0]&7)<<1)|0;f=b[e>>1]|0;b[e>>1]=f+1&65535;e=d+30|0;g=b[e>>1]|0;iy(d,f,1);f=b[e>>1]|0;b[e>>1]=(f^g)&1^f;f=d+1200|0;c[f>>2]=(c[f>>2]|0)+3;return 1}function jN(d){d=d|0;var e=0,f=0,g=0;e=d+4+((a[d+128|0]&7)<<1)|0;f=b[e>>1]|0;b[e>>1]=f-1&65535;e=d+30|0;g=b[e>>1]|0;iJ(d,f,1);f=b[e>>1]|0;b[e>>1]=(f^g)&1^f;f=d+1200|0;c[f>>2]=(c[f>>2]|0)+3;return 1}function jO(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a[d+128|0]&7;do{if((f|0)==4){if((c[d>>2]&4|0)!=0){break}g=d+12|0;h=(b[g>>1]|0)-2&65535;b[g>>1]=h;g=((e[d+24>>1]|0)<<4)+(h&65535)&c[d+80>>2];i=g+1|0;if(i>>>0<(c[d+76>>2]|0)>>>0){j=d+72|0;a[(c[j>>2]|0)+g|0]=h&255;a[(c[j>>2]|0)+i|0]=(h&65535)>>>8&255;k=d+1200|0;l=c[k>>2]|0;m=l+10|0;c[k>>2]=m;return 1}else{b5[c[d+48>>2]&255](c[d+32>>2]|0,g,h);k=d+1200|0;l=c[k>>2]|0;m=l+10|0;c[k>>2]=m;return 1}}}while(0);h=b[d+4+(f<<1)>>1]|0;f=d+12|0;g=(b[f>>1]|0)-2&65535;b[f>>1]=g;f=((e[d+24>>1]|0)<<4)+(g&65535)&c[d+80>>2];g=f+1|0;if(g>>>0<(c[d+76>>2]|0)>>>0){i=d+72|0;a[(c[i>>2]|0)+f|0]=h&255;a[(c[i>>2]|0)+g|0]=(h&65535)>>>8&255;k=d+1200|0;l=c[k>>2]|0;m=l+10|0;c[k>>2]=m;return 1}else{b5[c[d+48>>2]&255](c[d+32>>2]|0,f,h);k=d+1200|0;l=c[k>>2]|0;m=l+10|0;c[k>>2]=m;return 1}return 0}function jP(f){f=f|0;var g=0,h=0,i=0,j=0;g=f+12|0;h=b[g>>1]|0;b[g>>1]=h+2&65535;g=((e[f+24>>1]|0)<<4)+(h&65535)&c[f+80>>2];h=g+1|0;if(h>>>0<(c[f+76>>2]|0)>>>0){i=c[f+72>>2]|0;j=(d[i+h|0]|0)<<8|(d[i+g|0]|0)}else{j=b8[c[f+44>>2]&255](c[f+32>>2]|0,g)|0}b[f+4+((a[f+128|0]&7)<<1)>>1]=j;j=f+1200|0;c[j>>2]=(c[j>>2]|0)+8;return 1}function jQ(a){a=a|0;var b=0;b=a+1200|0;c[b>>2]=(c[b>>2]|0)+1;return ie(a)|0}function jR(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[d+129|0]|0)!=102){e=d+1200|0;c[e>>2]=(c[e>>2]|0)+1;f=ie(d)|0;return f|0}e=d+22|0;g=d+28|0;h=b[g>>1]|0;i=c[d+96>>2]|0;if((i|0)==0){j=d+1200|0;c[j>>2]=(c[j>>2]|0)+16;k=b[g>>1]|0;l=k<<16>>16==h<<16>>16;m=l?4:0;return m|0}j=b[e>>1]|0;b5[i&255](c[d+92>>2]|0,a[d+130|0]|0,a[d+131|0]|0);i=b[e>>1]|0;e=d+1200|0;c[e>>2]=(c[e>>2]|0)+16;if(i<<16>>16==j<<16>>16){k=b[g>>1]|0;l=k<<16>>16==h<<16>>16;m=l?4:0;return m|0}else{f=0;return f|0}return 0}function jS(a){a=a|0;var f=0,g=0,h=0;if((b[a+30>>1]&2048)==0){f=a+1200|0;c[f>>2]=(c[f>>2]|0)+4;g=2;return g|0}else{f=d[a+129|0]|0;h=a+28|0;b[h>>1]=(e[h>>1]|0)+2+((f&128|0)!=0?f|65280:f)&65535;mj(a);f=a+1200|0;c[f>>2]=(c[f>>2]|0)+16;g=0;return g|0}return 0}function jT(a){a=a|0;var f=0,g=0,h=0;if((b[a+30>>1]&2048)==0){f=d[a+129|0]|0;g=a+28|0;b[g>>1]=(e[g>>1]|0)+2+((f&128|0)!=0?f|65280:f)&65535;mj(a);f=a+1200|0;c[f>>2]=(c[f>>2]|0)+16;h=0;return h|0}else{f=a+1200|0;c[f>>2]=(c[f>>2]|0)+4;h=2;return h|0}return 0}function jU(a){a=a|0;var f=0,g=0,h=0;if((b[a+30>>1]&1)==0){f=a+1200|0;c[f>>2]=(c[f>>2]|0)+4;g=2;return g|0}else{f=d[a+129|0]|0;h=a+28|0;b[h>>1]=(e[h>>1]|0)+2+((f&128|0)!=0?f|65280:f)&65535;mj(a);f=a+1200|0;c[f>>2]=(c[f>>2]|0)+16;g=0;return g|0}return 0}function jV(a){a=a|0;var f=0,g=0,h=0;if((b[a+30>>1]&1)==0){f=d[a+129|0]|0;g=a+28|0;b[g>>1]=(e[g>>1]|0)+2+((f&128|0)!=0?f|65280:f)&65535;mj(a);f=a+1200|0;c[f>>2]=(c[f>>2]|0)+16;h=0;return h|0}else{f=a+1200|0;c[f>>2]=(c[f>>2]|0)+4;h=2;return h|0}return 0}function jW(a){a=a|0;var f=0,g=0,h=0;if((b[a+30>>1]&64)==0){f=a+1200|0;c[f>>2]=(c[f>>2]|0)+4;g=2;return g|0}else{f=d[a+129|0]|0;h=a+28|0;b[h>>1]=(e[h>>1]|0)+2+((f&128|0)!=0?f|65280:f)&65535;mj(a);f=a+1200|0;c[f>>2]=(c[f>>2]|0)+16;g=0;return g|0}return 0}function jX(a){a=a|0;var f=0,g=0,h=0;if((b[a+30>>1]&64)==0){f=d[a+129|0]|0;g=a+28|0;b[g>>1]=(e[g>>1]|0)+2+((f&128|0)!=0?f|65280:f)&65535;mj(a);f=a+1200|0;c[f>>2]=(c[f>>2]|0)+16;h=0;return h|0}else{f=a+1200|0;c[f>>2]=(c[f>>2]|0)+4;h=2;return h|0}return 0}function jY(a){a=a|0;var f=0,g=0,h=0;if((b[a+30>>1]&65)==0){f=a+1200|0;c[f>>2]=(c[f>>2]|0)+4;g=2;return g|0}else{f=d[a+129|0]|0;h=a+28|0;b[h>>1]=(e[h>>1]|0)+2+((f&128|0)!=0?f|65280:f)&65535;mj(a);f=a+1200|0;c[f>>2]=(c[f>>2]|0)+16;g=0;return g|0}return 0}function jZ(a){a=a|0;var f=0,g=0,h=0;if((b[a+30>>1]&65)==0){f=d[a+129|0]|0;g=a+28|0;b[g>>1]=(e[g>>1]|0)+2+((f&128|0)!=0?f|65280:f)&65535;mj(a);f=a+1200|0;c[f>>2]=(c[f>>2]|0)+16;h=0;return h|0}else{f=a+1200|0;c[f>>2]=(c[f>>2]|0)+4;h=2;return h|0}return 0}function j_(a){a=a|0;var f=0,g=0,h=0;if((b[a+30>>1]&128)==0){f=a+1200|0;c[f>>2]=(c[f>>2]|0)+4;g=2;return g|0}else{f=d[a+129|0]|0;h=a+28|0;b[h>>1]=(e[h>>1]|0)+2+((f&128|0)!=0?f|65280:f)&65535;mj(a);f=a+1200|0;c[f>>2]=(c[f>>2]|0)+16;g=0;return g|0}return 0}function j$(a){a=a|0;var f=0,g=0,h=0;if((b[a+30>>1]&128)==0){f=d[a+129|0]|0;g=a+28|0;b[g>>1]=(e[g>>1]|0)+2+((f&128|0)!=0?f|65280:f)&65535;mj(a);f=a+1200|0;c[f>>2]=(c[f>>2]|0)+16;h=0;return h|0}else{f=a+1200|0;c[f>>2]=(c[f>>2]|0)+4;h=2;return h|0}return 0}function j0(d){d=d|0;var e=0,f=0,g=0;e=d+4|0;f=b[e>>1]|0;g=d+4+((a[d+128|0]&7)<<1)|0;b[e>>1]=b[g>>1]|0;b[g>>1]=f;f=d+1200|0;c[f>>2]=(c[f>>2]|0)+3;return 1}function j1(a){a=a|0;var d=0,e=0;d=a+4|0;e=b[d>>1]|0;b[d>>1]=(e&128)!=0?e|-256:e&255;e=a+1200|0;c[e>>2]=(c[e>>2]|0)+2;return 1}function j2(a){a=a|0;var d=0;b[a+8>>1]=b[a+4>>1]>>15;d=a+1200|0;c[d>>2]=(c[d>>2]|0)+5;return 1}function j3(a){a=a|0;var b=0;b=a+1200|0;c[b>>2]=(c[b>>2]|0)+4;return 1}function j4(a){a=a|0;var f=0,g=0,h=0;if((b[a+30>>1]&4)==0){f=a+1200|0;c[f>>2]=(c[f>>2]|0)+4;g=2;return g|0}else{f=d[a+129|0]|0;h=a+28|0;b[h>>1]=(e[h>>1]|0)+2+((f&128|0)!=0?f|65280:f)&65535;mj(a);f=a+1200|0;c[f>>2]=(c[f>>2]|0)+16;g=0;return g|0}return 0}function j5(a){a=a|0;var f=0,g=0,h=0;if((b[a+30>>1]&4)==0){f=d[a+129|0]|0;g=a+28|0;b[g>>1]=(e[g>>1]|0)+2+((f&128|0)!=0?f|65280:f)&65535;mj(a);f=a+1200|0;c[f>>2]=(c[f>>2]|0)+16;h=0;return h|0}else{f=a+1200|0;c[f>>2]=(c[f>>2]|0)+4;h=2;return h|0}return 0}function j6(a){a=a|0;var f=0,g=0,h=0;f=e[a+30>>1]|0;if(((f>>>7^f>>>11)&1|0)==0){f=a+1200|0;c[f>>2]=(c[f>>2]|0)+4;g=2;return g|0}else{f=d[a+129|0]|0;h=a+28|0;b[h>>1]=(e[h>>1]|0)+2+((f&128|0)!=0?f|65280:f)&65535;mj(a);f=a+1200|0;c[f>>2]=(c[f>>2]|0)+16;g=0;return g|0}return 0}function j7(a){a=a|0;var f=0,g=0,h=0;f=e[a+30>>1]|0;if(((f>>>7^f>>>11)&1|0)==0){f=d[a+129|0]|0;g=a+28|0;b[g>>1]=(e[g>>1]|0)+2+((f&128|0)!=0?f|65280:f)&65535;mj(a);f=a+1200|0;c[f>>2]=(c[f>>2]|0)+16;h=0;return h|0}else{f=a+1200|0;c[f>>2]=(c[f>>2]|0)+4;h=2;return h|0}return 0}function j8(a){a=a|0;var f=0,g=0,h=0;f=e[a+30>>1]|0;do{if(((f>>>7^f>>>11)&1|0)==0){if((f&64|0)!=0){break}g=a+1200|0;c[g>>2]=(c[g>>2]|0)+4;h=2;return h|0}}while(0);f=d[a+129|0]|0;g=a+28|0;b[g>>1]=(e[g>>1]|0)+2+((f&128|0)!=0?f|65280:f)&65535;mj(a);f=a+1200|0;c[f>>2]=(c[f>>2]|0)+16;h=0;return h|0}function j9(a){a=a|0;var f=0,g=0,h=0,i=0;f=e[a+30>>1]|0;do{if(((f>>>7^f>>>11)&1|0)==0){if((f&64|0)!=0){break}g=d[a+129|0]|0;h=a+28|0;b[h>>1]=(e[h>>1]|0)+2+((g&128|0)!=0?g|65280:g)&65535;mj(a);g=a+1200|0;c[g>>2]=(c[g>>2]|0)+16;i=0;return i|0}}while(0);f=a+1200|0;c[f>>2]=(c[f>>2]|0)+4;i=2;return i|0}function ka(b){b=b|0;return b1[c[13192+(((a[b+129|0]&255)>>>3&7)<<2)>>2]&1023](b)|0}function kb(b){b=b|0;return b1[c[13160+(((a[b+129|0]&255)>>>3&7)<<2)>>2]&1023](b)|0}function kc(b){b=b|0;return b1[c[13128+(((a[b+129|0]&255)>>>3&7)<<2)>>2]&1023](b)|0}function kd(a){a=a|0;var f=0,g=0,h=0;f=a+129|0;iD(a,f);g=iE(a)|0;h=(d[f]|0)>>>3;f=b[a+4+((h&3)<<1)>>1]|0;iv(a,((h&4|0)!=0?(f&65535)>>>8:f)&255&g);g=a+1200|0;c[g>>2]=((c[a+1184>>2]|0)!=0?9:3)+(c[g>>2]|0);return(e[a+1196>>1]|0)+1|0}function ke(a){a=a|0;var f=0,g=0;f=a+129|0;iD(a,f);g=iF(a)|0;iw(a,b[a+4+(((d[f]|0)>>>3&7)<<1)>>1]&g);g=a+1200|0;c[g>>2]=((c[a+1184>>2]|0)!=0?9:3)+(c[g>>2]|0);return(e[a+1196>>1]|0)+1|0}function kf(a){a=a|0;var f=0,g=0,h=0,i=0,j=0;f=a+129|0;g=(d[f]|0)>>>3;iD(a,f);f=iE(a)|0;h=(g&4|0)!=0;i=a+4+((g&3)<<1)|0;g=b[i>>1]|0;iG(a,(h?(g&65535)>>>8:g)&255);g=b[i>>1]|0;if(h){j=g&255|(f&255)<<8}else{j=g&-256|f&255}b[i>>1]=j;j=a+1200|0;c[j>>2]=((c[a+1184>>2]|0)!=0?17:4)+(c[j>>2]|0);return(e[a+1196>>1]|0)+1|0}function kg(a){a=a|0;var f=0,g=0,h=0;f=a+129|0;g=(d[f]|0)>>>3&7;iD(a,f);f=iF(a)|0;h=a+4+(g<<1)|0;iH(a,b[h>>1]|0);b[h>>1]=f;f=a+1200|0;c[f>>2]=((c[a+1184>>2]|0)!=0?17:4)+(c[f>>2]|0);return(e[a+1196>>1]|0)+1|0}function kh(a){a=a|0;var b=0,f=0;b=a+129|0;iD(a,b);f=(d[b]|0)>>>3;b=e[a+4+((f&3)<<1)>>1]|0;iG(a,((f&4|0)!=0?b>>>8:b)&255);b=a+1200|0;c[b>>2]=((c[a+1184>>2]|0)!=0?9:2)+(c[b>>2]|0);return(e[a+1196>>1]|0)+1|0}function ki(a){a=a|0;var f=0;f=a+129|0;iD(a,f);iH(a,b[a+4+(((d[f]|0)>>>3&7)<<1)>>1]|0);f=a+1200|0;c[f>>2]=((c[a+1184>>2]|0)!=0?9:2)+(c[f>>2]|0);return(e[a+1196>>1]|0)+1|0}function kj(a){a=a|0;var f=0,g=0,h=0,i=0,j=0;f=a+129|0;iD(a,f);g=(d[f]|0)>>>3;f=iE(a)|0;h=a+4+((g&3)<<1)|0;i=b[h>>1]|0;if((g&4|0)==0){j=i&-256|f&255}else{j=i&255|(f&255)<<8}b[h>>1]=j;j=a+1200|0;c[j>>2]=((c[a+1184>>2]|0)!=0?8:2)+(c[j>>2]|0);return(e[a+1196>>1]|0)+1|0}function kk(a){a=a|0;var f=0,g=0;f=a+129|0;iD(a,f);g=(d[f]|0)>>>3&7;b[a+4+(g<<1)>>1]=iF(a)|0;g=a+1200|0;c[g>>2]=((c[a+1184>>2]|0)!=0?8:2)+(c[g>>2]|0);return(e[a+1196>>1]|0)+1|0}function kl(a){a=a|0;var f=0;f=a+129|0;iD(a,f);iH(a,b[a+20+(((d[f]|0)>>>3&3)<<1)>>1]|0);f=a+1200|0;c[f>>2]=((c[a+1184>>2]|0)!=0?9:2)+(c[f>>2]|0);return(e[a+1196>>1]|0)+1|0}function km(a){a=a|0;var f=0,g=0,h=0;f=a+129|0;iD(a,f);do{if((c[a+1184>>2]|0)==0){if((ie(a)|0)==0){g=0}else{break}return g|0}else{b[a+4+(((d[f]|0)>>>3&7)<<1)>>1]=b[a+1194>>1]|0;h=a+1200|0;c[h>>2]=(c[h>>2]|0)+2}}while(0);g=(e[a+1196>>1]|0)+1|0;return g|0}function kn(f){f=f|0;var g=0,h=0;g=f+129|0;h=(d[g]|0)>>>3&3;iD(f,g);b[f+20+(h<<1)>>1]=iF(f)|0;g=f+1200|0;c[g>>2]=((c[f+1184>>2]|0)!=0?8:2)+(c[g>>2]|0);if((h|0)==1){mj(f)}else if((h|0)==2){a[f+157|0]=0}return(e[f+1196>>1]|0)+1|0}function ko(a){a=a|0;var f=0,g=0,h=0,i=0;iD(a,a+129|0);f=a+12|0;g=b[f>>1]|0;b[f>>1]=g+2&65535;f=((e[a+24>>1]|0)<<4)+(g&65535)&c[a+80>>2];g=f+1|0;if(g>>>0<(c[a+76>>2]|0)>>>0){h=c[a+72>>2]|0;i=(d[h+g|0]|0)<<8|(d[h+f|0]|0)}else{i=b8[c[a+44>>2]&255](c[a+32>>2]|0,f)|0}iH(a,i);i=a+1200|0;c[i>>2]=((c[a+1184>>2]|0)!=0?17:8)+(c[i>>2]|0);return(e[a+1196>>1]|0)+1|0}function kp(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f+22|0;h=b[g>>1]|0;i=f+12|0;j=(b[i>>1]|0)-2&65535;b[i>>1]=j;k=f+24|0;l=f+80|0;m=((e[k>>1]|0)<<4)+(j&65535)&c[l>>2];j=m+1|0;n=f+76|0;if(j>>>0<(c[n>>2]|0)>>>0){o=f+72|0;a[(c[o>>2]|0)+m|0]=h&255;a[(c[o>>2]|0)+j|0]=(h&65535)>>>8&255}else{b5[c[f+48>>2]&255](c[f+32>>2]|0,m,h)}h=f+28|0;m=(b[h>>1]|0)+5&65535;j=(b[i>>1]|0)-2&65535;b[i>>1]=j;i=((e[k>>1]|0)<<4)+(j&65535)&c[l>>2];l=i+1|0;if(l>>>0<(c[n>>2]|0)>>>0){n=f+72|0;a[(c[n>>2]|0)+i|0]=m&255;a[(c[n>>2]|0)+l|0]=(m&65535)>>>8&255}else{b5[c[f+48>>2]&255](c[f+32>>2]|0,i,m)}b[h>>1]=(d[f+130|0]|0)<<8|(d[f+129|0]|0);b[g>>1]=(d[f+132|0]|0)<<8|(d[f+131|0]|0);mj(f);g=f+1200|0;c[g>>2]=(c[g>>2]|0)+28;return 0}function kq(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b[d+30>>1]&4053;if((c[d>>2]&32|0)==0){g=f|61442;h=g&65535;i=d+12|0;j=(b[i>>1]|0)-2&65535;b[i>>1]=j;i=((e[d+24>>1]|0)<<4)+(j&65535)&c[d+80>>2];j=i+1|0;if(j>>>0<(c[d+76>>2]|0)>>>0){k=d+72|0;a[(c[k>>2]|0)+i|0]=g&255;a[(c[k>>2]|0)+j|0]=(h&65535)>>>8&255;l=d+1200|0;m=c[l>>2]|0;n=m+10|0;c[l>>2]=n;return 1}else{b5[c[d+48>>2]&255](c[d+32>>2]|0,i,h);l=d+1200|0;m=c[l>>2]|0;n=m+10|0;c[l>>2]=n;return 1}}else{h=f&65535;i=d+12|0;j=(b[i>>1]|0)-2&65535;b[i>>1]=j;i=((e[d+24>>1]|0)<<4)+(j&65535)&c[d+80>>2];j=i+1|0;if(j>>>0<(c[d+76>>2]|0)>>>0){k=d+72|0;a[(c[k>>2]|0)+i|0]=f&255;a[(c[k>>2]|0)+j|0]=(h&65535)>>>8&255;l=d+1200|0;m=c[l>>2]|0;n=m+10|0;c[l>>2]=n;return 1}else{b5[c[d+48>>2]&255](c[d+32>>2]|0,i,h);l=d+1200|0;m=c[l>>2]|0;n=m+10|0;c[l>>2]=n;return 1}}return 0}function kr(a){a=a|0;var d=0;d=a+30|0;b[d>>1]=b[d>>1]&-256|(e[a+4>>1]|0)>>>8&213|2;d=a+1200|0;c[d>>2]=(c[d>>2]|0)+4;return 1}function ks(a){a=a|0;var d=0;d=a+4|0;b[d>>1]=((b[a+30>>1]&255&-43|2)&255)<<8|b[d>>1]&255;d=a+1200|0;c[d>>2]=(c[d>>2]|0)+4;return 1}function kt(a){a=a|0;var f=0,g=0,h=0,i=0;f=a+12|0;g=b[f>>1]|0;b[f>>1]=g+2&65535;f=((e[a+24>>1]|0)<<4)+(g&65535)&c[a+80>>2];g=f+1|0;if(g>>>0<(c[a+76>>2]|0)>>>0){h=c[a+72>>2]|0;i=(d[h+g|0]|0)<<8|(d[h+f|0]|0)}else{i=b8[c[a+44>>2]&255](c[a+32>>2]|0,f)|0}b[a+30>>1]=i&4053|-4094;i=a+1200|0;c[i>>2]=(c[i>>2]|0)+8;return 1}function ku(f){f=f|0;var g=0,h=0;g=(((d[f+130|0]|0)<<8|(d[f+129|0]|0))&65535)+((e[((c[f+144>>2]&2|0)==0?f+26|0:f+148|0)>>1]|0)<<4)&c[f+80>>2];if(g>>>0<(c[f+76>>2]|0)>>>0){h=a[(c[f+72>>2]|0)+g|0]|0}else{h=b8[c[f+36>>2]&255](c[f+32>>2]|0,g)|0}g=f+4|0;b[g>>1]=b[g>>1]&-256|h&255;h=f+1200|0;c[h>>2]=(c[h>>2]|0)+10;return 3}function kv(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=(((d[a+130|0]|0)<<8|(d[a+129|0]|0))&65535)+((e[((c[a+144>>2]&2|0)==0?a+26|0:a+148|0)>>1]|0)<<4)&c[a+80>>2];g=f+1|0;if(g>>>0<(c[a+76>>2]|0)>>>0){h=c[a+72>>2]|0;i=(d[h+g|0]|0)<<8|(d[h+f|0]|0);j=a+4|0;b[j>>1]=i;k=a+1200|0;l=c[k>>2]|0;m=l+10|0;c[k>>2]=m;return 3}else{i=b8[c[a+44>>2]&255](c[a+32>>2]|0,f)|0;j=a+4|0;b[j>>1]=i;k=a+1200|0;l=c[k>>2]|0;m=l+10|0;c[k>>2]=m;return 3}return 0}function kw(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=b[f+4>>1]&255;h=(((d[f+130|0]|0)<<8|(d[f+129|0]|0))&65535)+((e[((c[f+144>>2]&2|0)==0?f+26|0:f+148|0)>>1]|0)<<4)&c[f+80>>2];if(h>>>0<(c[f+76>>2]|0)>>>0){a[(c[f+72>>2]|0)+h|0]=g;i=f+1200|0;j=c[i>>2]|0;k=j+10|0;c[i>>2]=k;return 3}else{b5[c[f+40>>2]&255](c[f+32>>2]|0,h,g);i=f+1200|0;j=c[i>>2]|0;k=j+10|0;c[i>>2]=k;return 3}return 0}function kx(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=b[f+4>>1]|0;h=(((d[f+130|0]|0)<<8|(d[f+129|0]|0))&65535)+((e[((c[f+144>>2]&2|0)==0?f+26|0:f+148|0)>>1]|0)<<4)&c[f+80>>2];i=h+1|0;if(i>>>0<(c[f+76>>2]|0)>>>0){j=f+72|0;a[(c[j>>2]|0)+h|0]=g&255;a[(c[j>>2]|0)+i|0]=(g&65535)>>>8&255;k=f+1200|0;l=c[k>>2]|0;m=l+10|0;c[k>>2]=m;return 3}else{b5[c[f+48>>2]&255](c[f+32>>2]|0,h,g);k=f+1200|0;l=c[k>>2]|0;m=l+10|0;c[k>>2]=m;return 3}return 0}function ky(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=d+144|0;g=c[f>>2]|0;h=b[((g&2|0)==0?d+26|0:d+148|0)>>1]|0;i=b[d+20>>1]|0;j=((e[d+30>>1]|0)>>>9&2^2)-1&65535;if((g&12|0)==0){k=d+16|0;l=d+80|0;m=c[l>>2]|0;n=(e[k>>1]|0)+((h&65535)<<4)&m;o=d+76|0;p=c[o>>2]|0;if(n>>>0<p>>>0){q=a[(c[d+72>>2]|0)+n|0]|0;r=m;s=p}else{p=b8[c[d+36>>2]&255](c[d+32>>2]|0,n)|0;q=p;r=c[l>>2]|0;s=c[o>>2]|0}o=d+18|0;l=(e[o>>1]|0)+((i&65535)<<4)&r;if(l>>>0<s>>>0){a[(c[d+72>>2]|0)+l|0]=q}else{b5[c[d+40>>2]&255](c[d+32>>2]|0,l,q)}b[k>>1]=(b[k>>1]|0)+j&65535;b[o>>1]=(b[o>>1]|0)+j&65535;o=d+1200|0;c[o>>2]=(c[o>>2]|0)+18;t=1;return t|0}o=d+6|0;do{if((b[o>>1]|0)==0){k=d+1200|0;c[k>>2]=(c[k>>2]|0)+18;u=g}else{k=d+16|0;q=d+80|0;l=c[q>>2]|0;s=(e[k>>1]|0)+((h&65535)<<4)&l;r=d+76|0;p=c[r>>2]|0;if(s>>>0<p>>>0){v=a[(c[d+72>>2]|0)+s|0]|0;w=l;x=p}else{p=b8[c[d+36>>2]&255](c[d+32>>2]|0,s)|0;v=p;w=c[q>>2]|0;x=c[r>>2]|0}r=d+18|0;q=(e[r>>1]|0)+((i&65535)<<4)&w;if(q>>>0<x>>>0){a[(c[d+72>>2]|0)+q|0]=v}else{b5[c[d+40>>2]&255](c[d+32>>2]|0,q,v)}b[k>>1]=(b[k>>1]|0)+j&65535;b[r>>1]=(b[r>>1]|0)+j&65535;r=(b[o>>1]|0)-1&65535;b[o>>1]=r;k=c[f>>2]|0;q=d+1200|0;c[q>>2]=(c[q>>2]|0)+18;if(r<<16>>16==0){u=k;break}c[f>>2]=k|32;t=0;return t|0}}while(0);c[f>>2]=u&-33;t=1;return t|0}function kz(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=f+144|0;h=c[g>>2]|0;i=b[((h&2|0)==0?f+26|0:f+148|0)>>1]|0;j=b[f+20>>1]|0;k=((e[f+30>>1]|0)>>>8&4^4)-2&65535;if((h&12|0)==0){l=f+16|0;m=f+80|0;n=c[m>>2]|0;o=(e[l>>1]|0)+((i&65535)<<4)&n;p=o+1|0;q=f+76|0;r=c[q>>2]|0;if(p>>>0<r>>>0){s=c[f+72>>2]|0;t=d[s+p|0]<<8|d[s+o|0];u=n;v=r}else{r=b8[c[f+44>>2]&255](c[f+32>>2]|0,o)|0;t=r;u=c[m>>2]|0;v=c[q>>2]|0}q=f+18|0;m=(e[q>>1]|0)+((j&65535)<<4)&u;u=m+1|0;if(u>>>0<v>>>0){v=f+72|0;a[(c[v>>2]|0)+m|0]=t&255;a[(c[v>>2]|0)+u|0]=(t&65535)>>>8&255}else{b5[c[f+48>>2]&255](c[f+32>>2]|0,m,t)}b[l>>1]=(b[l>>1]|0)+k&65535;b[q>>1]=(b[q>>1]|0)+k&65535;q=f+1200|0;c[q>>2]=(c[q>>2]|0)+18;w=1;return w|0}q=f+6|0;do{if((b[q>>1]|0)==0){l=f+1200|0;c[l>>2]=(c[l>>2]|0)+18;x=h}else{l=f+16|0;t=f+80|0;m=c[t>>2]|0;u=(e[l>>1]|0)+((i&65535)<<4)&m;v=u+1|0;r=f+76|0;o=c[r>>2]|0;if(v>>>0<o>>>0){n=c[f+72>>2]|0;y=d[n+v|0]<<8|d[n+u|0];z=m;A=o}else{o=b8[c[f+44>>2]&255](c[f+32>>2]|0,u)|0;y=o;z=c[t>>2]|0;A=c[r>>2]|0}r=f+18|0;t=(e[r>>1]|0)+((j&65535)<<4)&z;o=t+1|0;if(o>>>0<A>>>0){u=f+72|0;a[(c[u>>2]|0)+t|0]=y&255;a[(c[u>>2]|0)+o|0]=(y&65535)>>>8&255}else{b5[c[f+48>>2]&255](c[f+32>>2]|0,t,y)}b[l>>1]=(b[l>>1]|0)+k&65535;b[r>>1]=(b[r>>1]|0)+k&65535;r=(b[q>>1]|0)-1&65535;b[q>>1]=r;l=c[g>>2]|0;t=f+1200|0;c[t>>2]=(c[t>>2]|0)+18;if(r<<16>>16==0){x=l;break}c[g>>2]=l|32;w=0;return w|0}}while(0);c[g>>2]=x&-33;w=1;return w|0}function kA(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=d+144|0;g=c[f>>2]|0;h=b[((g&2|0)==0?d+26|0:d+148|0)>>1]|0;i=b[d+20>>1]|0;j=d+30|0;k=((e[j>>1]|0)>>>9&2^2)-1&65535;if((g&12|0)==0){l=d+16|0;m=d+80|0;n=c[m>>2]|0;o=(e[l>>1]|0)+((h&65535)<<4)&n;p=d+76|0;q=c[p>>2]|0;if(o>>>0<q>>>0){r=a[(c[d+72>>2]|0)+o|0]|0;s=n;t=q}else{q=b8[c[d+36>>2]&255](c[d+32>>2]|0,o)|0;r=q;s=c[m>>2]|0;t=c[p>>2]|0}p=d+18|0;m=b[p>>1]|0;q=(m&65535)+((i&65535)<<4)&s;if(q>>>0<t>>>0){u=a[(c[d+72>>2]|0)+q|0]|0;v=m}else{m=b8[c[d+36>>2]&255](c[d+32>>2]|0,q)|0;u=m;v=b[p>>1]|0}b[l>>1]=(b[l>>1]|0)+k&65535;b[p>>1]=v+k&65535;iI(d,r,u);u=d+1200|0;c[u>>2]=(c[u>>2]|0)+22;w=1;return w|0}u=d+6|0;do{if((b[u>>1]|0)==0){r=d+1200|0;c[r>>2]=(c[r>>2]|0)+22;x=g}else{r=d+16|0;v=d+80|0;p=c[v>>2]|0;l=(e[r>>1]|0)+((h&65535)<<4)&p;m=d+76|0;q=c[m>>2]|0;if(l>>>0<q>>>0){y=a[(c[d+72>>2]|0)+l|0]|0;z=p;A=q}else{q=b8[c[d+36>>2]&255](c[d+32>>2]|0,l)|0;y=q;z=c[v>>2]|0;A=c[m>>2]|0}m=d+18|0;v=b[m>>1]|0;q=(v&65535)+((i&65535)<<4)&z;if(q>>>0<A>>>0){B=a[(c[d+72>>2]|0)+q|0]|0;C=v}else{v=b8[c[d+36>>2]&255](c[d+32>>2]|0,q)|0;B=v;C=b[m>>1]|0}b[r>>1]=(b[r>>1]|0)+k&65535;b[m>>1]=C+k&65535;b[u>>1]=(b[u>>1]|0)-1&65535;iI(d,y,B);m=c[f>>2]|0;r=(b[u>>1]|0)==0;v=d+1200|0;c[v>>2]=(c[v>>2]|0)+22;if(r){x=m;break}if(((e[j>>1]|0)>>>6&1|0)!=(m>>>2&1|0)){x=m;break}c[f>>2]=m|32;w=0;return w|0}}while(0);c[f>>2]=x&-33;w=1;return w|0}function kB(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=a+144|0;g=c[f>>2]|0;h=b[((g&2|0)==0?a+26|0:a+148|0)>>1]|0;i=b[a+20>>1]|0;j=a+30|0;k=((e[j>>1]|0)>>>8&4^4)-2&65535;if((g&12|0)==0){l=a+16|0;m=a+80|0;n=c[m>>2]|0;o=(e[l>>1]|0)+((h&65535)<<4)&n;p=o+1|0;q=a+76|0;r=c[q>>2]|0;if(p>>>0<r>>>0){s=c[a+72>>2]|0;t=d[s+p|0]<<8|d[s+o|0];u=n;v=r}else{r=b8[c[a+44>>2]&255](c[a+32>>2]|0,o)|0;t=r;u=c[m>>2]|0;v=c[q>>2]|0}q=a+18|0;m=b[q>>1]|0;r=(m&65535)+((i&65535)<<4)&u;u=r+1|0;if(u>>>0<v>>>0){v=c[a+72>>2]|0;w=d[v+u|0]<<8|d[v+r|0];x=m}else{m=b8[c[a+44>>2]&255](c[a+32>>2]|0,r)|0;w=m;x=b[q>>1]|0}b[l>>1]=(b[l>>1]|0)+k&65535;b[q>>1]=x+k&65535;iJ(a,t,w);w=a+1200|0;c[w>>2]=(c[w>>2]|0)+22;y=1;return y|0}w=a+6|0;do{if((b[w>>1]|0)==0){t=a+1200|0;c[t>>2]=(c[t>>2]|0)+22;z=g}else{t=a+16|0;x=a+80|0;q=c[x>>2]|0;l=(e[t>>1]|0)+((h&65535)<<4)&q;m=l+1|0;r=a+76|0;v=c[r>>2]|0;if(m>>>0<v>>>0){u=c[a+72>>2]|0;A=d[u+m|0]<<8|d[u+l|0];B=q;C=v}else{v=b8[c[a+44>>2]&255](c[a+32>>2]|0,l)|0;A=v;B=c[x>>2]|0;C=c[r>>2]|0}r=a+18|0;x=b[r>>1]|0;v=(x&65535)+((i&65535)<<4)&B;l=v+1|0;if(l>>>0<C>>>0){q=c[a+72>>2]|0;D=d[q+l|0]<<8|d[q+v|0];E=x}else{x=b8[c[a+44>>2]&255](c[a+32>>2]|0,v)|0;D=x;E=b[r>>1]|0}b[t>>1]=(b[t>>1]|0)+k&65535;b[r>>1]=E+k&65535;b[w>>1]=(b[w>>1]|0)-1&65535;iJ(a,A,D);r=c[f>>2]|0;t=(b[w>>1]|0)==0;x=a+1200|0;c[x>>2]=(c[x>>2]|0)+22;if(t){z=r;break}if(((e[j>>1]|0)>>>6&1|0)!=(r>>>2&1|0)){z=r;break}c[f>>2]=r|32;y=0;return y|0}}while(0);c[f>>2]=z&-33;y=1;return y|0}function kC(d){d=d|0;var e=0;iv(d,b[d+4>>1]&255&a[d+129|0]);e=d+1200|0;c[e>>2]=(c[e>>2]|0)+4;return 2}function kD(a){a=a|0;var e=0;iw(a,((d[a+130|0]|0)<<8|(d[a+129|0]|0))&b[a+4>>1]);e=a+1200|0;c[e>>2]=(c[e>>2]|0)+4;return 3}function kE(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=b[d+20>>1]|0;g=((e[d+30>>1]|0)>>>9&2^2)-1&65535;h=d+144|0;i=c[h>>2]|0;if((i&12|0)==0){j=d+18|0;k=b[d+4>>1]&255;l=c[d+80>>2]&(e[j>>1]|0)+((f&65535)<<4);if(l>>>0<(c[d+76>>2]|0)>>>0){a[(c[d+72>>2]|0)+l|0]=k}else{b5[c[d+40>>2]&255](c[d+32>>2]|0,l,k)}b[j>>1]=(b[j>>1]|0)+g&65535;j=d+1200|0;c[j>>2]=(c[j>>2]|0)+11;m=1;return m|0}j=d+6|0;do{if((b[j>>1]|0)==0){k=d+1200|0;c[k>>2]=(c[k>>2]|0)+11;n=i}else{k=d+18|0;l=b[d+4>>1]&255;o=c[d+80>>2]&(e[k>>1]|0)+((f&65535)<<4);if(o>>>0<(c[d+76>>2]|0)>>>0){a[(c[d+72>>2]|0)+o|0]=l}else{b5[c[d+40>>2]&255](c[d+32>>2]|0,o,l)}b[k>>1]=(b[k>>1]|0)+g&65535;k=(b[j>>1]|0)-1&65535;b[j>>1]=k;l=c[h>>2]|0;o=d+1200|0;c[o>>2]=(c[o>>2]|0)+11;if(k<<16>>16==0){n=l;break}c[h>>2]=l|32;m=0;return m|0}}while(0);c[h>>2]=n&-33;m=1;return m|0}function kF(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=b[d+20>>1]|0;g=((e[d+30>>1]|0)>>>8&4^4)-2&65535;h=d+144|0;i=c[h>>2]|0;if((i&12|0)==0){j=d+18|0;k=b[d+4>>1]|0;l=c[d+80>>2]&(e[j>>1]|0)+((f&65535)<<4);m=l+1|0;if(m>>>0<(c[d+76>>2]|0)>>>0){n=d+72|0;a[(c[n>>2]|0)+l|0]=k&255;a[(c[n>>2]|0)+m|0]=(k&65535)>>>8&255}else{b5[c[d+48>>2]&255](c[d+32>>2]|0,l,k)}b[j>>1]=(b[j>>1]|0)+g&65535;j=d+1200|0;c[j>>2]=(c[j>>2]|0)+11;o=1;return o|0}j=d+6|0;do{if((b[j>>1]|0)==0){k=d+1200|0;c[k>>2]=(c[k>>2]|0)+11;p=i}else{k=d+18|0;l=b[d+4>>1]|0;m=c[d+80>>2]&(e[k>>1]|0)+((f&65535)<<4);n=m+1|0;if(n>>>0<(c[d+76>>2]|0)>>>0){q=d+72|0;a[(c[q>>2]|0)+m|0]=l&255;a[(c[q>>2]|0)+n|0]=(l&65535)>>>8&255}else{b5[c[d+48>>2]&255](c[d+32>>2]|0,m,l)}b[k>>1]=(b[k>>1]|0)+g&65535;k=(b[j>>1]|0)-1&65535;b[j>>1]=k;l=c[h>>2]|0;m=d+1200|0;c[m>>2]=(c[m>>2]|0)+11;if(k<<16>>16==0){p=l;break}c[h>>2]=l|32;o=0;return o|0}}while(0);c[h>>2]=p&-33;o=1;return o|0}function kG(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=d+144|0;g=c[f>>2]|0;h=b[((g&2|0)==0?d+26|0:d+148|0)>>1]|0;i=((e[d+30>>1]|0)>>>9&2^2)-1&65535;if((g&12|0)==0){j=d+16|0;k=b[j>>1]|0;l=(k&65535)+((h&65535)<<4)&c[d+80>>2];if(l>>>0<(c[d+76>>2]|0)>>>0){m=a[(c[d+72>>2]|0)+l|0]|0;n=k}else{k=b8[c[d+36>>2]&255](c[d+32>>2]|0,l)|0;m=k;n=b[j>>1]|0}k=d+4|0;b[k>>1]=b[k>>1]&-256|m&255;b[j>>1]=n+i&65535;n=d+1200|0;c[n>>2]=(c[n>>2]|0)+12;o=1;return o|0}n=d+6|0;j=b[n>>1]|0;do{if(j<<16>>16==0){m=d+1200|0;c[m>>2]=(c[m>>2]|0)+12;p=g}else{m=d+16|0;k=b[m>>1]|0;l=(k&65535)+((h&65535)<<4)&c[d+80>>2];if(l>>>0<(c[d+76>>2]|0)>>>0){q=a[(c[d+72>>2]|0)+l|0]|0;r=k;s=j;t=g}else{k=b8[c[d+36>>2]&255](c[d+32>>2]|0,l)|0;q=k;r=b[m>>1]|0;s=b[n>>1]|0;t=c[f>>2]|0}k=d+4|0;b[k>>1]=b[k>>1]&-256|q&255;b[m>>1]=r+i&65535;m=s-1&65535;b[n>>1]=m;k=d+1200|0;c[k>>2]=(c[k>>2]|0)+12;if(m<<16>>16==0){p=t;break}c[f>>2]=t|32;o=0;return o|0}}while(0);c[f>>2]=p&-33;o=1;return o|0}function kH(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=a+144|0;g=c[f>>2]|0;h=b[((g&2|0)==0?a+26|0:a+148|0)>>1]|0;i=((e[a+30>>1]|0)>>>8&4^4)-2&65535;if((g&12|0)==0){j=a+16|0;k=b[j>>1]|0;l=(k&65535)+((h&65535)<<4)&c[a+80>>2];m=l+1|0;if(m>>>0<(c[a+76>>2]|0)>>>0){n=c[a+72>>2]|0;o=(d[n+m|0]|0)<<8|(d[n+l|0]|0);p=k}else{k=b8[c[a+44>>2]&255](c[a+32>>2]|0,l)|0;o=k;p=b[j>>1]|0}b[a+4>>1]=o;b[j>>1]=p+i&65535;p=a+1200|0;c[p>>2]=(c[p>>2]|0)+12;q=1;return q|0}p=a+6|0;j=b[p>>1]|0;do{if(j<<16>>16==0){o=a+1200|0;c[o>>2]=(c[o>>2]|0)+12;r=g}else{o=a+16|0;k=b[o>>1]|0;l=(k&65535)+((h&65535)<<4)&c[a+80>>2];n=l+1|0;if(n>>>0<(c[a+76>>2]|0)>>>0){m=c[a+72>>2]|0;s=(d[m+n|0]|0)<<8|(d[m+l|0]|0);t=k;u=j;v=g}else{k=b8[c[a+44>>2]&255](c[a+32>>2]|0,l)|0;s=k;t=b[o>>1]|0;u=b[p>>1]|0;v=c[f>>2]|0}b[a+4>>1]=s;b[o>>1]=t+i&65535;o=u-1&65535;b[p>>1]=o;k=a+1200|0;c[k>>2]=(c[k>>2]|0)+12;if(o<<16>>16==0){r=v;break}c[f>>2]=v|32;q=0;return q|0}}while(0);c[f>>2]=r&-33;q=1;return q|0}function kI(a){a=a|0;var e=0;e=a+4|0;b[e>>1]=d[a+129|0]|0|b[e>>1]&-256;e=a+1200|0;c[e>>2]=(c[e>>2]|0)+4;return 2}function kJ(a){a=a|0;var e=0;e=a+6|0;b[e>>1]=d[a+129|0]|0|b[e>>1]&-256;e=a+1200|0;c[e>>2]=(c[e>>2]|0)+4;return 2}function kK(a){a=a|0;var e=0;e=a+8|0;b[e>>1]=d[a+129|0]|0|b[e>>1]&-256;e=a+1200|0;c[e>>2]=(c[e>>2]|0)+4;return 2}function kL(a){a=a|0;var e=0;e=a+10|0;b[e>>1]=d[a+129|0]|0|b[e>>1]&-256;e=a+1200|0;c[e>>2]=(c[e>>2]|0)+4;return 2}function kM(a){a=a|0;var e=0;e=a+4|0;b[e>>1]=(d[a+129|0]|0)<<8|b[e>>1]&255;e=a+1200|0;c[e>>2]=(c[e>>2]|0)+4;return 2}function kN(a){a=a|0;var e=0;e=a+6|0;b[e>>1]=(d[a+129|0]|0)<<8|b[e>>1]&255;e=a+1200|0;c[e>>2]=(c[e>>2]|0)+4;return 2}function kO(a){a=a|0;var e=0;e=a+8|0;b[e>>1]=(d[a+129|0]|0)<<8|b[e>>1]&255;e=a+1200|0;c[e>>2]=(c[e>>2]|0)+4;return 2}function kP(a){a=a|0;var e=0;e=a+10|0;b[e>>1]=(d[a+129|0]|0)<<8|b[e>>1]&255;e=a+1200|0;c[e>>2]=(c[e>>2]|0)+4;return 2}function kQ(a){a=a|0;var e=0;b[a+4>>1]=(d[a+130|0]|0)<<8|(d[a+129|0]|0);e=a+1200|0;c[e>>2]=(c[e>>2]|0)+4;return 3}function kR(a){a=a|0;var e=0;b[a+6>>1]=(d[a+130|0]|0)<<8|(d[a+129|0]|0);e=a+1200|0;c[e>>2]=(c[e>>2]|0)+4;return 3}function kS(a){a=a|0;var e=0;b[a+8>>1]=(d[a+130|0]|0)<<8|(d[a+129|0]|0);e=a+1200|0;c[e>>2]=(c[e>>2]|0)+4;return 3}function kT(a){a=a|0;var e=0;b[a+10>>1]=(d[a+130|0]|0)<<8|(d[a+129|0]|0);e=a+1200|0;c[e>>2]=(c[e>>2]|0)+4;return 3}function kU(a){a=a|0;var e=0;b[a+12>>1]=(d[a+130|0]|0)<<8|(d[a+129|0]|0);e=a+1200|0;c[e>>2]=(c[e>>2]|0)+4;return 3}function kV(a){a=a|0;var e=0;b[a+14>>1]=(d[a+130|0]|0)<<8|(d[a+129|0]|0);e=a+1200|0;c[e>>2]=(c[e>>2]|0)+4;return 3}function kW(a){a=a|0;var e=0;b[a+16>>1]=(d[a+130|0]|0)<<8|(d[a+129|0]|0);e=a+1200|0;c[e>>2]=(c[e>>2]|0)+4;return 3}function kX(a){a=a|0;var e=0;b[a+18>>1]=(d[a+130|0]|0)<<8|(d[a+129|0]|0);e=a+1200|0;c[e>>2]=(c[e>>2]|0)+4;return 3}function kY(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b[d+20>>1]|0;g=d+30|0;h=((e[g>>1]|0)>>>9&2^2)-1&65535;i=d+144|0;j=c[i>>2]|0;k=d+4|0;if((j&12|0)==0){l=b[k>>1]|0;m=d+18|0;n=b[m>>1]|0;o=(n&65535)+((f&65535)<<4)&c[d+80>>2];if(o>>>0<(c[d+76>>2]|0)>>>0){p=a[(c[d+72>>2]|0)+o|0]|0;q=n}else{n=b8[c[d+36>>2]&255](c[d+32>>2]|0,o)|0;p=n;q=b[m>>1]|0}b[m>>1]=q+h&65535;iI(d,l&255,p);p=d+1200|0;c[p>>2]=(c[p>>2]|0)+15;r=1;return r|0}p=d+6|0;l=b[p>>1]|0;do{if(l<<16>>16==0){q=d+1200|0;c[q>>2]=(c[q>>2]|0)+15;s=j}else{q=b[k>>1]|0;m=d+18|0;n=b[m>>1]|0;o=(n&65535)+((f&65535)<<4)&c[d+80>>2];if(o>>>0<(c[d+76>>2]|0)>>>0){t=a[(c[d+72>>2]|0)+o|0]|0;u=n;v=l}else{n=b8[c[d+36>>2]&255](c[d+32>>2]|0,o)|0;t=n;u=b[m>>1]|0;v=b[p>>1]|0}b[m>>1]=u+h&65535;b[p>>1]=v-1&65535;iI(d,q&255,t);q=c[i>>2]|0;m=(b[p>>1]|0)==0;n=d+1200|0;c[n>>2]=(c[n>>2]|0)+15;if(m){s=q;break}if(((e[g>>1]|0)>>>6&1|0)!=(q>>>2&1|0)){s=q;break}c[i>>2]=q|32;r=0;return r|0}}while(0);c[i>>2]=s&-33;r=1;return r|0}function kZ(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=b[a+20>>1]|0;g=a+30|0;h=((e[g>>1]|0)>>>8&4^4)-2&65535;i=a+144|0;j=c[i>>2]|0;k=a+4|0;if((j&12|0)==0){l=b[k>>1]|0;m=a+18|0;n=b[m>>1]|0;o=(n&65535)+((f&65535)<<4)&c[a+80>>2];p=o+1|0;if(p>>>0<(c[a+76>>2]|0)>>>0){q=c[a+72>>2]|0;r=d[q+p|0]<<8|d[q+o|0];s=n}else{n=b8[c[a+44>>2]&255](c[a+32>>2]|0,o)|0;r=n;s=b[m>>1]|0}b[m>>1]=s+h&65535;iJ(a,l,r);r=a+1200|0;c[r>>2]=(c[r>>2]|0)+15;t=1;return t|0}r=a+6|0;l=b[r>>1]|0;do{if(l<<16>>16==0){s=a+1200|0;c[s>>2]=(c[s>>2]|0)+15;u=j}else{s=b[k>>1]|0;m=a+18|0;n=b[m>>1]|0;o=(n&65535)+((f&65535)<<4)&c[a+80>>2];q=o+1|0;if(q>>>0<(c[a+76>>2]|0)>>>0){p=c[a+72>>2]|0;v=d[p+q|0]<<8|d[p+o|0];w=n;x=l}else{n=b8[c[a+44>>2]&255](c[a+32>>2]|0,o)|0;v=n;w=b[m>>1]|0;x=b[r>>1]|0}b[m>>1]=w+h&65535;b[r>>1]=x-1&65535;iJ(a,s,v);s=c[i>>2]|0;m=(b[r>>1]|0)==0;n=a+1200|0;c[n>>2]=(c[n>>2]|0)+15;if(m){u=s;break}if(((e[g>>1]|0)>>>6&1|0)!=(s>>>2&1|0)){u=s;break}c[i>>2]=s|32;t=0;return t|0}}while(0);c[i>>2]=u&-33;t=1;return t|0}function k_(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=a+12|0;g=b[f>>1]|0;h=g+2&65535;b[f>>1]=h;i=((e[a+24>>1]|0)<<4)+(g&65535)&c[a+80>>2];g=i+1|0;if(g>>>0<(c[a+76>>2]|0)>>>0){j=c[a+72>>2]|0;k=(d[j+g|0]|0)<<8|(d[j+i|0]|0);l=h}else{h=b8[c[a+44>>2]&255](c[a+32>>2]|0,i)|0;k=h;l=b[f>>1]|0}b[a+28>>1]=k;b[f>>1]=((d[a+130|0]|0)<<8|(d[a+129|0]|0))+l&65535;mj(a);l=a+1200|0;c[l>>2]=(c[l>>2]|0)+20;return 0}function k$(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=a+12|0;g=b[f>>1]|0;b[f>>1]=g+2&65535;f=((e[a+24>>1]|0)<<4)+(g&65535)&c[a+80>>2];g=f+1|0;if(g>>>0<(c[a+76>>2]|0)>>>0){h=c[a+72>>2]|0;i=(d[h+g|0]|0)<<8|(d[h+f|0]|0);j=a+28|0;b[j>>1]=i;mj(a);k=a+1200|0;l=c[k>>2]|0;m=l+16|0;c[k>>2]=m;return 0}else{i=b8[c[a+44>>2]&255](c[a+32>>2]|0,f)|0;j=a+28|0;b[j>>1]=i;mj(a);k=a+1200|0;l=c[k>>2]|0;m=l+16|0;c[k>>2]=m;return 0}return 0}function k0(a){a=a|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=a+129|0;iD(a,e);if((c[a+1184>>2]|0)==0){f=a+1196|0;g=b[f>>1]|0;h=g&65535;i=h+1|0;return i|0}j=a+1192|0;k=b[j>>1]|0;l=a+1194|0;m=b[l>>1]|0;n=a+80|0;o=c[n>>2]|0;p=((k&65535)<<4)+(m&65535)&o;q=p+1|0;r=a+76|0;s=c[r>>2]|0;if(q>>>0<s>>>0){t=c[a+72>>2]|0;u=(d[t+q|0]|0)<<8|(d[t+p|0]|0);v=k;w=m;x=o;y=s}else{s=b8[c[a+44>>2]&255](c[a+32>>2]|0,p)|0;u=s;v=b[j>>1]|0;w=b[l>>1]|0;x=c[n>>2]|0;y=c[r>>2]|0}r=(w+2&65535)+((v&65535)<<4)&x;x=r+1|0;if(x>>>0<y>>>0){y=c[a+72>>2]|0;z=(d[y+x|0]|0)<<8|(d[y+r|0]|0)}else{z=b8[c[a+44>>2]&255](c[a+32>>2]|0,r)|0}b[a+4+(((d[e]|0)>>>3&7)<<1)>>1]=u;b[a+20>>1]=z;z=a+1200|0;c[z>>2]=(c[z>>2]|0)+16;f=a+1196|0;g=b[f>>1]|0;h=g&65535;i=h+1|0;return i|0}function k1(a){a=a|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=a+129|0;iD(a,e);if((c[a+1184>>2]|0)==0){f=a+1196|0;g=b[f>>1]|0;h=g&65535;i=h+1|0;return i|0}j=a+1192|0;k=b[j>>1]|0;l=a+1194|0;m=b[l>>1]|0;n=a+80|0;o=c[n>>2]|0;p=((k&65535)<<4)+(m&65535)&o;q=p+1|0;r=a+76|0;s=c[r>>2]|0;if(q>>>0<s>>>0){t=c[a+72>>2]|0;u=(d[t+q|0]|0)<<8|(d[t+p|0]|0);v=k;w=m;x=o;y=s}else{s=b8[c[a+44>>2]&255](c[a+32>>2]|0,p)|0;u=s;v=b[j>>1]|0;w=b[l>>1]|0;x=c[n>>2]|0;y=c[r>>2]|0}r=(w+2&65535)+((v&65535)<<4)&x;x=r+1|0;if(x>>>0<y>>>0){y=c[a+72>>2]|0;z=(d[y+x|0]|0)<<8|(d[y+r|0]|0)}else{z=b8[c[a+44>>2]&255](c[a+32>>2]|0,r)|0}b[a+4+(((d[e]|0)>>>3&7)<<1)>>1]=u;b[a+26>>1]=z;z=a+1200|0;c[z>>2]=(c[z>>2]|0)+16;f=a+1196|0;g=b[f>>1]|0;h=g&65535;i=h+1|0;return i|0}function k2(b){b=b|0;var d=0,f=0;iD(b,b+129|0);d=b+1196|0;iG(b,a[(e[d>>1]|0)+1+(b+128)|0]|0);f=b+1200|0;c[f>>2]=((c[b+1184>>2]|0)!=0?10:4)+(c[f>>2]|0);return(e[d>>1]|0)+2|0}function k3(a){a=a|0;var b=0,f=0;iD(a,a+129|0);b=a+1196|0;f=e[b>>1]|0;iH(a,(d[f+2+(a+128)|0]|0)<<8|(d[f+1+(a+128)|0]|0));f=a+1200|0;c[f>>2]=((c[a+1184>>2]|0)!=0?10:4)+(c[f>>2]|0);return(e[b>>1]|0)+3|0}function k4(a){a=a|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=a+12|0;f=b[e>>1]|0;g=f+2&65535;b[e>>1]=g;h=a+24|0;i=b[h>>1]|0;j=a+80|0;k=c[j>>2]|0;l=((i&65535)<<4)+(f&65535)&k;f=l+1|0;m=a+76|0;n=c[m>>2]|0;if(f>>>0<n>>>0){o=c[a+72>>2]|0;p=(d[o+f|0]|0)<<8|(d[o+l|0]|0);q=g;r=i;s=k;t=n}else{n=b8[c[a+44>>2]&255](c[a+32>>2]|0,l)|0;p=n;q=b[e>>1]|0;r=b[h>>1]|0;s=c[j>>2]|0;t=c[m>>2]|0}b[a+28>>1]=p;p=q+2&65535;b[e>>1]=p;m=((r&65535)<<4)+(q&65535)&s;s=m+1|0;if(s>>>0<t>>>0){t=c[a+72>>2]|0;u=(d[t+s|0]|0)<<8|(d[t+m|0]|0);v=p}else{p=b8[c[a+44>>2]&255](c[a+32>>2]|0,m)|0;u=p;v=b[e>>1]|0}b[a+22>>1]=u;b[e>>1]=((d[a+130|0]|0)<<8|(d[a+129|0]|0))+v&65535;mj(a);v=a+1200|0;c[v>>2]=(c[v>>2]|0)+25;return 0}function k5(a){a=a|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=a+12|0;f=b[e>>1]|0;g=f+2&65535;b[e>>1]=g;h=a+24|0;i=b[h>>1]|0;j=a+80|0;k=c[j>>2]|0;l=((i&65535)<<4)+(f&65535)&k;f=l+1|0;m=a+76|0;n=c[m>>2]|0;if(f>>>0<n>>>0){o=c[a+72>>2]|0;p=(d[o+f|0]|0)<<8|(d[o+l|0]|0);q=g;r=i;s=k;t=n}else{n=b8[c[a+44>>2]&255](c[a+32>>2]|0,l)|0;p=n;q=b[e>>1]|0;r=b[h>>1]|0;s=c[j>>2]|0;t=c[m>>2]|0}b[a+28>>1]=p;b[e>>1]=q+2&65535;e=((r&65535)<<4)+(q&65535)&s;s=e+1|0;if(s>>>0<t>>>0){t=c[a+72>>2]|0;u=(d[t+s|0]|0)<<8|(d[t+e|0]|0);v=a+22|0;b[v>>1]=u;mj(a);w=a+1200|0;x=c[w>>2]|0;y=x+26|0;c[w>>2]=y;return 0}else{u=b8[c[a+44>>2]&255](c[a+32>>2]|0,e)|0;v=a+22|0;b[v>>1]=u;mj(a);w=a+1200|0;x=c[w>>2]|0;y=x+26|0;c[w>>2]=y;return 0}return 0}function k6(a){a=a|0;var d=0;d=a+28|0;b[d>>1]=(b[d>>1]|0)+1&65535;id(a,3);mj(a);d=a+1200|0;c[d>>2]=(c[d>>2]|0)+52;return 0}function k7(a){a=a|0;var e=0;e=a+28|0;b[e>>1]=(b[e>>1]|0)+2&65535;id(a,d[a+129|0]|0);mj(a);e=a+1200|0;c[e>>2]=(c[e>>2]|0)+51;return 0}function k8(a){a=a|0;var d=0,e=0;if((b[a+30>>1]&2048)==0){d=a+1200|0;c[d>>2]=(c[d>>2]|0)+4;e=1;return e|0}else{d=a+28|0;b[d>>1]=(b[d>>1]|0)+1&65535;id(a,4);mj(a);d=a+1200|0;c[d>>2]=(c[d>>2]|0)+53;e=0;return e|0}return 0}function k9(a){a=a|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;e=a+12|0;f=b[e>>1]|0;g=f+2&65535;b[e>>1]=g;h=a+24|0;i=b[h>>1]|0;j=a+80|0;k=c[j>>2]|0;l=((i&65535)<<4)+(f&65535)&k;f=l+1|0;m=a+76|0;n=c[m>>2]|0;if(f>>>0<n>>>0){o=c[a+72>>2]|0;p=(d[o+f|0]|0)<<8|(d[o+l|0]|0);q=g;r=i;s=k;t=n}else{n=b8[c[a+44>>2]&255](c[a+32>>2]|0,l)|0;p=n;q=b[e>>1]|0;r=b[h>>1]|0;s=c[j>>2]|0;t=c[m>>2]|0}b[a+28>>1]=p;p=q+2&65535;b[e>>1]=p;n=((r&65535)<<4)+(q&65535)&s;q=n+1|0;if(q>>>0<t>>>0){l=c[a+72>>2]|0;u=(d[l+q|0]|0)<<8|(d[l+n|0]|0);v=p;w=r;x=s;y=t}else{t=b8[c[a+44>>2]&255](c[a+32>>2]|0,n)|0;u=t;v=b[e>>1]|0;w=b[h>>1]|0;x=c[j>>2]|0;y=c[m>>2]|0}b[a+22>>1]=u;b[e>>1]=v+2&65535;e=((w&65535)<<4)+(v&65535)&x;x=e+1|0;if(x>>>0<y>>>0){y=c[a+72>>2]|0;z=(d[y+x|0]|0)<<8|(d[y+e|0]|0);A=a+30|0;b[A>>1]=z;mj(a);B=a+1200|0;C=c[B>>2]|0;D=C+32|0;c[B>>2]=D;return 0}else{z=b8[c[a+44>>2]&255](c[a+32>>2]|0,e)|0;A=a+30|0;b[A>>1]=z;mj(a);B=a+1200|0;C=c[B>>2]|0;D=C+32|0;c[B>>2]=D;return 0}return 0}function la(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=a+129|0;g=(d[f]|0)>>>3&7;iD(a,f);f=iE(a)|0;do{if((g|0)==4){h=f&255;i=h<<1;j=i&65535;it(a,i&255);i=a+30|0;k=b[i>>1]|0;if((h&128|0)==0){h=k&-2;b[i>>1]=h;l=j;m=h;break}else{h=k|1;b[i>>1]=h;l=j;m=h;break}}else if((g|0)==3){h=f&255;j=a+30|0;i=b[j>>1]|0;k=((i&65535)<<7&128|h>>>1)&65535;if((h&1|0)==0){h=i&-2;b[j>>1]=h;l=k;m=h;break}else{h=i|1;b[j>>1]=h;l=k;m=h;break}}else if((g|0)==0){h=f&255;k=(h<<1|h>>>7)&65535;j=a+30|0;i=b[j>>1]|0;if((h&128|0)==0){h=i&-2;b[j>>1]=h;l=k;m=h;break}else{h=i|1;b[j>>1]=h;l=k;m=h;break}}else if((g|0)==5){h=(f&255)>>>1;k=h&255;it(a,h);h=a+30|0;j=b[h>>1]|0;if((f&1)==0){i=j&-2;b[h>>1]=i;l=k;m=i;break}else{i=j|1;b[h>>1]=i;l=k;m=i;break}}else if((g|0)==7){i=f&255;k=i>>>1|i&128;h=k&65535;it(a,k&255);k=a+30|0;j=b[k>>1]|0;if((i&1|0)==0){i=j&-2;b[k>>1]=i;l=h;m=i;break}else{i=j|1;b[k>>1]=i;l=h;m=i;break}}else if((g|0)==1){i=f&255;h=(i>>>1|i<<7)&65535;k=a+30|0;j=b[k>>1]|0;if((i&1|0)==0){i=j&-2;b[k>>1]=i;l=h;m=i;break}else{i=j|1;b[k>>1]=i;l=h;m=i;break}}else if((g|0)==2){i=f&255;h=a+30|0;k=b[h>>1]|0;j=(k&1|i<<1)&65535;if((i&128|0)==0){i=k&-2;b[h>>1]=i;l=j;m=i;break}else{i=k|1;b[h>>1]=i;l=j;m=i;break}}else{i=a+1200|0;c[i>>2]=(c[i>>2]|0)+1;n=ie(a)|0;return n|0}}while(0);b[a+30>>1]=((l&65535^f&255)&128|0)==0?m&-2049:m|2048;iG(a,l&255);l=a+1200|0;c[l>>2]=((c[a+1184>>2]|0)!=0?15:2)+(c[l>>2]|0);n=(e[a+1196>>1]|0)+1|0;return n|0}function lb(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=a+129|0;g=(d[f]|0)>>>3&7;iD(a,f);f=(iF(a)|0)&65535;do{if((g|0)==5){h=f>>>1;iu(a,h&65535);i=a+30|0;j=b[i>>1]|0;if((f&1|0)==0){k=j&-2;b[i>>1]=k;l=h;m=k;break}else{k=j|1;b[i>>1]=k;l=h;m=k;break}}else if((g|0)==3){k=a+30|0;h=b[k>>1]|0;i=(h&65535)<<15&32768|f>>>1;if((f&1|0)==0){j=h&-2;b[k>>1]=j;l=i;m=j;break}else{j=h|1;b[k>>1]=j;l=i;m=j;break}}else if((g|0)==1){j=f>>>1|f<<15;i=a+30|0;k=b[i>>1]|0;if((f&1|0)==0){h=k&-2;b[i>>1]=h;l=j;m=h;break}else{h=k|1;b[i>>1]=h;l=j;m=h;break}}else if((g|0)==4){h=f<<1;iu(a,h&65535);j=a+30|0;i=b[j>>1]|0;if((f&32768|0)==0){k=i&-2;b[j>>1]=k;l=h;m=k;break}else{k=i|1;b[j>>1]=k;l=h;m=k;break}}else if((g|0)==0){k=f<<1|f>>>15;h=a+30|0;j=b[h>>1]|0;if((f&32768|0)==0){i=j&-2;b[h>>1]=i;l=k;m=i;break}else{i=j|1;b[h>>1]=i;l=k;m=i;break}}else if((g|0)==7){i=f>>>1|f&32768;iu(a,i&65535);k=a+30|0;h=b[k>>1]|0;if((f&1|0)==0){j=h&-2;b[k>>1]=j;l=i;m=j;break}else{j=h|1;b[k>>1]=j;l=i;m=j;break}}else if((g|0)==2){j=a+30|0;i=b[j>>1]|0;k=i&1|f<<1;if((f&32768|0)==0){h=i&-2;b[j>>1]=h;l=k;m=h;break}else{h=i|1;b[j>>1]=h;l=k;m=h;break}}else{h=a+1200|0;c[h>>2]=(c[h>>2]|0)+1;n=ie(a)|0;return n|0}}while(0);b[a+30>>1]=((l^f)&32768|0)==0?m&-2049:m|2048;iH(a,l&65535);l=a+1200|0;c[l>>2]=((c[a+1184>>2]|0)!=0?15:2)+(c[l>>2]|0);n=(e[a+1196>>1]|0)+1|0;return n|0}function lc(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=d+129|0;g=a[f]|0;iD(d,f);f=iE(d)|0;h=f&255;i=e[d+6>>1]|0;j=((c[d>>2]&2|0)==0?255:31)&i;if((j|0)==0){k=d+1200|0;c[k>>2]=((c[d+1184>>2]|0)!=0?20:8)+(c[k>>2]|0);l=(e[d+1196>>1]|0)+1|0;return l|0}k=(g&255)>>>3&7;do{if((k|0)==1){g=f&255;m=i&7;n=g<<8-m|g>>>(m>>>0);m=n&65535;g=d+30|0;o=b[g>>1]|0;if((n&128|0)==0){b[g>>1]=o&-2;p=h;q=m;break}else{b[g>>1]=o|1;p=h;q=m;break}}else if((k|0)==7){m=f&255;o=((m&128|0)!=0?65280:0)|m;m=o>>>((j>>>0>7?7:j-1|0)>>>0);g=d+30|0;n=b[g>>1]|0;b[g>>1]=(m&1|0)==0?n&-2:n|1;n=m>>>1;it(d,n&255);p=o&65535;q=n&255}else if((k|0)==3){n=d+30|0;o=b[n>>1]|0;m=o<<8&256|h;g=m&65535;r=(j>>>0)%9|0;s=g>>>(r>>>0)|g<<9-r;r=s&65535;if((s&256|0)==0){b[n>>1]=o&-2;p=m;q=r;break}else{b[n>>1]=o|1;p=m;q=r;break}}else if((k|0)==4){if(j>>>0>8){t=0}else{t=(f&255)<<j&65535}it(d,t&255);r=d+30|0;m=b[r>>1]|0;if((t&256)==0){b[r>>1]=m&-2;p=h;q=t;break}else{b[r>>1]=m|1;p=h;q=t;break}}else if((k|0)==0){m=f&255;r=i&7;o=m>>>((8-r|0)>>>0)|m<<r;r=o&65535;m=d+30|0;n=b[m>>1]|0;if((o&1|0)==0){b[m>>1]=n&-2;p=h;q=r;break}else{b[m>>1]=n|1;p=h;q=r;break}}else if((k|0)==5){if(j>>>0>8){u=0}else{u=(f&255)>>>((j-1|0)>>>0)&65535}r=d+30|0;n=b[r>>1]|0;b[r>>1]=(u&1|0)==0?n&-2:n|1;n=u>>>1;it(d,n&255);p=h;q=n&65535}else if((k|0)==2){n=d+30|0;r=b[n>>1]|0;m=r<<8&256|h;o=m&65535;s=(j>>>0)%9|0;g=o<<s|o>>>((9-s|0)>>>0);s=g&65535;if((g&256|0)==0){b[n>>1]=r&-2;p=m;q=s;break}else{b[n>>1]=r|1;p=m;q=s;break}}else{s=d+1200|0;c[s>>2]=(c[s>>2]|0)+1;l=ie(d)|0;return l|0}}while(0);h=d+30|0;k=b[h>>1]|0;b[h>>1]=((p^q)&128)==0?k&-2049:k|2048;iG(d,q&255);q=d+1200|0;c[q>>2]=(c[q>>2]|0)+(j<<2)+((c[d+1184>>2]|0)!=0?20:8);l=(e[d+1196>>1]|0)+1|0;return l|0}function ld(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=d+129|0;g=a[f]|0;iD(d,f);f=(iF(d)|0)&65535;h=e[d+6>>1]|0;i=((c[d>>2]&2|0)==0?255:31)&h;if((i|0)==0){j=d+1200|0;c[j>>2]=((c[d+1184>>2]|0)!=0?20:8)+(c[j>>2]|0);k=(e[d+1196>>1]|0)+1|0;return k|0}j=(g&255)>>>3&7;do{if((j|0)==4){g=i>>>0>16?0:f<<i;iu(d,g&65535);l=d+30|0;m=b[l>>1]|0;if((g&65536|0)==0){b[l>>1]=m&-2;n=f;o=g;break}else{b[l>>1]=m|1;n=f;o=g;break}}else if((j|0)==1){g=h&15;m=f<<16-g|f>>>(g>>>0);g=d+30|0;l=b[g>>1]|0;if((m&32768|0)==0){b[g>>1]=l&-2;n=f;o=m;break}else{b[g>>1]=l|1;n=f;o=m;break}}else if((j|0)==3){m=d+30|0;l=b[m>>1]|0;g=(l&65535)<<16&65536|f;p=(i>>>0)%17|0;q=g>>>(p>>>0)|g<<17-p;if((q&65536|0)==0){b[m>>1]=l&-2;n=g;o=q;break}else{b[m>>1]=l|1;n=g;o=q;break}}else if((j|0)==5){if(i>>>0>16){r=0}else{r=f>>>((i-1|0)>>>0)}q=d+30|0;g=b[q>>1]|0;b[q>>1]=(r&1|0)==0?g&-2:g|1;g=r>>>1;iu(d,g&65535);n=f;o=g}else if((j|0)==0){g=h&15;q=f>>>((16-g|0)>>>0)|f<<g;g=d+30|0;l=b[g>>1]|0;if((q&1|0)==0){b[g>>1]=l&-2;n=f;o=q;break}else{b[g>>1]=l|1;n=f;o=q;break}}else if((j|0)==7){q=((f&32768|0)!=0?-65536:0)|f;l=q>>>((i>>>0>15?15:i-1|0)>>>0);g=d+30|0;m=b[g>>1]|0;b[g>>1]=(l&1|0)==0?m&-2:m|1;m=l>>>1;iu(d,m&65535);n=q;o=m&65535}else if((j|0)==2){m=d+30|0;q=b[m>>1]|0;l=(q&65535)<<16&65536|f;g=(i>>>0)%17|0;p=l<<g|l>>>((17-g|0)>>>0);if((p&65536|0)==0){b[m>>1]=q&-2;n=l;o=p;break}else{b[m>>1]=q|1;n=l;o=p;break}}else{p=d+1200|0;c[p>>2]=(c[p>>2]|0)+1;k=ie(d)|0;return k|0}}while(0);f=d+30|0;j=b[f>>1]|0;b[f>>1]=((n^o)&32768|0)==0?j&-2049:j|2048;iH(d,o&65535);o=d+1200|0;c[o>>2]=(c[o>>2]|0)+(i<<2)+((c[d+1184>>2]|0)!=0?20:8);k=(e[d+1196>>1]|0)+1|0;return k|0}function le(d){d=d|0;var e=0,f=0,g=0,h=0,i=0;e=a[d+129|0]|0;f=e&255;if(e<<24>>24==0){id(d,0);g=0;return g|0}else{e=d+4|0;h=b[e>>1]&255;i=(((h>>>0)%(f>>>0)|0)&255|((h>>>0)/(f>>>0)|0)<<8)&65535;b[e>>1]=i;iu(d,i);i=d+1200|0;c[i>>2]=(c[i>>2]|0)+83;g=2;return g|0}return 0}function lf(a){a=a|0;var e=0,f=0,g=0;e=a+4|0;f=b[e>>1]|0;g=ac((f&65535)>>>8,d[a+129|0]|0)|0;b[e>>1]=g+f&255;iu(a,g+(f&255)&65535);f=a+1200|0;c[f>>2]=(c[f>>2]|0)+60;return 2}function lg(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=d+4|0;g=b[f>>1]|0;h=((g&255)+(b[d+10>>1]|0)&65535)+((e[((c[d+144>>2]&2|0)==0?d+26|0:d+148|0)>>1]|0)<<4)&c[d+80>>2];if(h>>>0<(c[d+76>>2]|0)>>>0){i=a[(c[d+72>>2]|0)+h|0]|0;j=g;k=j&-256;l=i&255;m=k|l;b[f>>1]=m;n=d+1200|0;o=c[n>>2]|0;p=o+11|0;c[n>>2]=p;return 1}else{g=b8[c[d+36>>2]&255](c[d+32>>2]|0,h)|0;i=g;j=b[f>>1]|0;k=j&-256;l=i&255;m=k|l;b[f>>1]=m;n=d+1200|0;o=c[n>>2]|0;p=o+11|0;c[n>>2]=p;return 1}return 0}function lh(a){a=a|0;var b=0,d=0;if((c[a>>2]&16|0)==0){iD(a,a+129|0);b=a+1200|0;c[b>>2]=(c[b>>2]|0)+2;d=(e[a+1196>>1]|0)+1|0;return d|0}else{id(a,7);b=a+1200|0;c[b>>2]=(c[b>>2]|0)+50;d=0;return d|0}return 0}function li(a){a=a|0;var f=0,g=0,h=0,i=0;f=a+6|0;g=(e[f>>1]|0)+65535|0;b[f>>1]=g&65535;do{if((g&65535|0)!=0){if((b[a+30>>1]&64)!=0){break}f=d[a+129|0]|0;h=a+28|0;b[h>>1]=(e[h>>1]|0)+2+((f&128|0)!=0?f|65280:f)&65535;mj(a);f=a+1200|0;c[f>>2]=(c[f>>2]|0)+19;i=0;return i|0}}while(0);g=a+1200|0;c[g>>2]=(c[g>>2]|0)+5;i=2;return i|0}function lj(a){a=a|0;var f=0,g=0,h=0,i=0;f=a+6|0;g=(e[f>>1]|0)+65535|0;b[f>>1]=g&65535;do{if((g&65535|0)!=0){if((b[a+30>>1]&64)==0){break}f=d[a+129|0]|0;h=a+28|0;b[h>>1]=(e[h>>1]|0)+2+((f&128|0)!=0?f|65280:f)&65535;mj(a);f=a+1200|0;c[f>>2]=(c[f>>2]|0)+18;i=0;return i|0}}while(0);g=a+1200|0;c[g>>2]=(c[g>>2]|0)+5;i=2;return i|0}function lk(a){a=a|0;var f=0,g=0,h=0;f=a+6|0;g=(e[f>>1]|0)+65535|0;b[f>>1]=g&65535;if((g&65535|0)==0){g=a+1200|0;c[g>>2]=(c[g>>2]|0)+5;h=2;return h|0}else{g=d[a+129|0]|0;f=a+28|0;b[f>>1]=(e[f>>1]|0)+2+((g&128|0)!=0?g|65280:g)&65535;mj(a);g=a+1200|0;c[g>>2]=(c[g>>2]|0)+18;h=0;return h|0}return 0}function ll(a){a=a|0;var f=0,g=0,h=0;if((b[a+6>>1]|0)==0){f=d[a+129|0]|0;g=a+28|0;b[g>>1]=(e[g>>1]|0)+2+((f&128|0)!=0?f|65280:f)&65535;mj(a);f=a+1200|0;c[f>>2]=(c[f>>2]|0)+18;h=0;return h|0}else{f=a+1200|0;c[f>>2]=(c[f>>2]|0)+6;h=2;return h|0}return 0}function lm(a){a=a|0;var e=0,f=0;e=b8[c[a+56>>2]&255](c[a+52>>2]|0,d[a+129|0]|0)|0;f=a+4|0;b[f>>1]=b[f>>1]&-256|e&255;e=a+1200|0;c[e>>2]=(c[e>>2]|0)+11;return 2}function ln(a){a=a|0;var e=0;b[a+4>>1]=b8[c[a+64>>2]&255](c[a+52>>2]|0,d[a+129|0]|0)|0;e=a+1200|0;c[e>>2]=(c[e>>2]|0)+15;return 2}function lo(a){a=a|0;var e=0;b5[c[a+60>>2]&255](c[a+52>>2]|0,d[a+129|0]|0,b[a+4>>1]&255);e=a+1200|0;c[e>>2]=(c[e>>2]|0)+11;return 2}function lp(a){a=a|0;var e=0;b5[c[a+68>>2]&255](c[a+52>>2]|0,d[a+129|0]|0,b[a+4>>1]|0);e=a+1200|0;c[e>>2]=(c[e>>2]|0)+11;return 2}function lq(f){f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f+28|0;h=(b[g>>1]|0)+3&65535;i=f+12|0;j=(b[i>>1]|0)-2&65535;b[i>>1]=j;i=((e[f+24>>1]|0)<<4)+(j&65535)&c[f+80>>2];j=i+1|0;if(j>>>0<(c[f+76>>2]|0)>>>0){k=f+72|0;a[(c[k>>2]|0)+i|0]=h&255;a[(c[k>>2]|0)+j|0]=(h&65535)>>>8&255}else{b5[c[f+48>>2]&255](c[f+32>>2]|0,i,h)}b[g>>1]=((b[g>>1]|0)+3&65535)+((d[f+130|0]|0)<<8|(d[f+129|0]|0))&65535;mj(f);g=f+1200|0;c[g>>2]=(c[g>>2]|0)+19;return 0}function lr(a){a=a|0;var b=0;b=a+144|0;c[b>>2]=c[b>>2]|17;b=a+1200|0;c[b>>2]=(c[b>>2]|0)+2;return 1}function ls(a){a=a|0;var b=0;b=a+144|0;c[b>>2]=c[b>>2]|9;b=a+1200|0;c[b>>2]=(c[b>>2]|0)+2;return 1}function lt(a){a=a|0;var b=0;b=a+144|0;c[b>>2]=c[b>>2]|5;b=a+1200|0;c[b>>2]=(c[b>>2]|0)+2;return 1}function lu(a){a=a|0;var b=0;c[a+152>>2]=1;b=a+1200|0;c[b>>2]=(c[b>>2]|0)+2;return 1}function lv(a){a=a|0;var d=0;d=a+30|0;b[d>>1]=b[d>>1]^1;d=a+1200|0;c[d>>2]=(c[d>>2]|0)+2;return 1}function lw(a){a=a|0;var d=0;d=a+30|0;b[d>>1]=b[d>>1]&-2;d=a+1200|0;c[d>>2]=(c[d>>2]|0)+2;return 1}function lx(a){a=a|0;var d=0;d=a+30|0;b[d>>1]=b[d>>1]|1;d=a+1200|0;c[d>>2]=(c[d>>2]|0)+2;return 1}function ly(a){a=a|0;var d=0;d=a+30|0;b[d>>1]=b[d>>1]&-513;d=a+1200|0;c[d>>2]=(c[d>>2]|0)+2;return 1}function lz(a){a=a|0;var d=0;d=a+30|0;b[d>>1]=b[d>>1]|512;d=a+1200|0;c[d>>2]=(c[d>>2]|0)+2;return 1}function lA(a){a=a|0;var d=0;d=a+30|0;b[d>>1]=b[d>>1]&-1025;d=a+1200|0;c[d>>2]=(c[d>>2]|0)+2;return 1}function lB(a){a=a|0;var d=0;d=a+30|0;b[d>>1]=b[d>>1]|1024;d=a+1200|0;c[d>>2]=(c[d>>2]|0)+2;return 1}function lC(a){a=a|0;var e=0;e=a+28|0;b[e>>1]=((b[e>>1]|0)+3&65535)+((d[a+130|0]|0)<<8|(d[a+129|0]|0))&65535;mj(a);e=a+1200|0;c[e>>2]=(c[e>>2]|0)+15;return 0}function lD(a){a=a|0;var e=0;b[a+28>>1]=(d[a+130|0]|0)<<8|(d[a+129|0]|0);b[a+22>>1]=(d[a+132|0]|0)<<8|(d[a+131|0]|0);mj(a);e=a+1200|0;c[e>>2]=(c[e>>2]|0)+15;return 0}function lE(a){a=a|0;var f=0,g=0;f=d[a+129|0]|0;g=a+28|0;b[g>>1]=(e[g>>1]|0)+2+((f&128|0)!=0?f|65280:f)&65535;mj(a);f=a+1200|0;c[f>>2]=(c[f>>2]|0)+15;return 0}function lF(a){a=a|0;var d=0,f=0;d=b8[c[a+56>>2]&255](c[a+52>>2]|0,e[a+8>>1]|0)|0;f=a+4|0;b[f>>1]=b[f>>1]&-256|d&255;d=a+1200|0;c[d>>2]=(c[d>>2]|0)+9;return 1}function lG(a){a=a|0;var d=0;b[a+4>>1]=b8[c[a+64>>2]&255](c[a+52>>2]|0,e[a+8>>1]|0)|0;d=a+1200|0;c[d>>2]=(c[d>>2]|0)+13;return 1}function lH(a){a=a|0;var d=0;b5[c[a+60>>2]&255](c[a+52>>2]|0,e[a+8>>1]|0,b[a+4>>1]&255);d=a+1200|0;c[d>>2]=(c[d>>2]|0)+9;return 1}function lI(a){a=a|0;var d=0;b5[c[a+68>>2]&255](c[a+52>>2]|0,e[a+8>>1]|0,b[a+4>>1]|0);d=a+1200|0;c[d>>2]=(c[d>>2]|0)+9;return 1}function lJ(b){b=b|0;return b1[c[13096+(((a[b+129|0]&255)>>>3&7)<<2)>>2]&1023](b)|0}function lK(b){b=b|0;return b1[c[13064+(((a[b+129|0]&255)>>>3&7)<<2)>>2]&1023](b)|0}function lL(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=a+129|0;g=(d[f]|0)>>>3&7;if((g|0)==0){iD(a,f);h=iE(a)|0;iG(a,h+1&255);i=a+30|0;j=b[i>>1]|0;ix(a,h,1);h=b[i>>1]|0;b[i>>1]=(h^j)&1^h;h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?15:3)+(c[h>>2]|0);k=(e[a+1196>>1]|0)+1|0;return k|0}else if((g|0)==1){iD(a,f);f=iE(a)|0;iG(a,f-1&255);g=a+30|0;h=b[g>>1]|0;iI(a,f,1);f=b[g>>1]|0;b[g>>1]=(f^h)&1^f;f=a+1200|0;c[f>>2]=((c[a+1184>>2]|0)!=0?15:3)+(c[f>>2]|0);k=(e[a+1196>>1]|0)+1|0;return k|0}else{f=a+1200|0;c[f>>2]=(c[f>>2]|0)+1;k=ie(a)|0;return k|0}return 0}function lM(b){b=b|0;return b1[c[13032+(((a[b+129|0]&255)>>>3&7)<<2)>>2]&1023](b)|0}function lN(a){a=a|0;var d=0,f=0,g=0;iD(a,a+129|0);d=iF(a)|0;iH(a,d+1&65535);f=a+30|0;g=b[f>>1]|0;iy(a,d,1);d=b[f>>1]|0;b[f>>1]=(d^g)&1^d;d=a+1200|0;c[d>>2]=((c[a+1184>>2]|0)!=0?15:3)+(c[d>>2]|0);return(e[a+1196>>1]|0)+1|0}function lO(a){a=a|0;var d=0,f=0,g=0;iD(a,a+129|0);d=iF(a)|0;iH(a,d-1&65535);f=a+30|0;g=b[f>>1]|0;iJ(a,d,1);d=b[f>>1]|0;b[f>>1]=(d^g)&1^d;d=a+1200|0;c[d>>2]=((c[a+1184>>2]|0)!=0?15:3)+(c[d>>2]|0);return(e[a+1196>>1]|0)+1|0}function lP(d){d=d|0;var f=0,g=0,h=0,i=0,j=0;iD(d,d+129|0);f=d+28|0;g=((b[f>>1]|0)+1&65535)+(b[d+1196>>1]|0)&65535;h=d+12|0;i=(b[h>>1]|0)-2&65535;b[h>>1]=i;h=((e[d+24>>1]|0)<<4)+(i&65535)&c[d+80>>2];i=h+1|0;if(i>>>0<(c[d+76>>2]|0)>>>0){j=d+72|0;a[(c[j>>2]|0)+h|0]=g&255;a[(c[j>>2]|0)+i|0]=(g&65535)>>>8&255}else{b5[c[d+48>>2]&255](c[d+32>>2]|0,h,g)}b[f>>1]=iF(d)|0;mj(d);f=d+1200|0;c[f>>2]=((c[d+1184>>2]|0)!=0?21:16)+(c[f>>2]|0);return 0}function lQ(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;iD(f,f+129|0);if((c[f+1184>>2]|0)==0){g=(e[f+1196>>1]|0)+1|0;return g|0}h=f+22|0;i=b[h>>1]|0;j=f+12|0;k=(b[j>>1]|0)-2&65535;b[j>>1]=k;l=f+24|0;m=f+80|0;n=((e[l>>1]|0)<<4)+(k&65535)&c[m>>2];k=n+1|0;o=f+76|0;if(k>>>0<(c[o>>2]|0)>>>0){p=f+72|0;a[(c[p>>2]|0)+n|0]=i&255;a[(c[p>>2]|0)+k|0]=(i&65535)>>>8&255}else{b5[c[f+48>>2]&255](c[f+32>>2]|0,n,i)}i=f+28|0;n=((b[i>>1]|0)+1&65535)+(b[f+1196>>1]|0)&65535;k=(b[j>>1]|0)-2&65535;b[j>>1]=k;j=((e[l>>1]|0)<<4)+(k&65535)&c[m>>2];k=j+1|0;if(k>>>0<(c[o>>2]|0)>>>0){l=f+72|0;a[(c[l>>2]|0)+j|0]=n&255;a[(c[l>>2]|0)+k|0]=(n&65535)>>>8&255}else{b5[c[f+48>>2]&255](c[f+32>>2]|0,j,n)}n=b[f+1194>>1]|0;j=(e[((c[f+144>>2]&2|0)==0?f+1192|0:f+148|0)>>1]|0)<<4;k=c[m>>2]|0;l=j+(n&65535)&k;p=l+1|0;q=c[o>>2]|0;if(p>>>0<q>>>0){r=c[f+72>>2]|0;s=(d[r+p|0]|0)<<8|(d[r+l|0]|0);t=k;u=q}else{q=b8[c[f+44>>2]&255](c[f+32>>2]|0,l)|0;s=q;t=c[m>>2]|0;u=c[o>>2]|0}b[i>>1]=s;s=t&(n+2&65535)+j;j=s+1|0;if(j>>>0<u>>>0){u=c[f+72>>2]|0;v=(d[u+j|0]|0)<<8|(d[u+s|0]|0)}else{v=b8[c[f+44>>2]&255](c[f+32>>2]|0,s)|0}b[h>>1]=v;mj(f);v=f+1200|0;c[v>>2]=(c[v>>2]|0)+37;g=0;return g|0}function lR(a){a=a|0;var d=0;iD(a,a+129|0);b[a+28>>1]=iF(a)|0;mj(a);d=a+1200|0;c[d>>2]=((c[a+1184>>2]|0)!=0?18:11)+(c[d>>2]|0);return 0}function lS(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;iD(a,a+129|0);if((c[a+1184>>2]|0)==0){f=(e[a+1196>>1]|0)+1|0;return f|0}g=a+1192|0;h=b[g>>1]|0;i=a+1194|0;j=b[i>>1]|0;k=a+80|0;l=c[k>>2]|0;m=((h&65535)<<4)+(j&65535)&l;n=m+1|0;o=a+76|0;p=c[o>>2]|0;if(n>>>0<p>>>0){q=c[a+72>>2]|0;r=(d[q+n|0]|0)<<8|(d[q+m|0]|0);s=h;t=j;u=l;v=p}else{p=b8[c[a+44>>2]&255](c[a+32>>2]|0,m)|0;r=p;s=b[g>>1]|0;t=b[i>>1]|0;u=c[k>>2]|0;v=c[o>>2]|0}b[a+28>>1]=r;r=(t+2&65535)+((s&65535)<<4)&u;u=r+1|0;if(u>>>0<v>>>0){v=c[a+72>>2]|0;w=(d[v+u|0]|0)<<8|(d[v+r|0]|0)}else{w=b8[c[a+44>>2]&255](c[a+32>>2]|0,r)|0}b[a+22>>1]=w;mj(a);w=a+1200|0;c[w>>2]=(c[w>>2]|0)+24;f=0;return f|0}function lT(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;iD(d,d+129|0);f=d+1184|0;do{if((c[f>>2]|0)==0){if((b[d+1194>>1]|0)!=4){g=4007;break}if((c[d>>2]&4|0)!=0){g=4007;break}h=d+12|0;i=(b[h>>1]|0)-2&65535;b[h>>1]=i;h=(e[d+24>>1]<<4)+(i&65535)&c[d+80>>2];j=h+1|0;if(j>>>0<(c[d+76>>2]|0)>>>0){k=d+72|0;a[(c[k>>2]|0)+h|0]=i&255;a[(c[k>>2]|0)+j|0]=(i&65535)>>>8&255;break}else{b5[c[d+48>>2]&255](c[d+32>>2]|0,h,i);break}}else{g=4007}}while(0);do{if((g|0)==4007){i=iF(d)|0;h=d+12|0;j=(b[h>>1]|0)-2&65535;b[h>>1]=j;h=(e[d+24>>1]<<4)+(j&65535)&c[d+80>>2];j=h+1|0;if(j>>>0<(c[d+76>>2]|0)>>>0){k=d+72|0;a[(c[k>>2]|0)+h|0]=i&255;a[(c[k>>2]|0)+j|0]=(i&65535)>>>8&255;break}else{b5[c[d+48>>2]&255](c[d+32>>2]|0,h,i);break}}}while(0);g=d+1200|0;c[g>>2]=((c[f>>2]|0)!=0?16:10)+(c[g>>2]|0);return(e[d+1196>>1]|0)+1|0}function lU(a){a=a|0;var b=0,f=0,g=0;iD(a,a+129|0);b=iF(a)|0;f=a+1196|0;g=e[f>>1]|0;iw(a,((d[g+2+(a+128)|0]|0)<<8|(d[g+1+(a+128)|0]|0))&b);b=a+1200|0;c[b>>2]=((c[a+1184>>2]|0)!=0?11:5)+(c[b>>2]|0);return(e[f>>1]|0)+3|0}function lV(a){a=a|0;var b=0;iD(a,a+129|0);iH(a,~(iF(a)|0));b=a+1200|0;c[b>>2]=((c[a+1184>>2]|0)!=0?16:3)+(c[b>>2]|0);return(e[a+1196>>1]|0)+1|0}function lW(a){a=a|0;var b=0;iD(a,a+129|0);b=iF(a)|0;iH(a,-b&65535);iJ(a,0,b);b=a+1200|0;c[b>>2]=((c[a+1184>>2]|0)!=0?16:3)+(c[b>>2]|0);return(e[a+1196>>1]|0)+1|0}function lX(a){a=a|0;var d=0,f=0,g=0,h=0;iD(a,a+129|0);d=(iF(a)|0)&65535;f=a+4|0;g=ac(e[f>>1]|0,d)|0;b[f>>1]=g&65535;b[a+8>>1]=g>>>16&65535;f=a+30|0;d=b[f>>1]|0;h=(g&2147418112|0)==0?d&-2050:d|2049;b[f>>1]=(g|0)==0?h|64:h&-65;h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?131:115)+(c[h>>2]|0);return(e[a+1196>>1]|0)+1|0}function lY(a){a=a|0;var d=0,f=0,g=0,h=0,i=0;iD(a,a+129|0);d=a+4|0;f=e[d>>1]|0;g=(iF(a)|0)&65535;h=ac((g&32768|0)!=0?g|-65536:g,(f&32768|0)!=0?f|-65536:f)|0;b[d>>1]=h&65535;b[a+8>>1]=h>>>16&65535;d=h&-65536;h=a+30|0;f=b[h>>1]|0;if((d|0)==(-65536|0)|(d|0)==0){i=f&-2050}else{i=f|2049}b[h>>1]=i;i=a+1200|0;c[i>>2]=((c[a+1184>>2]|0)!=0?147:141)+(c[i>>2]|0);return(e[a+1196>>1]|0)+1|0}
function lZ(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0;iD(a,a+129|0);d=iF(a)|0;f=d&65535;if(d<<16>>16==0){d=a+1200|0;c[d>>2]=((c[a+1184>>2]|0)!=0?20:16)+(c[d>>2]|0);d=a+28|0;b[d>>1]=((b[d>>1]|0)+1&65535)+(b[a+1196>>1]|0)&65535;id(a,0);g=0;return g|0}d=a+8|0;h=a+4|0;i=(e[d>>1]|0)<<16|(e[h>>1]|0);j=(i>>>0)/(f>>>0)|0;if(j>>>0>65535){k=a+1200|0;c[k>>2]=((c[a+1184>>2]|0)!=0?20:16)+(c[k>>2]|0);k=a+28|0;b[k>>1]=((b[k>>1]|0)+1&65535)+(b[a+1196>>1]|0)&65535;id(a,0);g=0;return g|0}else{b[h>>1]=j&65535;b[d>>1]=((i>>>0)%(f>>>0)|0)&65535;f=a+1200|0;c[f>>2]=((c[a+1184>>2]|0)!=0?159:153)+(c[f>>2]|0);g=(e[a+1196>>1]|0)+1|0;return g|0}return 0}function l_(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;iD(a,a+129|0);d=a+8|0;f=e[d>>1]|0;g=f<<16;h=a+4|0;i=g|(e[h>>1]|0);j=(iF(a)|0)&65535;k=(j&32768|0)!=0;l=k?j|-65536:j;if((l|0)==0){m=a+1200|0;c[m>>2]=((c[a+1184>>2]|0)!=0?20:16)+(c[m>>2]|0);m=a+28|0;b[m>>1]=((b[m>>1]|0)+1&65535)+(b[a+1196>>1]|0)&65535;id(a,0);n=0;return n|0}m=(g|0)<0;g=m?-i|0:i;i=k?-l|0:j;l=(g>>>0)/(i>>>0)|0;k=(g>>>0)%(i>>>0)|0;do{if((f>>>15|0)==(j>>>15|0)){if(l>>>0<=32767){o=l&65535;break}i=a+1200|0;c[i>>2]=((c[a+1184>>2]|0)!=0?20:16)+(c[i>>2]|0);i=a+28|0;b[i>>1]=((b[i>>1]|0)+1&65535)+(b[a+1196>>1]|0)&65535;id(a,0);n=0;return n|0}else{if(l>>>0<=32768){o=-l&65535;break}i=a+1200|0;c[i>>2]=((c[a+1184>>2]|0)!=0?20:16)+(c[i>>2]|0);i=a+28|0;b[i>>1]=((b[i>>1]|0)+1&65535)+(b[a+1196>>1]|0)&65535;id(a,0);n=0;return n|0}}while(0);if(m){p=-k&65535}else{p=k&65535}b[h>>1]=o;b[d>>1]=p;p=a+1200|0;c[p>>2]=((c[a+1184>>2]|0)!=0?180:174)+(c[p>>2]|0);n=(e[a+1196>>1]|0)+1|0;return n|0}function l$(b){b=b|0;var d=0,f=0;iD(b,b+129|0);d=iE(b)|0;f=b+1196|0;iv(b,a[(e[f>>1]|0)+1+(b+128)|0]&d);d=b+1200|0;c[d>>2]=((c[b+1184>>2]|0)!=0?11:5)+(c[d>>2]|0);return(e[f>>1]|0)+2|0}function l0(a){a=a|0;var b=0;iD(a,a+129|0);iG(a,~(iE(a)|0));b=a+1200|0;c[b>>2]=((c[a+1184>>2]|0)!=0?16:3)+(c[b>>2]|0);return(e[a+1196>>1]|0)+1|0}function l1(a){a=a|0;var b=0;iD(a,a+129|0);b=iE(a)|0;iG(a,-b&255);iI(a,0,b);b=a+1200|0;c[b>>2]=((c[a+1184>>2]|0)!=0?16:3)+(c[b>>2]|0);return(e[a+1196>>1]|0)+1|0}function l2(a){a=a|0;var d=0,f=0,g=0,h=0;iD(a,a+129|0);d=(iE(a)|0)&255;f=a+4|0;g=ac(b[f>>1]&255,d)|0;b[f>>1]=g;f=a+30|0;d=b[f>>1]|0;h=(g&65535)<256?d&-2050:d|2049;b[f>>1]=g<<16>>16==0?h|64:h&-65;h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?79:73)+(c[h>>2]|0);return(e[a+1196>>1]|0)+1|0}function l3(a){a=a|0;var d=0,f=0,g=0,h=0,i=0;iD(a,a+129|0);d=(iE(a)|0)&255;f=a+4|0;g=e[f>>1]|0;h=ac((g&128|0)!=0?g|65280:g&255,(d&128|0)!=0?d|65280:d)|0;b[f>>1]=h&65535;f=h&65280;h=a+30|0;d=b[h>>1]|0;if((f|0)==65280|(f|0)==0){i=d&-2050}else{i=d|2049}b[h>>1]=i;i=a+1200|0;c[i>>2]=((c[a+1184>>2]|0)!=0?95:89)+(c[i>>2]|0);return(e[a+1196>>1]|0)+1|0}function l4(a){a=a|0;var d=0,f=0,g=0,h=0,i=0;iD(a,a+129|0);d=iE(a)|0;f=d&255;if(d<<24>>24==0){d=a+1200|0;c[d>>2]=((c[a+1184>>2]|0)!=0?20:16)+(c[d>>2]|0);d=a+28|0;b[d>>1]=((b[d>>1]|0)+1&65535)+(b[a+1196>>1]|0)&65535;id(a,0);g=0;return g|0}d=a+4|0;h=e[d>>1]|0;i=(h>>>0)/(f>>>0)|0;if((i&65280|0)==0){b[d>>1]=(((h>>>0)%(f>>>0)|0)<<8|i)&65535;i=a+1200|0;c[i>>2]=((c[a+1184>>2]|0)!=0?91:85)+(c[i>>2]|0);g=(e[a+1196>>1]|0)+1|0;return g|0}else{i=a+1200|0;c[i>>2]=((c[a+1184>>2]|0)!=0?20:16)+(c[i>>2]|0);i=a+28|0;b[i>>1]=((b[i>>1]|0)+1&65535)+(b[a+1196>>1]|0)&65535;id(a,0);g=0;return g|0}return 0}function l5(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;iD(a,a+129|0);d=a+4|0;f=b[d>>1]|0;g=(iE(a)|0)<<24>>24<0;h=(iE(a)|0)&255;i=g?h|65280:h;if((i|0)==0){h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?20:16)+(c[h>>2]|0);h=a+28|0;b[h>>1]=((b[h>>1]|0)+1&65535)+(b[a+1196>>1]|0)&65535;id(a,0);j=0;return j|0}h=f&65535;g=(h&32768|0)!=0;k=g?-f&65535:f;if((i&32768|0)==0){l=i&65535}else{l=65536-i&65535}f=(k&65535)/(l&65535)|0;m=(k&65535)%(l&65535)|0;do{if((h>>>15|0)==(i>>>15|0)){if((f&65535)<=127){n=f;break}l=a+1200|0;c[l>>2]=((c[a+1184>>2]|0)!=0?20:16)+(c[l>>2]|0);l=a+28|0;b[l>>1]=((b[l>>1]|0)+1&65535)+(b[a+1196>>1]|0)&65535;id(a,0);j=0;return j|0}else{if((f&65535)<=128){n=-f&255;break}l=a+1200|0;c[l>>2]=((c[a+1184>>2]|0)!=0?20:16)+(c[l>>2]|0);l=a+28|0;b[l>>1]=((b[l>>1]|0)+1&65535)+(b[a+1196>>1]|0)&65535;id(a,0);j=0;return j|0}}while(0);if(g){o=-m&255}else{o=m}b[d>>1]=o<<8|n;n=a+1200|0;c[n>>2]=((c[a+1184>>2]|0)!=0?112:106)+(c[n>>2]|0);j=(e[a+1196>>1]|0)+1|0;return j|0}function l6(a){a=a|0;var b=0,f=0,g=0,h=0;iD(a,a+129|0);b=iF(a)|0;f=a+1196|0;g=d[(e[f>>1]|0)+1+(a+128)|0]|0;h=(g&128|0)!=0?g|65280:g;iH(a,h+(b&65535)&65535);iy(a,b,h&65535);h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?17:4)+(c[h>>2]|0);return(e[f>>1]|0)+2|0}function l7(a){a=a|0;var b=0,f=0,g=0,h=0;iD(a,a+129|0);b=(iF(a)|0)&65535;f=a+1196|0;g=d[(e[f>>1]|0)+1+(a+128)|0]|0;h=(((g&128|0)!=0?g|65280:g)|b)&65535;iH(a,h);iw(a,h);h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?17:4)+(c[h>>2]|0);return(e[f>>1]|0)+2|0}function l8(a){a=a|0;var f=0,g=0,h=0,i=0;iD(a,a+129|0);f=iF(a)|0;g=a+1196|0;h=d[(e[g>>1]|0)+1+(a+128)|0]|0;i=(h&128|0)!=0?h|65280:h;h=b[a+30>>1]&1;iH(a,(h&65535)+(f&65535)+i&65535);iA(a,f,i&65535,h);h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?17:4)+(c[h>>2]|0);return(e[g>>1]|0)+2|0}function l9(a){a=a|0;var f=0,g=0,h=0,i=0;iD(a,a+129|0);f=iF(a)|0;g=a+1196|0;h=d[(e[g>>1]|0)+1+(a+128)|0]|0;i=(h&128|0)!=0?h|65280:h;h=b[a+30>>1]&1;iH(a,(f&65535)-(h&65535)-i&65535);iC(a,f,i&65535,h);h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?17:4)+(c[h>>2]|0);return(e[g>>1]|0)+2|0}function ma(a){a=a|0;var b=0,f=0,g=0,h=0;iD(a,a+129|0);b=(iF(a)|0)&65535;f=a+1196|0;g=d[(e[f>>1]|0)+1+(a+128)|0]|0;h=((g&128|0)!=0?g|65280:g)&b&65535;iH(a,h);iw(a,h);h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?17:4)+(c[h>>2]|0);return(e[f>>1]|0)+2|0}function mb(a){a=a|0;var b=0,f=0,g=0,h=0;iD(a,a+129|0);b=iF(a)|0;f=a+1196|0;g=d[(e[f>>1]|0)+1+(a+128)|0]|0;h=(g&128|0)!=0?g|65280:g;iH(a,(b&65535)-h&65535);iJ(a,b,h&65535);h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?17:4)+(c[h>>2]|0);return(e[f>>1]|0)+2|0}function mc(a){a=a|0;var b=0,f=0,g=0,h=0;iD(a,a+129|0);b=(iF(a)|0)&65535;f=a+1196|0;g=d[(e[f>>1]|0)+1+(a+128)|0]|0;h=(((g&128|0)!=0?g|65280:g)^b)&65535;iH(a,h);iw(a,h);h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?17:4)+(c[h>>2]|0);return(e[f>>1]|0)+2|0}function md(a){a=a|0;var b=0,f=0,g=0;iD(a,a+129|0);b=iF(a)|0;f=a+1196|0;g=d[(e[f>>1]|0)+1+(a+128)|0]|0;iJ(a,b,((g&128|0)!=0?g|65280:g)&65535);g=a+1200|0;c[g>>2]=((c[a+1184>>2]|0)!=0?10:4)+(c[g>>2]|0);return(e[f>>1]|0)+2|0}function me(a){a=a|0;var b=0,f=0,g=0,h=0;iD(a,a+129|0);b=iF(a)|0;f=a+1196|0;g=e[f>>1]|0;h=(d[g+2+(a+128)|0]|0)<<8|(d[g+1+(a+128)|0]|0);iH(a,h+(b&65535)&65535);iy(a,b,h&65535);h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?17:4)+(c[h>>2]|0);return(e[f>>1]|0)+3|0}function mf(a){a=a|0;var b=0,f=0,g=0,h=0;iD(a,a+129|0);b=iF(a)|0;f=a+1196|0;g=e[f>>1]|0;h=d[g+1+(a+128)|0]|0|b|(d[g+2+(a+128)|0]|0)<<8;iH(a,h);iw(a,h);h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?17:4)+(c[h>>2]|0);return(e[f>>1]|0)+3|0}function mg(a){a=a|0;var f=0,g=0,h=0,i=0;iD(a,a+129|0);f=iF(a)|0;g=a+1196|0;h=e[g>>1]|0;i=(d[h+2+(a+128)|0]|0)<<8|(d[h+1+(a+128)|0]|0);h=b[a+30>>1]&1;iH(a,i+(f&65535)+(h&65535)&65535);iA(a,f,i&65535,h);h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?17:4)+(c[h>>2]|0);return(e[g>>1]|0)+3|0}function mh(a){a=a|0;var f=0,g=0,h=0,i=0;iD(a,a+129|0);f=iF(a)|0;g=a+1196|0;h=e[g>>1]|0;i=(d[h+2+(a+128)|0]|0)<<8|(d[h+1+(a+128)|0]|0);h=b[a+30>>1]&1;iH(a,(f&65535)-i-(h&65535)&65535);iC(a,f,i&65535,h);h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?17:4)+(c[h>>2]|0);return(e[g>>1]|0)+3|0}function mi(a){a=a|0;var b=0,f=0,g=0,h=0;iD(a,a+129|0);b=iF(a)|0;f=a+1196|0;g=e[f>>1]|0;h=((d[g+2+(a+128)|0]|0)<<8|(d[g+1+(a+128)|0]|0))&b;iH(a,h);iw(a,h);h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?17:4)+(c[h>>2]|0);return(e[f>>1]|0)+3|0}function mj(a){a=a|0;c[a+124>>2]=0;return}function mk(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b+124|0;f=c[e>>2]|0;if(f>>>0<=d>>>0){g=0;c[e>>2]=g;return}if((f|0)==(d|0)){h=d}else{i=f-d|0;f=b+128|0;j=b+128+d|0;while(1){a[f]=a[j]|0;b=i-1|0;if((b|0)==0){break}else{i=b;f=f+1|0;j=j+1|0}}h=c[e>>2]|0}g=h-d|0;c[e>>2]=g;return}function ml(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;if(b>>>0>=4){return}c[a+(b*72|0)+24>>2]=d;c[a+(b*72|0)+28>>2]=e;return}function mm(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;if(b>>>0>=4){return}c[a+(b*72|0)+32>>2]=d;c[a+(b*72|0)+36>>2]=e;return}function mn(b){b=b|0;return a[b+289|0]|0}function mo(a){a=a|0;return c[a+292>>2]&255|0}function mp(a,c){a=a|0;c=c|0;var d=0;if(c>>>0>=4){d=0;return d|0}d=b[a+(c*72|0)+12>>1]&255;return d|0}function mq(a,c){a=a|0;c=c|0;var d=0;if(c>>>0>=4){d=0;return d|0}d=b[a+(c*72|0)+14>>1]|0;return d|0}function mr(a,c){a=a|0;c=c|0;var d=0;if(c>>>0<4){d=b[a+(c*72|0)+8>>1]|0}else{d=0}return d|0}function ms(a,c){a=a|0;c=c|0;var d=0;if(c>>>0<4){d=b[a+(c*72|0)+4>>1]|0}else{d=0}return d|0}function mt(a,c){a=a|0;c=c|0;var d=0;if(c>>>0>=4){d=0;return d|0}d=b[a+(c*72|0)+10>>1]|0;return d|0}function mu(a,c){a=a|0;c=c|0;var d=0;if(c>>>0<4){d=b[a+(c*72|0)+6>>1]|0}else{d=0}return d|0}function mv(b,c){b=b|0;c=c|0;a[b+297|0]=c<<24>>24!=0|0;return}function mw(a){a=a|0;var b=0,f=0,g=0,h=0;iD(a,a+129|0);b=iF(a)|0;f=a+1196|0;g=e[f>>1]|0;h=(d[g+2+(a+128)|0]|0)<<8|(d[g+1+(a+128)|0]|0);iH(a,(b&65535)-h&65535);iJ(a,b,h&65535);h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?17:4)+(c[h>>2]|0);return(e[f>>1]|0)+3|0}function mx(a){a=a|0;var b=0,f=0,g=0,h=0;iD(a,a+129|0);b=iF(a)|0;f=a+1196|0;g=e[f>>1]|0;h=((d[g+2+(a+128)|0]|0)<<8|(d[g+1+(a+128)|0]|0))^b;iH(a,h);iw(a,h);h=a+1200|0;c[h>>2]=((c[a+1184>>2]|0)!=0?17:4)+(c[h>>2]|0);return(e[f>>1]|0)+3|0}function my(a){a=a|0;var b=0,f=0,g=0;iD(a,a+129|0);b=iF(a)|0;f=a+1196|0;g=e[f>>1]|0;iJ(a,b,(d[g+2+(a+128)|0]|0)<<8|(d[g+1+(a+128)|0]|0));g=a+1200|0;c[g>>2]=((c[a+1184>>2]|0)!=0?10:4)+(c[g>>2]|0);return(e[f>>1]|0)+3|0}function mz(b){b=b|0;var d=0,f=0,g=0;iD(b,b+129|0);d=iE(b)|0;f=b+1196|0;g=a[(e[f>>1]|0)+1+(b+128)|0]|0;iG(b,g+d&255);ix(b,d,g);g=b+1200|0;c[g>>2]=((c[b+1184>>2]|0)!=0?17:4)+(c[g>>2]|0);return(e[f>>1]|0)+2|0}function mA(b){b=b|0;var d=0,f=0,g=0;iD(b,b+129|0);d=iE(b)|0;f=b+1196|0;g=a[(e[f>>1]|0)+1+(b+128)|0]|d;iG(b,g);iv(b,g);g=b+1200|0;c[g>>2]=((c[b+1184>>2]|0)!=0?17:4)+(c[g>>2]|0);return(e[f>>1]|0)+2|0}function mB(d){d=d|0;var f=0,g=0,h=0,i=0;iD(d,d+129|0);f=iE(d)|0;g=d+1196|0;h=a[(e[g>>1]|0)+1+(d+128)|0]|0;i=b[d+30>>1]&1;iG(d,((h&255)+(f&255)&65535)+i&255);iz(d,f,h,i&255);i=d+1200|0;c[i>>2]=((c[d+1184>>2]|0)!=0?17:4)+(c[i>>2]|0);return(e[g>>1]|0)+2|0}function mC(d){d=d|0;var f=0,g=0,h=0,i=0;iD(d,d+129|0);f=iE(d)|0;g=d+1196|0;h=a[(e[g>>1]|0)+1+(d+128)|0]|0;i=b[d+30>>1]&1;iG(d,((f&255)-(h&255)&65535)-i&255);iB(d,f,h,i&255);i=d+1200|0;c[i>>2]=((c[d+1184>>2]|0)!=0?17:4)+(c[i>>2]|0);return(e[g>>1]|0)+2|0}function mD(b){b=b|0;var d=0,f=0,g=0;iD(b,b+129|0);d=iE(b)|0;f=b+1196|0;g=a[(e[f>>1]|0)+1+(b+128)|0]&d;iG(b,g);iv(b,g);g=b+1200|0;c[g>>2]=((c[b+1184>>2]|0)!=0?17:4)+(c[g>>2]|0);return(e[f>>1]|0)+2|0}function mE(b){b=b|0;var d=0,f=0,g=0;iD(b,b+129|0);d=iE(b)|0;f=b+1196|0;g=a[(e[f>>1]|0)+1+(b+128)|0]|0;iG(b,d-g&255);iI(b,d,g);g=b+1200|0;c[g>>2]=((c[b+1184>>2]|0)!=0?17:4)+(c[g>>2]|0);return(e[f>>1]|0)+2|0}function mF(b){b=b|0;var d=0,f=0,g=0;iD(b,b+129|0);d=iE(b)|0;f=b+1196|0;g=a[(e[f>>1]|0)+1+(b+128)|0]^d;iG(b,g);iv(b,g);g=b+1200|0;c[g>>2]=((c[b+1184>>2]|0)!=0?17:4)+(c[g>>2]|0);return(e[f>>1]|0)+2|0}function mG(b){b=b|0;var d=0,f=0;iD(b,b+129|0);d=iE(b)|0;f=b+1196|0;iI(b,d,a[(e[f>>1]|0)+1+(b+128)|0]|0);d=b+1200|0;c[d>>2]=((c[b+1184>>2]|0)!=0?10:4)+(c[d>>2]|0);return(e[f>>1]|0)+2|0}function mH(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b[d+22>>1]|0;g=c[d+120>>2]|0;h=e[d+28>>1]|0;L137:do{if(h>>>0>(65535-g|0)>>>0){i=c[d+124>>2]|0;if(i>>>0>=g>>>0){break}j=(f&65535)<<4;k=d+80|0;l=d+76|0;m=d+72|0;n=d+44|0;o=d+32|0;p=i;do{i=c[k>>2]&(p+h&65535)+j;q=i+1|0;if(q>>>0<(c[l>>2]|0)>>>0){r=c[m>>2]|0;s=a[r+q|0]|0;t=a[r+i|0]|0}else{r=b8[c[n>>2]&255](c[o>>2]|0,i)|0;s=(r&65535)>>>8&255;t=r&255}a[d+128+p|0]=t;a[p+1+(d+128)|0]=s;p=p+2|0;}while(p>>>0<g>>>0)}else{p=d+80|0;o=c[p>>2]|0;n=o&((f&65535)<<4)+h;m=c[d+124>>2]|0;l=m>>>0<g>>>0;if((n+g|0)>>>0<=(c[d+76>>2]|0)>>>0){if(!l){break}j=d+72|0;k=m;while(1){a[d+128+k|0]=a[(c[j>>2]|0)+(k+n)|0]|0;k=k+1|0;if(k>>>0>=g>>>0){break L137}}}if(!l){break}k=d+44|0;j=d+32|0;r=m;i=o;while(1){q=b8[c[k>>2]&255](c[j>>2]|0,i&r+n)|0;a[d+128+r|0]=q&255;a[r+1+(d+128)|0]=(q&65535)>>>8&255;q=r+2|0;if(q>>>0>=g>>>0){break L137}r=q;i=c[p>>2]|0}}}while(0);c[d+124>>2]=c[d+116>>2];return}function mI(d){d=d|0;c[d>>2]=d;zP(d+4|0,0,10);b[d+14>>1]=16;a[d+16|0]=0;a[d+17|0]=0;zP(d+24|0,0,48);c[d+72>>2]=d;zP(d+76|0,0,10);b[d+86>>1]=16;a[d+88|0]=0;a[d+89|0]=0;zP(d+96|0,0,48);c[d+144>>2]=d;zP(d+148|0,0,10);b[d+158>>1]=16;a[d+160|0]=0;a[d+161|0]=0;zP(d+168|0,0,48);c[d+216>>2]=d;zP(d+220|0,0,10);b[d+230>>1]=16;a[d+232|0]=0;a[d+233|0]=0;c[d+292>>2]=0;a[d+296|0]=0;a[d+297|0]=0;c[d+300>>2]=0;c[d+304>>2]=0;zP(d+240|0,0,51);return}function mJ(d,e){d=d|0;e=e|0;var f=0,g=0;f=d+14|0;g=b[f>>1]|0;if(e<<24>>24!=0){b[f>>1]=g|5;if((g&16)!=0){return}a[(c[d>>2]|0)+288|0]=1;return}b[f>>1]=g&-6;g=d+16|0;if((a[g]|0)==0){return}a[g]=0;g=c[d+28>>2]|0;if((g|0)==0){return}b3[g&511](c[d+24>>2]|0,0);return}function mK(d,e){d=d|0;e=e|0;var f=0,g=0;f=d+158|0;g=b[f>>1]|0;if(e<<24>>24!=0){b[f>>1]=g|5;if((g&16)!=0){return}a[(c[d+144>>2]|0)+288|0]=1;return}b[f>>1]=g&-6;g=d+160|0;if((a[g]|0)==0){return}a[g]=0;g=c[d+172>>2]|0;if((g|0)==0){return}b3[g&511](c[d+168>>2]|0,0);return}function mL(d,e){d=d|0;e=e|0;var f=0,g=0;f=d+230|0;g=b[f>>1]|0;if(e<<24>>24!=0){b[f>>1]=g|5;if((g&16)!=0){return}a[(c[d+216>>2]|0)+288|0]=1;return}b[f>>1]=g&-6;g=d+232|0;if((a[g]|0)==0){return}a[g]=0;g=c[d+244>>2]|0;if((g|0)==0){return}b3[g&511](c[d+240>>2]|0,0);return}function mM(a,b,c){a=a|0;b=b|0;c=c|0;return}function mN(a,b,c){a=a|0;b=b|0;c=c|0;return}function mO(a,b){a=a|0;b=b|0;return-1|0}function mP(a,b){a=a|0;b=b|0;return-1|0}function mQ(c,d){c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((d|0)==0){e=c+290|0;f=(a[e]|0)==0;a[e]=f&1;e=b[c+8>>1]|0;g=(f?e:(e&65535)>>>8)&255;return g|0}else if((d|0)==4){e=c+290|0;f=(a[e]|0)==0;a[e]=f&1;e=b[c+152>>1]|0;g=(f?e:(e&65535)>>>8)&255;return g|0}else if((d|0)==5){e=c+290|0;f=(a[e]|0)==0;a[e]=f&1;e=b[c+154>>1]|0;g=(f?e:(e&65535)>>>8)&255;return g|0}else if((d|0)==13){g=0;return g|0}else if((d|0)==3){e=c+290|0;f=(a[e]|0)==0;a[e]=f&1;e=b[c+82>>1]|0;g=(f?e:(e&65535)>>>8)&255;return g|0}else if((d|0)==6){e=c+290|0;f=(a[e]|0)==0;a[e]=f&1;e=b[c+224>>1]|0;g=(f?e:(e&65535)>>>8)&255;return g|0}else if((d|0)==7){e=c+290|0;f=(a[e]|0)==0;a[e]=f&1;e=b[c+226>>1]|0;g=(f?e:(e&65535)>>>8)&255;return g|0}else if((d|0)==8){e=c+14|0;f=b[e>>1]|0;h=f&65535;b[e>>1]=f&-9;f=c+86|0;e=b[f>>1]|0;i=e&65535;b[f>>1]=e&-9;e=c+158|0;f=b[e>>1]|0;j=f&65535;b[e>>1]=f&-9;f=c+230|0;e=b[f>>1]|0;k=e&65535;b[f>>1]=e&-9;g=((i<<2&16|i>>>3&1)&255)<<1|(h<<2&16|h>>>3&1)&255|((j<<2&16|j>>>3&1)&255)<<2|((k<<2&16|k>>>3&1)&255)<<3;return g|0}else if((d|0)==2){k=c+290|0;j=(a[k]|0)==0;a[k]=j&1;k=b[c+80>>1]|0;g=(j?k:(k&65535)>>>8)&255;return g|0}else if((d|0)==1){d=c+290|0;k=(a[d]|0)==0;a[d]=k&1;d=b[c+10>>1]|0;g=(k?d:(d&65535)>>>8)&255;return g|0}else{g=-1;return g|0}return 0}function mR(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((e|0)==0){g=d+290|0;h=(a[g]|0)==0;i=d+8|0;j=b[i>>1]|0;if(h){k=j&-256|f&255}else{k=j&255|(f&255)<<8}b[i>>1]=k;b[d+4>>1]=k;a[g]=h&1;return}else if((e|0)==3){h=d+290|0;g=(a[h]|0)==0;k=d+82|0;i=b[k>>1]|0;if(g){l=i&-256|f&255}else{l=i&255|(f&255)<<8}b[k>>1]=l;b[d+78>>1]=l;a[h]=g&1;return}else if((e|0)==2){g=d+290|0;h=(a[g]|0)==0;l=d+80|0;k=b[l>>1]|0;if(h){m=k&-256|f&255}else{m=k&255|(f&255)<<8}b[l>>1]=m;b[d+76>>1]=m;a[g]=h&1;return}else if((e|0)==4){h=d+290|0;g=(a[h]|0)==0;m=d+152|0;l=b[m>>1]|0;if(g){n=l&-256|f&255}else{n=l&255|(f&255)<<8}b[m>>1]=n;b[d+148>>1]=n;a[h]=g&1;return}else if((e|0)==1){g=d+290|0;h=(a[g]|0)==0;n=d+10|0;m=b[n>>1]|0;if(h){o=m&-256|f&255}else{o=m&255|(f&255)<<8}b[n>>1]=o;b[d+6>>1]=o;a[g]=h&1;return}else if((e|0)==5){h=d+290|0;g=(a[h]|0)==0;o=d+154|0;n=b[o>>1]|0;if(g){p=n&-256|f&255}else{p=n&255|(f&255)<<8}b[o>>1]=p;b[d+150>>1]=p;a[h]=g&1;return}else if((e|0)==6){g=d+290|0;h=(a[g]|0)==0;p=d+224|0;o=b[p>>1]|0;if(h){q=o&-256|f&255}else{q=o&255|(f&255)<<8}b[p>>1]=q;b[d+220>>1]=q;a[g]=h&1;return}else if((e|0)==7){h=d+290|0;g=(a[h]|0)==0;q=d+226|0;p=b[q>>1]|0;if(g){r=p&-256|f&255}else{r=p&255|(f&255)<<8}b[q>>1]=r;b[d+222>>1]=r;a[h]=g&1;return}else if((e|0)==8){a[d+289|0]=f;a[d+288|0]=(f&255)>>>2&1^1;return}else if((e|0)==9){g=f&3;h=d+(g*72|0)+14|0;r=b[h>>1]|0;if(f<<24>>24==0){b[h>>1]=r&-7;return}b[h>>1]=r|6;if((r&16)!=0){return}a[(c[d+(g*72|0)>>2]|0)+288|0]=1;return}else if((e|0)==10){g=f&3;r=d+(g*72|0)+14|0;h=b[r>>1]|0;if((f&4)!=0){b[r>>1]=h|16;return}b[r>>1]=h&-17;if((h&3)==0){return}a[(c[d+(g*72|0)>>2]|0)+288|0]=1;return}else if((e|0)==11){b[d+((f&3)*72|0)+12>>1]=f&255;return}else if((e|0)==12){a[d+290|0]=0;return}else if((e|0)==13){mS(d);return}else if((e|0)==14){g=d+14|0;h=b[g>>1]|0;b[g>>1]=h&-17;if((h&3)!=0){a[(c[d>>2]|0)+288|0]=1}h=d+86|0;g=b[h>>1]|0;b[h>>1]=g&-17;if((g&3)!=0){a[(c[d+72>>2]|0)+288|0]=1}g=d+158|0;h=b[g>>1]|0;b[g>>1]=h&-17;if((h&3)!=0){a[(c[d+144>>2]|0)+288|0]=1}h=d+230|0;g=b[h>>1]|0;b[h>>1]=g&-17;if((g&3)==0){return}a[(c[d+216>>2]|0)+288|0]=1;return}else if((e|0)==15){e=d+14|0;g=b[e>>1]|0;do{if((f&1)==0){b[e>>1]=g&-17;if((g&3)==0){break}a[(c[d>>2]|0)+288|0]=1}else{b[e>>1]=g|16}}while(0);g=d+86|0;e=b[g>>1]|0;do{if((f&2)==0){b[g>>1]=e&-17;if((e&3)==0){break}a[(c[d+72>>2]|0)+288|0]=1}else{b[g>>1]=e|16}}while(0);e=d+158|0;g=b[e>>1]|0;do{if((f&4)==0){b[e>>1]=g&-17;if((g&3)==0){break}a[(c[d+144>>2]|0)+288|0]=1}else{b[e>>1]=g|16}}while(0);g=d+230|0;e=b[g>>1]|0;if((f&8)!=0){b[g>>1]=e|16;return}b[g>>1]=e&-17;if((e&3)==0){return}a[(c[d+216>>2]|0)+288|0]=1;return}else{return}}function mS(d){d=d|0;var e=0,f=0;zP(d+4|0,0,10);b[d+14>>1]=16;e=d+16|0;do{if((a[e]|0)!=0){a[e]=0;f=c[d+28>>2]|0;if((f|0)==0){break}b3[f&511](c[d+24>>2]|0,0)}}while(0);e=d+17|0;do{if((a[e]|0)!=0){a[e]=0;f=c[d+36>>2]|0;if((f|0)==0){break}b3[f&511](c[d+32>>2]|0,0)}}while(0);zP(d+76|0,0,10);b[d+86>>1]=16;e=d+88|0;do{if((a[e]|0)!=0){a[e]=0;f=c[d+100>>2]|0;if((f|0)==0){break}b3[f&511](c[d+96>>2]|0,0)}}while(0);e=d+89|0;do{if((a[e]|0)!=0){a[e]=0;f=c[d+108>>2]|0;if((f|0)==0){break}b3[f&511](c[d+104>>2]|0,0)}}while(0);zP(d+148|0,0,10);b[d+158>>1]=16;e=d+160|0;do{if((a[e]|0)!=0){a[e]=0;f=c[d+172>>2]|0;if((f|0)==0){break}b3[f&511](c[d+168>>2]|0,0)}}while(0);e=d+161|0;do{if((a[e]|0)!=0){a[e]=0;f=c[d+180>>2]|0;if((f|0)==0){break}b3[f&511](c[d+176>>2]|0,0)}}while(0);zP(d+220|0,0,10);b[d+230>>1]=16;e=d+232|0;do{if((a[e]|0)!=0){a[e]=0;f=c[d+244>>2]|0;if((f|0)==0){break}b3[f&511](c[d+240>>2]|0,0)}}while(0);e=d+233|0;do{if((a[e]|0)!=0){a[e]=0;f=c[d+252>>2]|0;if((f|0)==0){break}b3[f&511](c[d+248>>2]|0,0)}}while(0);a[d+288|0]=0;a[d+289|0]=0;a[d+290|0]=0;c[d+292>>2]=0;e=d+296|0;if((a[e]|0)==0){return}a[e]=0;e=c[d+304>>2]|0;if((e|0)==0){return}b3[e&511](c[d+300>>2]|0,0);return}function mT(a,b,d){a=a|0;b=b|0;d=d|0;c[a+604>>2]=d;c[a+600>>2]=b;return}function mU(a,b,d){a=a|0;b=b|0;d=d|0;c[a+612>>2]=d;c[a+608>>2]=b;return}function mV(a,b,d){a=a|0;b=b|0;d=d|0;c[a+620>>2]=d;c[a+616>>2]=b;return}function mW(a,b,d){a=a|0;b=b|0;d=d|0;c[a+628>>2]=d;c[a+624>>2]=b;return}function mX(a,b,d){a=a|0;b=b|0;d=d|0;c[a+636>>2]=d;c[a+632>>2]=b;return}function mY(a,b,d){a=a|0;b=b|0;d=d|0;c[a+572>>2]=b;c[a+588>>2]=d;return}function mZ(a,b){a=a|0;b=b|0;c[a+552>>2]=b;return}function m_(a){a=a|0;var c=0;c=b[a+594>>1]|0;return 115200/((c<<16>>16==0?1:c&65535)>>>0)|0|0}function m$(b){b=b|0;return(a[b+544|0]&3)+5|0}function m0(b){b=b|0;return((a[b+544|0]&4)!=0?2:1)|0}function m1(a){a=a|0;return(d[a+544|0]|0)>>>3&7|0}function m2(b){b=b|0;return a[b+546|0]&1|0}function m3(a){a=a|0;return(d[a+546|0]|0)>>>1&1|0}function m4(a){a=a|0;var b=0;b=(c[a+8>>2]|0)+1|0;return((b>>>0<(c[a+12>>2]|0)>>>0?b:0)|0)==(c[a+4>>2]|0)|0}function m5(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=b+272|0;g=c[f>>2]|0;if((g|0)==(c[b+276>>2]|0)){h=1;return h|0}a[d]=a[b+284+g|0]|0;if((e|0)==0){h=0;return h|0}e=(c[f>>2]|0)+1|0;c[f>>2]=e;if(e>>>0<(c[b+280>>2]|0)>>>0){h=0;return h|0}c[f>>2]=0;h=0;return h|0}function m6(a){a=a|0;return(c[a+272>>2]|0)==(c[a+276>>2]|0)|0}function m7(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=d+289|0;if((a[g]&4)!=0){return}h=d+288|0;if((f|0)==0){return}i=d+292|0;j=d+296|0;k=d+297|0;l=d+304|0;m=d+300|0;n=f;while(1){if((a[h]|0)==0){o=405;break}a[h]=0;f=c[i>>2]|0;p=0;L422:while(1){q=d+(f*72|0)+14|0;r=e[q>>1]|0;L424:do{if((r&3|0)!=0&(r&16|0)==0){a[h]=1;do{if((a[j]|0)!=1){a[j]=1;s=c[l>>2]|0;if((s|0)==0){break}b3[s&511](c[m>>2]|0,1)}}while(0);if((a[k]|0)==0){break L422}s=d+(f*72|0)+16|0;do{if((a[s]|0)!=1){a[s]=1;t=c[d+(f*72|0)+28>>2]|0;if((t|0)==0){break}b3[t&511](c[d+(f*72|0)+24>>2]|0,1)}}while(0);s=d+(f*72|0)+12|0;t=e[s>>1]|0;L435:do{if((t&192|0)!=192){u=t&12;do{if((u|0)==8){v=c[d+(f*72|0)+52>>2]|0;if((v|0)==0){w=0}else{w=b8[v&255](c[d+(f*72|0)+48>>2]|0,e[d+(f*72|0)+8>>1]|0)|0}v=c[d+(f*72|0)+60>>2]|0;if((v|0)==0){break}b3[v&511](c[d+(f*72|0)+56>>2]|0,w)}else if((u|0)==4){v=c[d+(f*72|0)+68>>2]|0;if((v|0)==0){x=0}else{x=b1[v&1023](c[d+(f*72|0)+64>>2]|0)|0}v=c[d+(f*72|0)+44>>2]|0;if((v|0)==0){break}b5[v&255](c[d+(f*72|0)+40>>2]|0,e[d+(f*72|0)+8>>1]|0,x)}else if((u|0)==0){v=c[d+(f*72|0)+68>>2]|0;if((v|0)!=0){y=c[d+(f*72|0)+64>>2]|0;b1[v&1023](y)|0}y=c[d+(f*72|0)+52>>2]|0;if((y|0)==0){break}b8[y&255](c[d+(f*72|0)+48>>2]|0,e[d+(f*72|0)+8>>1]|0)|0}}while(0);u=b[s>>1]|0;y=d+(f*72|0)+8|0;b[y>>1]=((b[y>>1]|0)-1&65535)+((u&65535)>>>4&2^2)&65535;v=d+(f*72|0)+10|0;z=(e[v>>1]|0)+65535|0;b[v>>1]=z&65535;L454:do{if((z&65535|0)==65535){A=b[q>>1]|0;b[q>>1]=A|8;if((u&16)==0){b[q>>1]=A|24}else{b[y>>1]=b[d+(f*72|0)+4>>1]|0;b[v>>1]=b[d+(f*72|0)+6>>1]|0}A=d+(f*72|0)+17|0;do{if((a[A]|0)==1){B=d+(f*72|0)+36|0}else{a[A]=1;C=d+(f*72|0)+36|0;D=c[C>>2]|0;if((D|0)==0){B=C;break}b3[D&511](c[d+(f*72|0)+32>>2]|0,1);if((a[A]|0)==0){break L454}else{B=C}}}while(0);a[A]=0;C=c[B>>2]|0;if((C|0)==0){break}b3[C&511](c[d+(f*72|0)+32>>2]|0,0)}else{if((u&192)==128){break L435}}}while(0);do{if((a[j]|0)!=0){a[j]=0;u=c[l>>2]|0;if((u|0)==0){break}b3[u&511](c[m>>2]|0,0)}}while(0);if((a[g]&16)==0){c[i>>2]=0;break L424}else{c[i>>2]=f+1&3;break L424}}}while(0);c[i>>2]=f}}while(0);q=p+1|0;if(q>>>0<4){f=f+1&3;p=q}else{o=398;break}}do{if((o|0)==398){o=0;if((a[j]|0)==0){break}a[j]=0;p=c[l>>2]|0;if((p|0)==0){break}b3[p&511](c[m>>2]|0,0)}}while(0);p=n-1|0;if((p|0)==0){o=406;break}else{n=p}}if((o|0)==405){return}else if((o|0)==406){return}}function m8(d){d=d|0;c[d>>2]=1;c[d+4>>2]=0;c[d+8>>2]=0;c[d+12>>2]=9;c[d+272>>2]=0;c[d+276>>2]=0;c[d+280>>2]=9;a[d+540|0]=0;a[d+541|0]=0;a[d+542|0]=0;a[d+543|0]=1;a[d+544|0]=0;a[d+545|0]=96;a[d+546|0]=0;a[d+547|0]=0;a[d+549|0]=1;c[d+552>>2]=10;a[d+556|0]=0;c[d+560>>2]=0;c[d+564>>2]=128;c[d+568>>2]=1;c[d+572>>2]=1;c[d+576>>2]=0;c[d+580>>2]=128;c[d+584>>2]=1;c[d+588>>2]=1;a[d+592|0]=1;a[d+548|0]=0;b[d+594>>1]=0;a[d+596|0]=0;zP(d+600|0,0,40);return}function m9(b,d){b=b|0;d=d|0;var e=0;if((aP(d|0,23544)|0)==0){c[b>>2]=0;a[b+592|0]=0;e=0;return e|0}if((aP(d|0,34272)|0)!=0){e=1;return e|0}c[b>>2]=1;a[b+592|0]=1;e=0;return e|0}function na(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b+547|0;f=a[e]|0;g=d<<24>>24==0?f&-33:f|32;a[e]=g;if(((g^f)&32)==0){a[e]=g&-3;return}a[e]=g|2;g=b+543|0;a[g]=1;e=a[b+542|0]|0;do{if((e&1)==0){h=420}else{if((a[b+545|0]&1)==0){h=420;break}a[g]=4;i=1}}while(0);L503:do{if((h|0)==420){do{if((e&2)!=0){if((a[b+545|0]&32)==0){break}if((a[b+549|0]|0)!=0){break}a[g]=2;i=1;break L503}}while(0);if((e&8)==0){i=0;break}a[g]=0;i=1}}while(0);g=b+596|0;if((a[g]|0)==i<<24>>24){return}a[g]=i;g=c[b+604>>2]|0;if((g|0)==0){return}b3[g&511](c[b+600>>2]|0,i);return}function nb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b+547|0;f=a[e]|0;g=d<<24>>24==0?f&-17:f|16;a[e]=g;if(((g^f)&16)==0){a[e]=g&-2;return}a[e]=g|1;g=b+543|0;a[g]=1;e=a[b+542|0]|0;do{if((e&1)==0){h=439}else{if((a[b+545|0]&1)==0){h=439;break}a[g]=4;i=1}}while(0);L527:do{if((h|0)==439){do{if((e&2)!=0){if((a[b+545|0]&32)==0){break}if((a[b+549|0]|0)!=0){break}a[g]=2;i=1;break L527}}while(0);if((e&8)==0){i=0;break}a[g]=0;i=1}}while(0);g=b+596|0;if((a[g]|0)==i<<24>>24){return}a[g]=i;g=c[b+604>>2]|0;if((g|0)==0){return}b3[g&511](c[b+600>>2]|0,i);return}function nc(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b+547|0;f=a[e]|0;g=d<<24>>24==0?f&127:f|-128;a[e]=g;if((g^f)<<24>>24>=0){a[e]=g&-9;return}a[e]=g|8;g=b+543|0;a[g]=1;e=a[b+542|0]|0;do{if((e&1)==0){h=458}else{if((a[b+545|0]&1)==0){h=458;break}a[g]=4;i=1}}while(0);L551:do{if((h|0)==458){do{if((e&2)!=0){if((a[b+545|0]&32)==0){break}if((a[b+549|0]|0)!=0){break}a[g]=2;i=1;break L551}}while(0);if((e&8)==0){i=0;break}a[g]=0;i=1}}while(0);g=b+596|0;if((a[g]|0)==i<<24>>24){return}a[g]=i;g=c[b+604>>2]|0;if((g|0)==0){return}b3[g&511](c[b+600>>2]|0,i);return}function nd(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b+547|0;f=a[e]|0;g=d<<24>>24==0?f&-65:f|64;a[e]=g;if(((g^f)&64)==0){a[e]=g&-5;return}a[e]=g|4;g=b+543|0;a[g]=1;e=a[b+542|0]|0;do{if((e&1)==0){h=477}else{if((a[b+545|0]&1)==0){h=477;break}a[g]=4;i=1}}while(0);L575:do{if((h|0)==477){do{if((e&2)!=0){if((a[b+545|0]&32)==0){break}if((a[b+549|0]|0)!=0){break}a[g]=2;i=1;break L575}}while(0);if((e&8)==0){i=0;break}a[g]=0;i=1}}while(0);g=b+596|0;if((a[g]|0)==i<<24>>24){return}a[g]=i;g=c[b+604>>2]|0;if((g|0)==0){return}b3[g&511](c[b+600>>2]|0,i);return}function ne(b){b=b|0;return a[b+545|0]|0}function nf(b){b=b|0;return a[b+547|0]|0}function ng(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b+8|0;f=c[e>>2]|0;g=f+1|0;h=b+12|0;i=g>>>0<(c[h>>2]|0)>>>0?g:0;g=b+4|0;if((i|0)==(c[g>>2]|0)){j=1;return j|0}a[b+16+f|0]=d;c[e>>2]=i;e=b+568|0;d=c[e>>2]|0;if((d|0)==0){j=0;return j|0}f=b+545|0;k=a[f]|0;if((k&1)!=0){j=0;return j|0}l=c[g>>2]|0;if((l|0)==(i|0)){j=0;return j|0}a[b+541|0]=a[b+16+l|0]|0;i=l+1|0;c[g>>2]=i;if(i>>>0>=(c[h>>2]|0)>>>0){c[g>>2]=0}c[e>>2]=d-1;d=b+560|0;if((c[d>>2]|0)==0){a[b+556|0]=1;c[d>>2]=c[b+564>>2]}a[f]=k|1;k=c[b+620>>2]|0;if((k|0)!=0){b3[k&511](c[b+616>>2]|0,1)}k=b+543|0;a[k]=1;d=a[b+542|0]|0;do{if((d&1)==0){m=507}else{if((a[f]&1)==0){m=507;break}a[k]=4;n=1}}while(0);L618:do{if((m|0)==507){do{if((d&2)!=0){if((a[f]&32)==0){break}if((a[b+549|0]|0)!=0){break}a[k]=2;n=1;break L618}}while(0);if((d&8)==0){n=0;break}if((a[b+547|0]&15)==0){n=0;break}a[k]=0;n=1}}while(0);k=b+596|0;if((a[k]|0)==n<<24>>24){j=0;return j|0}a[k]=n;k=c[b+604>>2]|0;if((k|0)==0){j=0;return j|0}b3[k&511](c[b+600>>2]|0,n);j=0;return j|0}function nh(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((f|0)==0){if((a[d+544|0]|0)<0){g=b[d+594>>1]&255;return g|0}h=d+541|0;i=a[h]|0;j=d+545|0;k=a[j]|0;a[j]=k&-2;l=d+543|0;a[l]=1;m=d+542|0;n=a[m]|0;do{if((n&2)==0){o=532}else{if((k&32)==0){o=532;break}if((a[d+549|0]|0)!=0){o=532;break}a[l]=2;p=1}}while(0);do{if((o|0)==532){if((n&8)==0){p=0;break}if((a[d+547|0]&15)==0){p=0;break}a[l]=0;p=1}}while(0);n=d+596|0;do{if((a[n]|0)!=p<<24>>24){a[n]=p;k=c[d+604>>2]|0;if((k|0)==0){break}b3[k&511](c[d+600>>2]|0,p)}}while(0);p=d+568|0;k=c[p>>2]|0;if((k|0)==0){g=i;return g|0}q=a[j]|0;if((q&1)!=0){g=i;return g|0}r=d+4|0;s=c[r>>2]|0;if((s|0)==(c[d+8>>2]|0)){g=i;return g|0}a[h]=a[d+16+s|0]|0;h=s+1|0;c[r>>2]=h;if(h>>>0>=(c[d+12>>2]|0)>>>0){c[r>>2]=0}c[p>>2]=k-1;k=d+560|0;if((c[k>>2]|0)==0){a[d+556|0]=1;c[k>>2]=c[d+564>>2]}a[j]=q|1;q=c[d+620>>2]|0;if((q|0)!=0){b3[q&511](c[d+616>>2]|0,1)}a[l]=1;q=a[m]|0;do{if((q&1)==0){o=550}else{if((a[j]&1)==0){o=550;break}a[l]=4;t=1}}while(0);L676:do{if((o|0)==550){do{if((q&2)!=0){if((a[j]&32)==0){break}if((a[d+549|0]|0)!=0){break}a[l]=2;t=1;break L676}}while(0);if((q&8)==0){t=0;break}if((a[d+547|0]&15)==0){t=0;break}a[l]=0;t=1}}while(0);if((a[n]|0)==t<<24>>24){g=i;return g|0}a[n]=t;n=c[d+604>>2]|0;if((n|0)==0){g=i;return g|0}b3[n&511](c[d+600>>2]|0,t);g=i;return g|0}else if((f|0)==7){if((a[d+592|0]|0)==0){g=-1;return g|0}g=a[d+548|0]|0;return g|0}else if((f|0)==4){g=a[d+546|0]|0;return g|0}else if((f|0)==5){g=a[d+545|0]|0;return g|0}else if((f|0)==6){i=c[d+636>>2]|0;if((i|0)!=0){b3[i&511](c[d+632>>2]|0,1)}i=d+547|0;t=a[i]|0;a[i]=t&-16;i=d+543|0;a[i]=1;n=a[d+542|0]|0;do{if((n&1)==0){o=581}else{if((a[d+545|0]&1)==0){o=581;break}a[i]=4;u=1}}while(0);do{if((o|0)==581){if((n&2)==0){u=0;break}if((a[d+545|0]&32)==0){u=0;break}if((a[d+549|0]|0)!=0){u=0;break}a[i]=2;u=1}}while(0);i=d+596|0;if((a[i]|0)==u<<24>>24){g=t;return g|0}a[i]=u;i=c[d+604>>2]|0;if((i|0)==0){g=t;return g|0}b3[i&511](c[d+600>>2]|0,u);g=t;return g|0}else if((f|0)==1){if((a[d+544|0]|0)<0){g=(e[d+594>>1]|0)>>>8&255;return g|0}else{g=a[d+542|0]|0;return g|0}}else if((f|0)==2){t=d+543|0;u=a[t]|0;if(u<<24>>24!=2){g=u;return g|0}a[d+549|0]=1;a[t]=1;u=a[d+542|0]|0;do{if((u&1)==0){o=567}else{if((a[d+545|0]&1)==0){o=567;break}a[t]=4;v=1}}while(0);do{if((o|0)==567){if((u&8)==0){v=0;break}if((a[d+547|0]&15)==0){v=0;break}a[t]=0;v=1}}while(0);t=d+596|0;if((a[t]|0)==v<<24>>24){g=2;return g|0}a[t]=v;t=c[d+604>>2]|0;if((t|0)==0){g=2;return g|0}b3[t&511](c[d+600>>2]|0,v);g=2;return g|0}else if((f|0)==3){g=a[d+544|0]|0;return g|0}else{g=-1;return g|0}return 0}function ni(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0;h=i;if((f|0)==0){j=a[e+544|0]|0;if(j<<24>>24<0){k=e+594|0;l=b[k>>1]&-256|g&255;b[k>>1]=l;k=ac((j&3)+6+((j&4)!=0?2:1)|0,c[e+552>>2]|0)|0;if((l&65535)>1){m=ac(k,l&65535)|0}else{m=k}c[e+564>>2]=m;c[e+580>>2]=m;m=c[e+628>>2]|0;if((m|0)==0){i=h;return}b3[m&511](c[e+624>>2]|0,1);i=h;return}m=e+545|0;k=a[m]|0;l=k&255;if((l&32|0)==0){j=c[q>>2]|0;n=e+540|0;o=d[n]|0;p=e+543|0;r=d[p]|0;s=g&255;bN(j|0,31544,(x=i,i=i+32|0,c[x>>2]=o,c[x+8>>2]=l,c[x+16>>2]=r,c[x+24>>2]=s,x)|0)|0;t=a[m]|0;u=n;v=p}else{t=k;u=e+540|0;v=e+543|0}a[u]=g;a[m]=t&-33;a[v]=1;m=a[e+542|0]|0;do{if((m&1)==0){w=625}else{if((t&1)==0){w=625;break}a[v]=4;y=1}}while(0);do{if((w|0)==625){if((m&8)==0){y=0;break}if((a[e+547|0]&15)==0){y=0;break}a[v]=0;y=1}}while(0);v=e+596|0;do{if((a[v]|0)!=y<<24>>24){a[v]=y;m=c[e+604>>2]|0;if((m|0)==0){break}b3[m&511](c[e+600>>2]|0,y)}}while(0);np(e);i=h;return}else if((f|0)==7){if((a[e+592|0]|0)==0){i=h;return}a[e+548|0]=g;i=h;return}else if((f|0)==3){y=e+544|0;if((a[y]|0)==g<<24>>24){i=h;return}a[y]=g;y=ac(c[e+552>>2]|0,(g&3)+6+((g&4)!=0?2:1)|0)|0;v=b[e+594>>1]|0;if((v&65535)>1){z=ac(v&65535,y)|0}else{z=y}c[e+564>>2]=z;c[e+580>>2]=z;z=c[e+628>>2]|0;if((z|0)==0){i=h;return}b3[z&511](c[e+624>>2]|0,1);i=h;return}else if((f|0)==4){z=e+546|0;y=d[z]|0;v=g&255;m=v&31;if((y|0)==(m|0)){i=h;return}t=v&16;do{if((y&16|0)==0){a[z]=m&255;if((t|0)!=0){w=660}}else{if((t|0)==0){u=e+547|0;k=a[u]|0;a[u]=k&15|(k&255)>>>4;a[z]=m&255;break}else{a[z]=m&255;w=660;break}}}while(0);if((w|0)==660){m=e+547|0;z=a[m]|0;t=z&15;y=(v&2|0)==0?t:t|16;t=(v&1|0)==0?y:y|32;y=(v&4|0)==0?t:t|64;t=(v&8|0)==0?y:y|-128;a[m]=(((t|-80)^64)&(t^z)&255)>>>4|t}t=c[e+628>>2]|0;if((t|0)==0){i=h;return}b3[t&511](c[e+624>>2]|0,1);i=h;return}else if((f|0)==1){f=a[e+544|0]|0;if(f<<24>>24<0){t=e+594|0;z=b[t>>1]&255|(g&255)<<8;b[t>>1]=z;t=ac((f&3)+6+((f&4)!=0?2:1)|0,c[e+552>>2]|0)|0;if((z&65535)>1){A=ac(t,z&65535)|0}else{A=t}c[e+564>>2]=A;c[e+580>>2]=A;A=c[e+628>>2]|0;if((A|0)==0){i=h;return}b3[A&511](c[e+624>>2]|0,1);i=h;return}a[e+542|0]=g&15;a[e+549|0]=0;A=e+543|0;a[A]=1;do{if((g&1)==0){w=640}else{if((a[e+545|0]&1)==0){w=640;break}a[A]=4;B=1}}while(0);L827:do{if((w|0)==640){do{if((g&2)!=0){if((a[e+545|0]&32)==0){break}a[A]=2;B=1;break L827}}while(0);if((g&8)==0){B=0;break}if((a[e+547|0]&15)==0){B=0;break}a[A]=0;B=1}}while(0);A=e+596|0;if((a[A]|0)==B<<24>>24){i=h;return}a[A]=B;A=c[e+604>>2]|0;if((A|0)==0){i=h;return}b3[A&511](c[e+600>>2]|0,B);i=h;return}else{i=h;return}}function nj(d){d=d|0;c[d+4>>2]=0;c[d+8>>2]=0;c[d+272>>2]=0;c[d+276>>2]=0;a[d+540|0]=0;a[d+541|0]=0;a[d+542|0]=0;a[d+543|0]=1;a[d+544|0]=0;a[d+545|0]=96;a[d+546|0]=0;a[d+547|0]=0;a[d+548|0]=0;a[d+549|0]=1;a[d+556|0]=0;b[d+594>>1]=0;return}function nk(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;if(b>>>0>=3){return}c[a+(b*28|0)+16>>2]=d;c[a+(b*28|0)+20>>2]=e;return}function nl(c,d){c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0;if(d>>>0>=3){f=-1;return f|0}g=c+(d*28|0)+5|0;h=a[g]|0;i=h&255;if((i&1|0)!=0){a[g]=h&-2;f=a[c+(d*28|0)+3|0]|0;return f|0}if((i&2|0)!=0){a[g]=h&-3;f=a[c+(d*28|0)+4|0]|0;return f|0}h=c+(d*28|0)+6|0;g=a[h]|0;if(g<<24>>24==0){i=a[c+(d*28|0)+8|0]|0;a[h]=i;j=i}else{j=g}if((j&1)==0){a[h]=j&-3;f=(e[c+(d*28|0)+26>>1]|0)>>>8&255;return f|0}else{a[h]=j&-2;f=b[c+(d*28|0)+26>>1]&255;return f|0}return 0}function nm(a,c){a=a|0;c=c|0;var d=0;if(c>>>0>=3){d=-1;return d|0}d=b[a+(c*28|0)+26>>1]|0;return d|0}function nn(c,d){c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;if(d>>>0>=3){f=-1;g=f&255;return g|0}h=c+(d*28|0)+5|0;i=a[h]|0;j=i&255;if((j&1|0)!=0){a[h]=i&-2;f=a[c+(d*28|0)+3|0]|0;g=f&255;return g|0}if((j&2|0)!=0){a[h]=i&-3;f=a[c+(d*28|0)+4|0]|0;g=f&255;return g|0}i=c+(d*28|0)+6|0;h=a[i]|0;if(h<<24>>24==0){j=a[c+(d*28|0)+8|0]|0;a[i]=j;k=j}else{k=h}if((k&1)==0){a[i]=k&-3;f=(e[c+(d*28|0)+26>>1]|0)>>>8&255;g=f&255;return g|0}else{a[i]=k&-2;f=b[c+(d*28|0)+26>>1]&255;g=f&255;return g|0}return 0}function no(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=b+556|0;if((a[e]|0)==0){return}f=b+560|0;g=c[f>>2]|0;do{if((g|0)!=0){if(g>>>0>d>>>0){c[f>>2]=g-d;break}c[f>>2]=0;h=c[b+572>>2]|0;i=b+568|0;c[i>>2]=h;if((h|0)==0){break}j=b+545|0;k=a[j]|0;if((k&1)!=0){break}l=b+4|0;m=c[l>>2]|0;if((m|0)==(c[b+8>>2]|0)){break}a[b+541|0]=a[b+16+m|0]|0;n=m+1|0;c[l>>2]=n;if(n>>>0>=(c[b+12>>2]|0)>>>0){c[l>>2]=0}c[i>>2]=h-1;a[e]=1;c[f>>2]=c[b+564>>2];a[j]=k|1;k=c[b+620>>2]|0;if((k|0)!=0){b3[k&511](c[b+616>>2]|0,1)}k=b+543|0;a[k]=1;h=a[b+542|0]|0;do{if((h&1)==0){o=740}else{if((a[j]&1)==0){o=740;break}a[k]=4;p=1}}while(0);L916:do{if((o|0)==740){do{if((h&2)!=0){if((a[j]&32)==0){break}if((a[b+549|0]|0)!=0){break}a[k]=2;p=1;break L916}}while(0);if((h&8)==0){p=0;break}if((a[b+547|0]&15)==0){p=0;break}a[k]=0;p=1}}while(0);k=b+596|0;if((a[k]|0)==p<<24>>24){break}a[k]=p;k=c[b+604>>2]|0;if((k|0)==0){break}b3[k&511](c[b+600>>2]|0,p)}}while(0);p=b+576|0;o=c[p>>2]|0;do{if((o|0)!=0){if(o>>>0>d>>>0){c[p>>2]=o-d;break}else{c[p>>2]=0;c[b+584>>2]=c[b+588>>2];np(b);break}}}while(0);if((c[f>>2]|0)==0){q=(c[p>>2]|0)!=0|0}else{q=1}a[e]=q;return}function np(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b+584|0;if((c[d>>2]|0)==0){return}e=b+545|0;f=a[e]|0;if((f&32)!=0){a[e]=f|64;return}f=b+546|0;g=a[b+540|0]|0;do{if((a[f]&16)==0){h=b+276|0;i=c[h>>2]|0;j=i+1|0;k=j>>>0<(c[b+280>>2]|0)>>>0?j:0;if((k|0)==(c[b+272>>2]|0)){return}else{a[b+284+i|0]=g;c[h>>2]=k;break}}else{k=b+8|0;h=c[k>>2]|0;i=h+1|0;j=i>>>0<(c[b+12>>2]|0)>>>0?i:0;if((j|0)==(c[b+4>>2]|0)){break}a[b+16+h|0]=g;c[k>>2]=j}}while(0);c[d>>2]=(c[d>>2]|0)-1;d=b+576|0;if((c[d>>2]|0)==0){a[b+556|0]=1;c[d>>2]=c[b+580>>2]}d=a[e]|0;g=d&-97;a[e]=g|32;j=b+549|0;a[j]=0;do{if((a[f]&16)==0){k=c[b+612>>2]|0;if((k|0)==0){break}b3[k&511](c[b+608>>2]|0,1)}else{k=b+568|0;h=c[k>>2]|0;if((h|0)==0){break}if((d&1)!=0){break}i=b+4|0;l=c[i>>2]|0;if((l|0)==(c[b+8>>2]|0)){break}a[b+541|0]=a[b+16+l|0]|0;m=l+1|0;c[i>>2]=m;if(m>>>0>=(c[b+12>>2]|0)>>>0){c[i>>2]=0}c[k>>2]=h-1;h=b+560|0;if((c[h>>2]|0)==0){a[b+556|0]=1;c[h>>2]=c[b+564>>2]}a[e]=g|33;h=c[b+620>>2]|0;if((h|0)!=0){b3[h&511](c[b+616>>2]|0,1)}h=b+543|0;a[h]=1;k=a[b+542|0]|0;do{if((k&1)==0){n=783}else{if((a[e]&1)==0){n=783;break}a[h]=4;o=1}}while(0);L977:do{if((n|0)==783){do{if((k&2)!=0){if((a[e]&32)==0){break}if((a[j]|0)!=0){break}a[h]=2;o=1;break L977}}while(0);if((k&8)==0){o=0;break}if((a[b+547|0]&15)==0){o=0;break}a[h]=0;o=1}}while(0);h=b+596|0;if((a[h]|0)==o<<24>>24){break}a[h]=o;h=c[b+604>>2]|0;if((h|0)==0){break}b3[h&511](c[b+600>>2]|0,o)}}while(0);o=b+543|0;a[o]=1;g=a[b+542|0]|0;do{if((g&1)==0){n=798}else{if((a[e]&1)==0){n=798;break}a[o]=4;p=1}}while(0);L993:do{if((n|0)==798){do{if((g&2)!=0){if((a[e]&32)==0){break}if((a[j]|0)!=0){break}a[o]=2;p=1;break L993}}while(0);if((g&8)==0){p=0;break}if((a[b+547|0]&15)==0){p=0;break}a[o]=0;p=1}}while(0);o=b+596|0;if((a[o]|0)==p<<24>>24){return}a[o]=p;o=c[b+604>>2]|0;if((o|0)==0){return}b3[o&511](c[b+600>>2]|0,p);return}function nq(d){d=d|0;var e=0;zP(d|0,0,7);a[d+8|0]=3;c[d+16>>2]=0;a[d+24|0]=0;c[d+20>>2]=0;e=d+9|0;y=0;a[e]=y&255;y=y>>8;a[e+1|0]=y&255;y=y>>8;a[e+2|0]=y&255;y=y>>8;a[e+3|0]=y&255;zP(d+26|0,0,9);a[d+36|0]=3;c[d+44>>2]=0;a[d+52|0]=0;c[d+48>>2]=0;e=d+37|0;y=0;a[e]=y&255;y=y>>8;a[e+1|0]=y&255;y=y>>8;a[e+2|0]=y&255;y=y>>8;a[e+3|0]=y&255;zP(d+54|0,0,9);a[d+64|0]=3;c[d+72>>2]=0;a[d+80|0]=0;c[d+76>>2]=0;b[d+82>>1]=0;e=d+65|0;y=0;a[e]=y&255;y=y>>8;a[e+1|0]=y&255;y=y>>8;a[e+2|0]=y&255;y=y>>8;a[e+3|0]=y&255;return}function nr(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0;if(e>>>0>=3){return}g=b+(e*28|0)+12|0;if((a[g]|0)==f<<24>>24){return}h=d[b+(e*28|0)+9|0]|0;if((13>>>(h>>>0)&1|0)!=0){b3[c[408+(h*12|0)>>2]&511](b+(e*28|0)|0,f)}a[g]=f;return}function ns(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0;if(f>>>0<3){h=e+(f*28|0)|0;i=e+(f*28|0)+2|0;j=a[i]|0;if(j<<24>>24==0){k=a[e+(f*28|0)+8|0]|0;a[i]=k;l=k}else{l=j}j=l&255;do{if((j&1|0)==0){if((j&2|0)==0){m=l;break}k=l&-3;a[i]=k;a[e+(f*28|0)+1|0]=g;m=k}else{k=l&-2;a[i]=k;a[h|0]=g;m=k}}while(0);do{if(m<<24>>24==0){i=a[e+(f*28|0)+9|0]|0;if((i&255)>=6){break}l=i&255;if((13>>>(l>>>0)&1|0)==0){break}b2[c[400+(l*12|0)>>2]&255](h)}}while(0);if((a[e+(f*28|0)+11|0]|0)!=0){return}b[e+(f*28|0)+26>>1]=d[e+(f*28|0)+1|0]<<8|d[h|0];return}if((f|0)!=3){return}f=(g&255)>>>6;if((f|0)==3|(g&-64)<<24>>24==-64){return}h=(g&255)>>>4&3;if(h<<24>>24==0){m=e+(f*28|0)+5|0;if((a[m]|0)!=0){return}a[m]=a[e+(f*28|0)+8|0]|0;m=b[e+(f*28|0)+26>>1]|0;a[e+(f*28|0)+3|0]=m&255;a[e+(f*28|0)+4|0]=(m&65535)>>>8&255;return}a[e+(f*28|0)+7|0]=g;a[e+(f*28|0)+2|0]=h;a[e+(f*28|0)+5|0]=0;a[e+(f*28|0)+6|0]=h;a[e+(f*28|0)|0]=0;a[e+(f*28|0)+1|0]=0;a[e+(f*28|0)+11|0]=0;a[e+(f*28|0)+8|0]=h;h=(g&255)>>>1&7;m=e+(f*28|0)+9|0;a[m]=h;a[e+(f*28|0)+10|0]=g&1;if((h<<24>>24|0)==6){a[m]=2;return}else if((h<<24>>24|0)==7){a[m]=3;return}else{return}}function nt(a,b,c){a=a|0;b=b|0;c=c|0;ns(a,b,c&255);return}function nu(a,b,c){a=a|0;b=b|0;c=c|0;ns(a,b,c&255);return}function nv(b,c){b=b|0;c=c|0;var d=0,e=0;d=b+11|0;if((a[d]|0)==0){e=0;a[d]=e;return}e=c<<24>>24!=0|0;a[d]=e;return}function nw(b,c){b=b|0;c=c|0;return a[b+4+(c*20|0)+2|0]|a[b+4+(c*20|0)+1|0]|0}function nx(d){d=d|0;var e=0,f=0;zP(d|0,0,7);a[d+8|0]=3;a[d+9|0]=0;a[d+10|0]=0;a[d+11|0]=0;b[d+26>>1]=0;e=d+24|0;do{if((a[e]|0)!=0){a[e]=0;f=c[d+20>>2]|0;if((f|0)==0){break}b3[f&511](c[d+16>>2]|0,0)}}while(0);zP(d+28|0,0,7);a[d+36|0]=3;a[d+37|0]=0;a[d+38|0]=0;a[d+39|0]=0;b[d+54>>1]=0;e=d+52|0;do{if((a[e]|0)!=0){a[e]=0;f=c[d+48>>2]|0;if((f|0)==0){break}b3[f&511](c[d+44>>2]|0,0)}}while(0);zP(d+56|0,0,7);a[d+64|0]=3;a[d+65|0]=0;a[d+66|0]=0;a[d+67|0]=0;b[d+82>>1]=0;e=d+80|0;if((a[e]|0)==0){return}a[e]=0;e=c[d+76>>2]|0;if((e|0)==0){return}b3[e&511](c[d+72>>2]|0,0);return}function ny(b,d){b=b|0;d=d|0;var e=0,f=0;do{if((a[b+11|0]|0)!=0){e=a[b+9|0]|0;if((e&255)>=6){break}f=e&255;if((13>>>(f>>>0)&1|0)==0){break}b3[c[404+(f*12|0)>>2]&511](b|0,d)}}while(0);do{if((a[b+39|0]|0)!=0){f=a[b+37|0]|0;if((f&255)>=6){break}e=f&255;if((13>>>(e>>>0)&1|0)==0){break}b3[c[404+(e*12|0)>>2]&511](b+28|0,d)}}while(0);if((a[b+67|0]|0)==0){return}e=a[b+65|0]|0;if((e&255)>=6){return}f=e&255;if((13>>>(f>>>0)&1|0)==0){return}b3[c[404+(f*12|0)>>2]&511](b+56|0,d);return}function nz(e){e=e|0;var f=0,g=0;f=e+24|0;do{if((a[f]|0)!=0){a[f]=0;g=c[e+20>>2]|0;if((g|0)==0){break}b3[g&511](c[e+16>>2]|0,0)}}while(0);b[e+26>>1]=d[e+1|0]<<8|d[e|0];if((a[e+12|0]|0)==0){return}a[e+11|0]=1;return}function nA(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((f|0)==0){return}g=d+12|0;h=d+24|0;i=d+26|0;j=d+20|0;k=d+16|0;d=f;do{do{if((a[g]|0)!=0){if((a[h]|0)!=0){break}f=(e[i>>1]|0)+65535|0;b[i>>1]=f&65535;if((f&65535|0)!=0){break}a[h]=1;f=c[j>>2]|0;if((f|0)==0){break}b3[f&511](c[k>>2]|0,1)}}while(0);d=d-1|0;}while((d|0)!=0);return}function nB(e){e=e|0;var f=0,g=0;f=e+24|0;do{if((a[f]|0)!=1){a[f]=1;g=c[e+20>>2]|0;if((g|0)==0){break}b3[g&511](c[e+16>>2]|0,1)}}while(0);b[e+26>>1]=d[e+1|0]<<8|d[e|0];if((a[e+12|0]|0)==0){return}a[e+11|0]=1;return}function nC(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;if((f|0)==0){return}g=e+26|0;h=e+24|0;i=e+1|0;j=e|0;k=e+12|0;l=e+11|0;m=e+20|0;n=e+16|0;e=f;while(1){f=b[g>>1]|0;o=f&65535;do{if(e>>>0<o>>>0){p=o-e&65535;b[g>>1]=p;q=0;r=p;s=928}else{p=o-1|0;if((f&65535)>1){b[g>>1]=1;t=e-p|0;s=930;break}else{u=p&65535;b[g>>1]=u;q=e-1|0;r=u;s=928;break}}}while(0);do{if((s|0)==928){s=0;if((r<<16>>16|0)==1){t=q;s=930;break}else if((r<<16>>16|0)!=0){v=q;break}do{if((a[h]|0)!=1){a[h]=1;f=c[m>>2]|0;if((f|0)==0){break}b3[f&511](c[n>>2]|0,1)}}while(0);b[g>>1]=d[i]<<8|d[j];if((a[k]|0)==0){v=q;break}a[l]=1;v=q}}while(0);do{if((s|0)==930){s=0;if((a[h]|0)==0){v=t;break}a[h]=0;f=c[m>>2]|0;if((f|0)==0){v=t;break}b3[f&511](c[n>>2]|0,0);v=t}}while(0);if((v|0)==0){break}else{e=v}}return}function nD(e,f){e=e|0;f=f|0;var g=0,h=0,i=0;if(f<<24>>24==0){a[e+11|0]=0;return}f=e+12|0;if((a[f]|0)!=0){return}if((a[e+2|0]|0)!=0){return}g=e+24|0;do{if((a[g]|0)==1){h=1}else{a[g]=1;i=c[e+20>>2]|0;if((i|0)==0){h=1;break}b3[i&511](c[e+16>>2]|0,1);h=(a[f]|0)==0}}while(0);b[e+26>>1]=d[e+1|0]<<8|d[e|0];f=e+11|0;if(!h){a[f]=1}a[f]=1;return}function nE(e){e=e|0;var f=0,g=0,h=0;f=e+11|0;if((a[f]|0)!=0){return}g=e+24|0;do{if((a[g]|0)!=1){a[g]=1;h=c[e+20>>2]|0;if((h|0)==0){break}b3[h&511](c[e+16>>2]|0,1)}}while(0);b[e+26>>1]=a[e|0]&254|d[e+1|0]<<8;if((a[e+12|0]|0)==0){return}a[f]=1;return}function nF(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if((f|0)==0){return}g=e+26|0;h=e+1|0;i=e|0;j=e+24|0;k=e+20|0;l=e+16|0;e=f;while(1){f=b[g>>1]|0;m=f&65535;do{if(f<<16>>16==0){n=((d[h]|0)<<8|(d[i]|0))-2&65535&-2;b[g>>1]=n;o=e-1|0;p=n;q=973}else{n=e<<1;if(n>>>0>m>>>0){b[g>>1]=0;r=e-(m>>>1)|0;q=975;break}else{s=m-n&65535;b[g>>1]=s;o=0;p=s;q=973;break}}}while(0);if((q|0)==973){q=0;if(p<<16>>16==0){r=o;q=975}else{t=o}}do{if((q|0)==975){q=0;m=a[j]|0;f=m<<24>>24==0|0;if(m<<24>>24==f<<24>>24){t=r;break}a[j]=f;m=c[k>>2]|0;if((m|0)==0){t=r;break}b3[m&511](c[l>>2]|0,f);t=r}}while(0);if((t|0)==0){break}else{e=t}}return}function nG(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0;if(f<<24>>24==0){f=e+24|0;do{if((a[f]|0)!=1){a[f]=1;g=c[e+20>>2]|0;if((g|0)==0){break}b3[g&511](c[e+16>>2]|0,1)}}while(0);a[e+11|0]=0;return}f=e+12|0;if((a[f]|0)!=0){return}if((a[e+2|0]|0)!=0){return}g=e+11|0;do{if((a[g]|0)==0){h=e+24|0;do{if((a[h]|0)==1){i=1}else{a[h]=1;j=c[e+20>>2]|0;if((j|0)==0){i=1;break}b3[j&511](c[e+16>>2]|0,1);i=(a[f]|0)==0}}while(0);b[e+26>>1]=a[e|0]&254|d[e+1|0]<<8;if(i){break}a[g]=1}}while(0);a[g]=1;return}function nH(b){b=b|0;a[b|0]=0;a[b+1|0]=0;a[b+2|0]=-128;a[b+4|0]=0;a[b+5|0]=0;a[b+6|0]=0;zP(b+8|0,0,19);zP(b+28|0,0,19);zP(b+48|0,0,16);return}function nI(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b+4+(d*20|0)|0;f=b+4+(d*20|0)+2|0;g=a[f]|0;do{if(g<<24>>24==0){h=0}else{i=c[b+4+(d*20|0)+8>>2]|0;if((i|0)==0){h=g;break}a[e|0]=b1[i&1023](c[b+4+(d*20|0)+4>>2]|0)|0;h=a[f]|0}}while(0);return a[b+4+(d*20|0)+1|0]&~h|h&a[e|0]|0}function nJ(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;if((e|0)==0){a[b+5|0]=f;g=a[b+6|0]|0;if(g<<24>>24==-1){return}h=c[b+20>>2]|0;if((h|0)==0){return}b3[h&511](c[b+16>>2]|0,~g&f);return}else if((e|0)==1){a[b+25|0]=f;g=a[b+26|0]|0;if(g<<24>>24==-1){return}h=c[b+40>>2]|0;if((h|0)==0){return}b3[h&511](c[b+36>>2]|0,~g&f);return}else if((e|0)==3){g=f&255;if((g&128|0)!=0){a[b+2|0]=f;a[b|0]=(f&255)>>>5&3;a[b+1|0]=(f&255)>>>2&1;a[b+6|0]=g<<27>>31&255;a[b+26|0]=g<<30>>31&255;a[b+46|0]=((g&1|0)!=0?15:0)|((g&8|0)!=0?-16:0);return}h=b+45|0;i=d[h]|0;j=1<<(g>>>1&7);if((g&1|0)==0){k=i&(j^255)&255}else{k=(i|j)&255}a[h]=k;h=a[b+46|0]|0;if(h<<24>>24==-1){return}j=c[b+60>>2]|0;if((j|0)==0){return}b3[j&511](c[b+56>>2]|0,k&~h);return}else if((e|0)==2){a[b+45|0]=f;e=a[b+46|0]|0;if(e<<24>>24==-1){return}h=c[b+60>>2]|0;if((h|0)==0){return}b3[h&511](c[b+56>>2]|0,~e&f);return}else{return}}function nK(a,b,c){a=a|0;b=b|0;c=c|0;nJ(a,b,c&255);return}function nL(a,b,c){a=a|0;b=b|0;c=c|0;nJ(a,b,c&255);return}function nM(a,b){a=a|0;b=b|0;var c=0;a=b&7;if((a|0)==1){c=110}else if((a|0)==7){c=54}else if((a|0)==2){c=116}else if((a|0)==5){c=104}else if((a|0)==3){c=114}else if((a|0)==6){c=108}else if((a|0)==0){c=112}else if((a|0)==4){c=106}else{c=0}return c|0}function nN(a,b,d){a=a|0;b=b|0;d=d|0;c[a+64>>2]=b;c[a+68>>2]=d;return}function nO(b){b=b|0;return a[b+7|0]|0}function nP(b){b=b|0;return a[b+8|0]|0}function nQ(b){b=b|0;return a[b+9|0]|0}function nR(b,c){b=b|0;c=c|0;var d=0;if(c>>>0<4){d=a[b+c|0]|0}else{d=0}return d|0}function nS(b,c){b=b|0;c=c|0;var d=0;if(c>>>0<3){d=a[b+4+c|0]|0}else{d=0}return d|0}function nT(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((d|0)==0){e=b+4|0;f=b+6|0;g=a[f]|0;do{if(g<<24>>24==0){h=0}else{i=c[b+12>>2]|0;if((i|0)==0){h=g;break}a[e|0]=b1[i&1023](c[b+8>>2]|0)|0;h=a[f]|0}}while(0);j=a[b+5|0]&~h|a[e|0]&h;return j|0}else if((d|0)==2){h=b+44|0;e=b+46|0;f=a[e]|0;do{if(f<<24>>24==0){k=0}else{g=c[b+52>>2]|0;if((g|0)==0){k=f;break}a[h|0]=b1[g&1023](c[b+48>>2]|0)|0;k=a[e]|0}}while(0);j=a[b+45|0]&~k|a[h|0]&k;return j|0}else if((d|0)==1){k=b+24|0;h=b+26|0;e=a[h]|0;do{if(e<<24>>24==0){l=0}else{f=c[b+32>>2]|0;if((f|0)==0){l=e;break}a[k|0]=b1[f&1023](c[b+28>>2]|0)|0;l=a[h]|0}}while(0);j=a[b+25|0]&~l|a[k|0]&l;return j|0}else if((d|0)==3){j=a[b+2|0]|0;return j|0}else{j=0;return j|0}return 0}function nU(a,b){a=a|0;b=b|0;return(nT(a,b)|0)&255|0}function nV(a,b){a=a|0;b=b|0;return(nT(a,b)|0)&255|0}function nW(b){b=b|0;c[b+12>>2]=0;c[b+16>>2]=0;zP(b|0,0,7);c[b+20>>2]=1;a[b+7|0]=0;a[b+8|0]=-1;a[b+9|0]=0;a[b+10|0]=0;zP(b+24|0,0,49);return}function nX(a,b){a=a|0;b=b|0;n3(a,0,b<<24>>24!=0|0);return}function nY(a,b){a=a|0;b=b|0;n3(a,1,b<<24>>24!=0|0);return}function nZ(a,b){a=a|0;b=b|0;n3(a,2,b<<24>>24!=0|0);return}function n_(a,b){a=a|0;b=b|0;n3(a,3,b<<24>>24!=0|0);return}function n$(a,b){a=a|0;b=b|0;n3(a,4,b<<24>>24!=0|0);return}function n0(a,b){a=a|0;b=b|0;n3(a,5,b<<24>>24!=0|0);return}function n1(a,b){a=a|0;b=b|0;n3(a,6,b<<24>>24!=0|0);return}function n2(a,b){a=a|0;b=b|0;n3(a,7,b<<24>>24!=0|0);return}function n3(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=1<<(e&7);e=b+10|0;h=d[e]|0;if(!((g&h|0)!=0^f<<24>>24!=0)){return}if(f<<24>>24==0){f=(g|-256)^255;a[e]=h&f&255;i=b+7|0;j=d[i]&f&255;a[i]=j;k=j}else{a[e]=(h|g)&255;h=b+7|0;e=(d[h]|g)&255;a[h]=e;k=e}e=~d[b+8|0];h=k&255&e;if((h|0)==0){k=b+72|0;if((a[k]|0)==0){return}a[k]=0;k=c[b+68>>2]|0;if((k|0)==0){return}b3[k&511](c[b+64>>2]|0,0);return}k=d[b+9|0]&e;e=1<<c[b+24>>2];L1365:do{if((k&e|0)==0){g=e;while(1){if((g&h|0)!=0){break}j=g<<1|g>>>7;if((j&k|0)==0){g=j&255}else{break L1365}}g=b+72|0;if((a[g]|0)==1){return}a[g]=1;g=c[b+68>>2]|0;if((g|0)==0){return}b3[g&511](c[b+64>>2]|0,1);return}}while(0);k=b+72|0;if((a[k]|0)==0){return}a[k]=0;k=c[b+68>>2]|0;if((k|0)==0){return}b3[k&511](c[b+64>>2]|0,0);return}function n4(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=b+72|0;do{if((a[e]|0)!=0){a[e]=0;f=c[b+68>>2]|0;if((f|0)==0){break}b3[f&511](c[b+64>>2]|0,0)}}while(0);f=b+7|0;g=a[f]|0;h=b+8|0;i=g&~a[h];if(i<<24>>24==0){j=c[q>>2]|0;aB(22280,24,1,j|0)|0;k=(c[b+12>>2]|0)+7&255;return k|0}j=i&255;i=b+24|0;l=c[i>>2]|0;m=(j<<8|j)>>>((l&7)>>>0);if((m&1|0)==0){j=l;n=m;while(1){m=n>>>1;o=j+1|0;if((m&1|0)==0){j=o;n=m}else{p=o;break}}}else{p=l}l=p&7;n=1<<l;a[f]=(n^255)&(g&255)&255;do{if((a[b+3|0]&2)==0){g=b+9|0;a[g]=(d[g]|n)&255}else{if((c[b+28>>2]|0)==0){break}c[i>>2]=p+1&7}}while(0);p=b+32+(l<<2)|0;c[p>>2]=(c[p>>2]|0)+1;p=~d[h];h=d[f]&p;L1403:do{if((h|0)==0){if((a[e]|0)==0){break}a[e]=0;f=c[b+68>>2]|0;if((f|0)==0){break}b3[f&511](c[b+64>>2]|0,0)}else{f=d[b+9|0]&p;n=1<<c[i>>2];L1408:do{if((f&n|0)==0){g=n;while(1){if((g&h|0)!=0){break}j=g<<1|g>>>7;if((j&f|0)==0){g=j&255}else{break L1408}}if((a[e]|0)==1){break L1403}a[e]=1;g=c[b+68>>2]|0;if((g|0)==0){break L1403}b3[g&511](c[b+64>>2]|0,1);break L1403}}while(0);if((a[e]|0)==0){break}a[e]=0;f=c[b+68>>2]|0;if((f|0)==0){break}b3[f&511](c[b+64>>2]|0,0)}}while(0);k=(c[b+12>>2]|0)+l&255;return k|0}function n5(a){a=a|0;return}function n6(b,d){b=b|0;d=d|0;var e=0;if((d|0)==0){e=a[(c[b+20>>2]|0)==0?b+9|0:b+7|0]|0;return e|0}else if((d|0)==1){e=a[b+8|0]|0;return e|0}else{e=-1;return e|0}return 0}function n7(b,d){b=b|0;d=d|0;var e=0;if((d|0)==0){e=a[(c[b+20>>2]|0)==0?b+9|0:b+7|0]|0}else if((d|0)==1){e=a[b+8|0]|0}else{e=-1}return e&255|0}function n8(b,d){b=b|0;d=d|0;var e=0;if((d|0)==0){e=a[(c[b+20>>2]|0)==0?b+9|0:b+7|0]|0}else if((d|0)==1){e=a[b+8|0]|0}else{e=-1}return e&255|0}function n9(a,b,d){a=a|0;b=b|0;d=d|0;c[a+12512>>2]=d;c[a+12504>>2]=b;return}function oa(a,b,d){a=a|0;b=b|0;d=d|0;c[a+12524>>2]=d;c[a+12516>>2]=b;return}function ob(a,b,d){a=a|0;b=b|0;d=d|0;c[a+12496>>2]=b;c[a+12500>>2]=d;return}function oc(a,b){a=a|0;b=b|0;c[a+12448>>2]=b;return}function od(b,c){b=b|0;c=c|0;a[b+12440|0]=(c|0)!=0|0;return}function oe(b,c){b=b|0;c=c|0;a[b+12441|0]=(c|0)!=0|0;return}function of(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;do{if((e|0)==0){g=f&255;if((g&16|0)!=0){a[b|0]=f;c[b+12>>2]=0;zP(b+1|0,0,6);c[b+16>>2]=1;c[b+20>>2]=1;c[b+24>>2]=0;c[b+28>>2]=0;a[b+8|0]=0;a[b+9|0]=0;break}if((g&24|0)!=0){if((g&152|0)!=8){break}a[b+6|0]=f;do{if((g&2|0)!=0){h=b+20|0;if((g&1|0)==0){c[h>>2]=1;break}else{c[h>>2]=0;break}}}while(0);if((g&4|0)!=0){h=c[q>>2]|0;aB(34072,20,1,h|0)|0}if((g&96|0)!=96){break}h=c[q>>2]|0;aB(31440,33,1,h|0)|0;break}a[b+5|0]=f;h=b+9|0;i=a[h]|0;if(i<<24>>24==0){j=255}else{k=i&255;l=c[b+24>>2]|0;m=(k<<8|k)>>>((l&7)>>>0);if((m&1|0)==0){k=l;n=m;while(1){m=n>>>1;o=k+1|0;if((m&1|0)==0){k=o;n=m}else{p=o;break}}}else{p=l}j=p&7}n=1<<(j&7);k=g>>>5;if((k|0)==6){c[b+24>>2]=g+1&7;break}else if((k|0)==0){c[b+28>>2]=0;break}else if((k|0)==7){a[h]=i&255&(1<<(g&7)^255)&255;c[b+24>>2]=g+1&7;break}else if((k|0)==3){a[h]=i&255&(1<<(g&7)^255)&255;break}else if((k|0)==1){if(j>>>0>=16){break}a[h]=(n^255)&(i&255)&255;break}else if((k|0)==5){if(j>>>0>=16){break}a[h]=(n^255)&(i&255)&255;c[b+24>>2]=j+1&7;break}else if((k|0)==4){c[b+28>>2]=1;break}else{break}}else if((e|0)==1){k=b+16|0;n=c[k>>2]|0;if((n|0)==3){a[b+3|0]=f;c[k>>2]=0;break}else if((n|0)==0){a[b+4|0]=f;a[b+8|0]=f;break}else if((n|0)==1){a[b+1|0]=f;c[b+12>>2]=f&248;o=d[b|0]|0;if((o&2|0)==0){c[k>>2]=2;break}if((o&1|0)==0){c[k>>2]=0;break}else{c[k>>2]=3;break}}else if((n|0)==2){a[b+2|0]=f;if((a[b|0]&1)==0){c[k>>2]=0;break}else{c[k>>2]=3;break}}else{break}}}while(0);f=~d[b+8|0];e=d[b+7|0]&f;if((e|0)==0){j=b+72|0;if((a[j]|0)==0){return}a[j]=0;j=c[b+68>>2]|0;if((j|0)==0){return}b3[j&511](c[b+64>>2]|0,0);return}j=d[b+9|0]&f;f=1<<c[b+24>>2];L1507:do{if((j&f|0)==0){p=f;while(1){if((p&e|0)!=0){break}k=p<<1|p>>>7;if((k&j|0)==0){p=k&255}else{break L1507}}p=b+72|0;if((a[p]|0)==1){return}a[p]=1;p=c[b+68>>2]|0;if((p|0)==0){return}b3[p&511](c[b+64>>2]|0,1);return}}while(0);j=b+72|0;if((a[j]|0)==0){return}a[j]=0;j=c[b+68>>2]|0;if((j|0)==0){return}b3[j&511](c[b+64>>2]|0,0);return}function og(a,b,c){a=a|0;b=b|0;c=c|0;of(a,b,c&255);return}function oh(a,b,c){a=a|0;b=b|0;c=c|0;of(a,b,c&255);return}function oi(b){b=b|0;var d=0;zP(b|0,0,7);c[b+12>>2]=8;c[b+16>>2]=0;c[b+20>>2]=1;a[b+7|0]=0;a[b+8|0]=-1;a[b+9|0]=0;c[b+24>>2]=0;c[b+28>>2]=0;d=b+72|0;if((a[d]|0)==0){return}a[d]=0;d=c[b+68>>2]|0;if((d|0)==0){return}b3[d&511](c[b+64>>2]|0,0);return}function oj(d){d=d|0;a[d|0]=4;a[d+1|0]=-128;a[d+2|0]=-64;a[d+3|0]=0;a[d+4|0]=0;a[d+5|0]=0;c[d+24>>2]=0;zP(d+8|0,0,13);c[d+1052>>2]=1;c[d+1056>>2]=0;c[d+1060>>2]=0;a[d+1064|0]=0;c[d+1068>>2]=0;c[d+2096>>2]=2;c[d+2100>>2]=0;c[d+2104>>2]=0;a[d+2108|0]=0;c[d+2112>>2]=0;c[d+3140>>2]=3;c[d+3144>>2]=0;c[d+3148>>2]=0;a[d+3152|0]=0;c[d+3156>>2]=0;c[d+4184>>2]=d+8;c[d+4188>>2]=0;c[d+4192>>2]=0;c[d+4212>>2]=0;c[d+4216>>2]=0;c[d+4236>>2]=0;c[d+4240>>2]=0;a[d+12436|0]=1;a[d+12437|0]=0;b[d+12438>>1]=1;a[d+12440|0]=0;a[d+12441|0]=0;c[d+12444>>2]=0;c[d+12448>>2]=1e6;c[d+12452>>2]=0;c[d+12456>>2]=0;c[d+12460>>2]=5e4;b[d+12464>>1]=0;c[d+12512>>2]=0;c[d+12516>>2]=0;a[d+12520|0]=0;c[d+12524>>2]=0;zP(d+12476|0,0,16);zP(d+12496|0,0,13);return}function ok(b){b=b|0;var d=0,e=0;a[b+1|0]=-128;c[b+4188>>2]=0;c[b+4192>>2]=0;c[b+4212>>2]=0;c[b+4216>>2]=0;c[b+4236>>2]=0;c[b+4240>>2]=0;d=b+2|0;y=0;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;a[b+12437|0]=15;c[b+12444>>2]=0;c[b+12476>>2]=268;c[b+12480>>2]=0;c[b+12484>>2]=0;c[b+12488>>2]=0;d=b+12508|0;do{if((a[d]|0)!=0){a[d]=0;e=c[b+12512>>2]|0;if((e|0)==0){break}b3[e&511](c[b+12504>>2]|0,0)}}while(0);d=b+12520|0;if((a[d]|0)==0){return}a[d]=0;d=c[b+12524>>2]|0;if((d|0)==0){return}b3[d&511](c[b+12516>>2]|0,0);return}function ol(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b+12476|0;f=b+12492|0;zP(e|0,0,20);g=0;while(1){if(g>>>0>=11){h=1256;break}if((a[16360+(g*12|0)|0]&d)<<24>>24==(a[16361+(g*12|0)|0]|0)){break}else{g=g+1|0}}if((h|0)==1256){return}c[b+4192>>2]=c[16364+(g*12|0)>>2];c[e>>2]=238;h=c[16368+(g*12|0)>>2]|0;c[f>>2]=h;c[b+4188>>2]=1;a[b+4196|0]=d;if(!((g|0)==10|(g|0)==7)){return}c[e>>2]=0;e=b+1|0;a[e]=a[e]&111|16;b2[h&255](b);return}function om(b,d){b=b|0;d=d|0;var e=0,f=0;e=b+12508|0;do{if((a[e]|0)!=0){a[e]=0;f=c[b+12512>>2]|0;if((f|0)==0){break}b3[f&511](c[b+12504>>2]|0,0)}}while(0);e=a[b+1|0]|0;do{if(e<<24>>24>-1){if((a[b+12520|0]|0)!=0){break}return}}while(0);if((e&64)!=0){return}e=c[b+12476>>2]|0;if((e|0)==0){return}b3[e&511](b,d);return}function on(b){b=b|0;var d=0,e=0,f=0;d=b+12508|0;do{if((a[d]|0)!=0){a[d]=0;e=c[b+12512>>2]|0;if((e|0)==0){break}b3[e&511](c[b+12504>>2]|0,0)}}while(0);d=c[b+12480>>2]|0;if((d|0)==0){f=0;return f|0}f=b1[d&1023](b)|0;return f|0}function oo(b,d){b=b|0;d=d|0;var e=0,f=0;if((d|0)==2){e=a[b|0]|0;return e|0}else if((d|0)==4){e=a[b+1|0]|0;return e|0}else if((d|0)==5){d=b+12508|0;do{if((a[d]|0)!=0){a[d]=0;f=c[b+12512>>2]|0;if((f|0)==0){break}b3[f&511](c[b+12504>>2]|0,0)}}while(0);d=c[b+12480>>2]|0;if((d|0)==0){e=0;return e|0}e=b1[d&1023](b)|0;return e|0}else{e=-1;return e|0}return 0}function op(b){b=b|0;var f=0,g=0,h=0,i=0;f=a[b+4197|0]&3;g=b+8+(f*1044|0)+4|0;h=c[g>>2]|0;a[b+8+(f*1044|0)+12|0]=0;c[g>>2]=0;c[b+8+(f*1044|0)+16>>2]=0;c[b+4184>>2]=b+8+(f*1044|0);g=b+1|0;a[g]=(d[g]|1<<f)&255;if((a[b+12440|0]|0)==0){c[b+12444>>2]=0;i=b+12488|0;c[i>>2]=334;return}else{c[b+12444>>2]=ac(((ac(e[b+12438>>1]|0,c[b+12448>>2]|0)|0)>>>0)/1e3|0,h)|0;i=b+12488|0;c[i>>2]=334;return}}function oq(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;if((d|0)==2){f=b|0;do{if(((a[f]^e)&4)!=0){if((e&4)!=0){g=b+12508|0;if((a[g]|0)==1){break}a[g]=1;g=c[b+12512>>2]|0;if((g|0)==0){break}b3[g&511](c[b+12504>>2]|0,1);break}a[b+1|0]=-128;c[b+4188>>2]=0;c[b+4192>>2]=0;c[b+4212>>2]=0;c[b+4216>>2]=0;c[b+4236>>2]=0;c[b+4240>>2]=0;g=b+2|0;y=0;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;a[b+12437|0]=15;c[b+12444>>2]=0;c[b+12476>>2]=268;c[b+12480>>2]=0;c[b+12484>>2]=0;c[b+12488>>2]=0;g=b+12508|0;do{if((a[g]|0)!=0){a[g]=0;h=c[b+12512>>2]|0;if((h|0)==0){break}b3[h&511](c[b+12504>>2]|0,0)}}while(0);g=b+12520|0;if((a[g]|0)==0){break}a[g]=0;g=c[b+12524>>2]|0;if((g|0)==0){break}b3[g&511](c[b+12516>>2]|0,0)}}while(0);a[f]=e;return}else if((d|0)==5){d=b+12508|0;do{if((a[d]|0)!=0){a[d]=0;f=c[b+12512>>2]|0;if((f|0)==0){break}b3[f&511](c[b+12504>>2]|0,0)}}while(0);d=a[b+1|0]|0;do{if(d<<24>>24>-1){if((a[b+12520|0]|0)!=0){break}return}}while(0);if((d&64)!=0){return}d=c[b+12476>>2]|0;if((d|0)==0){return}b3[d&511](b,e);return}else{return}}function or(a,b){a=a|0;b=b|0;if(b<<24>>24==0){return}b=c[a+12484>>2]|0;if((b|0)==0){return}b2[b&255](a);return}function os(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=a+12456|0;f=(c[e>>2]|0)+(d*25e4|0)|0;g=c[a+12448>>2]|0;h=a+12452|0;i=(c[h>>2]|0)+((f>>>0)/(g>>>0)|0)|0;c[h>>2]=i;c[e>>2]=(f>>>0)%(g>>>0)|0;g=c[a+12460>>2]|0;if(i>>>0>=g>>>0){c[h>>2]=i-g;g=a+12464|0;b[g>>1]=(b[g>>1]|0)+1&65535}g=a+12444|0;i=c[g>>2]|0;c[g>>2]=i>>>0>d>>>0?i-d|0:0;i=c[a+12488>>2]|0;if((i|0)==0){return}b3[i&511](a,d);return}function ot(b,d){b=b|0;d=d|0;var e=0,f=0;e=b+4188|0;f=c[e>>2]|0;c[e>>2]=f+1;a[b+4196+f|0]=d;if((c[e>>2]|0)>>>0<(c[b+4192>>2]|0)>>>0){return}c[b+12476>>2]=0;e=b+1|0;a[e]=a[e]&111|16;e=c[b+12492>>2]|0;if((e|0)==0){return}b2[e&255](b);return}function ou(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=d[f+4197|0]|0;h=g&3;a[f+8+(h*1044|0)+12|0]=0;c[f+8+(h*1044|0)+8>>2]=g>>>2&1;c[f+8+(h*1044|0)+16>>2]=0;g=f+4184|0;c[g>>2]=f+8+(h*1044|0);oM(f);a[f+2|0]=0;a[f+3|0]=0;a[f+4|0]=0;a[f+12466|0]=0;h=f+12464|0;b[h>>1]=0;i=c[g>>2]|0;g=c[i+16>>2]|0;do{if((g|0)==0){j=0}else{k=f+12452|0;l=0;while(1){if(l>>>0>=g>>>0){m=1356;break}if((e[i+20+(l<<3)+6>>1]|0)>>>0>(c[k>>2]|0)>>>0){break}else{l=l+1|0}}if((m|0)==1356){j=g-1|0;break}if((l|0)==0){j=g-1|0;break}else{j=l-1|0;break}}}while(0);m=j+1|0;j=m>>>0<g>>>0?m:0;if(g>>>0<=j>>>0){g=c[f+12460>>2]|0;m=f+12452|0;if((a[f+12440|0]|0)!=0){k=z4(c[f+12448>>2]|0,0,g-(c[m>>2]|0)|0,0)|0;n=z5(k,G,25e4,0)|0;c[f+12444>>2]=n;o=f+12488|0;c[o>>2]=2;p=f+12484|0;c[p>>2]=30;return}c[m>>2]=g;n=g;k=0;do{n=n-g|0;k=k+1&65535;}while(n>>>0>=g>>>0);c[m>>2]=n;b[h>>1]=k;c[f+12444>>2]=0;o=f+12488|0;c[o>>2]=2;p=f+12484|0;c[p>>2]=30;return}k=e[i+20+(j<<3)+6>>1]|0;j=f+12452|0;i=c[j>>2]|0;n=k-i|0;if(k>>>0<i>>>0){q=(c[f+12460>>2]|0)+n|0}else{q=n}n=q+128|0;if((a[f+12440|0]|0)!=0){q=z4(c[f+12448>>2]|0,0,n,0)|0;k=z5(q,G,25e4,0)|0;c[f+12444>>2]=k;o=f+12488|0;c[o>>2]=2;p=f+12484|0;c[p>>2]=30;return}k=i+n|0;c[j>>2]=k;n=c[f+12460>>2]|0;if(k>>>0>=n>>>0){i=k;k=0;do{i=i-n|0;k=k+1&65535;}while(i>>>0>=n>>>0);c[j>>2]=i;b[h>>1]=k}c[f+12444>>2]=0;o=f+12488|0;c[o>>2]=2;p=f+12484|0;c[p>>2]=30;return}function ov(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=d[f+4197|0]|0;h=g&3;a[f+8+(h*1044|0)+12|0]=0;c[f+8+(h*1044|0)+8>>2]=g>>>2&1;c[f+8+(h*1044|0)+16>>2]=0;g=f+4184|0;c[g>>2]=f+8+(h*1044|0);oM(f);a[f+2|0]=0;a[f+3|0]=4;a[f+4|0]=0;b[f+12468>>1]=0;b[f+12464>>1]=0;h=c[g>>2]|0;if((c[h+16>>2]|0)==0){g=z4(c[f+12448>>2]|0,0,(c[f+12460>>2]|0)-(c[f+12452>>2]|0)|0,0)|0;i=z5(g,G,25e4,0)|0;c[f+12444>>2]=i;j=f+12488|0;c[j>>2]=452;k=f+12484|0;c[k>>2]=146;return}i=e[h+26>>1]|0;h=c[f+12452>>2]|0;g=i-h|0;if(i>>>0<h>>>0){l=(c[f+12460>>2]|0)+g|0}else{l=g}g=z4(c[f+12448>>2]|0,0,l+128|0,0)|0;l=z5(g,G,25e4,0)|0;c[f+12444>>2]=l;j=f+12488|0;c[j>>2]=452;k=f+12484|0;c[k>>2]=146;return}function ow(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=d[f+4197|0]|0;h=g&3;a[f+8+(h*1044|0)+12|0]=0;c[f+8+(h*1044|0)+8>>2]=g>>>2&1;c[f+8+(h*1044|0)+16>>2]=0;g=f+4184|0;c[g>>2]=f+8+(h*1044|0);oM(f);b[f+12464>>1]=0;a[f+2|0]=0;a[f+3|0]=0;a[f+4|0]=0;h=c[g>>2]|0;g=c[h+16>>2]|0;do{if((g|0)==0){i=0}else{j=f+12452|0;k=0;while(1){if(k>>>0>=g>>>0){l=1391;break}if((e[h+20+(k<<3)+6>>1]|0)>>>0>(c[j>>2]|0)>>>0){break}else{k=k+1|0}}if((l|0)==1391){i=g-1|0;break}if((k|0)==0){i=g-1|0;break}else{i=k-1|0;break}}}while(0);l=i+1|0;i=l>>>0<g>>>0?l:0;if(g>>>0<=i>>>0){g=z4(c[f+12448>>2]|0,0,(c[f+12460>>2]|0)-(c[f+12452>>2]|0)|0,0)|0;l=z5(g,G,25e4,0)|0;c[f+12444>>2]=l;m=f+12488|0;c[m>>2]=308;return}l=e[h+20+(i<<3)+6>>1]|0;i=c[f+12452>>2]|0;h=l-i|0;if(l>>>0<i>>>0){n=(c[f+12460>>2]|0)+h|0}else{n=h}h=z4(c[f+12448>>2]|0,0,n+128|0,0)|0;n=z5(h,G,25e4,0)|0;c[f+12444>>2]=n;m=f+12488|0;c[m>>2]=308;return}function ox(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=d[f+4197|0]|0;h=g&3;a[f+8+(h*1044|0)+12|0]=0;c[f+8+(h*1044|0)+8>>2]=g>>>2&1;c[f+8+(h*1044|0)+16>>2]=0;g=f+4184|0;c[g>>2]=f+8+(h*1044|0);oM(f);a[f+2|0]=0;a[f+3|0]=0;a[f+4|0]=0;h=f+12464|0;b[h>>1]=0;i=c[g>>2]|0;g=c[i+16>>2]|0;do{if((g|0)==0){j=0}else{k=f+12452|0;l=0;while(1){if(l>>>0>=g>>>0){m=1407;break}if((e[i+20+(l<<3)+6>>1]|0)>>>0>(c[k>>2]|0)>>>0){break}else{l=l+1|0}}if((m|0)==1407){j=g-1|0;break}if((l|0)==0){j=g-1|0;break}else{j=l-1|0;break}}}while(0);m=j+1|0;j=m>>>0<g>>>0?m:0;if(g>>>0<=j>>>0){g=c[f+12460>>2]|0;m=f+12452|0;if((a[f+12440|0]|0)!=0){k=z4(c[f+12448>>2]|0,0,g-(c[m>>2]|0)|0,0)|0;n=z5(k,G,25e4,0)|0;c[f+12444>>2]=n;o=f+12484|0;c[o>>2]=92;p=f+12488|0;c[p>>2]=178;return}c[m>>2]=g;n=g;k=0;do{n=n-g|0;k=k+1&65535;}while(n>>>0>=g>>>0);c[m>>2]=n;b[h>>1]=k;c[f+12444>>2]=0;o=f+12484|0;c[o>>2]=92;p=f+12488|0;c[p>>2]=178;return}k=e[i+20+(j<<3)+6>>1]|0;j=f+12452|0;i=c[j>>2]|0;n=k-i|0;if(k>>>0<i>>>0){q=(c[f+12460>>2]|0)+n|0}else{q=n}n=q+128|0;if((a[f+12440|0]|0)!=0){q=z4(c[f+12448>>2]|0,0,n,0)|0;k=z5(q,G,25e4,0)|0;c[f+12444>>2]=k;o=f+12484|0;c[o>>2]=92;p=f+12488|0;c[p>>2]=178;return}k=i+n|0;c[j>>2]=k;n=c[f+12460>>2]|0;if(k>>>0>=n>>>0){i=k;k=0;do{i=i-n|0;k=k+1&65535;}while(i>>>0>=n>>>0);c[j>>2]=i;b[h>>1]=k}c[f+12444>>2]=0;o=f+12484|0;c[o>>2]=92;p=f+12488|0;c[p>>2]=178;return}function oy(e){e=e|0;var f=0,g=0,h=0,i=0,j=0;f=d[e+4197|0]|0;g=f&3;a[e+8+(g*1044|0)+12|0]=0;c[e+8+(g*1044|0)+8>>2]=f>>>2&1;c[e+8+(g*1044|0)+16>>2]=0;c[e+4184>>2]=e+8+(g*1044|0);g=e+2|0;a[g]=0;a[e+3|0]=0;a[e+4|0]=0;if((a[e+4196|0]&64)==0){a[g]=64;oJ(e);return}b[e+12472>>1]=0;g=c[e+12460>>2]|0;f=e+12452|0;if((a[e+12440|0]|0)==0){c[f>>2]=g;h=e+12464|0;i=g;j=b[h>>1]|0;do{i=i-g|0;j=j+1&65535;}while(i>>>0>=g>>>0);c[f>>2]=i;b[h>>1]=j;c[e+12444>>2]=0}else{j=z4(c[e+12448>>2]|0,0,g-(c[f>>2]|0)|0,0)|0;f=z5(j,G,25e4,0)|0;c[e+12444>>2]=f}c[e+12484>>2]=46;c[e+12488>>2]=458;return}function oz(b){b=b|0;var f=0,g=0,h=0,i=0,j=0;f=a[b+4197|0]&3;g=d[b+4198|0]|0;h=b+8+(f*1044|0)+4|0;i=c[h>>2]|0;a[b+8+(f*1044|0)+12|0]=0;c[h>>2]=g;c[b+8+(f*1044|0)+16>>2]=0;c[b+4184>>2]=b+8+(f*1044|0);h=b+1|0;a[h]=(d[h]|1<<f)&255;if((a[b+12440|0]|0)==0){c[b+12444>>2]=0;j=b+12488|0;c[j>>2]=74;return}else{c[b+12444>>2]=ac(((ac(e[b+12438>>1]|0,c[b+12448>>2]|0)|0)>>>0)/1e3|0,i>>>0<g>>>0?g-i|0:i-g|0)|0;j=b+12488|0;c[j>>2]=74;return}}function oA(b){b=b|0;var d=0;if((a[b+12440|0]|0)==0){d=0}else{d=((c[b+12448>>2]|0)>>>0)/1e4|0}c[b+12444>>2]=d;c[b+12488>>2]=450;return}function oB(b){b=b|0;var d=0;if((a[b+12440|0]|0)==0){d=0}else{d=((c[b+12448>>2]|0)>>>0)/1e4|0}c[b+12444>>2]=d;c[b+12488>>2]=28;return}function oC(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=16-((d[e+4197|0]|0)>>>4)&255;g=a[e+4198|0]&1;a[e+12436|0]=g^1;b[e+12438>>1]=f&255;c[e+12476>>2]=268;c[e+12480>>2]=0;c[e+12484>>2]=0;c[e+12488>>2]=0;f=e+1|0;h=a[f]&-81;a[f]=h;if(g<<24>>24!=0){i=h;j=i&95;k=j|-128;a[f]=k;return}g=e+12520|0;if((a[g]|0)==0){i=h;j=i&95;k=j|-128;a[f]=k;return}a[g]=0;g=c[e+12524>>2]|0;if((g|0)==0){i=h;j=i&95;k=j|-128;a[f]=k;return}b3[g&511](c[e+12516>>2]|0,0);i=a[f]|0;j=i&95;k=j|-128;a[f]=k;return}function oD(b){b=b|0;var e=0,f=0,g=0,h=0,j=0;e=i;bN(c[q>>2]|0,21976,(x=i,i=i+8|0,c[x>>2]=d[b+4196|0]|0,x)|0)|0;a[b+4220|0]=-128;c[b+4212>>2]=0;c[b+4216>>2]=1;c[b+12476>>2]=0;c[b+12480>>2]=266;c[b+12484>>2]=0;c[b+12488>>2]=0;f=b+1|0;g=a[f]|80;a[f]=g;do{if((a[b+12436|0]|0)==0){h=g}else{j=b+12520|0;if((a[j]|0)==0){h=g;break}a[j]=0;j=c[b+12524>>2]|0;if((j|0)==0){h=g;break}b3[j&511](c[b+12516>>2]|0,0);h=a[f]|0}}while(0);a[f]=h&95|-128;i=e;return}function oE(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=b+4212|0;e=c[d>>2]|0;f=e+1|0;c[d>>2]=f;d=a[b+4220+e|0]|0;if(f>>>0<(c[b+4216>>2]|0)>>>0){return d|0}c[b+12476>>2]=268;c[b+12480>>2]=0;c[b+12484>>2]=0;c[b+12488>>2]=0;f=b+1|0;e=a[f]&-81;a[f]=e;do{if((a[b+12436|0]|0)==0){g=e}else{h=b+12520|0;if((a[h]|0)==0){g=e;break}a[h]=0;h=c[b+12524>>2]|0;if((h|0)==0){g=e;break}b3[h&511](c[b+12516>>2]|0,0);g=a[f]|0}}while(0);a[f]=g&95|-128;return d|0}function oF(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((c[b+12444>>2]|0)!=0){return}d=a[b+4197|0]&3;e=b+5|0;f=a[e]|0;g=f&-57|40;a[e]=g;if((c[b+8+(d*1044|0)+4>>2]|0)==0){d=f|56;a[e]=d;h=d}else{h=g}a[b+4220|0]=h;c[b+4212>>2]=0;c[b+4216>>2]=1;c[b+12476>>2]=0;c[b+12480>>2]=266;c[b+12484>>2]=0;c[b+12488>>2]=0;h=b+1|0;g=a[h]|80;a[h]=g;do{if((a[b+12436|0]|0)==0){i=g}else{d=b+12520|0;if((a[d]|0)==0){i=g;break}a[d]=0;d=c[b+12524>>2]|0;if((d|0)==0){i=g;break}b3[d&511](c[b+12516>>2]|0,0);i=a[h]|0}}while(0);a[h]=i&95|-128;return}function oG(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((c[b+12444>>2]|0)!=0){return}d=b+2|0;e=a[d]|0;f=b+4220|0;a[f]=e;a[b+4221|0]=c[(c[b+4184>>2]|0)+4>>2]&255;L1842:do{if((e&32)==0){g=b+12437|0;h=a[g]|0;if(h<<24>>24==0){a[f]=-128;i=1;break}a[f]=-64;j=0;while(1){if(j>>>0>=4){i=2;break L1842}k=h&255;l=1<<j;if((k&l|0)==0){j=j+1|0}else{break}}a[f]=(j|192)&255;a[g]=k&(l^255)&255;i=2}else{a[d]=e&31;i=2}}while(0);e=b+12508|0;do{if((a[e]|0)!=0){a[e]=0;d=c[b+12512>>2]|0;if((d|0)==0){break}b3[d&511](c[b+12504>>2]|0,0)}}while(0);c[b+4212>>2]=0;c[b+4216>>2]=i;c[b+12476>>2]=0;c[b+12480>>2]=266;c[b+12484>>2]=0;c[b+12488>>2]=0;i=b+1|0;e=a[i]|80;a[i]=e;do{if((a[b+12436|0]|0)==0){m=e}else{d=b+12520|0;if((a[d]|0)==0){m=e;break}a[d]=0;d=c[b+12524>>2]|0;if((d|0)==0){m=e;break}b3[d&511](c[b+12516>>2]|0,0);m=a[i]|0}}while(0);a[i]=m&95|-128;return}function oH(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((c[b+12444>>2]|0)!=0){return}e=a[b+4197|0]|0;f=b+1|0;g=(1<<(e&3)^255)&d[f]&255;a[f]=g;a[b+2|0]=e&7|32;e=b+12508|0;do{if((a[e]|0)==1){h=g}else{a[e]=1;i=c[b+12512>>2]|0;if((i|0)==0){h=g;break}b3[i&511](c[b+12504>>2]|0,1);h=a[f]|0}}while(0);c[b+12476>>2]=268;c[b+12480>>2]=0;c[b+12484>>2]=0;c[b+12488>>2]=0;g=h&-81;a[f]=g;do{if((a[b+12436|0]|0)==0){j=g}else{h=b+12520|0;if((a[h]|0)==0){j=g;break}a[h]=0;h=c[b+12524>>2]|0;if((h|0)==0){j=g;break}b3[h&511](c[b+12516>>2]|0,0);j=a[f]|0}}while(0);a[f]=j&95|-128;return}function oI(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if((c[b+12444>>2]|0)!=0){return}e=a[b+4197|0]|0;f=b+1|0;g=(1<<(e&3)^255)&d[f]&255;a[f]=g;a[b+2|0]=e&7|32;e=b+12508|0;do{if((a[e]|0)==1){h=g}else{a[e]=1;i=c[b+12512>>2]|0;if((i|0)==0){h=g;break}b3[i&511](c[b+12504>>2]|0,1);h=a[f]|0}}while(0);c[b+12476>>2]=268;c[b+12480>>2]=0;c[b+12484>>2]=0;c[b+12488>>2]=0;g=h&-81;a[f]=g;do{if((a[b+12436|0]|0)==0){j=g}else{h=b+12520|0;if((a[h]|0)==0){j=g;break}a[h]=0;h=c[b+12524>>2]|0;if((h|0)==0){j=g;break}b3[h&511](c[b+12516>>2]|0,0);j=a[f]|0}}while(0);a[f]=j&95|-128;return}function oJ(b){b=b|0;var d=0,e=0,f=0,g=0;d=b+2|0;e=a[b+4197|0]|0;f=e&7|a[d]&-8;a[d]=f;a[b+4220|0]=f;a[b+4221|0]=a[b+3|0]|0;a[b+4222|0]=a[b+4|0]|0;a[b+4223|0]=c[(c[b+4184>>2]|0)+4>>2]&255;a[b+4224|0]=(e&255)>>>2&1;a[b+4225|0]=(a[b+4199|0]|0)+1&255;a[b+4226|0]=a[b+4198|0]|0;c[b+4212>>2]=0;c[b+4216>>2]=7;c[b+12476>>2]=0;c[b+12480>>2]=266;c[b+12484>>2]=0;c[b+12488>>2]=0;e=b+1|0;f=a[e]|80;a[e]=f;do{if((a[b+12436|0]|0)==0){g=f}else{d=b+12520|0;if((a[d]|0)==0){g=f;break}a[d]=0;d=c[b+12524>>2]|0;if((d|0)==0){g=f;break}b3[d&511](c[b+12516>>2]|0,0);g=a[e]|0}}while(0);a[e]=g&95|-128;g=b+12508|0;if((a[g]|0)==1){return}a[g]=1;g=c[b+12512>>2]|0;if((g|0)==0){return}b3[g&511](c[b+12504>>2]|0,1);return}function oK(b,f){b=b|0;f=f|0;var g=0,h=0,i=0;if((c[b+12444>>2]|0)!=0){return}if((e[b+12472>>1]|0)>>>0>=(d[b+4199|0]|0)>>>0){oJ(b);return}c[b+4236>>2]=0;c[b+4240>>2]=4;c[b+12476>>2]=100;c[b+12488>>2]=0;f=b+1|0;g=a[f]|0;h=g&-65;a[f]=h;do{if((a[b+12436|0]|0)==0){a[f]=h|-96;i=b+12508|0;if((a[i]|0)==1){break}a[i]=1;i=c[b+12512>>2]|0;if((i|0)==0){break}b3[i&511](c[b+12504>>2]|0,1)}else{a[f]=g&31;i=b+12520|0;if((a[i]|0)==1){break}a[i]=1;i=c[b+12524>>2]|0;if((i|0)==0){break}b3[i&511](c[b+12516>>2]|0,1)}}while(0);a[f]=a[f]|16;return}function oL(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;i=i+24|0;h=g|0;j=e+4236|0;k=c[j>>2]|0;c[j>>2]=k+1;a[e+4244+k|0]=f;if((c[j>>2]|0)>>>0<4){i=g;return}do{if((a[e+12436|0]|0)!=0){j=e+12520|0;if((a[j]|0)==0){break}a[j]=0;j=c[e+12524>>2]|0;if((j|0)==0){break}b3[j&511](c[e+12516>>2]|0,0)}}while(0);j=c[e+4184>>2]|0;f=c[j>>2]|0;k=c[j+4>>2]|0;l=c[j+8>>2]|0;m=d[e+4198|0]|0;n=d[e+4200|0]|0;o=a[e+4201|0]|0;a[j+12|0]=0;j=e+12472|0;p=b[j>>1]|0;q=e+4244|0;r=c[e+12500>>2]|0;do{if((r|0)!=0){s=a[q]|0;t=e+4245|0;u=a[t]|0;v=e+4246|0;w=a[v]|0;x=e+4247|0;y=a[x]|0;a[h|0]=f&255;a[h+1|0]=k&255;a[h+2|0]=l&255;a[h+3|0]=p&255;a[h+4|0]=s;a[h+5|0]=u;a[h+6|0]=w;a[h+7|0]=y;c[h+8>>2]=0;c[h+12>>2]=0;a[h+16|0]=o;if((b4[r&127](c[e+12496>>2]|0,3,h)|0)!=0){break}a[e+4223|0]=a[q]|0;a[e+4224|0]=a[t]|0;a[e+4225|0]=(a[v]|0)+1&255;a[e+4226|0]=a[x]|0;x=(b[j>>1]|0)+1&65535;b[j>>1]=x;do{if((x&65535)>>>0<(d[e+4199|0]|0)>>>0){v=(128<<m)+62+n<<3;if((a[e+12440|0]|0)!=0){t=z4(c[e+12448>>2]|0,0,v,0)|0;y=z5(t,G,25e4,0)|0;c[e+12444>>2]=y;break}y=e+12452|0;t=(c[y>>2]|0)+v|0;c[y>>2]=t;v=c[e+12460>>2]|0;if(t>>>0>=v>>>0){w=e+12464|0;u=t;t=b[w>>1]|0;do{u=u-v|0;t=t+1&65535;}while(u>>>0>=v>>>0);c[y>>2]=u;b[w>>1]=t}c[e+12444>>2]=0}else{v=c[e+12460>>2]|0;s=e+12452|0;if((a[e+12440|0]|0)!=0){z=z4(c[e+12448>>2]|0,0,v-(c[s>>2]|0)|0,0)|0;A=z5(z,G,25e4,0)|0;c[e+12444>>2]=A;break}c[s>>2]=v;A=e+12464|0;z=v;B=b[A>>1]|0;do{z=z-v|0;B=B+1&65535;}while(z>>>0>=v>>>0);c[s>>2]=z;b[A>>1]=B;c[e+12444>>2]=0}}while(0);c[e+12476>>2]=0;c[e+12488>>2]=458;i=g;return}}while(0);a[e+2|0]=64;n=e+3|0;a[n]=a[n]|2;oJ(e);i=g;return}function oM(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;e=i;i=i+24|0;f=e|0;g=c[d+4184>>2]|0;h=g+12|0;if((a[h]|0)!=0){i=e;return}j=g+16|0;c[j>>2]=0;k=g|0;l=g+4|0;m=g+8|0;n=f|0;o=d+12500|0;p=f+1|0;q=f+2|0;r=f+3|0;s=f+4|0;t=f+5|0;u=f+6|0;v=f+7|0;w=d+12496|0;x=0;y=0;while(1){z=c[l>>2]|0;A=c[m>>2]|0;B=c[o>>2]|0;if((B|0)==0){C=y;break}a[n]=c[k>>2]&255;a[p]=z&255;a[q]=A&255;a[r]=x&255;zP(s|0,0,13);A=b4[B&127](c[w>>2]|0,4,f)|0;B=a[t]|0;z=a[u]|0;D=a[v]|0;if((A|0)!=0){E=1584;break}a[g+20+(x<<3)|0]=a[s]|0;a[g+20+(x<<3)+1|0]=B;a[g+20+(x<<3)+2|0]=z;b[g+20+(x<<3)+4>>1]=D&255;D=(c[j>>2]|0)+1|0;c[j>>2]=D;z=x+1|0;if(z>>>0<128){x=z;y=D}else{C=D;break}}if((E|0)==1584){C=c[j>>2]|0}if((C|0)!=0){E=(c[d+12460>>2]<<1)-2400|0;d=0;y=C;do{b[g+20+(d<<3)+6>>1]=(((ac(E,d)|0)>>>0)/((y<<1|1)>>>0)|0)+1200&65535;d=d+1|0;y=c[j>>2]|0;}while(d>>>0<y>>>0)}a[h]=1;i=e;return}function oN(b){b=b|0;var d=0,e=0,f=0,g=0;d=b+2|0;e=a[b+4197|0]&7|a[d]&-8;a[d]=e;a[b+4220|0]=e;a[b+4221|0]=a[b+3|0]|0;a[b+4222|0]=a[b+4|0]|0;a[b+4223|0]=a[b+4198|0]|0;a[b+4224|0]=a[b+4199|0]|0;a[b+4225|0]=a[b+4200|0]|0;a[b+4226|0]=a[b+4201|0]|0;c[b+4212>>2]=0;c[b+4216>>2]=7;c[b+12476>>2]=0;c[b+12480>>2]=266;c[b+12484>>2]=0;c[b+12488>>2]=0;e=b+1|0;d=a[e]|80;a[e]=d;do{if((a[b+12436|0]|0)==0){f=d}else{g=b+12520|0;if((a[g]|0)==0){f=d;break}a[g]=0;g=c[b+12524>>2]|0;if((g|0)==0){f=d;break}b3[g&511](c[b+12516>>2]|0,0);f=a[e]|0}}while(0);a[e]=f&95|-128;f=b+12508|0;if((a[f]|0)==1){return}a[f]=1;f=c[b+12512>>2]|0;if((f|0)==0){return}b3[f&511](c[b+12504>>2]|0,1);return}function oO(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=f+12464|0;h=b[g>>1]|0;if((h&65535)>1){i=f+2|0;a[i]=a[i]&63|64;i=f+3|0;a[i]=a[i]|1;oN(f);return}i=f+12444|0;if((c[i>>2]|0)!=0){return}j=c[f+4184>>2]|0;k=j+16|0;l=c[k>>2]|0;m=(l|0)==0;do{if(m){n=0;o=0}else{p=f+12452|0;q=0;while(1){if(q>>>0>=l>>>0){r=1614;break}if((e[j+20+(q<<3)+6>>1]|0)>>>0>(c[p>>2]|0)>>>0){r=1611;break}else{q=q+1|0}}do{if((r|0)==1611){if((q|0)==0){s=l;break}else{s=q;break}}else if((r|0)==1614){s=l}}while(0);q=s-1|0;if(m){n=0;o=q;break}p=f+12452|0;t=0;while(1){if(t>>>0>=l>>>0){r=1622;break}if((e[j+20+(t<<3)+6>>1]|0)>>>0>(c[p>>2]|0)>>>0){break}else{t=t+1|0}}if((r|0)==1622){n=l-1|0;o=q;break}if((t|0)==0){n=l-1|0;o=q;break}else{n=t-1|0;o=q;break}}}while(0);r=n+1|0;n=r>>>0<l>>>0?r:0;do{if(l>>>0>n>>>0){r=e[j+20+(n<<3)+6>>1]|0;m=f+12452|0;s=c[m>>2]|0;p=r-s|0;if(r>>>0<s>>>0){u=(c[f+12460>>2]|0)+p|0}else{u=p}p=u+128|0;if((a[f+12440|0]|0)!=0){r=z4(c[f+12448>>2]|0,0,p,0)|0;v=z5(r,G,25e4,0)|0;c[i>>2]=v;break}v=s+p|0;c[m>>2]=v;p=c[f+12460>>2]|0;if(v>>>0>=p>>>0){s=v;v=h;do{s=s-p|0;v=v+1&65535;}while(s>>>0>=p>>>0);c[m>>2]=s;b[g>>1]=v}c[i>>2]=0}else{p=c[f+12460>>2]|0;q=f+12452|0;if((a[f+12440|0]|0)!=0){t=z4(c[f+12448>>2]|0,0,p-(c[q>>2]|0)|0,0)|0;r=z5(t,G,25e4,0)|0;c[i>>2]=r;break}c[q>>2]=p;r=p;t=h;do{r=r-p|0;t=t+1&65535;}while(r>>>0>=p>>>0);c[q>>2]=r;b[g>>1]=t;c[i>>2]=0}}while(0);if((a[f+4196|0]&64)==0){return}i=a[f+4201|0]|0;h=i&255;if(o>>>0>=(c[k>>2]|0)>>>0){return}if((a[j+20+(o<<3)|0]|0)!=(a[f+4198|0]|0)){return}if((a[j+20+(o<<3)+1|0]|0)!=(a[f+4199|0]|0)){return}if((a[j+20+(o<<3)+2|0]|0)!=(a[f+4200|0]|0)){return}if((e[j+20+(o<<3)+4>>1]|0)>>>0<h>>>0){return}b[g>>1]=0;if((i&255)>6){g=f+2|0;a[g]=a[g]&63|64;oN(f);return}c[f+4236>>2]=0;if(i<<24>>24==0){c[f+4240>>2]=d[f+4204|0]|0}else{c[f+4240>>2]=128<<h}b[f+12470>>1]=o&65535;c[f+12476>>2]=26;c[f+12488>>2]=0;o=f+1|0;h=a[o]|0;i=h&-65;a[o]=i;do{if((a[f+12436|0]|0)==0){a[o]=i|-96;g=f+12508|0;if((a[g]|0)==1){break}a[g]=1;g=c[f+12512>>2]|0;if((g|0)==0){break}b3[g&511](c[f+12504>>2]|0,1)}else{a[o]=h&31;g=f+12520|0;if((a[g]|0)==1){break}a[g]=1;g=c[f+12524>>2]|0;if((g|0)==0){break}b3[g&511](c[f+12516>>2]|0,1)}}while(0);a[o]=a[o]|16;return}function oP(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=i;i=i+24|0;g=f|0;h=d+4236|0;j=c[h>>2]|0;c[h>>2]=j+1;a[d+4244+j|0]=e;e=d+4240|0;j=c[e>>2]|0;if((c[h>>2]|0)>>>0<j>>>0){i=f;return}do{if((a[d+12436|0]|0)==0){k=j}else{h=d+12520|0;if((a[h]|0)==0){k=j;break}a[h]=0;h=c[d+12524>>2]|0;if((h|0)==0){k=j;break}b3[h&511](c[d+12516>>2]|0,0);k=c[e>>2]|0}}while(0);e=d+4244|0;j=d+4184|0;h=c[j>>2]|0;l=c[h>>2]|0;m=c[h+4>>2]|0;n=c[h+8>>2]|0;h=b[d+12470>>1]|0;o=d+4200|0;p=a[o]|0;q=g|0;r=c[d+12500>>2]|0;do{if((r|0)==0){s=2}else{if(k>>>0>8192){s=1;break}a[q]=l&255;a[g+1|0]=m&255;a[g+2|0]=n&255;a[g+3|0]=h&255;a[g+4|0]=0;a[g+5|0]=0;a[g+6|0]=p;a[g+7|0]=0;c[g+8>>2]=e;c[g+12>>2]=k;a[g+16|0]=0;t=b4[r&127](c[d+12496>>2]|0,1,g)|0;if((t|0)!=0){s=t;break}t=a[o]|0;do{if((a[d+12441|0]|0)==0){if(t<<24>>24!=(a[d+4202|0]|0)){u=1682;break}a[o]=1;do{if((a[d+4196|0]|0)<0){v=d+4197|0;w=a[v]^4;a[v]=w;v=d+4199|0;a[v]=a[v]^1;if((w&4)!=0){x=v;break}w=d+4198|0;a[w]=(a[w]|0)+1&255;x=v}else{v=d+4198|0;a[v]=(a[v]|0)+1&255;x=d+4199|0}}while(0);a[(c[j>>2]|0)+12|0]=0;c[(c[j>>2]|0)+8>>2]=a[x]&1;c[(c[j>>2]|0)+16>>2]=0;oM(d)}else{u=1682}}while(0);if((u|0)==1682){a[o]=t+1&255}c[d+12476>>2]=0;c[d+12488>>2]=178;i=f;return}}while(0);o=d+2|0;a[o]=a[o]&63|64;if((s&128|0)!=0){o=d+3|0;a[o]=a[o]|2}if((s&2|0)!=0){s=d+3|0;a[s]=a[s]|1}oN(d);i=f;return}function oQ(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((e[d+12464>>1]|0)>1){f=a[d+4197|0]&7|64;a[d+2|0]=f;g=d+3|0;h=a[g]|5;a[g]=h;a[d+4220|0]=f;a[d+4221|0]=h;a[d+4222|0]=a[d+4|0]|0;c[d+4212>>2]=0;h=d+4223|0;y=0;a[h]=y&255;y=y>>8;a[h+1|0]=y&255;y=y>>8;a[h+2|0]=y&255;y=y>>8;a[h+3|0]=y&255;c[d+4216>>2]=7;c[d+12476>>2]=0;c[d+12480>>2]=266;c[d+12484>>2]=0;c[d+12488>>2]=0;h=d+1|0;f=a[h]|80;a[h]=f;do{if((a[d+12436|0]|0)==0){i=f}else{g=d+12520|0;if((a[g]|0)==0){i=f;break}a[g]=0;g=c[d+12524>>2]|0;if((g|0)==0){i=f;break}b3[g&511](c[d+12516>>2]|0,0);i=a[h]|0}}while(0);a[h]=i&95|-128;i=d+12508|0;if((a[i]|0)==1){return}a[i]=1;i=c[d+12512>>2]|0;if((i|0)==0){return}b3[i&511](c[d+12504>>2]|0,1);return}i=d+12444|0;if((c[i>>2]|0)!=0){return}h=c[d+4184>>2]|0;f=h+16|0;g=c[f>>2]|0;do{if((g|0)==0){j=0}else{k=d+12452|0;l=0;while(1){if(l>>>0>=g>>>0){m=1709;break}if((e[h+20+(l<<3)+6>>1]|0)>>>0>(c[k>>2]|0)>>>0){break}else{l=l+1|0}}if((m|0)==1709){j=g-1|0;break}if((l|0)==0){j=g-1|0;break}else{j=l-1|0;break}}}while(0);k=j+1|0;j=k>>>0<g>>>0?k:0;if(g>>>0>j>>>0){g=e[h+20+(j<<3)+6>>1]|0;j=c[d+12452>>2]|0;k=g-j|0;if(g>>>0<j>>>0){n=(c[d+12460>>2]|0)+k|0}else{n=k}k=z4(c[d+12448>>2]|0,0,n+128|0,0)|0;o=G;p=k;q=j}else{j=c[d+12452>>2]|0;k=z4(c[d+12448>>2]|0,0,(c[d+12460>>2]|0)-j|0,0)|0;o=G;p=k;q=j}j=z5(p,o,25e4,0)|0;c[i>>2]=j;if((a[d+4196|0]&64)==0){return}j=c[f>>2]|0;do{if((j|0)==0){r=0}else{f=0;while(1){if(f>>>0>=j>>>0){m=1722;break}if((e[h+20+(f<<3)+6>>1]|0)>>>0>q>>>0){break}else{f=f+1|0}}if((m|0)==1722){r=j-1|0;break}if((f|0)==0){r=j-1|0;break}else{r=f-1|0;break}}}while(0);if(r>>>0>=j>>>0){return}j=d+2|0;m=a[d+4197|0]&7|a[j]&-8;a[j]=m;a[d+4220|0]=m;a[d+4221|0]=a[d+3|0]|0;a[d+4222|0]=a[d+4|0]|0;a[d+4223|0]=a[h+20+(r<<3)|0]|0;a[d+4224|0]=a[h+20+(r<<3)+1|0]|0;a[d+4225|0]=a[h+20+(r<<3)+2|0]|0;a[d+4226|0]=b[h+20+(r<<3)+4>>1]&255;c[d+4212>>2]=0;c[d+4216>>2]=7;c[d+12476>>2]=0;c[d+12480>>2]=266;c[d+12484>>2]=0;c[d+12488>>2]=0;r=d+1|0;h=a[r]|80;a[r]=h;do{if((a[d+12436|0]|0)==0){s=h}else{m=d+12520|0;if((a[m]|0)==0){s=h;break}a[m]=0;m=c[d+12524>>2]|0;if((m|0)==0){s=h;break}b3[m&511](c[d+12516>>2]|0,0);s=a[r]|0}}while(0);a[r]=s&95|-128;s=d+12508|0;if((a[s]|0)==1){return}a[s]=1;s=c[d+12512>>2]|0;if((s|0)==0){return}b3[s&511](c[d+12504>>2]|0,1);return}function oR(d,f){d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+24|0;g=f|0;h=d+12464|0;j=b[h>>1]|0;if((j&65535)>1){k=d+2|0;a[k]=a[k]&63|64;k=d+3|0;a[k]=a[k]|1;oS(d);i=f;return}k=d+12444|0;if((c[k>>2]|0)!=0){i=f;return}l=c[d+4184>>2]|0;m=l+16|0;n=c[m>>2]|0;o=(n|0)==0;do{if(o){p=0;q=0}else{r=d+12452|0;s=0;while(1){if(s>>>0>=n>>>0){t=1751;break}if((e[l+20+(s<<3)+6>>1]|0)>>>0>(c[r>>2]|0)>>>0){t=1748;break}else{s=s+1|0}}do{if((t|0)==1748){if((s|0)==0){u=n;break}else{u=s;break}}else if((t|0)==1751){u=n}}while(0);s=u-1|0;if(o){p=0;q=s;break}r=d+12452|0;v=0;while(1){if(v>>>0>=n>>>0){t=1759;break}if((e[l+20+(v<<3)+6>>1]|0)>>>0>(c[r>>2]|0)>>>0){break}else{v=v+1|0}}if((t|0)==1759){p=n-1|0;q=s;break}if((v|0)==0){p=n-1|0;q=s;break}else{p=v-1|0;q=s;break}}}while(0);t=p+1|0;p=t>>>0<n>>>0?t:0;do{if(n>>>0>p>>>0){t=e[l+20+(p<<3)+6>>1]|0;o=d+12452|0;u=c[o>>2]|0;r=t-u|0;if(t>>>0<u>>>0){w=(c[d+12460>>2]|0)+r|0}else{w=r}r=w+128|0;if((a[d+12440|0]|0)!=0){t=z4(c[d+12448>>2]|0,0,r,0)|0;x=z5(t,G,25e4,0)|0;c[k>>2]=x;break}x=u+r|0;c[o>>2]=x;r=c[d+12460>>2]|0;if(x>>>0>=r>>>0){u=x;x=j;do{u=u-r|0;x=x+1&65535;}while(u>>>0>=r>>>0);c[o>>2]=u;b[h>>1]=x}c[k>>2]=0}else{r=c[d+12460>>2]|0;s=d+12452|0;if((a[d+12440|0]|0)!=0){v=z4(c[d+12448>>2]|0,0,r-(c[s>>2]|0)|0,0)|0;t=z5(v,G,25e4,0)|0;c[k>>2]=t;break}c[s>>2]=r;t=r;v=j;do{t=t-r|0;v=v+1&65535;}while(t>>>0>=r>>>0);c[s>>2]=t;b[h>>1]=v;c[k>>2]=0}}while(0);if((a[d+4196|0]&64)==0){i=f;return}if(q>>>0>=(c[m>>2]|0)>>>0){i=f;return}b[h>>1]=0;do{if((a[l+20+(q<<3)|0]|0)==(a[d+4198|0]|0)){if((a[l+20+(q<<3)+1|0]|0)!=(a[d+4199|0]|0)){break}if((a[l+20+(q<<3)+2|0]|0)!=(a[d+4200|0]|0)){break}h=d+3|0;a[h]=a[h]&-5}}while(0);h=c[l>>2]|0;m=c[l+4>>2]|0;k=c[l+8>>2]|0;j=a[l+20+(q<<3)+2|0]|0;l=c[d+12500>>2]|0;do{if((l|0)==0){c[d+4236>>2]=0;c[d+4240>>2]=8192;y=1}else{a[g|0]=h&255;a[g+1|0]=m&255;a[g+2|0]=k&255;a[g+3|0]=q&255;a[g+4|0]=0;a[g+5|0]=0;a[g+6|0]=j;a[g+7|0]=0;c[g+8>>2]=d+4244;w=g+12|0;c[w>>2]=8192;a[g+16|0]=0;p=b4[l&127](c[d+12496>>2]|0,0,g)|0;n=c[w>>2]|0;do{if((p&8|0)==0){if((p&16|0)==0){break}w=d+3|0;a[w]=a[w]|32;w=d+4|0;a[w]=a[w]|32}else{w=d+3|0;a[w]=a[w]|32}}while(0);c[d+4236>>2]=0;c[d+4240>>2]=n;if((p&-89|0)!=0){y=(p&2|0)==0?-124:1;break}if((n|0)==0){i=f;return}v=d+1|0;t=a[v]|0;s=t|64;a[v]=s;do{if((a[d+12436|0]|0)==0){a[v]=t|-32;w=d+12508|0;if((a[w]|0)==1){break}a[w]=1;w=c[d+12512>>2]|0;if((w|0)==0){break}b3[w&511](c[d+12504>>2]|0,1)}else{a[v]=s&95;w=d+12520|0;if((a[w]|0)==1){break}a[w]=1;w=c[d+12524>>2]|0;if((w|0)==0){break}b3[w&511](c[d+12516>>2]|0,1)}}while(0);a[v]=a[v]|16;c[d+12488>>2]=0;c[d+12480>>2]=380;i=f;return}}while(0);g=d+2|0;a[g]=a[g]&63|64;g=d+3|0;a[g]=y|a[g];oS(d);i=f;return}function oS(b){b=b|0;var d=0,e=0,f=0,g=0;d=b+2|0;e=a[b+4197|0]&7|a[d]&-8;a[d]=e;a[b+4220|0]=e;a[b+4221|0]=a[b+3|0]|0;a[b+4222|0]=a[b+4|0]|0;a[b+4223|0]=a[b+4198|0]|0;a[b+4224|0]=a[b+4199|0]|0;a[b+4225|0]=a[b+4200|0]|0;a[b+4226|0]=a[b+4201|0]|0;c[b+4212>>2]=0;c[b+4216>>2]=7;c[b+12476>>2]=0;c[b+12480>>2]=266;c[b+12484>>2]=0;c[b+12488>>2]=0;e=b+1|0;d=a[e]|80;a[e]=d;do{if((a[b+12436|0]|0)==0){f=d}else{g=b+12520|0;if((a[g]|0)==0){f=d;break}a[g]=0;g=c[b+12524>>2]|0;if((g|0)==0){f=d;break}b3[g&511](c[b+12516>>2]|0,0);f=a[e]|0}}while(0);a[e]=f&95|-128;f=b+12508|0;if((a[f]|0)==1){return}a[f]=1;f=c[b+12512>>2]|0;if((f|0)==0){return}b3[f&511](c[b+12504>>2]|0,1);return}function oT(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=e+4236|0;g=c[f>>2]|0;h=g+1|0;c[f>>2]=h;i=a[e+4244+g|0]|0;g=e+12436|0;do{if((a[g]|0)==0){j=h}else{k=e+12520|0;if((a[k]|0)==0){j=h;break}a[k]=0;k=c[e+12524>>2]|0;if((k|0)==0){j=h;break}b3[k&511](c[e+12516>>2]|0,0);j=c[f>>2]|0}}while(0);f=e+1|0;h=a[f]|0;if(j>>>0>=(c[e+4240>>2]|0)>>>0){a[f]=h&63;j=e+12468|0;k=(b[j>>1]|0)+1&65535;b[j>>1]=k;if((k&65535)>>>0<(d[e+4202|0]|0)>>>0){c[e+12480>>2]=0;c[e+12488>>2]=452;return i|0}else{oS(e);return i|0}}k=h|64;a[f]=k;do{if((a[g]|0)==0){a[f]=h|-32;j=e+12508|0;if((a[j]|0)==1){break}a[j]=1;j=c[e+12512>>2]|0;if((j|0)==0){break}b3[j&511](c[e+12504>>2]|0,1)}else{a[f]=k&95;j=e+12520|0;if((a[j]|0)==1){break}a[j]=1;j=c[e+12524>>2]|0;if((j|0)==0){break}b3[j&511](c[e+12516>>2]|0,1)}}while(0);a[f]=a[f]|16;return i|0}function oU(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;g=i;i=i+24|0;h=g|0;j=f+12464|0;k=b[j>>1]|0;if((k&65535)>1){a[f+12466|0]=1;l=f+2|0;a[l]=a[l]&63|64;l=f+3|0;a[l]=a[l]|5;oY(f);i=g;return}l=f+12444|0;if((c[l>>2]|0)!=0){i=g;return}m=f+4184|0;n=c[m>>2]|0;o=n+16|0;p=c[o>>2]|0;q=(p|0)==0;do{if(q){r=0;s=0}else{t=f+12452|0;u=0;while(1){if(u>>>0>=p>>>0){v=1847;break}if((e[n+20+(u<<3)+6>>1]|0)>>>0>(c[t>>2]|0)>>>0){v=1844;break}else{u=u+1|0}}do{if((v|0)==1844){if((u|0)==0){w=p;break}else{w=u;break}}else if((v|0)==1847){w=p}}while(0);u=w-1|0;if(q){r=0;s=u;break}t=f+12452|0;x=0;while(1){if(x>>>0>=p>>>0){v=1855;break}if((e[n+20+(x<<3)+6>>1]|0)>>>0>(c[t>>2]|0)>>>0){break}else{x=x+1|0}}if((v|0)==1855){r=p-1|0;s=u;break}if((x|0)==0){r=p-1|0;s=u;break}else{r=x-1|0;s=u;break}}}while(0);q=r+1|0;r=q>>>0<p>>>0?q:0;do{if(p>>>0>r>>>0){q=e[n+20+(r<<3)+6>>1]|0;w=f+12452|0;t=c[w>>2]|0;y=q-t|0;if(q>>>0<t>>>0){z=(c[f+12460>>2]|0)+y|0}else{z=y}y=z+128|0;if((a[f+12440|0]|0)!=0){q=z4(c[f+12448>>2]|0,0,y,0)|0;A=z5(q,G,25e4,0)|0;c[l>>2]=A;break}A=t+y|0;c[w>>2]=A;y=c[f+12460>>2]|0;if(A>>>0>=y>>>0){t=A;A=k;do{t=t-y|0;A=A+1&65535;}while(t>>>0>=y>>>0);c[w>>2]=t;b[j>>1]=A}c[l>>2]=0}else{y=c[f+12460>>2]|0;u=f+12452|0;if((a[f+12440|0]|0)!=0){x=z4(c[f+12448>>2]|0,0,y-(c[u>>2]|0)|0,0)|0;q=z5(x,G,25e4,0)|0;c[l>>2]=q;break}c[u>>2]=y;q=y;x=k;do{q=q-y|0;x=x+1&65535;}while(q>>>0>=y>>>0);c[u>>2]=q;b[j>>1]=x;c[l>>2]=0}}while(0);l=f+4196|0;if((a[l]&64)==0){i=g;return}k=f+4199|0;z=f+4200|0;r=a[z]|0;p=a[f+4201|0]|0;y=p&255;if(s>>>0>=(c[o>>2]|0)>>>0){i=g;return}o=f+4198|0;if((a[n+20+(s<<3)|0]|0)!=(a[o]|0)){i=g;return}if((a[n+20+(s<<3)+1|0]|0)!=(a[k]|0)){i=g;return}if((a[n+20+(s<<3)+2|0]|0)!=r<<24>>24){i=g;return}if((e[n+20+(s<<3)+4>>1]|0)>>>0<y>>>0){i=g;return}b[j>>1]=0;if((p&255)>6){a[f+12466|0]=1;j=f+2|0;a[j]=a[j]&63|64;j=f+3|0;a[j]=a[j]|-124;oY(f);i=g;return}if(p<<24>>24==0){B=d[f+4204|0]|0}else{B=128<<y}y=f+4244|0;p=c[n>>2]|0;j=c[n+4>>2]|0;A=c[n+8>>2]|0;n=h|0;t=c[f+12500>>2]|0;do{if((t|0)==0){C=B;D=2;v=1896}else{if(B>>>0>8192){C=0;D=1;v=1896;break}a[n]=p&255;a[h+1|0]=j&255;a[h+2|0]=A&255;a[h+3|0]=s&255;a[h+4|0]=0;a[h+5|0]=0;a[h+6|0]=r;a[h+7|0]=0;c[h+8>>2]=y;w=h+12|0;c[w>>2]=B;a[h+16|0]=0;E=b4[t&127](c[f+12496>>2]|0,0,h)|0;F=c[w>>2]|0;if((E&12|0)==0){do{if((E&32|0)==0){H=1}else{w=a[l]|0;if((w&32)==0){H=0;break}I=a[z]|0;do{if((a[f+12441|0]|0)==0){if(I<<24>>24!=(a[f+4202|0]|0)){v=1901;break}a[z]=1;do{if(w<<24>>24<0){J=f+4197|0;K=a[J]^4;a[J]=K;a[k]=a[k]^1;if((K&4)!=0){break}a[o]=(a[o]|0)+1&255}else{a[o]=(a[o]|0)+1&255}}while(0);a[(c[m>>2]|0)+12|0]=0;c[(c[m>>2]|0)+8>>2]=a[k]&1;c[(c[m>>2]|0)+16>>2]=0;oM(f)}else{v=1901}}while(0);if((v|0)==1901){a[z]=I+1&255}w=f+4|0;a[w]=a[w]|64;i=g;return}}while(0);c[f+4236>>2]=0;c[f+4240>>2]=F;if((E|0)==0){L=F;break}else{M=H;N=F;O=E;v=1909;break}}else{a[f+12466|0]=1;x=f+2|0;a[x]=a[x]&63|64;do{if((E&2|0)==0){if((E&8|0)!=0){x=f+3|0;a[x]=a[x]|32;break}if((E&4|0)!=0){x=f+3|0;a[x]=a[x]|1;x=f+4|0;a[x]=a[x]|1;break}if((E&32|0)!=0){x=f+4|0;a[x]=a[x]|64;break}x=f+3|0;q=a[x]|0;if((E&16|0)==0){a[x]=q|-124;break}else{a[x]=q|32;q=f+4|0;a[q]=a[q]|32;break}}else{q=f+3|0;a[q]=a[q]|5}}while(0);oY(f);i=g;return}}}while(0);if((v|0)==1896){c[f+4236>>2]=0;c[f+4240>>2]=C;M=1;N=C;O=D;v=1909}do{if((v|0)==1909){a[f+12466|0]=1;D=f+2|0;a[D]=a[D]&63|64;if((O&2|0)!=0){D=f+3|0;a[D]=a[D]|5;L=N;break}if((O&8|0)!=0){D=f+3|0;a[D]=a[D]|32;L=N;break}if((O&4|0)!=0){D=f+3|0;a[D]=a[D]|1;D=f+4|0;a[D]=a[D]|1;L=N;break}if(!M){D=f+4|0;a[D]=a[D]|64;L=N;break}D=f+3|0;C=a[D]|0;if((O&16|0)==0){a[D]=C|-124;L=N;break}else{a[D]=C|32;C=f+4|0;a[C]=a[C]|32;L=N;break}}}while(0);if((L|0)==0){oY(f);i=g;return}L=f+1|0;N=a[L]|0;O=N|64;a[L]=O;do{if((a[f+12436|0]|0)==0){a[L]=N|-32;M=f+12508|0;if((a[M]|0)==1){break}a[M]=1;M=c[f+12512>>2]|0;if((M|0)==0){break}b3[M&511](c[f+12504>>2]|0,1)}else{a[L]=O&95;M=f+12520|0;if((a[M]|0)==1){break}a[M]=1;M=c[f+12524>>2]|0;if((M|0)==0){break}b3[M&511](c[f+12516>>2]|0,1)}}while(0);a[L]=a[L]|16;c[f+12488>>2]=0;c[f+12480>>2]=6;i=g;return}function oV(b,d){b=b|0;d=d|0;a[b+2152|0]=1;c[b+2156>>2]=d;c[b+2160>>2]=d;d=b+2208|0;a[d]=a[d]|1;return}function oW(a){a=a|0;return(d[a+88|0]|0)<<8|(d[a+89|0]|0)|0}function oX(a){a=a|0;return(d[a+90|0]|0)<<8|(d[a+91|0]|0)|0}function oY(b){b=b|0;var d=0,e=0,f=0,g=0;d=b+2|0;e=a[b+4197|0]&7|a[d]&-8;a[d]=e;a[b+4220|0]=e;a[b+4221|0]=a[b+3|0]|0;a[b+4222|0]=a[b+4|0]|0;a[b+4223|0]=a[b+4198|0]|0;a[b+4224|0]=a[b+4199|0]|0;a[b+4225|0]=a[b+4200|0]|0;a[b+4226|0]=a[b+4201|0]|0;c[b+4212>>2]=0;c[b+4216>>2]=7;c[b+12476>>2]=0;c[b+12480>>2]=266;c[b+12484>>2]=0;c[b+12488>>2]=0;e=b+1|0;d=a[e]|80;a[e]=d;do{if((a[b+12436|0]|0)==0){f=d}else{g=b+12520|0;if((a[g]|0)==0){f=d;break}a[g]=0;g=c[b+12524>>2]|0;if((g|0)==0){f=d;break}b3[g&511](c[b+12516>>2]|0,0);f=a[e]|0}}while(0);a[e]=f&95|-128;f=b+12508|0;if((a[f]|0)==1){return}a[f]=1;f=c[b+12512>>2]|0;if((f|0)==0){return}b3[f&511](c[b+12504>>2]|0,1);return}function oZ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=b+4236|0;e=c[d>>2]|0;f=e+1|0;c[d>>2]=f;g=a[b+4244+e|0]|0;e=b+12436|0;do{if((a[e]|0)==0){h=f}else{i=b+12520|0;if((a[i]|0)==0){h=f;break}a[i]=0;i=c[b+12524>>2]|0;if((i|0)==0){h=f;break}b3[i&511](c[b+12516>>2]|0,0);h=c[d>>2]|0}}while(0);d=b+1|0;f=a[d]|0;if(h>>>0<(c[b+4240>>2]|0)>>>0){h=f|64;a[d]=h;do{if((a[e]|0)==0){a[d]=f|-32;i=b+12508|0;if((a[i]|0)==1){break}a[i]=1;i=c[b+12512>>2]|0;if((i|0)==0){break}b3[i&511](c[b+12504>>2]|0,1)}else{a[d]=h&95;i=b+12520|0;if((a[i]|0)==1){break}a[i]=1;i=c[b+12524>>2]|0;if((i|0)==0){break}b3[i&511](c[b+12516>>2]|0,1)}}while(0);a[d]=a[d]|16;return g|0}a[d]=f&63;c[b+12480>>2]=0;c[b+12488>>2]=2;if((a[b+12466|0]|0)!=0){oY(b);return g|0}f=b+4200|0;d=a[f]|0;do{if((a[b+12441|0]|0)==0){if(d<<24>>24!=(a[b+4202|0]|0)){break}a[f]=1;do{if((a[b+4196|0]|0)<0){h=b+4197|0;e=a[h]^4;a[h]=e;h=b+4199|0;a[h]=a[h]^1;if((e&4)!=0){j=h;break}e=b+4198|0;a[e]=(a[e]|0)+1&255;j=h}else{h=b+4198|0;a[h]=(a[h]|0)+1&255;j=b+4199|0}}while(0);h=b+4184|0;a[(c[h>>2]|0)+12|0]=0;c[(c[h>>2]|0)+8>>2]=a[j]&1;c[(c[h>>2]|0)+16>>2]=0;oM(b);return g|0}}while(0);a[f]=d+1&255;return g|0}function o_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=ac(b*3|0,d)|0;f=a+2200|0;do{if(e>>>0>(c[f>>2]|0)>>>0){g=a+2204|0;h=zJ(c[g>>2]|0,e)|0;if((h|0)==0){i=1;return i|0}else{c[g>>2]=h;c[f>>2]=e;break}}}while(0);c[a+2192>>2]=b;c[a+2196>>2]=d;i=0;return i|0}function o$(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0.0,ar=0.0,as=0.0,at=0.0,au=0.0,av=0.0,aw=0.0,ax=0.0,ay=0.0,az=0.0,aA=0.0,aB=0.0,aC=0.0,aD=0.0,aE=0.0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0;e=b+2192|0;c[e>>2]=0;f=b+2196|0;c[f>>2]=0;g=b+68|0;h=c[g>>2]|0;i=d[h+4|0]|0;if((i&8|0)==0){j=b+2200|0;k=b+2204|0;do{if((c[j>>2]|0)>>>0<384e3){l=zJ(c[k>>2]|0,384e3)|0;if((l|0)!=0){c[k>>2]=l;c[j>>2]=384e3;m=1997;break}l=c[f>>2]|0;if((l|0)==0){return}else{n=l;o=c[e>>2]|0;break}}else{m=1997}}while(0);if((m|0)==1997){c[e>>2]=640;c[f>>2]=200;n=200;o=640}m=0;j=c[k>>2]|0;k=o;o=n;while(1){n=(m&8)>>>0<8;if((k|0)==0){p=j;q=0;r=o}else{l=0;s=j;do{t=(l&8)>>>0<8^n?32:0;a[s]=t;a[s+1|0]=t;a[s+2|0]=t;s=s+3|0;l=l+1|0;u=c[e>>2]|0;}while(l>>>0<u>>>0);p=s;q=u;r=c[f>>2]|0}l=m+1|0;if(l>>>0<r>>>0){m=l;j=p;k=q;o=r}else{break}}return}if((i&2|0)==0){r=b+2164|0;o=c[r>>2]|0;q=o<<3;k=b+2172|0;p=b+2168|0;j=c[p>>2]|0;m=ac(j,c[k>>2]|0)|0;u=ac(o*24|0,m)|0;o=b+2200|0;do{if(u>>>0>(c[o>>2]|0)>>>0){l=b+2204|0;n=zJ(c[l>>2]|0,u)|0;if((n|0)==0){return}else{c[l>>2]=n;c[o>>2]=u;v=c[p>>2]|0;break}}else{v=j}}while(0);c[e>>2]=q;c[f>>2]=m;m=b+60|0;q=c[m>>2]|0;j=b+88|0;u=b+89|0;if((v|0)==0){w=0;x=b+2152|0}else{o=b+2204|0;n=b+2152|0;l=c[r>>2]|0;t=(d[j]<<8|d[u])<<1&16382;y=0;z=l;A=c[k>>2]|0;B=v;v=l;while(1){l=c[o>>2]|0;C=ac(ac(z,A)|0,y)|0;if((z|0)==0){D=t;E=0;F=A;G=B;H=v}else{I=t;J=0;K=A;L=v;while(1){M=a[q+(I+1)|0]|0;N=c[g>>2]|0;if((a[N+4|0]&32)==0|M<<24>>24>-1){O=M;P=0}else{O=(a[N+5|0]&16)==0?M&127:M;P=(a[n]|0)==0|0}M=O&255;N=M&15;Q=16496+(N*3|0)|0;R=M>>>4;M=16496+(R*3|0)|0;S=d[q+I|0]<<3;if((K|0)==0){T=0;W=L}else{X=(P|0)==0;Y=16497+(R*3|0)|0;Z=16498+(R*3|0)|0;R=16497+(N*3|0)|0;_=16498+(N*3|0)|0;N=0;$=l+((J+C|0)*24|0)|0;while(1){if(X){aa=a[(N&7|S)+(b+98)|0]|0;ab=0}else{aa=0;ab=0}while(1){if(aa<<24>>24>-1){ad=ab*3|0;a[$+ad|0]=a[M]|0;a[$+(ad+1)|0]=a[Y]|0;a[$+(ad+2)|0]=a[Z]|0}else{ad=ab*3|0;a[$+ad|0]=a[Q]|0;a[$+(ad+1)|0]=a[R]|0;a[$+(ad+2)|0]=a[_]|0}ad=ab+1|0;if(ad>>>0<8){aa=aa<<1;ab=ad}else{break}}ad=c[r>>2]|0;ae=N+1|0;af=c[k>>2]|0;if(ae>>>0<af>>>0){N=ae;$=$+(ad*24|0)|0}else{T=af;W=ad;break}}}ag=I+2&16382;$=J+1|0;if($>>>0<W>>>0){I=ag;J=$;K=T;L=W}else{break}}D=ag;E=W;F=T;G=c[p>>2]|0;H=W}L=y+1|0;if(L>>>0<G>>>0){t=D;y=L;z=E;A=F;B=G;v=H}else{w=G;x=n;break}}}if((a[x]|0)==0){return}x=a[b+86|0]|0;if((x&96)==32){return}n=c[r>>2]|0;if((n|0)==0){return}G=(d[b+90|0]<<8|d[b+91|0])-(d[j]<<8|d[u])&16383;if(G>>>0>=(ac(n,w)|0)>>>0){return}w=(G>>>0)%(n>>>0)|0;u=(G>>>0)/(n>>>0)|0;G=x&31;x=a[b+87|0]&31;j=c[k>>2]|0;if(G>>>0>=j>>>0){return}k=x>>>0<j>>>0?x:j-1|0;x=(ac(u,n)|0)+w<<1|1;H=a[(c[m>>2]|0)+x|0]&15;x=16496+(H*3|0)|0;if(G>>>0>k>>>0){return}m=((ac((ac(j,u)|0)+G|0,n)|0)+w|0)*24|0;w=16497+(H*3|0)|0;n=16498+(H*3|0)|0;H=G;G=(c[b+2204>>2]|0)+m|0;while(1){a[G]=a[x]|0;a[G+1|0]=a[w]|0;a[G+2|0]=a[n]|0;a[G+3|0]=a[x]|0;a[G+4|0]=a[w]|0;a[G+5|0]=a[n]|0;a[G+6|0]=a[x]|0;a[G+7|0]=a[w]|0;a[G+8|0]=a[n]|0;a[G+9|0]=a[x]|0;a[G+10|0]=a[w]|0;a[G+11|0]=a[n]|0;a[G+12|0]=a[x]|0;a[G+13|0]=a[w]|0;a[G+14|0]=a[n]|0;a[G+15|0]=a[x]|0;a[G+16|0]=a[w]|0;a[G+17|0]=a[n]|0;a[G+18|0]=a[x]|0;a[G+19|0]=a[w]|0;a[G+20|0]=a[n]|0;a[G+21|0]=a[x]|0;a[G+22|0]=a[w]|0;a[G+23|0]=a[n]|0;m=H+1|0;if(m>>>0>k>>>0){break}else{H=m;G=G+((c[r>>2]|0)*24|0)|0}}return}if((i&16|0)==0){r=b+2164|0;G=c[r>>2]|0;H=G<<3;k=b+2168|0;n=c[k>>2]|0;w=n<<1;x=ac(G*24|0,w)|0;m=b+2200|0;do{if(x>>>0>(c[m>>2]|0)>>>0){u=b+2204|0;j=zJ(c[u>>2]|0,x)|0;if((j|0)==0){return}else{c[u>>2]=j;c[m>>2]=x;ah=c[r>>2]|0;ai=c[k>>2]|0;break}}else{ah=G;ai=n}}while(0);c[e>>2]=H;c[f>>2]=w;w=ah<<1;H=ai<<1;if((H|0)==0){return}ai=b+60|0;n=(w|0)==0;G=ah*24|0;ah=(d[b+88|0]<<8|d[b+89|0])<<1&8190;k=0;r=c[b+2204>>2]|0;while(1){x=c[ai>>2]|0;m=k&1;j=m<<13;if(n){aj=r}else{u=r;v=0;while(1){B=d[x+(v+ah&8191|j)|0]|0;F=d[(B>>>6)+(b+94)|0]|0;a[u]=a[16496+(F*3|0)|0]|0;a[u+1|0]=a[16497+(F*3|0)|0]|0;a[u+2|0]=a[16498+(F*3|0)|0]|0;F=d[(B>>>4&3)+(b+94)|0]|0;a[u+3|0]=a[16496+(F*3|0)|0]|0;a[u+4|0]=a[16497+(F*3|0)|0]|0;a[u+5|0]=a[16498+(F*3|0)|0]|0;F=d[(B>>>2&3)+(b+94)|0]|0;a[u+6|0]=a[16496+(F*3|0)|0]|0;a[u+7|0]=a[16497+(F*3|0)|0]|0;a[u+8|0]=a[16498+(F*3|0)|0]|0;F=d[(B&3)+(b+94)|0]|0;a[u+9|0]=a[16496+(F*3|0)|0]|0;a[u+10|0]=a[16497+(F*3|0)|0]|0;a[u+11|0]=a[16498+(F*3|0)|0]|0;F=v+1|0;if(F>>>0<w>>>0){u=u+12|0;v=F}else{break}}aj=r+G|0}if((m|0)==0){ak=ah}else{ak=ah+w&8191}v=k+1|0;if(v>>>0<H>>>0){ah=ak;k=v;r=aj}else{break}}return}if((i&4|0)!=0){i=b+2164|0;aj=c[i>>2]|0;r=aj<<4;k=b+2168|0;ak=c[k>>2]|0;ah=ak<<1;H=ac(aj*48|0,ah)|0;w=b+2200|0;do{if(H>>>0>(c[w>>2]|0)>>>0){G=b+2204|0;n=zJ(c[G>>2]|0,H)|0;if((n|0)==0){return}else{c[G>>2]=n;c[w>>2]=H;al=c[k>>2]|0;am=c[i>>2]|0;break}}else{al=ak;am=aj}}while(0);c[e>>2]=r;c[f>>2]=ah;ah=al<<1;al=am<<1;if((ah|0)==0){return}r=b+60|0;aj=(al|0)==0;ak=b+94|0;i=am*48|0;am=(d[b+88|0]<<8|d[b+89|0])<<1&8190;k=0;H=c[b+2204>>2]|0;while(1){w=c[r>>2]|0;n=k&1;G=n<<13;if(aj){an=H}else{ai=H;v=0;while(1){u=d[w+(v+am&8191|G)|0]|0;j=ai;x=0;while(1){if((u&128|0)==0){ao=0}else{ao=d[ak]|0}a[j]=a[16496+(ao*3|0)|0]|0;a[j+1|0]=a[16497+(ao*3|0)|0]|0;a[j+2|0]=a[16498+(ao*3|0)|0]|0;F=x+1|0;if(F>>>0<8){u=u<<1&254;j=j+3|0;x=F}else{break}}x=v+1|0;if(x>>>0<al>>>0){ai=ai+24|0;v=x}else{break}}an=H+i|0}if((n|0)==0){ap=am}else{ap=am+al&8191}v=k+1|0;if(v>>>0<ah>>>0){am=ap;k=v;H=an}else{break}}return}an=b+2146|0;if((a[an]|0)==0){H=b+2148|0;if((c[H>>2]|0)==0){c[H>>2]=zH(240)|0}k=a[h+5|0]|0;aq=(k&32)==0?.8726646259971648:.6108652381980153;ar=+V(+aq);as=+U(+aq);h=k&15;k=16496+(h*3|0)|0;ap=16497+(h*3|0)|0;am=16498+(h*3|0)|0;h=0;do{aq=(((h&8|0)!=0?1.0:0.0)-((h&2|0)!=0?1.0:0.0))*.5*.6666666666666666;at=(((h&4|0)!=0?1.0:0.0)-((h&1|0)!=0?1.0:0.0))*.5*.6666666666666666;au=as*aq+ar*at;av=as*at-ar*aq;aq=au*.956;at=av*.621;aw=au*.272;ax=av*.647;ay=au*1.105;au=av*1.702;ah=0;do{av=+(ah>>>0>>>0)*.25;az=at+(aq+av);aA=av-aw-ax;aB=au+(av-ay);if(az<0.0){aC=0.0}else{aC=az>1.0?1.0:az}if(aA<0.0){aD=0.0}else{aD=aA>1.0?1.0:aA}if(aB<0.0){aE=0.0}else{aE=aB>1.0?1.0:aB}al=c[H>>2]|0;i=((ah<<4)+h|0)*3|0;a[al+i|0]=~~(aC*+(d[k]|0));a[al+(i+1)|0]=~~(aD*+(d[ap]|0));a[al+(i+2)|0]=~~(aE*+(d[am]|0));ah=ah+1|0;}while(ah>>>0<5);h=h+1|0;}while(h>>>0<16);a[an]=1}an=b+2164|0;h=c[an>>2]|0;am=h<<4;ap=b+2168|0;k=c[ap>>2]|0;H=k<<1;ah=ac(h*48|0,H)|0;n=b+2200|0;i=b+2204|0;al=c[i>>2]|0;do{if(ah>>>0>(c[n>>2]|0)>>>0){ao=zJ(al,ah)|0;if((ao|0)==0){return}else{c[i>>2]=ao;c[n>>2]=ah;aF=c[ap>>2]|0;aG=c[an>>2]|0;aH=ao;break}}else{aF=k;aG=h;aH=al}}while(0);c[e>>2]=am;c[f>>2]=H;H=aF<<1;aF=aG<<1;if((H|0)==0){return}f=b+60|0;am=aG<<4;e=b+2148|0;if((am|0)==0){return}al=aG*48|0;aG=(d[b+88|0]<<8|d[b+89|0])<<1&8190;b=0;h=0;k=aH;while(1){aH=c[f>>2]|0;an=h&1;ap=an<<13;ah=(d[aH+(aG&8191|ap)|0]|0)>>>7;n=ah;i=ah;ah=b;ao=0;ak=k;while(1){do{if((ao&3|0)==0){if((ao&7|0)==0){aj=d[aH+((ao>>>3)+aG&8191|ap)|0]|0;aI=aj<<4|aj>>>4;break}else{aI=ah>>>4;break}}else{aI=ah}}while(0);aj=i-(n>>>3&1)|0;r=n<<1;v=ao+1|0;ai=v>>>0<am>>>0;do{if(ai){if((d[aH+((v>>>3)+aG&8191|ap)|0]&128>>>((v&7)>>>0)|0)==0){aJ=aj;aK=r;break}aJ=aj+1|0;aK=r|1}else{aJ=aj;aK=r}}while(0);r=c[e>>2]|0;aj=(aJ<<4|aI&15)*3|0;a[ak]=a[r+aj|0]|0;a[ak+1|0]=a[r+(aj+1)|0]|0;a[ak+2|0]=a[r+(aj+2)|0]|0;if(ai){n=aK;i=aJ;ah=aI;ao=v;ak=ak+3|0}else{break}}if((an|0)==0){aL=aG}else{aL=aG+aF&8191}ak=h+1|0;if(ak>>>0<H>>>0){aG=aL;b=aI;h=ak;k=k+al|0}else{break}}return}function o0(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if((e|0)==0){a[c[b+68>>2]|0]=f&31;return}else if((e|0)==5){g=b+68|0;a[(c[g>>2]|0)+5|0]=f;h=c[g>>2]|0;g=a[h+4|0]|0;i=a[h+5|0]|0;h=i&255;a[b+94|0]=i&15;do{if((g&4)==0){i=b+95|0;if((h&32|0)==0){a[i]=2;a[b+96|0]=4;a[b+97|0]=6;j=10;k=12;l=14;break}else{a[i]=3;a[b+96|0]=5;a[b+97|0]=7;j=11;k=13;l=15;break}}else{a[b+95|0]=3;a[b+96|0]=4;a[b+97|0]=7;j=11;k=12;l=15}}while(0);if((h&16|0)!=0){a[b+95|0]=j;a[b+96|0]=k;a[b+97|0]=l}l=b+2208|0;a[l]=a[l]|1;return}else if((e|0)==4){l=b+68|0;a[(c[l>>2]|0)+4|0]=f;k=c[l>>2]|0;l=a[k+4|0]|0;j=a[k+5|0]|0;k=j&255;a[b+94|0]=j&15;do{if((l&4)==0){j=b+95|0;if((k&32|0)==0){a[j]=2;a[b+96|0]=4;a[b+97|0]=6;m=10;n=12;o=14;break}else{a[j]=3;a[b+96|0]=5;a[b+97|0]=7;m=11;n=13;o=15;break}}else{a[b+95|0]=3;a[b+96|0]=4;a[b+97|0]=7;m=11;n=12;o=15}}while(0);if((k&16|0)!=0){a[b+95|0]=m;a[b+96|0]=n;a[b+97|0]=o}o=(a[b+85|0]&31)+1|0;c[b+2172>>2]=o;n=d[b+77|0]|0;c[b+2164>>2]=n;m=d[b+82|0]|0;c[b+2168>>2]=m;k=(d[b+76|0]<<3)+8|0;c[b+2176>>2]=k;c[b+2184>>2]=n<<3;n=(d[b+80|0]|0)+7|0;c[b+2180>>2]=ac(ac(k,o)|0,n)|0;c[b+2188>>2]=ac(ac(m,o)|0,k)|0;k=b+2208|0;a[k]=a[k]|1;return}else if((e|0)==8){k=(c[b+68>>2]|0)+6|0;a[k]=a[k]|2;return}else if((e|0)==1){k=b+68|0;a[(c[k>>2]|0)+1|0]=f;o=a[c[k>>2]|0]|0;if((o&255)>15){return}k=(o&255)+(b+76)|0;if((a[k]|0)==f<<24>>24){return}a[k]=f;k=(a[b+85|0]&31)+1|0;c[b+2172>>2]=k;o=d[b+77|0]|0;c[b+2164>>2]=o;m=d[b+82|0]|0;c[b+2168>>2]=m;n=(d[b+76|0]<<3)+8|0;c[b+2176>>2]=n;c[b+2184>>2]=o<<3;o=(d[b+80|0]|0)+7|0;c[b+2180>>2]=ac(ac(n,k)|0,o)|0;c[b+2188>>2]=ac(ac(m,k)|0,n)|0;n=b+2208|0;a[n]=a[n]|1;return}else if((e|0)==7){n=(c[b+68>>2]|0)+6|0;a[n]=a[n]&-3;return}else{a[(c[b+68>>2]|0)+e|0]=f;return}}function o1(a){a=a|0;return c[a+56>>2]|0}function o2(a){a=a|0;return c[a+64>>2]|0}function o3(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;if((e|0)==0){f=a[c[b+68>>2]|0]|0;return f|0}else if((e|0)==6){ph(b,0);g=c[b+68>>2]|0;h=a[g+4|0]|0;i=z4(c[b+36>>2]|0,0,14318184,0)|0;j=z5(i,G,1193182,0)|0;if((h&1)==0){k=j>>>1|G<<31}else{k=j}j=a[g+6|0]|0;g=j|9;if(k>>>0>=(c[b+2188>>2]|0)>>>0){f=g;return f|0}h=g&-9;g=c[b+2176>>2]|0;if((g|0)==0){f=h;return f|0}f=((k>>>0)%(g>>>0)|0)>>>0<(c[b+2184>>2]|0)>>>0?j&-10:h;return f|0}else if((e|0)==1){e=d[c[b+68>>2]|0]|0;if((e-12|0)>>>0>5){f=-1;return f|0}f=a[b+76+e|0]|0;return f|0}else{f=-1;return f|0}return 0}function o4(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;do{if((e|0)==0){f=a[c[b+68>>2]|0]|0}else if((e|0)==6){ph(b,0);g=c[b+68>>2]|0;h=a[g+4|0]|0;i=z4(c[b+36>>2]|0,0,14318184,0)|0;j=z5(i,G,1193182,0)|0;if((h&1)==0){k=j>>>1|G<<31}else{k=j}j=a[g+6|0]|0;g=j|9;if(k>>>0>=(c[b+2188>>2]|0)>>>0){f=g;break}h=g&-9;g=c[b+2176>>2]|0;if((g|0)==0){f=h;break}f=((k>>>0)%(g>>>0)|0)>>>0<(c[b+2184>>2]|0)>>>0?j&-10:h}else if((e|0)==1){h=d[c[b+68>>2]|0]|0;if((h-12|0)>>>0>5){f=-1;break}f=a[b+76+h|0]|0}else{f=-1}}while(0);k=f&255;if((e+1|0)>>>0>=(c[(c[b+64>>2]|0)+40>>2]|0)>>>0){l=k;return l|0}do{if((e|0)==0){f=d[c[b+68>>2]|0]|0;if((f-12|0)>>>0>5){m=-1;break}m=a[b+76+f|0]|0}else if((e|0)==(-1|0)){m=a[c[b+68>>2]|0]|0}else if((e|0)==5){ph(b,0);f=c[b+68>>2]|0;h=a[f+4|0]|0;j=z4(c[b+36>>2]|0,0,14318184,0)|0;g=z5(j,G,1193182,0)|0;if((h&1)==0){n=g>>>1|G<<31}else{n=g}g=a[f+6|0]|0;f=g|9;if(n>>>0>=(c[b+2188>>2]|0)>>>0){m=f;break}h=f&-9;f=c[b+2176>>2]|0;if((f|0)==0){m=h;break}m=((n>>>0)%(f>>>0)|0)>>>0<(c[b+2184>>2]|0)>>>0?g&-10:h}else{m=-1}}while(0);l=(m&255)<<8|k;return l|0}function o5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;o0(a,b,d&255);e=b+1|0;if(e>>>0>=(c[(c[a+64>>2]|0)+40>>2]|0)>>>0){return}o0(a,e,(d&65535)>>>8&255);return}function o6(a){a=a|0;if((a|0)==0){return}r2(c[a+56>>2]|0);r2(c[a+64>>2]|0);zI(c[a+2148>>2]|0);zI(a);return}function o7(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;qH(b|0);g=b;c[b+32>>2]=g;c[b>>2]=104;c[b+4>>2]=36;c[b+8>>2]=24;c[b+12>>2]=2;c[b+16>>2]=256;c[b+20>>2]=44;c[b+24>>2]=448;c[b+28>>2]=52;c[b+48>>2]=0;c[b+52>>2]=86;h=r0(e,f>>>0<16384?16384:f,1)|0;f=b+56|0;c[f>>2]=h;c[h+24>>2]=g;c[(c[f>>2]|0)+12>>2]=76;c[(c[f>>2]|0)+16>>2]=26;h=c[f>>2]|0;c[b+60>>2]=c[h+44>>2];r3(h,0);h=r0(d,16,1)|0;d=b+64|0;c[d>>2]=h;c[h+24>>2]=g;c[(c[d>>2]|0)+12>>2]=74;c[(c[d>>2]|0)+16>>2]=44;c[c[d>>2]>>2]=28;c[(c[d>>2]|0)+4>>2]=36;g=c[d>>2]|0;c[b+68>>2]=c[g+44>>2];r3(g,0);zP(b+72|0,0,23);a[b+95|0]=11;a[b+96|0]=13;a[b+97|0]=15;a[b+2146|0]=0;c[b+2148>>2]=0;a[b+2152|0]=1;c[b+2156>>2]=0;c[b+2160>>2]=16;c[b+2200>>2]=0;c[b+2204>>2]=0;a[b+2208|0]=0;g=b+98|0;zP(b+2164|0,0,28);zO(g|0,18592,2048)|0;return}function o8(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+8|0;g=f|0;if((xz(33328,d)|0)==0){h=-1;i=f;return h|0}if((xB(e,g)|0)!=0){h=1;i=f;return h|0}e=c[g>>2]|0;a[b+2152|0]=1;c[b+2156>>2]=e;c[b+2160>>2]=e;e=b+2208|0;a[e]=a[e]|1;h=0;i=f;return h|0}function o9(a,b){a=a|0;b=b|0;c[a+72>>2]=b;if((b|0)==0){return}zl(b,640,200)|0;return}function pa(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;aB(39336,9,1,e|0)|0;g=(d[b+90|0]|0)<<8|(d[b+91|0]|0);h=b+68|0;j=d[(c[h>>2]|0)+5|0]|0;bN(e|0,38288,(x=i,i=i+32|0,c[x>>2]=(d[b+88|0]|0)<<8|(d[b+89|0]|0),c[x+8>>2]=g,c[x+16>>2]=j&15,c[x+24>>2]=j>>>5&1,x)|0)|0;j=a[(c[h>>2]|0)+4|0]|0;g=z4(c[b+36>>2]|0,0,14318184,0)|0;k=z5(g,G,1193182,0)|0;if((j&1)==0){l=k>>>1|G<<31}else{l=k}k=c[b+2176>>2]|0;j=c[b+2184>>2]|0;g=c[b+2180>>2]|0;m=c[b+2188>>2]|0;bN(e|0,37288,(x=i,i=i+40|0,c[x>>2]=l,c[x+8>>2]=k,c[x+16>>2]=j,c[x+24>>2]=g,c[x+32>>2]=m,x)|0)|0;m=c[h>>2]|0;h=d[m+5|0]|0;g=d[m+6|0]|0;j=d[b+94|0]|0;k=d[b+95|0]|0;l=d[b+96|0]|0;n=d[b+97|0]|0;bN(e|0,35456,(x=i,i=i+56|0,c[x>>2]=d[m+4|0]|0,c[x+8>>2]=h,c[x+16>>2]=g,c[x+24>>2]=j,c[x+32>>2]=k,c[x+40>>2]=l,c[x+48>>2]=n,x)|0)|0;bN(e|0,34832,(x=i,i=i+8|0,c[x>>2]=d[b+76|0]|0,x)|0)|0;n=1;do{aA(((n&7|0)!=0?32:45)|0,e|0)|0;bN(e|0,34048,(x=i,i=i+8|0,c[x>>2]=d[b+76+n|0]|0,x)|0)|0;n=n+1|0;}while(n>>>0<18);aB(33712,2,1,e|0)|0;ax(e|0)|0;i=f;return}function pb(b,d){b=b|0;d=d|0;var e=0,f=0;do{if((d|0)!=0){e=b+72|0;if((c[e>>2]|0)==0){break}b2[c[b+52>>2]&255](b);f=b+2196|0;zp(c[e>>2]|0,c[b+2192>>2]|0,c[f>>2]|0);zq(c[e>>2]|0,c[b+2204>>2]|0,0,c[f>>2]|0);zs(c[e>>2]|0)}}while(0);d=b+2208|0;a[d]=a[d]|1;return}function pc(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=(c[b+60>>2]|0)+d|0;if((a[f]|0)==e<<24>>24){return}a[f]=e;e=b+2208|0;a[e]=a[e]|1;return}function pd(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=e&255;g=b+60|0;h=(c[g>>2]|0)+d|0;if((a[h]|0)!=f<<24>>24){a[h]=f;f=b+2208|0;a[f]=a[f]|1}f=d+1|0;if(f>>>0>=(c[(c[b+56>>2]|0)+40>>2]|0)>>>0){return}d=(e&65535)>>>8&255;e=(c[g>>2]|0)+f|0;if((a[e]|0)==d<<24>>24){return}a[e]=d;d=b+2208|0;a[d]=a[d]|1;return}function pe(a,b,d){a=a|0;b=b|0;d=d|0;c[a+200>>2]=b;c[a+204>>2]=d;return}function pf(a){a=a|0;return c[a+52>>2]|0}function pg(a){a=a|0;return c[a+60>>2]|0}function ph(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=c[b+2180>>2]|0;if(d>>>0<5e4){return}e=b+36|0;f=(c[b+68>>2]|0)+4|0;g=a[f]|0;h=z4(c[e>>2]|0,0,14318184,0)|0;i=z5(h,G,1193182,0)|0;if((g&1)==0){j=i>>>1|G<<31}else{j=i}if(j>>>0<(c[b+2188>>2]|0)>>>0){i=b+2208|0;a[i]=a[i]&-3;return}if(j>>>0>=d>>>0){c[e>>2]=0;c[b+40>>2]=0;c[b+44>>2]=0}e=b+2208|0;d=a[e]|0;if((d&2)!=0){return}j=b+2156|0;i=c[j>>2]|0;do{if((i|0)==0){k=d}else{g=i-1|0;c[j>>2]=g;if((g|0)!=0){k=d;break}c[j>>2]=c[b+2160>>2];g=b+2152|0;a[g]=(a[g]|0)==0|0;if((a[f]&2)!=0){k=d;break}g=d|1;a[e]=g;k=g}}while(0);d=b+72|0;f=c[d>>2]|0;if((f|0)!=0){if((k&1)==0){l=f}else{b2[c[b+52>>2]&255](b);f=b+2196|0;zp(c[d>>2]|0,c[b+2192>>2]|0,c[f>>2]|0);zq(c[d>>2]|0,c[b+2204>>2]|0,0,c[f>>2]|0);l=c[d>>2]|0}zs(l)}a[e]=2;return}function pi(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+48|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;yi(b,21776,e,980)|0;yi(b,34016,f,753664)|0;yi(b,31400,g,16384)|0;yj(b,29408,h,0)|0;yj(b,27624,j,0)|0;ym(b,26112,k,0)|0;b=c[f>>2]|0;l=c[g>>2]|0;m=c[h>>2]|0;n=c[k>>2]|0;xv(2,24776,23248,(x=i,i=i+40|0,c[x>>2]=c[e>>2],c[x+8>>2]=b,c[x+16>>2]=l,c[x+24>>2]=m,c[x+32>>2]=(n|0)!=0?n:21952,x)|0);n=c[e>>2]|0;e=c[f>>2]|0;f=c[g>>2]|0;g=zH(2212)|0;if((g|0)==0){o=0;i=d;return o|0}o7(g,n,e,f);f=g+98|0;if((c[h>>2]|0)==0){zO(f|0,18592,2048)|0}else{zO(f|0,16544,2048)|0}h=c[k>>2]|0;do{if((h|0)!=0){e=bl(h|0,40856)|0;if((e|0)!=0){n=bK(f|0,1,2048,e|0)|0;au(e|0)|0;if((n|0)==2048){break}}xt(0,20760,(x=i,i=i+8|0,c[x>>2]=c[k>>2],x)|0)}}while(0);k=c[j>>2]|0;a[g+2152|0]=1;c[g+2156>>2]=k;c[g+2160>>2]=k;k=g+2208|0;a[k]=a[k]|1;o=g;i=d;return o|0}function pj(a){a=a|0;if((a|0)==0){return}r2(c[a+52>>2]|0);r2(c[a+60>>2]|0);zI(a);return}function pk(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;qH(b|0);f=b;c[b+32>>2]=f;c[b>>2]=58;c[b+4>>2]=52;c[b+8>>2]=56;c[b+12>>2]=406;c[b+16>>2]=94;c[b+20>>2]=306;c[b+24>>2]=232;c[b+28>>2]=170;c[b+48>>2]=0;g=zH(262144)|0;h=b+56|0;c[h>>2]=g;if((g|0)==0){return}g=r0(e,131072,0)|0;e=b+52|0;c[e>>2]=g;c[g+24>>2]=f;r4(c[e>>2]|0,c[h>>2]|0,1);c[(c[e>>2]|0)+12>>2]=96;c[(c[e>>2]|0)+16>>2]=64;c[c[e>>2]>>2]=120;c[(c[e>>2]|0)+4>>2]=54;g=c[e>>2]|0;c[h>>2]=c[g+44>>2];r3(g,0);g=r0(d,48,1)|0;d=b+60|0;c[d>>2]=g;c[g+24>>2]=f;c[(c[d>>2]|0)+12>>2]=6;c[(c[d>>2]|0)+16>>2]=100;c[c[d>>2]>>2]=2;c[(c[d>>2]|0)+4>>2]=4;f=c[d>>2]|0;c[b+64>>2]=c[f+44>>2];r3(f,0);zP(b+68|0,0,61);zP(b+132|0,0,13);a[b+145|0]=9;c[b+148>>2]=0;a[b+152|0]=1;c[b+156>>2]=0;c[b+160>>2]=16;c[b+188>>2]=0;c[b+192>>2]=0;a[b+196|0]=0;c[b+200>>2]=0;c[b+204>>2]=0;a[b+208|0]=0;zP(b+164|0,0,16);return}function pl(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+8|0;g=f|0;if((xz(33696,d)|0)==0){h=-1;i=f;return h|0}if((xB(e,g)|0)!=0){h=1;i=f;return h|0}e=c[g>>2]|0;a[b+152|0]=1;c[b+156>>2]=e;c[b+160>>2]=e;e=b+196|0;a[e]=a[e]|1;h=0;i=f;return h|0}function pm(a,b){a=a|0;b=b|0;c[a+48>>2]=b;if((b|0)==0){return}zl(b,640,400)|0;return}function pn(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;aB(24712,9,1,e|0)|0;g=(d[b+123|0]|0)<<1;h=(d[b+118|0]|0)<<8|(d[b+119|0]|0);j=d[b+128|0]|0;k=(a[b+111|0]&16)==0?j:j|256;bN(e|0,23160,(x=i,i=i+32|0,c[x>>2]=(d[b+116|0]|0)<<8|(d[b+117|0]|0),c[x+8>>2]=g,c[x+16>>2]=h,c[x+24>>2]=k,x)|0)|0;k=c[b+36>>2]|0;h=0;g=b+64|0;if((a[(c[g>>2]|0)+28|0]&4)==0){j=z4(k,h,14318180,0)|0;l=G;m=j}else{j=z4(k,h,16257e3,0)|0;l=G;m=j}j=b+69|0;if((a[j]&8)==0){h=z5(m,l,1193182,0)|0;n=h}else{h=z5(m,l,2386364,0)|0;n=h}h=c[b+164>>2]|0;l=c[b+168>>2]|0;m=c[b+172>>2]|0;k=c[b+176>>2]|0;bN(e|0,21880,(x=i,i=i+40|0,c[x>>2]=n,c[x+8>>2]=h,c[x+16>>2]=l,c[x+24>>2]=m,c[x+32>>2]=k,x)|0)|0;k=c[g>>2]|0;g=d[k+18|0]|0;m=d[k+42|0]|0;bN(e|0,20680,(x=i,i=i+24|0,c[x>>2]=d[k+28|0]|0,c[x+8>>2]=g,c[x+16>>2]=m,x)|0)|0;m=d[b+104|0]|0;bN(e|0,35384,(x=i,i=i+16|0,c[x>>2]=40832,c[x+8>>2]=m,x)|0)|0;m=1;do{aA(((m&7|0)!=0?32:45)|0,e|0)|0;bN(e|0,34264,(x=i,i=i+8|0,c[x>>2]=d[b+104+m|0]|0,x)|0)|0;m=m+1|0;}while(m>>>0<25);aB(34040,2,1,e|0)|0;m=d[b+82|0]|0;bN(e|0,35384,(x=i,i=i+16|0,c[x>>2]=39304,c[x+8>>2]=m,x)|0)|0;m=1;do{aA(((m&7|0)!=0?32:45)|0,e|0)|0;bN(e|0,34264,(x=i,i=i+8|0,c[x>>2]=d[b+82+m|0]|0,x)|0)|0;m=m+1|0;}while(m>>>0<22);aB(34040,2,1,e|0)|0;m=d[b+68|0]|0;bN(e|0,35384,(x=i,i=i+16|0,c[x>>2]=38248,c[x+8>>2]=m,x)|0)|0;aA(32,e|0)|0;bN(e|0,34264,(x=i,i=i+8|0,c[x>>2]=d[j]|0,x)|0)|0;aA(32,e|0)|0;bN(e|0,34264,(x=i,i=i+8|0,c[x>>2]=d[b+70|0]|0,x)|0)|0;aA(32,e|0)|0;bN(e|0,34264,(x=i,i=i+8|0,c[x>>2]=d[b+71|0]|0,x)|0)|0;aA(32,e|0)|0;bN(e|0,34264,(x=i,i=i+8|0,c[x>>2]=d[b+72|0]|0,x)|0)|0;aB(34040,2,1,e|0)|0;j=d[b+73|0]|0;bN(e|0,35384,(x=i,i=i+16|0,c[x>>2]=37272,c[x+8>>2]=j,x)|0)|0;aA(32,e|0)|0;bN(e|0,34264,(x=i,i=i+8|0,c[x>>2]=d[b+74|0]|0,x)|0)|0;aA(32,e|0)|0;bN(e|0,34264,(x=i,i=i+8|0,c[x>>2]=d[b+75|0]|0,x)|0)|0;aA(32,e|0)|0;bN(e|0,34264,(x=i,i=i+8|0,c[x>>2]=d[b+76|0]|0,x)|0)|0;aA(32,e|0)|0;bN(e|0,34264,(x=i,i=i+8|0,c[x>>2]=d[b+77|0]|0,x)|0)|0;aA(32,e|0)|0;bN(e|0,34264,(x=i,i=i+8|0,c[x>>2]=d[b+78|0]|0,x)|0)|0;aA(32,e|0)|0;bN(e|0,34264,(x=i,i=i+8|0,c[x>>2]=d[b+79|0]|0,x)|0)|0;aA(32,e|0)|0;bN(e|0,34264,(x=i,i=i+8|0,c[x>>2]=d[b+80|0]|0,x)|0)|0;aA(45,e|0)|0;bN(e|0,34264,(x=i,i=i+8|0,c[x>>2]=d[b+81|0]|0,x)|0)|0;aB(34040,2,1,e|0)|0;ax(e|0)|0;i=f;return}function po(b,d){b=b|0;d=d|0;var e=0,f=0;do{if((d|0)!=0){e=b+48|0;if((c[e>>2]|0)==0){break}pz(b);f=b+184|0;zp(c[e>>2]|0,c[b+180>>2]|0,c[f>>2]|0);zq(c[e>>2]|0,c[b+192>>2]|0,0,c[f>>2]|0);zs(c[e>>2]|0)}}while(0);d=b+196|0;a[d]=a[d]|1;return}function pp(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=c[b+172>>2]|0;if(e>>>0<5e4){return}f=b+36|0;g=c[f>>2]|0;h=0;i=b+64|0;if((a[(c[i>>2]|0)+28|0]&4)==0){j=z4(g,h,14318180,0)|0;k=G;l=j}else{j=z4(g,h,16257e3,0)|0;k=G;l=j}if((a[b+69|0]&8)==0){j=z5(l,k,1193182,0)|0;m=j}else{j=z5(l,k,2386364,0)|0;m=j}if(m>>>0<(c[b+176>>2]|0)>>>0){j=b+196|0;a[j]=a[j]&-3;return}do{if(m>>>0>=e>>>0){c[f>>2]=0;c[b+40>>2]=0;c[b+44>>2]=0;c[b+136>>2]=a[b+101|0]&15;j=d[b+116|0]<<8|d[b+117|0];k=b+132|0;if((c[k>>2]|0)==(j|0)){break}c[k>>2]=j;j=b+196|0;a[j]=a[j]|1}}while(0);f=b+196|0;e=a[f]|0;if((e&2)!=0){return}m=b+156|0;j=c[m>>2]|0;do{if((j|0)==0){n=e}else{k=j-1|0;c[m>>2]=k;if((k|0)!=0){n=e;break}c[m>>2]=c[b+160>>2];k=b+152|0;a[k]=(a[k]|0)==0|0;k=d[b+98|0]|0;if((k&1|0)==0){l=e|1;a[f]=l;n=l;break}if((k&8|0)==0){n=e;break}k=e|1;a[f]=k;n=k}}while(0);e=b+48|0;m=c[e>>2]|0;if((m|0)!=0){if((n&1)==0){o=m}else{pz(b);m=b+184|0;zp(c[e>>2]|0,c[b+180>>2]|0,c[m>>2]|0);zq(c[e>>2]|0,c[b+192>>2]|0,0,c[m>>2]|0);o=c[e>>2]|0}zs(o)}a[f]=2;if((a[b+121|0]&32)!=0){return}f=b+208|0;if((a[f]|0)==1){return}o=(c[i>>2]|0)+18|0;a[o]=a[o]|-128;a[f]=1;f=c[b+204>>2]|0;if((f|0)==0){return}b3[f&511](c[b+200>>2]|0,1);return}function pq(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if((a[(c[b+64>>2]|0)+28|0]&2)==0){return}g=(d[b+79|0]|0)>>>2&3;do{if((g|0)==3){h=e-98304|0;if(h>>>0<=32767){i=h;break}return}else if((g|0)==1){if(e>>>0<=65535){i=e;break}return}else if((g|0)==2){h=e-65536|0;if(h>>>0<=32767){i=h;break}return}else{i=e}}while(0);e=a[b+78|0]&3;g=a[b+70|0]|0;if((a[b+72|0]&4)==0){j=i&65534;k=((i&1|0)!=0?10:5)&g}else{j=i&65535;k=g}do{if((e|0)==0){g=a[b+76|0]|0;i=g&7;h=f&255;l=h<<8-i|h>>>(i>>>0);i=a[b+73|0]|0;h=d[b+74|0]|0;if((h&1|0)==0){m=l&255}else{m=i<<7<<24>>24>>7}if((h&2|0)==0){n=l&255}else{n=i<<6<<24>>24>>7}if((h&4|0)==0){o=l&255}else{o=i<<5<<24>>24>>7}if((h&8|0)==0){p=l&255;q=o;r=n;s=m;t=g;u=2369;break}else{p=i<<4<<24>>24>>7;q=o;r=n;s=m;t=g;u=2369;break}}else if((e|0)==1){v=a[b+141|0]|0;w=a[b+142|0]|0;x=a[b+143|0]|0;y=a[b+144|0]|0}else if((e|0)==2){g=f&255;p=g<<28>>31&255;q=g<<29>>31&255;r=g<<30>>31&255;s=g<<31>>31&255;t=a[b+76|0]|0;u=2369}else{return}}while(0);do{if((u|0)==2369){f=(t&255)>>>3&3;if((f|0)==3){v=a[b+141|0]^s;w=a[b+142|0]^r;x=a[b+143|0]^q;y=a[b+144|0]^p;break}else if((f|0)==1){v=a[b+141|0]&s;w=a[b+142|0]&r;x=a[b+143|0]&q;y=a[b+144|0]&p;break}else if((f|0)==2){v=a[b+141|0]|s;w=a[b+142|0]|r;x=a[b+143|0]|q;y=a[b+144|0]|p;break}else{v=s;w=r;x=q;y=p;break}}}while(0);p=a[b+81|0]|0;q=~(p&255);r=((d[b+142|0]|0)&q|p&w&255)&255;w=((d[b+143|0]|0)&q|p&x&255)&255;x=((d[b+144|0]|0)&q|p&y&255)&255;y=k&255;if((y&1|0)!=0){a[(c[b+56>>2]|0)+j|0]=((d[b+141|0]|0)&q|p&v&255)&255}if((y&2|0)!=0){a[(c[b+56>>2]|0)+(j|65536)|0]=r}if((y&4|0)!=0){a[(c[b+56>>2]|0)+(j|131072)|0]=w}if((y&8|0)!=0){a[(c[b+56>>2]|0)+(j|196608)|0]=x}x=b+196|0;a[x]=a[x]|1;return}function pr(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((a[(c[b+64>>2]|0)+28|0]&2)==0){f=-1;return f|0}g=(d[b+79|0]|0)>>>2&3;do{if((g|0)==2){h=e-65536|0;if(h>>>0>32767){f=-1}else{i=h;break}return f|0}else if((g|0)==1){if(e>>>0>65535){f=-1}else{i=e;break}return f|0}else if((g|0)==3){h=e-98304|0;if(h>>>0>32767){f=-1}else{i=h;break}return f|0}else{i=e}}while(0);e=i&1;g=(a[b+72|0]&4)==0;h=(g?65534:65535)&i;i=a[b+78|0]|0;j=c[b+56>>2]|0;k=a[j+h|0]|0;a[b+141|0]=k;l=a[j+(h|65536)|0]|0;a[b+142|0]=l;m=a[j+(h|131072)|0]|0;a[b+143|0]=m;n=a[j+(h|196608)|0]|0;a[b+144|0]=n;if((i&8)==0){i=d[b+77|0]|0;if(g){o=i&2|e}else{o=i&3}f=a[b+141+o|0]|0;return f|0}o=k&255;k=l&255;l=m&255;m=n&255;n=a[b+80|0]|0;i=a[b+75|0]|0;b=128;e=0;while(1){if((((((k&b|0)!=0?2:0)|(o&b|0)!=0|((l&b|0)!=0?4:0)|((m&b|0)!=0?8:0))^i)&n)<<24>>24==0){p=(e&255|b)&255}else{p=e}g=b>>>1;if((g|0)==0){f=p;break}else{b=g;e=p}}return f|0}function ps(b,d,e){b=b|0;d=d|0;e=e|0;if((a[(c[b+64>>2]|0)+28|0]&2)==0){return}pq(b,d,e&255);pq(b,d+1|0,(e&65535)>>>8&255);return}function pt(b,d){b=b|0;d=d|0;var e=0,f=0;if((a[(c[b+64>>2]|0)+28|0]&2)==0){e=0;return e|0}f=pr(b,d)|0;e=((pr(b,d+1|0)|0)&255)<<8|f&255;return e|0}function pu(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;do{if(e>>>0<16){if((a[(c[b+64>>2]|0)+28|0]&1)==0){g=e+32|0;break}else{return}}else{if(e>>>0<=32){g=e;break}if((a[(c[b+64>>2]|0)+28|0]&1)!=0){g=e;break}return}}while(0);if((g|0)==18){a[(c[b+64>>2]|0)+28|0]=f;e=b+196|0;a[e]=a[e]|1;return}else if((g|0)==21){e=b+64|0;a[(c[e>>2]|0)+21|0]=f;h=a[(c[e>>2]|0)+20|0]&7;if(h>>>0>4){return}if((a[b+68+h|0]|0)==f<<24>>24){return}if((h|0)==2){a[b+70|0]=f;return}else if((h|0)==1){a[b+69|0]=f;e=b+196|0;a[e]=a[e]|1;return}else if((h|0)==4){a[b+72|0]=f;return}else if((h|0)==3){a[b+71|0]=f;e=b+196|0;a[e]=a[e]|1;return}else if((h|0)==0){a[b+68|0]=f;return}else{return}}else if((g|0)==16){h=b+140|0;e=(c[b+64>>2]|0)+16|0;do{if((a[h]|0)==0){a[e]=f;i=1}else{j=a[e]&31;if(j>>>0>21){i=0;break}k=b+82+j|0;if((a[k]|0)==f<<24>>24){i=0;break}a[k]=f;k=b+196|0;a[k]=a[k]|1;i=0}}while(0);a[h]=i;return}else if((g|0)==17){i=b+140|0;h=(c[b+64>>2]|0)+16|0;do{if((a[i]|0)==0){a[h]=f;l=1}else{e=a[h]&31;if(e>>>0>21){l=0;break}k=b+82+e|0;if((a[k]|0)==f<<24>>24){l=0;break}a[k]=f;k=b+196|0;a[k]=a[k]|1;l=0}}while(0);a[i]=l;return}else if((g|0)==30){a[(c[b+64>>2]|0)+30|0]=f;return}else if((g|0)==31){l=b+64|0;a[(c[l>>2]|0)+31|0]=f;i=a[(c[l>>2]|0)+30|0]&15;if(i>>>0>8){return}l=b+73+i|0;if((a[l]|0)==f<<24>>24){return}a[l]=f;if((i|0)!=5){return}i=b+196|0;a[i]=a[i]|1;return}else if((g|0)==28|(g|0)==42){return}else if((g|0)==36){a[(c[b+64>>2]|0)+36|0]=f;return}else if((g|0)==20){a[(c[b+64>>2]|0)+20|0]=f;return}else if((g|0)==37){i=b+64|0;a[(c[i>>2]|0)+37|0]=f;l=c[i>>2]|0;i=a[l+36|0]&31;if(i>>>0>24){return}h=b+104+i|0;if((a[h]|0)==f<<24>>24){return}do{if((i|0)==17){if((f&16)!=0){break}k=b+208|0;if((a[k]|0)==0){break}e=l+18|0;a[e]=a[e]&127;a[k]=0;k=c[b+204>>2]|0;if((k|0)==0){break}b3[k&511](c[b+200>>2]|0,0)}}while(0);a[h]=f;h=(a[b+69|0]&1)==0?9:8;l=ac(h,(d[b+104|0]|0)+2|0)|0;i=b+164|0;k=(c[i>>2]|0)!=(l|0)|0;c[i>>2]=l;i=ac((d[b+105|0]|0)+1|0,h)|0;h=b+168|0;e=(c[h>>2]|0)!=(i|0)|k;c[h>>2]=i;i=d[b+111|0]|0;h=ac((i<<8&256|d[b+110|0])+1|0,l)|0;k=b+172|0;j=e|(c[k>>2]|0)!=(h|0);c[k>>2]=h;h=ac((i<<7&256|d[b+122|0])+1|0,l)|0;l=b+176|0;i=j|(c[l>>2]|0)!=(h|0);c[l>>2]=h;h=b+196|0;l=a[h]|0;if((i|0)==0){m=l}else{i=l|1;a[h]=i;m=i}a[h]=m|1;return}else{if(g>>>0>=48){return}a[(c[b+64>>2]|0)+g|0]=f;return}}function pv(a,b,c){a=a|0;b=b|0;c=c|0;pu(a,b,c&255);pu(a,b+1|0,(c&65535)>>>8&255);return}function pw(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;do{if(e>>>0<16){if((a[(c[b+64>>2]|0)+28|0]&1)==0){f=e+32|0;break}else{g=-1;return g|0}}else{if(e>>>0<=32){f=e;break}if((a[(c[b+64>>2]|0)+28|0]&1)==0){g=-1}else{f=e;break}return g|0}}while(0);if((f|0)==37){e=a[(c[b+64>>2]|0)+36|0]&31;if((e-12|0)>>>0>5){g=-1;return g|0}g=a[b+104+e|0]|0;return g|0}else if((f|0)==42){pp(b,0);a[b+140|0]=0;e=c[b+36>>2]|0;h=0;i=c[b+64>>2]|0;if((a[i+28|0]&4)==0){j=z4(e,h,14318180,0)|0;k=G;l=j}else{j=z4(e,h,16257e3,0)|0;k=G;l=j}if((a[b+69|0]&8)==0){j=z5(l,k,1193182,0)|0;m=j}else{j=z5(l,k,2386364,0)|0;m=j}j=i+42|0;i=a[j]|0;if(m>>>0<(c[b+176>>2]|0)>>>0){n=((m>>>0)%((c[b+164>>2]|0)>>>0)|0)>>>0>=(c[b+168>>2]|0)>>>0|i&-10}else{n=i|9}i=n+16&48|n&-49;a[j]=i;g=i;return g|0}else if((f|0)==28){g=a[(c[b+64>>2]|0)+28|0]|0;return g|0}else if((f|0)==18){i=b+64|0;j=c[i>>2]|0;n=j+18|0;m=a[n]|0;a[n]=(8>>>(((d[j+28|0]|0)>>>2&3)>>>0)&(d[b+145|0]|0)|0)==0?m&-17:m|16;g=a[(c[i>>2]|0)+18|0]|0;return g|0}else if((f|0)==36){g=a[(c[b+64>>2]|0)+36|0]|0;return g|0}else if((f|0)==24){g=2;return g|0}else{g=-1;return g|0}return 0}function px(a,b){a=a|0;b=b|0;var c=0;c=pw(a,b)|0;return((pw(a,b+1|0)|0)&255)<<8|c&255|0}function py(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+32|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;yi(b,21336,f,944)|0;yi(b,33896,g,655360)|0;yj(b,31344,h,9)|0;yj(b,29320,j,0)|0;b=c[g>>2]|0;k=c[h>>2]|0;xv(2,27576,26016,(x=i,i=i+24|0,c[x>>2]=c[f>>2],c[x+8>>2]=b,c[x+16>>2]=k,x)|0);k=c[f>>2]|0;f=c[g>>2]|0;g=zH(212)|0;if((g|0)==0){l=0;i=e;return l|0}pk(g,k,f);f=c[h>>2]|0;a[g+145|0]=f&255;c[g+148>>2]=d[13016+(f&15)|0]|0;f=c[j>>2]|0;a[g+152|0]=1;c[g+156>>2]=f;c[g+160>>2]=f;f=g+196|0;a[f]=a[f]|1;l=g;i=e;return l|0}function pz(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0;e=i;i=i+16|0;f=e|0;g=e+8|0;h=b+180|0;c[h>>2]=0;j=b+184|0;c[j>>2]=0;k=a[b+69|0]|0;l=k&1;m=ac((d[b+105|0]|0)+1|0,l<<24>>24!=0?8:9)|0;n=a[b+111|0]|0;o=((n&255)<<7&256|d[b+122|0])+1|0;do{if((k&32)==0){if((a[b+68|0]&3)!=3){break}if(m>>>0<16|o>>>0<16){break}p=l<<24>>24==0?9:8;q=(a[b+113|0]&31)+1|0;if((a[b+79|0]&1)!=0){r=d[b+128|0]|0;s=(n&16)==0?r:r|256;r=m*3|0;t=ac(o,r)|0;u=b+188|0;do{if(t>>>0>(c[u>>2]|0)>>>0){v=b+192|0;w=zJ(c[v>>2]|0,t)|0;if((w|0)==0){i=e;return}else{c[v>>2]=w;c[u>>2]=t;break}}}while(0);c[h>>2]=m;c[j>>2]=o;if((a[b+98|0]&8)==0){x=0;y=0}else{x=(a[b+152|0]|0)!=0?255:0;y=255}t=c[b+136>>2]|0;u=c[b+56>>2]|0;w=b+192|0;v=d[b+123|0]<<1;z=b+127|0;A=128>>>((t&7)>>>0);B=t<<1&6;C=b+78|0;if((m|0)==0){i=e;return}D=0;E=c[b+132>>2]|0;F=0;while(1){G=c[w>>2]|0;H=G+(ac(F,r)|0)|0;G=a[z]|0;if((G&64)==0){I=(E<<1|E>>>15)&65535}else{I=E}if((G&1)==0){G=D<<13&8192;J=I&-8193|G;K=G}else{J=I;K=D<<13&8192}G=t;L=E+1&65535;M=A;N=B;O=(d[u+(J+196608)|0]^y|x)&255;P=a[u+(J+131072)|0]|0;Q=a[u+(J+65536)|0]|0;R=a[u+J|0]|0;S=0;T=H;while(1){if(G>>>0<p>>>0){U=R;V=Q;W=P;X=O;Y=N;Z=M;_=L;$=G}else{H=a[z]|0;if((H&64)==0){aa=(L<<1|L>>>15)&65535}else{aa=L}if((H&1)==0){ab=aa&-8193|K}else{ab=aa}U=a[u+ab|0]|0;V=a[u+(ab+65536)|0]|0;W=a[u+(ab+131072)|0]|0;X=(d[u+(ab+196608)|0]^y|x)&255;Y=0;Z=128;_=L+1&65535;$=0}H=U&255;if((a[C]&32)==0){ad=U;ae=V;af=((W&255&Z|0)!=0?4:0)|((X&255&Z|0)!=0?8:0)|((V&255&Z|0)!=0?2:0)|(H&Z|0)!=0;ag=Y;ah=Z>>>1}else{ai=Y+2|0;aj=ai>>>0>6;ad=aj?V:U;ae=aj?0:V;af=H>>>((6-Y|0)>>>0)&3;ag=aj?0:ai;ah=Z}pA(b,af,T,T+1|0,T+2|0);ai=S+1|0;if(ai>>>0<m>>>0){G=$+1|0;L=_;M=ah;N=ag;O=X;P=W;Q=ae;R=ad;S=ai;T=T+3|0}else{break}}T=D+1|0;if(T>>>0<q>>>0){ak=E;al=T}else{ak=E+v&65535;al=0}T=F+1|0;if(T>>>0>=o>>>0){break}D=al;E=(F|0)==(s|0)?0:ak;F=T}i=e;return}F=m*3|0;s=ac(o,F)|0;E=b+188|0;D=b+192|0;do{if(s>>>0>(c[E>>2]|0)>>>0){v=zJ(c[D>>2]|0,s)|0;if((v|0)==0){i=e;return}else{c[D>>2]=v;c[E>>2]=s;break}}}while(0);c[h>>2]=m;c[j>>2]=o;s=b+56|0;E=c[s>>2]|0;v=d[b+123|0]<<1;C=d[b+118|0]<<8|d[b+119|0];u=(m|0)==0;z=b+127|0;B=f|0;A=g|0;t=b+98|0;r=f+1|0;w=f+2|0;T=g+1|0;S=g+2|0;R=b+114|0;Q=b+115|0;P=b+152|0;O=b+71|0;N=b+124|0;M=c[b+132>>2]|0;L=0;while(1){G=o-L|0;ai=G>>>0>q>>>0?q:G;G=c[D>>2]|0;aj=ac(L,m)|0;if(!u){H=(ai|0)==0;am=M;an=0;while(1){ao=m-an|0;ap=ao>>>0>p>>>0?p:ao;ao=a[z]|0;if((ao&64)==0){aq=(am<<1|am>>>15)&65535}else{aq=am}ar=(ao&1)==0?aq&-8193:aq;ao=G+((an+aj|0)*3|0)|0;as=d[E+ar|0]|0;at=d[E+(ar+65536)|0]|0;ar=(am|0)==(C|0);if((a[t]&8)==0){au=0;av=at}else{if((at&128|0)==0){aw=0}else{aw=(a[P]|0)==0|0}au=aw;av=at&127}pA(b,av&15,B,r,w);pA(b,av>>>4,A,T,S);at=a[R]&31;ax=a[Q]&31;if(ar){ay=(a[P]|0)!=0}else{ay=0}ar=ax>>>0<at>>>0|0;az=a[t]|0;if((az&4)==0){aA=0}else{aA=(as-192|0)>>>0<32|0}do{if((az&2)==0){aB=65535}else{if((av&7|0)!=1){aB=65535;break}aB=a[N]&31}}while(0);az=c[s>>2]|0;aC=d[O]|0;aD=as<<5|((av&8|0)==0?aC:aC>>>2)<<14&49152|131072;if(!H){aC=(au|0)==0;aE=(aA|0)==0;aF=(ap|0)==0;aG=0;aH=ar;aI=ao;while(1){do{if(aC){if((aG|0)==(aB|0)){aJ=65535;break}aK=d[az+(aG+aD)|0]|0;aL=aK<<1;if(aE){aJ=aL;break}aJ=aL|aK&1}else{aJ=0}}while(0);if(ay){if((aG|0)==(at|0)){aM=(aH|0)==0|0}else{aM=aH}if((aG|0)==(ax|0)){aN=(aM|0)==0|0}else{aN=aM}aO=aN;aP=(aN|0)==0?aJ:65535}else{aO=aH;aP=aJ}if(!aF){aK=0;aL=aP;while(1){if((aL&256|0)==0){aQ=aK*3|0;a[aI+aQ|0]=a[A]|0;a[aI+(aQ+1)|0]=a[T]|0;a[aI+(aQ+2)|0]=a[S]|0}else{aQ=aK*3|0;a[aI+aQ|0]=a[B]|0;a[aI+(aQ+1)|0]=a[r]|0;a[aI+(aQ+2)|0]=a[w]|0}aQ=aK+1|0;if(aQ>>>0<ap>>>0){aK=aQ;aL=aL<<1}else{break}}}aL=aG+1|0;if(aL>>>0<ai>>>0){aG=aL;aH=aO;aI=aI+F|0}else{break}}}aI=ap+an|0;if(aI>>>0<m>>>0){am=am+1&65535;an=aI}else{break}}}an=ai+L|0;if(an>>>0>=o>>>0){break}M=M+v&65535;L=an}i=e;return}}while(0);o=b+188|0;m=b+192|0;do{if((c[o>>2]|0)>>>0<192e3){b=zJ(c[m>>2]|0,192e3)|0;if((b|0)==0){break}c[m>>2]=b;c[o>>2]=192e3;aR=2538}else{aR=2538}}while(0);if((aR|0)==2538){c[h>>2]=320;c[j>>2]=200}j=0;h=c[m>>2]|0;while(1){m=(j&8)>>>0<8;aR=0;o=h;while(1){b=(aR&8)>>>0<8^m?32:0;a[o]=b;a[o+1|0]=b;a[o+2|0]=b;b=aR+1|0;if(b>>>0<320){aR=b;o=o+3|0}else{break}}o=j+1|0;if(o>>>0<200){j=o;h=h+960|0}else{break}}i=e;return}function pA(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;do{if((a[(c[b+64>>2]|0)+28|0]|0)>-1){i=a[(e&15&d[b+100|0])+(b+82)|0]|0;j=i;k=i&255}else{i=c[b+148>>2]|0;l=a[(e&15&d[b+100|0])+(b+82)|0]|0;m=l&255;if((i|0)==1){j=l;k=m;break}else if((i|0)!=2){i=l<<1&2|(l&255)>>>3&1;n=i<<2|i;a[h]=n<<4|n;n=(l&255)>>>4&1|l&2;i=n<<2|n;a[g]=i<<4|i;i=(l&255)>>>1&2|(l&255)>>>5&1;l=i<<2|i;a[f]=l<<4|l;return}a[f]=0;a[g]=0;a[h]=0;if((m&8|0)!=0){a[f]=(a[f]|0)-24&255;a[g]=(a[g]|0)-112&255;a[h]=(a[h]|0)+80&255}if((m&16|0)==0){return}a[f]=(a[f]|0)+23&255;a[g]=(a[g]|0)+96&255;a[h]=(a[h]|0)+120&255;return}}while(0);b=(k&16|0)!=0?85:0;a[f]=(((k&4|0)!=0?170:0)|b)&255;a[g]=(((k&2|0)!=0?170:0)|b)&255;a[h]=(((k&1|0)!=0?170:0)|b)&255;if(j<<24>>24!=6){return}a[g]=85;return}function pB(a){a=a|0;return c[a+48>>2]|0}function pC(a){a=a|0;return c[a+56>>2]|0}function pD(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=(c[b+52>>2]|0)+d|0;if((a[f]|0)==e<<24>>24){return}a[f]=e;e=b+196|0;a[e]=a[e]|1;return}function pE(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=e&255;g=b+52|0;h=(c[g>>2]|0)+d|0;if((a[h]|0)!=f<<24>>24){a[h]=f;f=b+196|0;a[f]=a[f]|1}f=d+1|0;if(f>>>0>=(c[(c[b+48>>2]|0)+40>>2]|0)>>>0){return}d=(e&65535)>>>8&255;e=(c[g>>2]|0)+f|0;if((a[e]|0)==d<<24>>24){return}a[e]=d;d=b+196|0;a[d]=a[d]|1;return}function pF(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=zH(200)|0;if((e|0)==0){f=0;return f|0}qH(e);c[e+32>>2]=e;c[e>>2]=84;c[e+4>>2]=38;c[e+8>>2]=236;c[e+12>>2]=202;c[e+16>>2]=432;c[e+20>>2]=30;c[e+24>>2]=166;c[e+28>>2]=460;g=r0(d,65536,1)|0;d=e+48|0;c[d>>2]=g;c[g+24>>2]=e;c[(c[d>>2]|0)+12>>2]=16;c[(c[d>>2]|0)+16>>2]=92;g=c[d>>2]|0;c[e+52>>2]=c[g+44>>2];r3(g,0);rN(c[d>>2]|0,32768);d=r0(b,16,1)|0;b=e+56|0;c[b>>2]=d;c[d+24>>2]=e;c[(c[b>>2]|0)+12>>2]=140;c[(c[b>>2]|0)+16>>2]=126;c[c[b>>2]>>2]=86;c[(c[b>>2]|0)+4>>2]=32;d=c[b>>2]|0;c[e+60>>2]=c[d+44>>2];r3(d,0);zP(e+64|0,0,22);c[e+88>>2]=9432;a[e+92|0]=0;a[e+93|0]=0;a[e+94|0]=0;a[e+95|0]=-24;a[e+96|0]=-112;a[e+97|0]=80;a[e+98|0]=-24;a[e+99|0]=-112;a[e+100|0]=80;a[e+101|0]=-24;a[e+102|0]=-112;a[e+103|0]=80;a[e+104|0]=-24;a[e+105|0]=-112;a[e+106|0]=80;a[e+107|0]=-24;a[e+108|0]=-112;a[e+109|0]=80;a[e+110|0]=-24;a[e+111|0]=-112;a[e+112|0]=80;a[e+113|0]=-24;a[e+114|0]=-112;a[e+115|0]=80;a[e+116|0]=-1;a[e+117|0]=-16;a[e+118|0]=-56;a[e+119|0]=-1;a[e+120|0]=-16;a[e+121|0]=-56;a[e+122|0]=-1;a[e+123|0]=-16;a[e+124|0]=-56;a[e+125|0]=-1;a[e+126|0]=-16;a[e+127|0]=-56;a[e+128|0]=-1;a[e+129|0]=-16;a[e+130|0]=-56;a[e+131|0]=-1;a[e+132|0]=-16;a[e+133|0]=-56;a[e+134|0]=-1;a[e+135|0]=-16;a[e+136|0]=-56;a[e+137|0]=-1;a[e+138|0]=-16;a[e+139|0]=-56;a[e+140|0]=-1;a[e+141|0]=-16;a[e+142|0]=-56;a[e+143|0]=1;c[e+144>>2]=0;c[e+148>>2]=16;c[e+188>>2]=0;c[e+192>>2]=0;a[e+196|0]=0;zP(e+152|0,0,28);f=e;return f|0}function pG(a){a=a|0;if((a|0)==0){return}r2(c[a+48>>2]|0);r2(c[a+56>>2]|0);zI(a);return}function pH(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+8|0;g=f|0;if((xz(33312,d)|0)==0){h=-1;i=f;return h|0}if((xB(e,g)|0)!=0){h=1;i=f;return h|0}e=c[g>>2]|0;a[b+143|0]=1;c[b+144>>2]=e;c[b+148>>2]=e;e=b+196|0;a[e]=a[e]|1;h=0;i=f;return h|0}function pI(a,b){a=a|0;b=b|0;c[a+64>>2]=b;if((b|0)==0){return}zl(b,720,350)|0;return}function pJ(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;aB(39248,28,1,e|0)|0;g=(d[b+82|0]|0)<<8|(d[b+83|0]|0);h=(d[b+80|0]|0)<<8|(d[b+81|0]|0);j=b+60|0;bN(e|0,38192,(x=i,i=i+24|0,c[x>>2]=(d[(c[j>>2]|0)+4|0]|0)>>>7&255,c[x+8>>2]=h,c[x+16>>2]=g,x)|0)|0;g=b+36|0;h=z4(c[g>>2]|0,0,16257e3,0)|0;k=z5(h,G,1193182,0)|0;h=b+164|0;l=c[h>>2]|0;m=b+172|0;n=c[m>>2]|0;o=c[b+168>>2]|0;p=b+176|0;q=c[p>>2]|0;bN(e|0,37216,(x=i,i=i+40|0,c[x>>2]=k,c[x+8>>2]=l,c[x+16>>2]=n,c[x+24>>2]=o,c[x+32>>2]=q,x)|0)|0;q=c[j>>2]|0;o=d[q]|0;n=d[q+4|0]|0;pL(b,0);q=z4(c[g>>2]|0,0,16257e3,0)|0;g=z5(q,G,1193182,0)|0;q=g;g=(c[j>>2]|0)+6|0;a[g]=a[g]^8;g=c[j>>2]|0;j=a[g+6|0]|0;l=j&8;k=q>>>0<(c[p>>2]|0)>>>0;p=(k?-127:1)|j&118;j=c[h>>2]|0;do{if((j|0)==0){r=p}else{if(((q>>>0)%(j>>>0)|0)>>>0>=(c[m>>2]|0)>>>0){r=p;break}h=p&-10;if(!k){r=h;break}r=h|l}}while(0);l=d[g+11|0]|0;bN(e|0,35328,(x=i,i=i+32|0,c[x>>2]=o,c[x+8>>2]=n,c[x+16>>2]=r&255,c[x+24>>2]=l,x)|0)|0;bN(e|0,34816,(x=i,i=i+8|0,c[x>>2]=d[b+68|0]|0,x)|0)|0;l=1;do{if((l&7|0)==0){aA(45,e|0)|0}else{aA(32,e|0)|0}bN(e|0,34032,(x=i,i=i+8|0,c[x>>2]=d[b+68+l|0]|0,x)|0)|0;l=l+1|0;}while(l>>>0<18);aB(33680,2,1,e|0)|0;ax(e|0)|0;i=f;return}function pK(b,d){b=b|0;d=d|0;var e=0,f=0;do{if((d|0)!=0){e=b+64|0;if((c[e>>2]|0)==0){break}pR(b);f=b+184|0;zp(c[e>>2]|0,c[b+180>>2]|0,c[f>>2]|0);zq(c[e>>2]|0,c[b+192>>2]|0,0,c[f>>2]|0);zs(c[e>>2]|0)}}while(0);d=b+196|0;a[d]=a[d]|1;return}function pL(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;d=c[b+168>>2]|0;if(d>>>0<5e4){return}e=b+36|0;f=z4(c[e>>2]|0,0,16257e3,0)|0;g=z5(f,G,1193182,0)|0;f=g;if(f>>>0<(c[b+176>>2]|0)>>>0){g=b+196|0;a[g]=a[g]&-3;return}if(f>>>0>=d>>>0){c[e>>2]=0;c[b+40>>2]=0;c[b+44>>2]=0}e=b+196|0;d=a[e]|0;if((d&2)!=0){return}f=b+144|0;g=c[f>>2]|0;do{if((g|0)==0){h=d}else{i=g-1|0;c[f>>2]=i;if((i|0)!=0){h=d;break}c[f>>2]=c[b+148>>2];i=b+143|0;a[i]=(a[i]|0)==0|0;if((a[(c[b+60>>2]|0)+4|0]&2)!=0){h=d;break}i=d|1;a[e]=i;h=i}}while(0);d=b+64|0;f=c[d>>2]|0;if((f|0)!=0){if((h&1)==0){j=f}else{pR(b);f=b+184|0;zp(c[d>>2]|0,c[b+180>>2]|0,c[f>>2]|0);zq(c[d>>2]|0,c[b+192>>2]|0,0,c[f>>2]|0);j=c[d>>2]|0}zs(j)}a[e]=2;return}function pM(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((e|0)==0){a[c[b+60>>2]|0]=f;return}else if((e|0)==11){g=b+60|0;a[(c[g>>2]|0)+11|0]=f;rN(c[b+48>>2]|0,(a[(c[g>>2]|0)+11|0]&2)==0?32768:65536);return}else if((e|0)==1){g=b+60|0;a[(c[g>>2]|0)+1|0]=f;h=a[c[g>>2]|0]|0;if((h&255)>15){return}i=(h&255)+(b+68)|0;if((a[i]|0)==f<<24>>24){return}a[i]=f;i=(a[b+77|0]&31)+1|0;c[b+160>>2]=i;h=d[b+69|0]|0;c[b+152>>2]=h;j=d[b+74|0]|0;c[b+156>>2]=j;k=(d[b+68|0]|0)+1|0;if((a[(c[g>>2]|0)+4|0]&2)==0){g=k*9|0;c[b+164>>2]=g;c[b+172>>2]=h*9|0;l=g}else{g=k<<4;c[b+164>>2]=g;c[b+172>>2]=h<<4;l=g}g=(d[b+72|0]|0)+1|0;c[b+168>>2]=ac(ac(l,i)|0,g)|0;c[b+176>>2]=ac(ac(j,i)|0,l)|0;l=b+196|0;a[l]=a[l]|1;return}else if((e|0)==4){e=b+60|0;l=c[e>>2]|0;i=d[l+11|0]|0;j=(i&1|0)==0?f&-3:f;f=(i&2|0)==0?j&127:j;j=l+4|0;if((a[j]|0)==f<<24>>24){return}a[j]=f;f=(a[b+77|0]&31)+1|0;c[b+160>>2]=f;j=d[b+69|0]|0;c[b+152>>2]=j;l=d[b+74|0]|0;c[b+156>>2]=l;i=(d[b+68|0]|0)+1|0;if((a[(c[e>>2]|0)+4|0]&2)==0){e=i*9|0;c[b+164>>2]=e;c[b+172>>2]=j*9|0;m=e}else{e=i<<4;c[b+164>>2]=e;c[b+172>>2]=j<<4;m=e}e=(d[b+72|0]|0)+1|0;c[b+168>>2]=ac(ac(m,f)|0,e)|0;c[b+176>>2]=ac(ac(l,f)|0,m)|0;m=b+196|0;a[m]=a[m]|1;return}else{return}}function pN(a,b,c){a=a|0;b=b|0;c=c|0;pM(a,b,c&255);pM(a,b+1|0,(c&65535)>>>8&255);return}function pO(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;if((d|0)==0){e=a[c[b+60>>2]|0]|0;return e|0}else if((d|0)==1){f=a[c[b+60>>2]|0]|0;if((f&255)>15){e=-1;return e|0}e=a[(f&255)+(b+68)|0]|0;return e|0}else if((d|0)==11){e=a[(c[b+60>>2]|0)+11|0]|0;return e|0}else if((d|0)==6){pL(b,0);f=z4(c[b+36>>2]|0,0,16257e3,0)|0;g=z5(f,G,1193182,0)|0;f=g;g=b+60|0;h=(c[g>>2]|0)+6|0;a[h]=a[h]^8;h=a[(c[g>>2]|0)+6|0]|0;g=f>>>0<(c[b+176>>2]|0)>>>0;i=(g?-127:1)|h&118;j=c[b+164>>2]|0;if((j|0)==0){e=i;return e|0}if(((f>>>0)%(j>>>0)|0)>>>0>=(c[b+172>>2]|0)>>>0){e=i;return e|0}j=i&-10;if(!g){e=j;return e|0}e=j|h&8;return e|0}else if((d|0)==4){e=a[(c[b+60>>2]|0)+4|0]|0;return e|0}else{e=-1;return e|0}return 0}function pP(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;do{if((d|0)==0){e=a[c[b+60>>2]|0]|0;if((e&255)>15){f=-1;g=e;break}f=a[(e&255)+(b+68)|0]|0;g=e}else if((d|0)==(-1|0)){f=a[c[b+60>>2]|0]|0;g=-1}else if((d|0)==4){f=-1;g=a[(c[b+60>>2]|0)+4|0]|0}else if((d|0)==3){f=a[(c[b+60>>2]|0)+4|0]|0;g=-1}else if((d|0)==5){pL(b,0);e=z4(c[b+36>>2]|0,0,16257e3,0)|0;h=z5(e,G,1193182,0)|0;e=h;h=b+60|0;i=(c[h>>2]|0)+6|0;a[i]=a[i]^8;i=a[(c[h>>2]|0)+6|0]|0;h=e>>>0<(c[b+176>>2]|0)>>>0;j=(h?-127:1)|i&118;k=c[b+164>>2]|0;if((k|0)==0){f=j;g=-1;break}if(((e>>>0)%(k>>>0)|0)>>>0>=(c[b+172>>2]|0)>>>0){f=j;g=-1;break}k=j&-10;if(!h){f=k;g=-1;break}f=k|i&8;g=-1}else if((d|0)==10){f=a[(c[b+60>>2]|0)+11|0]|0;g=-1}else if((d|0)==11){f=-1;g=a[(c[b+60>>2]|0)+11|0]|0}else if((d|0)==1){i=a[c[b+60>>2]|0]|0;if((i&255)>15){f=-1;g=-1;break}f=-1;g=a[(i&255)+(b+68)|0]|0}else if((d|0)==6){pL(b,0);i=z4(c[b+36>>2]|0,0,16257e3,0)|0;k=z5(i,G,1193182,0)|0;i=k;k=b+60|0;h=(c[k>>2]|0)+6|0;a[h]=a[h]^8;h=a[(c[k>>2]|0)+6|0]|0;k=i>>>0<(c[b+176>>2]|0)>>>0;j=(k?-127:1)|h&118;e=c[b+164>>2]|0;if((e|0)==0){f=-1;g=j;break}if(((i>>>0)%(e>>>0)|0)>>>0>=(c[b+172>>2]|0)>>>0){f=-1;g=j;break}e=j&-10;if(!k){f=-1;g=e;break}f=-1;g=e|h&8}else{f=-1;g=-1}}while(0);return(f&255)<<8|g&255|0}function pQ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+64|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;l=d+48|0;m=d+56|0;yi(b,21128,e,948)|0;yi(b,33776,f,720896)|0;yj(b,31320,m,0)|0;ym(b,29264,l,27560)|0;n=c[l>>2]|0;c[g>>2]=0;do{if((aP(n|0,27560)|0)==0){c[h>>2]=15241296;c[j>>2]=16773320;o=15241296;p=16773320}else{if((aP(n|0,20656)|0)==0){c[h>>2]=5614165;c[j>>2]=11206570;o=5614165;p=11206570;break}if((aP(n|0,40824)|0)==0){c[h>>2]=11184810;c[j>>2]=16777215;o=11184810;p=16777215;break}else{c[h>>2]=15241296;c[j>>2]=16773320;o=15241296;p=16773320;break}}}while(0);yi(b,25992,g,0)|0;yi(b,24696,h,o)|0;yi(b,23136,j,p)|0;yi(b,21856,k,c[j>>2]|0)|0;b=pF(c[e>>2]|0,c[f>>2]|0)|0;if((b|0)==0){q=0;i=d;return q|0}f=c[g>>2]|0;a[b+92|0]=f>>>16&255;a[b+93|0]=f>>>8&255;a[b+94|0]=f&255;f=c[h>>2]|0;h=f>>>16&255;g=f>>>8&255;e=f&255;a[b+95|0]=h;a[b+96|0]=g;a[b+97|0]=e;a[b+98|0]=h;a[b+99|0]=g;a[b+100|0]=e;a[b+101|0]=h;a[b+102|0]=g;a[b+103|0]=e;a[b+104|0]=h;a[b+105|0]=g;a[b+106|0]=e;a[b+107|0]=h;a[b+108|0]=g;a[b+109|0]=e;a[b+110|0]=h;a[b+111|0]=g;a[b+112|0]=e;a[b+113|0]=h;a[b+114|0]=g;a[b+115|0]=e;e=c[j>>2]|0;j=e>>>16&255;g=e>>>8&255;h=e&255;a[b+116|0]=j;a[b+117|0]=g;a[b+118|0]=h;a[b+119|0]=j;a[b+120|0]=g;a[b+121|0]=h;a[b+122|0]=j;a[b+123|0]=g;a[b+124|0]=h;a[b+125|0]=j;a[b+126|0]=g;a[b+127|0]=h;a[b+128|0]=j;a[b+129|0]=g;a[b+130|0]=h;a[b+131|0]=j;a[b+132|0]=g;a[b+133|0]=h;a[b+134|0]=j;a[b+135|0]=g;a[b+136|0]=h;a[b+137|0]=j;a[b+138|0]=g;a[b+139|0]=h;h=c[k>>2]|0;a[b+140|0]=h>>>16&255;a[b+141|0]=h>>>8&255;a[b+142|0]=h&255;h=c[m>>2]|0;a[b+143|0]=1;c[b+144>>2]=h;c[b+148>>2]=h;h=b+196|0;a[h]=a[h]|1;q=b|0;i=d;return q|0}function pR(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0;e=b+60|0;f=c[e>>2]|0;g=d[f+4|0]|0;if((g&8|0)==0){h=b+188|0;i=b+192|0;do{if((c[h>>2]|0)>>>0<756e3){j=zJ(c[i>>2]|0,756e3)|0;if((j|0)!=0){c[i>>2]=j;c[h>>2]=756e3;k=2786;break}j=c[b+184>>2]|0;if((j|0)==0){return}else{l=j;m=c[b+180>>2]|0;break}}else{k=2786}}while(0);if((k|0)==2786){c[b+180>>2]=720;c[b+184>>2]=350;l=350;m=720}h=b+184|0;j=b+180|0;n=0;o=c[i>>2]|0;i=m;m=l;while(1){l=(n&8)>>>0<8;if((i|0)==0){p=o;q=0;r=m}else{s=0;t=o;do{u=(s&8)>>>0<8^l?32:0;a[t]=u;a[t+1|0]=u;a[t+2|0]=u;t=t+3|0;s=s+1|0;v=c[j>>2]|0;}while(s>>>0<v>>>0);p=t;q=v;r=c[h>>2]|0}s=n+1|0;if(s>>>0<r>>>0){n=s;o=p;i=q;m=r}else{break}}return}r=b+152|0;m=c[r>>2]|0;do{if((m|0)!=0){q=b+156|0;i=c[q>>2]|0;if((i|0)==0){break}if((g&2|0)!=0){p=m<<1;o=b+160|0;n=ac(c[o>>2]|0,i)|0;h=m<<4;v=m*48|0;j=ac(n,v)|0;s=b+188|0;l=b+192|0;u=c[l>>2]|0;do{if(j>>>0>(c[s>>2]|0)>>>0){w=zJ(u,j)|0;if((w|0)==0){return}else{c[l>>2]=w;c[s>>2]=j;x=w;y=c[e>>2]|0;break}}else{x=u;y=f}}while(0);c[b+180>>2]=h;c[b+184>>2]=n;u=c[b+52>>2]|0;j=(a[y+4|0]|0)<0?u+32768|0:u;if((n|0)==0){return}u=b+140|0;s=b+92|0;if((p|0)==0){return}l=0;t=(d[b+80|0]<<8|d[b+81|0])<<1&32766;w=0;z=x;while(1){A=l<<13&24576;B=0;C=z;while(1){D=a[j+(B+t&8191|A)|0]|0;E=D<<24>>24<0?u:s;a[C]=a[E|0]|0;a[C+1|0]=a[E+1|0]|0;a[C+2|0]=a[E+2|0]|0;E=(D&64)!=0?u:s;a[C+3|0]=a[E|0]|0;a[C+4|0]=a[E+1|0]|0;a[C+5|0]=a[E+2|0]|0;E=(D&32)!=0?u:s;a[C+6|0]=a[E|0]|0;a[C+7|0]=a[E+1|0]|0;a[C+8|0]=a[E+2|0]|0;E=(D&16)!=0?u:s;a[C+9|0]=a[E|0]|0;a[C+10|0]=a[E+1|0]|0;a[C+11|0]=a[E+2|0]|0;E=(D&8)!=0?u:s;a[C+12|0]=a[E|0]|0;a[C+13|0]=a[E+1|0]|0;a[C+14|0]=a[E+2|0]|0;E=(D&4)!=0?u:s;a[C+15|0]=a[E|0]|0;a[C+16|0]=a[E+1|0]|0;a[C+17|0]=a[E+2|0]|0;E=(D&2)!=0?u:s;a[C+18|0]=a[E|0]|0;a[C+19|0]=a[E+1|0]|0;a[C+20|0]=a[E+2|0]|0;E=(D&1)!=0?u:s;a[C+21|0]=a[E|0]|0;a[C+22|0]=a[E+1|0]|0;a[C+23|0]=a[E+2|0]|0;E=B+1|0;if(E>>>0<p>>>0){B=E;C=C+24|0}else{break}}C=l+1|0;if(C>>>0<(c[o>>2]|0)>>>0){F=t;G=C}else{F=(c[r>>2]<<1)+t&8191;G=0}C=w+1|0;if(C>>>0<n>>>0){l=G;t=F;w=C;z=z+v|0}else{break}}return}v=m*9|0;z=b+160|0;w=ac(c[z>>2]|0,i)|0;t=ac(m*27|0,w)|0;l=b+188|0;n=b+192|0;do{if(t>>>0>(c[l>>2]|0)>>>0){o=zJ(c[n>>2]|0,t)|0;if((o|0)==0){return}else{c[n>>2]=o;c[l>>2]=t;H=c[q>>2]|0;I=c[e>>2]|0;break}}else{H=i;I=f}}while(0);c[b+180>>2]=v;c[b+184>>2]=w;i=b+52|0;t=c[i>>2]|0;l=(a[I+4|0]|0)<0?t+32768|0:t;if((H|0)==0){J=0;K=b+143|0}else{t=b+92|0;o=b+113|0;p=b+137|0;s=b+88|0;u=b+143|0;j=c[r>>2]|0;h=0;C=(d[b+80|0]<<8|d[b+81|0])<<1&32766;B=c[n>>2]|0;A=j;E=H;D=j;while(1){if((A|0)==0){L=C;M=0;N=E;O=D;P=c[z>>2]|0}else{j=C;Q=0;R=D;while(1){S=B+(Q*27|0)|0;T=a[l+j|0]|0;U=a[l+(j+1)|0]|0;V=(a[(c[e>>2]|0)+4|0]&32)==0;if(V){W=U;X=0}else{if(U<<24>>24>-1){Y=0}else{Y=(a[u]|0)==0|0}W=U&127;X=Y}U=W&255;Z=(U&7|0)==1?13:65535;_=T&255;$=(T+64&255)<32;do{if((U&119|0)==112){if((U&128|0)==0){aa=o;ab=t;break}aa=V?p:o;ab=t}else{aa=t;ab=b+92+((U&15)*3|0)|0}}while(0);U=c[s>>2]|0;V=_*14|0;L3587:do{if((c[z>>2]|0)==0){ad=R;ae=0}else{T=aa+1|0;af=aa+2|0;ag=ab+1|0;ah=ab+2|0;if((X|0)==0){ai=0;aj=S}else{ak=0;al=S;while(1){a[al]=a[aa]|0;a[al+1|0]=a[T]|0;a[al+2|0]=a[af]|0;a[al+3|0]=a[aa]|0;a[al+4|0]=a[T]|0;a[al+5|0]=a[af]|0;a[al+6|0]=a[aa]|0;a[al+7|0]=a[T]|0;a[al+8|0]=a[af]|0;a[al+9|0]=a[aa]|0;a[al+10|0]=a[T]|0;a[al+11|0]=a[af]|0;a[al+12|0]=a[aa]|0;a[al+13|0]=a[T]|0;a[al+14|0]=a[af]|0;a[al+15|0]=a[aa]|0;a[al+16|0]=a[T]|0;a[al+17|0]=a[af]|0;a[al+18|0]=a[aa]|0;a[al+19|0]=a[T]|0;a[al+20|0]=a[af]|0;a[al+21|0]=a[aa]|0;a[al+22|0]=a[T]|0;a[al+23|0]=a[af]|0;a[al+24|0]=a[aa]|0;a[al+25|0]=a[T]|0;a[al+26|0]=a[af]|0;am=c[r>>2]|0;an=ak+1|0;ao=c[z>>2]|0;if(an>>>0<ao>>>0){ak=an;al=al+(am*27|0)|0}else{ad=am;ae=ao;break L3587}}}while(1){do{if((ai|0)==(Z|0)){ap=0;aq=511}else{al=d[U+(((ai>>>0)%14|0)+V)|0]|0;ak=al<<1;if(!$){ap=0;aq=ak;break}ap=0;aq=ak|al&1}}while(0);while(1){if((aq&256|0)==0){al=ap*3|0;a[aj+al|0]=a[aa]|0;a[aj+(al+1)|0]=a[T]|0;a[aj+(al+2)|0]=a[af]|0}else{al=ap*3|0;a[aj+al|0]=a[ab]|0;a[aj+(al+1)|0]=a[ag]|0;a[aj+(al+2)|0]=a[ah]|0}al=ap+1|0;if(al>>>0<9){ap=al;aq=aq<<1}else{break}}al=c[r>>2]|0;ak=ai+1|0;ao=c[z>>2]|0;if(ak>>>0<ao>>>0){ai=ak;aj=aj+(al*27|0)|0}else{ad=al;ae=ao;break}}}}while(0);ar=j+2&32766;$=Q+1|0;if($>>>0<ad>>>0){j=ar;Q=$;R=ad}else{break}}L=ar;M=ad;N=c[q>>2]|0;O=ad;P=ae}R=B+(ac(P*27|0,M)|0)|0;Q=h+1|0;if(Q>>>0<N>>>0){h=Q;C=L;B=R;A=M;E=N;D=O}else{J=N;K=u;break}}}if((a[K]|0)==0){return}u=a[b+78|0]|0;if((u&96)==32){return}D=c[i>>2]|0;E=(a[(c[e>>2]|0)+4|0]|0)<0?D+32768|0:D;D=c[r>>2]|0;if((D|0)==0|(J|0)==0){return}A=d[b+82|0]<<8&16128|d[b+83|0];B=d[b+80|0]<<8&16128|d[b+81|0];if(A>>>0<B>>>0){return}if(A>>>0>=(B+(ac(D,J)|0)|0)>>>0){return}C=A-B|0;B=(C>>>0)%(D>>>0)|0;A=(C>>>0)/(D>>>0)|0;C=u&31;u=a[b+79|0]&31;h=c[z>>2]|0;if(C>>>0>=h>>>0){return}q=u>>>0<h>>>0?u:h-1|0;u=a[E+((ac(A,D)|0)+B<<1|1)|0]&15;E=b+92+(u*3|0)|0;if(C>>>0>q>>>0){return}s=((ac((ac(h,A)|0)+C|0,D)|0)+B|0)*27|0;B=b+92+(u*3|0)+1|0;D=b+92+(u*3|0)+2|0;u=C;C=(c[n>>2]|0)+s|0;while(1){a[C]=a[E]|0;a[C+1|0]=a[B]|0;a[C+2|0]=a[D]|0;a[C+3|0]=a[E]|0;a[C+4|0]=a[B]|0;a[C+5|0]=a[D]|0;a[C+6|0]=a[E]|0;a[C+7|0]=a[B]|0;a[C+8|0]=a[D]|0;a[C+9|0]=a[E]|0;a[C+10|0]=a[B]|0;a[C+11|0]=a[D]|0;a[C+12|0]=a[E]|0;a[C+13|0]=a[B]|0;a[C+14|0]=a[D]|0;a[C+15|0]=a[E]|0;a[C+16|0]=a[B]|0;a[C+17|0]=a[D]|0;a[C+18|0]=a[E]|0;a[C+19|0]=a[B]|0;a[C+20|0]=a[D]|0;a[C+21|0]=a[E]|0;a[C+22|0]=a[B]|0;a[C+23|0]=a[D]|0;a[C+24|0]=a[E]|0;a[C+25|0]=a[B]|0;a[C+26|0]=a[D]|0;s=u+1|0;if(s>>>0>q>>>0){break}else{u=s;C=C+((c[r>>2]|0)*27|0)|0}}return}}while(0);r=b+188|0;J=b+192|0;do{if((c[r>>2]|0)>>>0<756e3){e=zJ(c[J>>2]|0,756e3)|0;if((e|0)!=0){c[J>>2]=e;c[r>>2]=756e3;k=2799;break}e=c[b+184>>2]|0;if((e|0)==0){return}else{as=e;at=c[b+180>>2]|0;break}}else{k=2799}}while(0);if((k|0)==2799){c[b+180>>2]=720;c[b+184>>2]=350;as=350;at=720}k=b+184|0;r=b+180|0;b=0;e=c[J>>2]|0;J=at;at=as;while(1){as=(b&8)>>>0<8;if((J|0)==0){au=e;av=0;aw=at}else{K=0;N=e;do{O=(K&8)>>>0<8^as?32:0;a[N]=O;a[N+1|0]=O;a[N+2|0]=O;N=N+3|0;K=K+1|0;ax=c[r>>2]|0;}while(K>>>0<ax>>>0);au=N;av=ax;aw=c[k>>2]|0}K=b+1|0;if(K>>>0<aw>>>0){b=K;e=au;J=av;at=aw}else{break}}return}function pS(a){a=a|0;return c[a+48>>2]|0}function pT(a){a=a|0;return c[a+4148>>2]|0}function pU(b,c,d){b=b|0;c=c|0;d=d|0;var e=0;e=(c&4095)+(b+52)|0;if((a[e]|0)==d<<24>>24){return}a[e]=d;d=b+4288|0;a[d]=a[d]|1;return}function pV(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0;f=e&255;g=(d&4095)+(b+52)|0;if((a[g]|0)!=f<<24>>24){a[g]=f;f=b+4288|0;a[f]=a[f]|1}f=d+1|0;if(f>>>0>=(c[(c[b+48>>2]|0)+40>>2]|0)>>>0){return}d=(e&65535)>>>8&255;e=(f&4095)+(b+52)|0;if((a[e]|0)==d<<24>>24){return}a[e]=d;d=b+4288|0;a[d]=a[d]|1;return}function pW(b,c){b=b|0;c=c|0;return a[(c&4095)+(b+52)|0]|0}function pX(a,b){a=a|0;b=b|0;return(d[(b+1&4095)+(a+52)|0]|0)<<8|(d[(b&4095)+(a+52)|0]|0)|0}function pY(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;if((e|0)==0){a[c[b+4152>>2]|0]=f;return}else if((e|0)==1){g=b+4152|0;a[(c[g>>2]|0)+1|0]=f;h=a[c[g>>2]|0]|0;if((h&255)>15){return}g=(h&255)+(b+4160)|0;if((a[g]|0)==f<<24>>24){return}a[g]=f;g=(a[b+4169|0]&31)+1|0;c[b+4252>>2]=g;h=d[b+4161|0]|0;c[b+4244>>2]=h;i=d[b+4166|0]|0;c[b+4248>>2]=i;j=((d[b+4160|0]|0)*9|0)+9|0;c[b+4256>>2]=j;c[b+4264>>2]=h*9|0;h=(d[b+4164|0]|0)+1|0;c[b+4260>>2]=ac(ac(j,g)|0,h)|0;c[b+4268>>2]=ac(ac(i,g)|0,j)|0;j=b+4288|0;a[j]=a[j]|1;return}else if((e|0)==4){a[(c[b+4152>>2]|0)+4|0]=f;f=b+4288|0;a[f]=a[f]|1;return}else{return}}function pZ(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=f&255;if((e|0)==0){h=b+4152|0;a[c[h>>2]|0]=g;i=(f&65535)>>>8&255;a[(c[h>>2]|0)+1|0]=i;j=a[c[h>>2]|0]|0;if((j&255)>15){return}h=(j&255)+(b+4160)|0;if((a[h]|0)==i<<24>>24){return}a[h]=i;i=(a[b+4169|0]&31)+1|0;c[b+4252>>2]=i;h=d[b+4161|0]|0;c[b+4244>>2]=h;j=d[b+4166|0]|0;c[b+4248>>2]=j;k=((d[b+4160|0]|0)*9|0)+9|0;c[b+4256>>2]=k;c[b+4264>>2]=h*9|0;h=(d[b+4164|0]|0)+1|0;c[b+4260>>2]=ac(ac(k,i)|0,h)|0;c[b+4268>>2]=ac(ac(j,i)|0,k)|0;k=b+4288|0;a[k]=a[k]|1;return}else if((e|0)==4){a[(c[b+4152>>2]|0)+4|0]=g;k=b+4288|0;a[k]=a[k]|1;return}else if((e|0)==1){k=b+4152|0;a[(c[k>>2]|0)+1|0]=g;i=a[c[k>>2]|0]|0;if((i&255)>15){return}k=(i&255)+(b+4160)|0;if((a[k]|0)==g<<24>>24){return}a[k]=g;g=(a[b+4169|0]&31)+1|0;c[b+4252>>2]=g;k=d[b+4161|0]|0;c[b+4244>>2]=k;i=d[b+4166|0]|0;c[b+4248>>2]=i;j=((d[b+4160|0]|0)*9|0)+9|0;c[b+4256>>2]=j;c[b+4264>>2]=k*9|0;k=(d[b+4164|0]|0)+1|0;c[b+4260>>2]=ac(ac(j,g)|0,k)|0;c[b+4268>>2]=ac(ac(i,g)|0,j)|0;j=b+4288|0;a[j]=a[j]|1;return}else{j=(f&65535)>>>8&255;if((e|0)==(-1|0)){a[c[b+4152>>2]|0]=j;return}else if((e|0)==3){a[(c[b+4152>>2]|0)+4|0]=j;j=b+4288|0;a[j]=a[j]|1;return}else{return}}}function p_(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=zH(4292)|0;if((f|0)==0){g=0;return g|0}qH(f);c[f+32>>2]=f;c[f>>2]=88;c[f+4>>2]=60;c[f+8>>2]=360;c[f+12>>2]=468;c[f+16>>2]=528;c[f+20>>2]=172;c[f+24>>2]=462;c[f+28>>2]=328;h=r0(d,e>>>0<4096?4096:e,0)|0;e=f+48|0;c[e>>2]=h;c[h+24>>2]=f;c[(c[e>>2]|0)+12>>2]=56;c[(c[e>>2]|0)+16>>2]=130;c[c[e>>2]>>2]=22;c[(c[e>>2]|0)+4>>2]=84;zP(f+52|0,0,4096);e=r0(b,16,1)|0;b=f+4148|0;c[b>>2]=e;c[e+24>>2]=f;c[(c[b>>2]|0)+12>>2]=62;c[(c[b>>2]|0)+16>>2]=82;c[c[b>>2]>>2]=8;c[(c[b>>2]|0)+4>>2]=118;e=c[b>>2]|0;c[f+4152>>2]=c[e+44>>2];r3(e,0);zP(f+4156|0,0,22);c[f+4180>>2]=1816;a[f+4184|0]=0;a[f+4185|0]=0;a[f+4186|0]=0;a[f+4187|0]=0;a[f+4188|0]=-86;a[f+4189|0]=0;a[f+4190|0]=0;a[f+4191|0]=-86;a[f+4192|0]=0;a[f+4193|0]=0;a[f+4194|0]=-86;a[f+4195|0]=0;a[f+4196|0]=0;a[f+4197|0]=-86;a[f+4198|0]=0;a[f+4199|0]=0;a[f+4200|0]=-86;a[f+4201|0]=0;a[f+4202|0]=0;a[f+4203|0]=-86;a[f+4204|0]=0;a[f+4205|0]=0;a[f+4206|0]=-86;a[f+4207|0]=0;a[f+4208|0]=-86;a[f+4209|0]=-1;a[f+4210|0]=-86;a[f+4211|0]=-86;a[f+4212|0]=-1;a[f+4213|0]=-86;a[f+4214|0]=-86;a[f+4215|0]=-1;a[f+4216|0]=-86;a[f+4217|0]=-86;a[f+4218|0]=-1;a[f+4219|0]=-86;a[f+4220|0]=-86;a[f+4221|0]=-1;a[f+4222|0]=-86;a[f+4223|0]=-86;a[f+4224|0]=-1;a[f+4225|0]=-86;a[f+4226|0]=-86;a[f+4227|0]=-1;a[f+4228|0]=-86;a[f+4229|0]=-86;a[f+4230|0]=-1;a[f+4231|0]=-86;c[f+4280>>2]=0;c[f+4284>>2]=0;a[f+4288|0]=0;zP(f+4244|0,0,28);g=f;return g|0}function p$(a){a=a|0;if((a|0)==0){return}r2(c[a+48>>2]|0);r2(c[a+4148>>2]|0);zI(a);return}function p0(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+8|0;g=f|0;if((xz(32272,d)|0)==0){h=-1;i=f;return h|0}if((xB(e,g)|0)!=0){h=1;i=f;return h|0}e=c[g>>2]|0;a[b+4232|0]=1;c[b+4236>>2]=e;c[b+4240>>2]=e;e=b+4288|0;a[e]=a[e]|1;h=0;i=f;return h|0}function p1(a,b){a=a|0;b=b|0;c[a+4156>>2]=b;if((b|0)==0){return}zl(b,720,350)|0;return}function p2(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;aB(37200,9,1,e|0)|0;g=(d[b+4174|0]|0)<<8|(d[b+4175|0]|0);bN(e|0,35296,(x=i,i=i+16|0,c[x>>2]=(d[b+4172|0]|0)<<8|(d[b+4173|0]|0),c[x+8>>2]=g,x)|0)|0;g=b+36|0;h=z4(c[g>>2]|0,0,16257e3,0)|0;j=z5(h,G,1193182,0)|0;h=b+4256|0;k=c[h>>2]|0;l=b+4264|0;m=c[l>>2]|0;n=c[b+4260>>2]|0;o=b+4268|0;p=c[o>>2]|0;bN(e|0,34768,(x=i,i=i+40|0,c[x>>2]=j,c[x+8>>2]=k,c[x+16>>2]=m,c[x+24>>2]=n,c[x+32>>2]=p,x)|0)|0;p=b+4152|0;n=c[p>>2]|0;m=d[n]|0;k=d[n+4|0]|0;p4(b,0);n=z4(c[g>>2]|0,0,16257e3,0)|0;g=z5(n,G,1193182,0)|0;n=g;g=(c[p>>2]|0)+6|0;a[g]=a[g]^8;g=a[(c[p>>2]|0)+6|0]|0;p=g&-10;j=p|1;q=c[h>>2]|0;do{if((q|0)==0){r=j}else{if(((n>>>0)%(q>>>0)|0)>>>0>=(c[l>>2]|0)>>>0){r=j;break}r=n>>>0<(c[o>>2]|0)>>>0?g&-2:p}}while(0);bN(e|0,34504,(x=i,i=i+24|0,c[x>>2]=m,c[x+8>>2]=k,c[x+16>>2]=r&255,x)|0)|0;bN(e|0,34248,(x=i,i=i+8|0,c[x>>2]=d[b+4160|0]|0,x)|0)|0;r=1;do{if((r&7|0)==0){aA(45,e|0)|0}else{aA(32,e|0)|0}bN(e|0,33304,(x=i,i=i+8|0,c[x>>2]=d[b+4160+r|0]|0,x)|0)|0;r=r+1|0;}while(r>>>0<18);aB(32536,2,1,e|0)|0;ax(e|0)|0;i=f;return}function p3(b,d){b=b|0;d=d|0;var e=0,f=0;do{if((d|0)!=0){e=b+4156|0;if((c[e>>2]|0)==0){break}p8(b);f=b+4276|0;zp(c[e>>2]|0,c[b+4272>>2]|0,c[f>>2]|0);zq(c[e>>2]|0,c[b+4284>>2]|0,0,c[f>>2]|0);zs(c[e>>2]|0)}}while(0);d=b+4288|0;a[d]=a[d]|1;return}function p4(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;d=c[b+4260>>2]|0;if(d>>>0<5e4){return}e=b+36|0;f=z4(c[e>>2]|0,0,16257e3,0)|0;g=z5(f,G,1193182,0)|0;f=g;if(f>>>0<(c[b+4268>>2]|0)>>>0){g=b+4288|0;a[g]=a[g]&-3;return}if(f>>>0>=d>>>0){c[e>>2]=0;c[b+40>>2]=0;c[b+44>>2]=0}e=b+4288|0;d=a[e]|0;if((d&2)!=0){return}f=b+4236|0;g=c[f>>2]|0;do{if((g|0)==0){h=d}else{i=g-1|0;c[f>>2]=i;if((i|0)!=0){h=d;break}c[f>>2]=c[b+4240>>2];i=b+4232|0;a[i]=(a[i]|0)==0|0;i=d|1;a[e]=i;h=i}}while(0);d=b+4156|0;f=c[d>>2]|0;if((f|0)!=0){if((h&1)==0){j=f}else{p8(b);f=b+4276|0;zp(c[d>>2]|0,c[b+4272>>2]|0,c[f>>2]|0);zq(c[d>>2]|0,c[b+4284>>2]|0,0,c[f>>2]|0);j=c[d>>2]|0}zs(j)}a[e]=2;return}function p5(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;if((d|0)==0){e=a[c[b+4152>>2]|0]|0;return e|0}else if((d|0)==6){p4(b,0);f=z4(c[b+36>>2]|0,0,16257e3,0)|0;g=z5(f,G,1193182,0)|0;f=g;g=b+4152|0;h=(c[g>>2]|0)+6|0;a[h]=a[h]^8;h=a[(c[g>>2]|0)+6|0]|0;g=h&-10;i=g|1;j=c[b+4256>>2]|0;if((j|0)==0){e=i;return e|0}if(((f>>>0)%(j>>>0)|0)>>>0>=(c[b+4264>>2]|0)>>>0){e=i;return e|0}e=f>>>0<(c[b+4268>>2]|0)>>>0?h&-2:g;return e|0}else if((d|0)==1){d=a[c[b+4152>>2]|0]|0;if((d&255)>15){e=-1;return e|0}e=a[(d&255)+(b+4160)|0]|0;return e|0}else{e=-1;return e|0}return 0}function p6(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;do{if((d|0)==0){e=a[c[b+4152>>2]|0]|0;if((e&255)>15){f=-1;g=e;break}f=a[(e&255)+(b+4160)|0]|0;g=e}else if((d|0)==(-1|0)){f=a[c[b+4152>>2]|0]|0;g=-1}else if((d|0)==1){e=a[c[b+4152>>2]|0]|0;if((e&255)>15){f=-1;g=-1;break}f=-1;g=a[(e&255)+(b+4160)|0]|0}else if((d|0)==5){p4(b,0);e=z4(c[b+36>>2]|0,0,16257e3,0)|0;h=z5(e,G,1193182,0)|0;e=h;h=b+4152|0;i=(c[h>>2]|0)+6|0;a[i]=a[i]^8;i=a[(c[h>>2]|0)+6|0]|0;h=i&-10;j=h|1;k=c[b+4256>>2]|0;if((k|0)==0){f=j;g=-1;break}if(((e>>>0)%(k>>>0)|0)>>>0>=(c[b+4264>>2]|0)>>>0){f=j;g=-1;break}f=e>>>0<(c[b+4268>>2]|0)>>>0?i&-2:h;g=-1}else if((d|0)==6){p4(b,0);h=z4(c[b+36>>2]|0,0,16257e3,0)|0;i=z5(h,G,1193182,0)|0;h=i;i=b+4152|0;e=(c[i>>2]|0)+6|0;a[e]=a[e]^8;e=a[(c[i>>2]|0)+6|0]|0;i=e&-10;j=i|1;k=c[b+4256>>2]|0;if((k|0)==0){f=-1;g=j;break}if(((h>>>0)%(k>>>0)|0)>>>0>=(c[b+4264>>2]|0)>>>0){f=-1;g=j;break}f=-1;g=h>>>0<(c[b+4268>>2]|0)>>>0?e&-2:i}else{f=-1;g=-1}}while(0);return(f&255)<<8|g&255|0}function p7(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+64|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;l=d+48|0;m=d+56|0;yi(b,20952,e,948)|0;yi(b,33744,f,720896)|0;yi(b,31304,g,32768)|0;yj(b,29248,m,0)|0;n=c[f>>2]|0;o=c[g>>2]|0;xv(2,27544,25944,(x=i,i=i+24|0,c[x>>2]=c[e>>2],c[x+8>>2]=n,c[x+16>>2]=o,x)|0);ym(b,24688,l,23128)|0;o=c[l>>2]|0;c[h>>2]=0;do{if((aP(o|0,39240)|0)==0){c[j>>2]=15241296;c[k>>2]=16773320;p=15241296;q=16773320}else{if((aP(o|0,23128)|0)==0){c[j>>2]=5614165;c[k>>2]=11206570;p=5614165;q=11206570;break}if((aP(o|0,38184)|0)==0){c[j>>2]=11184810;c[k>>2]=16777215;p=11184810;q=16777215;break}else{c[j>>2]=15241296;c[k>>2]=16773320;p=15241296;q=16773320;break}}}while(0);yi(b,21832,h,0)|0;yi(b,20640,j,p)|0;yi(b,40808,k,q)|0;q=p_(c[e>>2]|0,c[f>>2]|0,c[g>>2]|0)|0;if((q|0)==0){r=0;i=d;return r|0}g=c[h>>2]|0;a[q+4184|0]=g>>>16&255;a[q+4185|0]=g>>>8&255;a[q+4186|0]=g&255;g=c[j>>2]|0;j=g>>>16&255;h=g>>>8&255;f=g&255;a[q+4187|0]=j;a[q+4188|0]=h;a[q+4189|0]=f;a[q+4190|0]=j;a[q+4191|0]=h;a[q+4192|0]=f;a[q+4193|0]=j;a[q+4194|0]=h;a[q+4195|0]=f;a[q+4196|0]=j;a[q+4197|0]=h;a[q+4198|0]=f;a[q+4199|0]=j;a[q+4200|0]=h;a[q+4201|0]=f;a[q+4202|0]=j;a[q+4203|0]=h;a[q+4204|0]=f;a[q+4205|0]=j;a[q+4206|0]=h;a[q+4207|0]=f;f=c[k>>2]|0;k=f>>>16&255;h=f>>>8&255;j=f&255;a[q+4208|0]=k;a[q+4209|0]=h;a[q+4210|0]=j;a[q+4211|0]=k;a[q+4212|0]=h;a[q+4213|0]=j;a[q+4214|0]=k;a[q+4215|0]=h;a[q+4216|0]=j;a[q+4217|0]=k;a[q+4218|0]=h;a[q+4219|0]=j;a[q+4220|0]=k;a[q+4221|0]=h;a[q+4222|0]=j;a[q+4223|0]=k;a[q+4224|0]=h;a[q+4225|0]=j;a[q+4226|0]=k;a[q+4227|0]=h;a[q+4228|0]=j;a[q+4229|0]=k;a[q+4230|0]=h;a[q+4231|0]=j;j=c[m>>2]|0;a[q+4232|0]=1;c[q+4236>>2]=j;c[q+4240>>2]=j;j=q+4288|0;a[j]=a[j]|1;r=q|0;i=d;return r|0}function p8(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0;e=b+4152|0;if((a[(c[e>>2]|0)+4|0]&8)==0){f=b+4280|0;g=b+4284|0;do{if((c[f>>2]|0)>>>0<756e3){h=zJ(c[g>>2]|0,756e3)|0;if((h|0)!=0){c[g>>2]=h;c[f>>2]=756e3;i=3027;break}h=c[b+4276>>2]|0;if((h|0)==0){return}else{j=h;k=c[b+4272>>2]|0;break}}else{i=3027}}while(0);if((i|0)==3027){c[b+4272>>2]=720;c[b+4276>>2]=350;j=350;k=720}f=b+4276|0;h=b+4272|0;l=0;m=c[g>>2]|0;g=k;k=j;while(1){j=(l&8)>>>0<8;if((g|0)==0){n=m;o=0;p=k}else{q=0;r=m;do{s=(q&8)>>>0<8^j?32:0;a[r]=s;a[r+1|0]=s;a[r+2|0]=s;r=r+3|0;q=q+1|0;t=c[h>>2]|0;}while(q>>>0<t>>>0);n=r;o=t;p=c[f>>2]|0}q=l+1|0;if(q>>>0<p>>>0){l=q;m=n;g=o;k=p}else{break}}return}p=b+4244|0;k=c[p>>2]|0;do{if((k|0)!=0){o=b+4248|0;g=c[o>>2]|0;if((g|0)==0){break}n=k*9|0;m=b+4252|0;l=ac(c[m>>2]|0,g)|0;f=ac(k*27|0,l)|0;t=b+4280|0;h=b+4284|0;do{if(f>>>0>(c[t>>2]|0)>>>0){q=zJ(c[h>>2]|0,f)|0;if((q|0)==0){return}else{c[h>>2]=q;c[t>>2]=f;u=c[o>>2]|0;break}}else{u=g}}while(0);c[b+4272>>2]=n;c[b+4276>>2]=l;if((u|0)==0){v=0;w=b+4232|0}else{g=b+4184|0;f=b+4205|0;t=b+4229|0;r=b+4180|0;q=b+4232|0;j=c[p>>2]|0;s=0;x=(d[b+4172|0]<<8|d[b+4173|0])<<1&4094;y=c[h>>2]|0;z=j;A=u;B=j;while(1){if((z|0)==0){C=x;D=0;E=A;F=B;G=c[m>>2]|0}else{j=x;H=0;I=B;while(1){J=y+(H*27|0)|0;K=a[b+52+j|0]|0;L=a[j+1+(b+52)|0]|0;M=(a[(c[e>>2]|0)+4|0]&32)==0;if(M){N=L;O=0}else{if(L<<24>>24>-1){P=0}else{P=(a[q]|0)==0|0}N=L&127;O=P}L=N&255;Q=(L&7|0)==1?13:65535;R=K&255;S=(K+64&255)<32;do{if((L&119|0)==112){if((L&128|0)==0){T=f;U=g;break}T=M?t:f;U=g}else{T=g;U=b+4184+((L&15)*3|0)|0}}while(0);L=c[r>>2]|0;M=R*14|0;L3878:do{if((c[m>>2]|0)==0){V=I;W=0}else{K=T+1|0;X=T+2|0;Y=U+1|0;Z=U+2|0;if((O|0)==0){_=0;$=J}else{if(S){aa=0;ab=J;while(1){a[ab]=a[T]|0;a[ab+1|0]=a[K]|0;a[ab+2|0]=a[X]|0;a[ab+3|0]=a[T]|0;a[ab+4|0]=a[K]|0;a[ab+5|0]=a[X]|0;a[ab+6|0]=a[T]|0;a[ab+7|0]=a[K]|0;a[ab+8|0]=a[X]|0;a[ab+9|0]=a[T]|0;a[ab+10|0]=a[K]|0;a[ab+11|0]=a[X]|0;a[ab+12|0]=a[T]|0;a[ab+13|0]=a[K]|0;a[ab+14|0]=a[X]|0;a[ab+15|0]=a[T]|0;a[ab+16|0]=a[K]|0;a[ab+17|0]=a[X]|0;a[ab+18|0]=a[T]|0;a[ab+19|0]=a[K]|0;a[ab+20|0]=a[X]|0;a[ab+21|0]=a[T]|0;a[ab+22|0]=a[K]|0;a[ab+23|0]=a[X]|0;a[ab+24|0]=a[T]|0;a[ab+25|0]=a[K]|0;a[ab+26|0]=a[X]|0;ad=c[p>>2]|0;ae=aa+1|0;af=c[m>>2]|0;if(ae>>>0<af>>>0){aa=ae;ab=ab+(ad*27|0)|0}else{V=ad;W=af;break L3878}}}else{ab=0;aa=J;while(1){a[aa]=a[T]|0;a[aa+1|0]=a[K]|0;a[aa+2|0]=a[X]|0;a[aa+3|0]=a[T]|0;a[aa+4|0]=a[K]|0;a[aa+5|0]=a[X]|0;a[aa+6|0]=a[T]|0;a[aa+7|0]=a[K]|0;a[aa+8|0]=a[X]|0;a[aa+9|0]=a[T]|0;a[aa+10|0]=a[K]|0;a[aa+11|0]=a[X]|0;a[aa+12|0]=a[T]|0;a[aa+13|0]=a[K]|0;a[aa+14|0]=a[X]|0;a[aa+15|0]=a[T]|0;a[aa+16|0]=a[K]|0;a[aa+17|0]=a[X]|0;a[aa+18|0]=a[T]|0;a[aa+19|0]=a[K]|0;a[aa+20|0]=a[X]|0;a[aa+21|0]=a[T]|0;a[aa+22|0]=a[K]|0;a[aa+23|0]=a[X]|0;a[aa+24|0]=a[T]|0;a[aa+25|0]=a[K]|0;a[aa+26|0]=a[X]|0;af=c[p>>2]|0;ad=ab+1|0;ae=c[m>>2]|0;if(ad>>>0<ae>>>0){ab=ad;aa=aa+(af*27|0)|0}else{V=af;W=ae;break L3878}}}}while(1){do{if((_|0)==(Q|0)){ag=0;ah=511}else{aa=d[L+(((_>>>0)%14|0)+M)|0]|0;ab=aa<<1;if(!S){ag=0;ah=ab;break}ag=0;ah=ab|aa&1}}while(0);while(1){if((ah&256|0)==0){aa=ag*3|0;a[$+aa|0]=a[T]|0;a[$+(aa+1)|0]=a[K]|0;a[$+(aa+2)|0]=a[X]|0}else{aa=ag*3|0;a[$+aa|0]=a[U]|0;a[$+(aa+1)|0]=a[Y]|0;a[$+(aa+2)|0]=a[Z]|0}aa=ag+1|0;if(aa>>>0<9){ag=aa;ah=ah<<1}else{break}}aa=c[p>>2]|0;ab=_+1|0;ae=c[m>>2]|0;if(ab>>>0<ae>>>0){_=ab;$=$+(aa*27|0)|0}else{V=aa;W=ae;break}}}}while(0);ai=j+2&4094;S=H+1|0;if(S>>>0<V>>>0){j=ai;H=S;I=V}else{break}}C=ai;D=V;E=c[o>>2]|0;F=V;G=W}I=y+(ac(D*27|0,G)|0)|0;H=s+1|0;if(H>>>0<E>>>0){s=H;x=C;y=I;z=D;A=E;B=F}else{v=E;w=q;break}}}if((a[w]|0)==0){return}q=a[b+4170|0]|0;if((q&96)==32){return}B=c[p>>2]|0;if((B|0)==0|(v|0)==0){return}A=d[b+4172|0]<<8|d[b+4173|0];z=(d[b+4174|0]<<8|d[b+4175|0])-A&4095;y=(z>>>0)%(B>>>0)|0;x=(z>>>0)/(B>>>0)|0;z=q&31;q=a[b+4171|0]&31;s=c[m>>2]|0;if(z>>>0>=s>>>0){return}o=q>>>0<s>>>0?q:s-1|0;q=a[(A+1+((ac(x,B)|0)+y<<1)&4095)+(b+52)|0]&15;A=b+4184+(q*3|0)|0;if(z>>>0>o>>>0){return}r=((ac((ac(s,x)|0)+z|0,B)|0)+y|0)*27|0;y=b+4184+(q*3|0)+1|0;B=b+4184+(q*3|0)+2|0;q=z;z=(c[h>>2]|0)+r|0;while(1){a[z]=a[A]|0;a[z+1|0]=a[y]|0;a[z+2|0]=a[B]|0;a[z+3|0]=a[A]|0;a[z+4|0]=a[y]|0;a[z+5|0]=a[B]|0;a[z+6|0]=a[A]|0;a[z+7|0]=a[y]|0;a[z+8|0]=a[B]|0;a[z+9|0]=a[A]|0;a[z+10|0]=a[y]|0;a[z+11|0]=a[B]|0;a[z+12|0]=a[A]|0;a[z+13|0]=a[y]|0;a[z+14|0]=a[B]|0;a[z+15|0]=a[A]|0;a[z+16|0]=a[y]|0;a[z+17|0]=a[B]|0;a[z+18|0]=a[A]|0;a[z+19|0]=a[y]|0;a[z+20|0]=a[B]|0;a[z+21|0]=a[A]|0;a[z+22|0]=a[y]|0;a[z+23|0]=a[B]|0;a[z+24|0]=a[A]|0;a[z+25|0]=a[y]|0;a[z+26|0]=a[B]|0;r=q+1|0;if(r>>>0>o>>>0){break}else{q=r;z=z+((c[p>>2]|0)*27|0)|0}}return}}while(0);p=b+4280|0;v=b+4284|0;do{if((c[p>>2]|0)>>>0<756e3){w=zJ(c[v>>2]|0,756e3)|0;if((w|0)!=0){c[v>>2]=w;c[p>>2]=756e3;i=3040;break}w=c[b+4276>>2]|0;if((w|0)==0){return}else{aj=w;ak=c[b+4272>>2]|0;break}}else{i=3040}}while(0);if((i|0)==3040){c[b+4272>>2]=720;c[b+4276>>2]=350;aj=350;ak=720}i=b+4276|0;p=b+4272|0;b=0;w=c[v>>2]|0;v=ak;ak=aj;while(1){aj=(b&8)>>>0<8;if((v|0)==0){al=w;am=0;an=ak}else{E=0;F=w;do{D=(E&8)>>>0<8^aj?32:0;a[F]=D;a[F+1|0]=D;a[F+2|0]=D;F=F+3|0;E=E+1|0;ao=c[p>>2]|0;}while(E>>>0<ao>>>0);al=F;am=ao;an=c[i>>2]|0}E=b+1|0;if(E>>>0<an>>>0){b=E;w=al;v=am;ak=an}else{break}}return}function p9(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;if((d|0)==10){e=a[(c[b+68>>2]|0)+10|0]|0}else{e=o3(b,d)|0}f=e&255;e=d+1|0;if(e>>>0>=(c[(c[b+64>>2]|0)+40>>2]|0)>>>0){g=f;return g|0}if((e|0)==10){h=a[(c[b+68>>2]|0)+10|0]|0}else{h=o3(b,e)|0}g=(h&255)<<8|f;return g|0}function qa(b,d){b=b|0;d=d|0;var e=0;if((d|0)==10){e=a[(c[b+68>>2]|0)+10|0]|0;return e|0}else{e=o3(b,d)|0;return e|0}return 0}function qb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;if((d|0)==10){a[(c[b+68>>2]|0)+10|0]=e;f=b+2208|0;a[f]=a[f]|1;return}else{o0(b,d,e);return}}function qc(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0;f=e&255;if((d|0)==10){a[(c[b+68>>2]|0)+10|0]=f;g=b+2208|0;a[g]=a[g]|1}else{o0(b,d,f)}f=d+1|0;if(f>>>0>=(c[(c[b+64>>2]|0)+40>>2]|0)>>>0){return}d=(e&65535)>>>8&255;if((f|0)==10){a[(c[b+68>>2]|0)+10|0]=d;e=b+2208|0;a[e]=a[e]|1;return}else{o0(b,f,d);return}}function qd(a,b,d){a=a|0;b=b|0;d=d|0;c[a+968>>2]=b;c[a+972>>2]=d;return}function qe(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;aB(25808,18,1,b|0)|0;f=oW(a)|0;g=oX(a)|0;h=a+68|0;j=d[(c[h>>2]|0)+5|0]|0;bN(b|0,24560,(x=i,i=i+32|0,c[x>>2]=f,c[x+8>>2]=g,c[x+16>>2]=j&15,c[x+24>>2]=j>>>5&1,x)|0)|0;j=c[h>>2]|0;h=d[j+5|0]|0;g=d[j+6|0]|0;f=d[j+10|0]|0;k=d[a+94|0]|0;l=d[a+95|0]|0;m=d[a+96|0]|0;n=d[a+97|0]|0;bN(b|0,22992,(x=i,i=i+64|0,c[x>>2]=d[j+4|0]|0,c[x+8>>2]=h,c[x+16>>2]=g,c[x+24>>2]=f,c[x+32>>2]=k,c[x+40>>2]=l,c[x+48>>2]=m,c[x+56>>2]=n,x)|0)|0;bN(b|0,21744,(x=i,i=i+8|0,c[x>>2]=d[a+76|0]|0,x)|0)|0;n=1;do{aA(((n&7|0)!=0?32:45)|0,b|0)|0;bN(b|0,39104,(x=i,i=i+8|0,c[x>>2]=d[a+76+n|0]|0,x)|0)|0;n=n+1|0;}while(n>>>0<18);aB(38064,2,1,b|0)|0;ax(b|0)|0;i=e;return}function qf(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=c[b+68>>2]|0;do{if((a[e+4|0]&18)==18){if((a[e+10|0]&1)==0){break}f=b+2164|0;g=b+2168|0;if((o_(b,c[f>>2]<<4,c[g>>2]<<2)|0)!=0){return}h=c[f>>2]|0;f=h<<1;i=c[g>>2]<<2;if((i|0)==0){return}g=b+60|0;j=b+94|0;if((f|0)==0){return}k=h*48|0;h=0;l=c[b+2204>>2]|0;while(1){m=c[g>>2]|0;n=(h<<13&24576)+(ac(h>>>2,f)|0)|0;o=l;p=0;while(1){q=d[m+(n+p)|0]|0;r=o;s=0;while(1){if((q&128|0)==0){t=0}else{t=d[j]|0}a[r]=a[16496+(t*3|0)|0]|0;a[r+1|0]=a[16497+(t*3|0)|0]|0;a[r+2|0]=a[16498+(t*3|0)|0]|0;u=s+1|0;if(u>>>0<8){q=q<<1;r=r+3|0;s=u}else{break}}s=p+1|0;if(s>>>0<f>>>0){o=o+24|0;p=s}else{break}}p=h+1|0;if(p>>>0<i>>>0){h=p;l=l+k|0}else{break}}return}}while(0);o$(b);return}function qg(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+32|0;d=b|0;e=b+8|0;f=b+16|0;g=b+24|0;yi(a,20672,d,980)|0;yi(a,33688,e,753664)|0;yi(a,31296,f,32768)|0;yj(a,29240,g,0)|0;a=c[f>>2]|0;if(a>>>0<32768){c[f>>2]=32768;h=32768}else{h=a}a=c[e>>2]|0;xv(2,27536,25896,(x=i,i=i+24|0,c[x>>2]=c[d>>2],c[x+8>>2]=a,c[x+16>>2]=h,x)|0);h=c[d>>2]|0;d=c[e>>2]|0;e=c[f>>2]|0;f=zH(2212)|0;a=f;if((f|0)==0){j=0;i=b;return j|0}o7(a,h,d,e>>>0<32768?32768:e);c[f+20>>2]=266;c[f+52>>2]=192;e=f+64|0;c[(c[e>>2]|0)+12>>2]=50;c[(c[e>>2]|0)+16>>2]=22;c[c[e>>2]>>2]=46;c[(c[e>>2]|0)+4>>2]=52;oV(a,c[g>>2]|0);j=f;i=b;return j|0}function qh(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;if((d|0)==9){e=a[(c[b+68>>2]|0)+9|0]|0}else{e=o3(b,d)|0}f=e&255;e=d+1|0;if(e>>>0>=(c[(c[b+64>>2]|0)+40>>2]|0)>>>0){g=f;return g|0}if((e|0)==9){h=a[(c[b+68>>2]|0)+9|0]|0}else{h=o3(b,e)|0}g=(h&255)<<8|f;return g|0}function qi(b,d){b=b|0;d=d|0;var e=0;if((d|0)==9){e=a[(c[b+68>>2]|0)+9|0]|0;return e|0}else{e=o3(b,d)|0;return e|0}return 0}function qj(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;if((d|0)==9){a[(c[b+68>>2]|0)+9|0]=e;f=b+2208|0;a[f]=a[f]|1;return}else{o0(b,d,e);return}}function qk(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0;f=e&255;if((d|0)==9){a[(c[b+68>>2]|0)+9|0]=f;g=b+2208|0;a[g]=a[g]|1}else{o0(b,d,f)}f=d+1|0;if(f>>>0>=(c[(c[b+64>>2]|0)+40>>2]|0)>>>0){return}d=(e&65535)>>>8&255;if((f|0)==9){a[(c[b+68>>2]|0)+9|0]=d;e=b+2208|0;a[e]=a[e]|1;return}else{o0(b,f,d);return}}function ql(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;aB(25776,27,1,b|0)|0;f=oW(a)|0;g=oX(a)|0;h=a+68|0;j=d[(c[h>>2]|0)+5|0]|0;bN(b|0,24512,(x=i,i=i+32|0,c[x>>2]=f,c[x+8>>2]=g,c[x+16>>2]=j&15,c[x+24>>2]=j>>>5&1,x)|0)|0;j=c[h>>2]|0;h=d[j+5|0]|0;g=d[j+6|0]|0;f=d[j+9|0]|0;k=d[a+94|0]|0;l=d[a+95|0]|0;m=d[a+96|0]|0;n=d[a+97|0]|0;bN(b|0,22912,(x=i,i=i+64|0,c[x>>2]=d[j+4|0]|0,c[x+8>>2]=h,c[x+16>>2]=g,c[x+24>>2]=f,c[x+32>>2]=k,c[x+40>>2]=l,c[x+48>>2]=m,c[x+56>>2]=n,x)|0)|0;bN(b|0,21728,(x=i,i=i+8|0,c[x>>2]=d[a+76|0]|0,x)|0)|0;n=1;do{aA(((n&7|0)!=0?32:45)|0,b|0)|0;bN(b|0,39096,(x=i,i=i+8|0,c[x>>2]=d[a+76+n|0]|0,x)|0)|0;n=n+1|0;}while(n>>>0<18);aB(38056,2,1,b|0)|0;ax(b|0)|0;i=e;return}function qm(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;e=i;i=i+16|0;f=e|0;g=b+68|0;h=c[g>>2]|0;do{if((a[h+4|0]&2)!=0){j=d[h+9|0]|0;if((j&48|0)==0){break}k=b+2164|0;l=c[k>>2]|0;if((j&16|0)!=0){j=b+2168|0;if((o_(b,l<<3,c[j>>2]<<1)|0)!=0){i=e;return}m=c[b+60>>2]|0;if((a[(c[g>>2]|0)+9|0]&64)==0){n=m+16384|0;c[f>>2]=n;c[f+8>>2]=m;o=n;p=m}else{c[f>>2]=m;n=m+16384|0;c[f+8>>2]=n;o=m;p=n}c[f+4>>2]=o+8192;c[f+12>>2]=p+8192;n=c[k>>2]|0;m=n<<1;q=c[j>>2]<<1;if((q|0)==0|(m|0)==0){i=e;return}j=n*24|0;n=0;r=c[b+2204>>2]|0;while(1){s=n&1;t=f+(s<<2)|0;u=f+((s|2)<<2)|0;s=0;v=r;w=c[t>>2]|0;while(1){x=d[w+s|0]|0;y=d[(c[u>>2]|0)+s|0]|0;z=y>>>4&12|x>>>6;a[v]=a[16496+(z*3|0)|0]|0;a[v+1|0]=a[16497+(z*3|0)|0]|0;a[v+2|0]=a[16498+(z*3|0)|0]|0;z=y>>>2&12|x>>>4&3;a[v+3|0]=a[16496+(z*3|0)|0]|0;a[v+4|0]=a[16497+(z*3|0)|0]|0;a[v+5|0]=a[16498+(z*3|0)|0]|0;z=y&12|x>>>2&3;a[v+6|0]=a[16496+(z*3|0)|0]|0;a[v+7|0]=a[16497+(z*3|0)|0]|0;a[v+8|0]=a[16498+(z*3|0)|0]|0;z=y<<2&12|x&3;a[v+9|0]=a[16496+(z*3|0)|0]|0;a[v+10|0]=a[16497+(z*3|0)|0]|0;a[v+11|0]=a[16498+(z*3|0)|0]|0;z=s+1|0;A=c[t>>2]|0;if(z>>>0<m>>>0){s=z;v=v+12|0;w=A}else{break}}c[t>>2]=A+m;c[u>>2]=(c[u>>2]|0)+m;w=n+1|0;if(w>>>0<q>>>0){n=w;r=r+j|0}else{break}}i=e;return}j=b+2168|0;if((o_(b,l<<4,c[j>>2]<<1)|0)!=0){i=e;return}r=c[b+60>>2]|0;if((a[(c[g>>2]|0)+9|0]&64)==0){n=r+16384|0;c[f>>2]=n;c[f+8>>2]=r;B=n;C=r}else{c[f>>2]=r;n=r+16384|0;c[f+8>>2]=n;B=r;C=n}c[f+4>>2]=B+8192;c[f+12>>2]=C+8192;n=c[k>>2]|0;r=n<<1;q=c[j>>2]<<1;if((q|0)==0|(r|0)==0){i=e;return}j=n*48|0;n=0;m=c[b+2204>>2]|0;while(1){w=n&1;v=f+(w<<2)|0;s=f+((w|2)<<2)|0;w=0;z=m;x=c[v>>2]|0;while(1){y=d[x+w|0]|0;D=d[(c[s>>2]|0)+w|0]|0;E=z;F=0;while(1){G=d[(y>>>7&1|D>>>6&2)+(b+94)|0]|0;a[E]=a[16496+(G*3|0)|0]|0;a[E+1|0]=a[16497+(G*3|0)|0]|0;a[E+2|0]=a[16498+(G*3|0)|0]|0;G=F+1|0;if(G>>>0<8){y=y<<1;D=D<<1;E=E+3|0;F=G}else{break}}F=w+1|0;H=c[v>>2]|0;if(F>>>0<r>>>0){w=F;z=z+24|0;x=H}else{break}}c[v>>2]=H+r;c[s>>2]=(c[s>>2]|0)+r;x=n+1|0;if(x>>>0<q>>>0){n=x;m=m+j|0}else{break}}i=e;return}}while(0);o$(b);i=e;return}function qn(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+32|0;d=b|0;e=b+8|0;f=b+16|0;g=b+24|0;yi(a,41800,d,980)|0;yi(a,40784,e,753664)|0;yi(a,33224,f,32768)|0;yj(a,31120,g,0)|0;a=c[f>>2]|0;if(a>>>0<32768){c[f>>2]=32768;h=32768}else{h=a}a=c[e>>2]|0;xv(2,29096,27336,(x=i,i=i+24|0,c[x>>2]=c[d>>2],c[x+8>>2]=a,c[x+16>>2]=h,x)|0);h=c[d>>2]|0;d=c[e>>2]|0;e=c[f>>2]|0;f=zH(2212)|0;a=f;if((f|0)==0){j=0;i=b;return j|0}o7(a,h,d,e>>>0<32768?32768:e);c[f+20>>2]=156;c[f+52>>2]=186;e=f+64|0;c[(c[e>>2]|0)+12>>2]=116;c[(c[e>>2]|0)+16>>2]=40;c[c[e>>2]>>2]=58;c[(c[e>>2]|0)+4>>2]=124;oV(a,c[g>>2]|0);j=f;i=b;return j|0}function qo(a){a=a|0;if((a|0)==0){return}r2(c[a+52>>2]|0);r2(c[a+60>>2]|0);zI(a);return}function qp(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;qH(b|0);f=b;c[b+32>>2]=f;c[b>>2]=96;c[b+4>>2]=78;c[b+8>>2]=470;c[b+12>>2]=530;c[b+16>>2]=466;c[b+20>>2]=204;c[b+24>>2]=46;c[b+28>>2]=468;c[b+48>>2]=0;g=zH(262144)|0;h=b+56|0;c[h>>2]=g;if((g|0)==0){return}g=r0(e,131072,0)|0;e=b+52|0;c[e>>2]=g;c[g+24>>2]=f;r4(c[e>>2]|0,c[h>>2]|0,1);c[(c[e>>2]|0)+12>>2]=30;c[(c[e>>2]|0)+16>>2]=128;c[c[e>>2]>>2]=64;c[(c[e>>2]|0)+4>>2]=10;g=c[e>>2]|0;c[h>>2]=c[g+44>>2];r3(g,0);g=r0(d,48,1)|0;d=b+60|0;c[d>>2]=g;c[g+24>>2]=f;c[(c[d>>2]|0)+12>>2]=48;c[(c[d>>2]|0)+16>>2]=94;c[c[d>>2]>>2]=72;c[(c[d>>2]|0)+4>>2]=98;f=c[d>>2]|0;c[b+64>>2]=c[f+44>>2];r3(f,0);zP(b+68|0,0,837);zP(b+908|0,0,13);a[b+921|0]=1;c[b+924>>2]=0;c[b+928>>2]=16;c[b+968>>2]=0;c[b+972>>2]=0;a[b+976|0]=0;zP(b+932|0,0,33);return}function qq(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;do{if((xz(34216,d)|0)==0){h=-1}else{if((xB(e,g)|0)!=0){h=1;break}j=c[g>>2]|0;a[b+921|0]=1;c[b+924>>2]=j;c[b+928>>2]=j;h=0}}while(0);i=f;return h|0}function qr(a){a=a|0;return c[a+52>>2]|0}function qs(a){a=a|0;return c[a+60>>2]|0}function qt(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;if((a[(c[b+64>>2]|0)+28|0]&2)==0){return}g=b+73|0;h=(d[b+79|0]|0)>>>2&3;do{if((h|0)==1){if(e>>>0<=65535){i=e;break}return}else if((h|0)==3){j=e-98304|0;if(j>>>0<=32767){i=j;break}return}else if((h|0)==2){j=e-65536|0;if(j>>>0<=32767){i=j;break}return}else{i=e}}while(0);e=a[b+78|0]&3;h=a[b+70|0]|0;j=a[b+81|0]|0;k=d[b+72|0]|0;do{if((k&8|0)==0){if((k&4|0)!=0){l=i&65535;m=h;break}l=i&65534;m=((i&1|0)!=0?10:5)&h}else{l=i&65532;m=1<<(i&3)&255}}while(0);do{if((e|0)==2){i=f&255;n=j;o=i<<28>>31&255;p=i<<29>>31&255;q=i<<30>>31&255;r=i<<31>>31&255;s=a[b+76|0]|0;t=3281}else if((e|0)==1){u=a[b+917|0]|0;v=a[b+918|0]|0;w=a[b+919|0]|0;x=a[b+920|0]|0;y=j}else if((e|0)==3){i=a[b+76|0]|0;h=i&7;k=f&255;z=d[g|0]|0;n=(k<<8-h|k>>>(h>>>0))&(j&255)&255;o=z<<28>>31&255;p=z<<29>>31&255;q=z<<30>>31&255;r=z<<31>>31&255;s=i;t=3281}else if((e|0)==0){i=a[b+76|0]|0;z=i&7;h=f&255;k=h<<8-z|h>>>(z>>>0);z=a[g|0]|0;h=d[b+74|0]|0;if((h&1|0)==0){A=k&255}else{A=z<<7<<24>>24>>7}if((h&2|0)==0){B=k&255}else{B=z<<6<<24>>24>>7}if((h&4|0)==0){C=k&255}else{C=z<<5<<24>>24>>7}if((h&8|0)==0){n=j;o=k&255;p=C;q=B;r=A;s=i;t=3281;break}else{n=j;o=z<<4<<24>>24>>7;p=C;q=B;r=A;s=i;t=3281;break}}else{return}}while(0);do{if((t|0)==3281){A=(s&255)>>>3&3;if((A|0)==2){u=a[b+917|0]|r;v=a[b+918|0]|q;w=a[b+919|0]|p;x=a[b+920|0]|o;y=n;break}else if((A|0)==3){u=a[b+917|0]^r;v=a[b+918|0]^q;w=a[b+919|0]^p;x=a[b+920|0]^o;y=n;break}else if((A|0)==1){u=a[b+917|0]&r;v=a[b+918|0]&q;w=a[b+919|0]&p;x=a[b+920|0]&o;y=n;break}else{u=r;v=q;w=p;x=o;y=n;break}}}while(0);n=~(y&255);o=((d[b+918|0]|0)&n|v&y&255)&255;v=((d[b+919|0]|0)&n|w&y&255)&255;w=((d[b+920|0]|0)&n|x&y&255)&255;x=m&255;if((x&1|0)!=0){a[(c[b+56>>2]|0)+l|0]=((d[b+917|0]|0)&n|u&y&255)&255}if((x&2|0)!=0){a[(c[b+56>>2]|0)+(l|65536)|0]=o}if((x&4|0)!=0){a[(c[b+56>>2]|0)+(l|131072)|0]=v}if((x&8|0)!=0){a[(c[b+56>>2]|0)+(l|196608)|0]=w}w=b+964|0;a[w]=a[w]|1;return}function qu(a,b){a=a|0;b=b|0;c[a+48>>2]=b;if((b|0)==0){return}zl(b,720,400)|0;return}function qv(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;aB(27320,9,1,e|0)|0;g=(d[b+122|0]|0)<<1;h=(d[b+117|0]|0)<<8|(d[b+118|0]|0);j=d[b+127|0]|0;k=(a[b+110|0]&16)==0?j:j|256;j=(a[b+112|0]&64)==0?k:k|512;bN(e|0,25720,(x=i,i=i+32|0,c[x>>2]=(d[b+115|0]|0)<<8|(d[b+116|0]|0),c[x+8>>2]=g,c[x+16>>2]=h,c[x+24>>2]=j,x)|0)|0;j=c[b+36>>2]|0;h=0;g=b+64|0;k=(d[(c[g>>2]|0)+28|0]|0)>>>2&3;if((k|0)==0){l=z4(j,h,25175e3,0)|0;m=G;n=l}else if((k|0)==2|(k|0)==3){l=z4(j,h,28322e3,0)|0;m=G;n=l}else if((k|0)==1){k=z4(j,h,28322e3,0)|0;m=G;n=k}else{m=h;n=j}j=b+69|0;if((a[j]&8)==0){h=z5(n,m,1193182,0)|0;o=h}else{h=z5(n,m,2386364,0)|0;o=h}h=c[b+932>>2]|0;m=c[b+936>>2]|0;n=c[b+940>>2]|0;k=c[b+944>>2]|0;bN(e|0,24464,(x=i,i=i+40|0,c[x>>2]=o,c[x+8>>2]=h,c[x+16>>2]=m,c[x+24>>2]=n,c[x+32>>2]=k,x)|0)|0;k=c[g>>2]|0;g=d[k+18|0]|0;n=d[k+42|0]|0;bN(e|0,22880,(x=i,i=i+24|0,c[x>>2]=d[k+28|0]|0,c[x+8>>2]=g,c[x+16>>2]=n,x)|0)|0;n=d[b+103|0]|0;bN(e|0,38040,(x=i,i=i+16|0,c[x>>2]=21720,c[x+8>>2]=n,x)|0)|0;n=1;do{aA(((n&7|0)!=0?32:45)|0,e|0)|0;bN(e|0,34744,(x=i,i=i+8|0,c[x>>2]=d[b+103+n|0]|0,x)|0)|0;n=n+1|0;}while(n>>>0<25);aB(34480,2,1,e|0)|0;n=d[b+82|0]|0;bN(e|0,38040,(x=i,i=i+16|0,c[x>>2]=41776,c[x+8>>2]=n,x)|0)|0;n=1;do{aA(((n&7|0)!=0?32:45)|0,e|0)|0;bN(e|0,34744,(x=i,i=i+8|0,c[x>>2]=d[b+82+n|0]|0,x)|0)|0;n=n+1|0;}while(n>>>0<21);aB(34480,2,1,e|0)|0;n=d[b+68|0]|0;bN(e|0,38040,(x=i,i=i+16|0,c[x>>2]=40664,c[x+8>>2]=n,x)|0)|0;aA(32,e|0)|0;bN(e|0,34744,(x=i,i=i+8|0,c[x>>2]=d[j]|0,x)|0)|0;aA(32,e|0)|0;bN(e|0,34744,(x=i,i=i+8|0,c[x>>2]=d[b+70|0]|0,x)|0)|0;aA(32,e|0)|0;bN(e|0,34744,(x=i,i=i+8|0,c[x>>2]=d[b+71|0]|0,x)|0)|0;aA(32,e|0)|0;bN(e|0,34744,(x=i,i=i+8|0,c[x>>2]=d[b+72|0]|0,x)|0)|0;aB(34480,2,1,e|0)|0;j=d[b+73|0]|0;bN(e|0,38040,(x=i,i=i+16|0,c[x>>2]=39088,c[x+8>>2]=j,x)|0)|0;aA(32,e|0)|0;bN(e|0,34744,(x=i,i=i+8|0,c[x>>2]=d[b+74|0]|0,x)|0)|0;aA(32,e|0)|0;bN(e|0,34744,(x=i,i=i+8|0,c[x>>2]=d[b+75|0]|0,x)|0)|0;aA(32,e|0)|0;bN(e|0,34744,(x=i,i=i+8|0,c[x>>2]=d[b+76|0]|0,x)|0)|0;aA(32,e|0)|0;bN(e|0,34744,(x=i,i=i+8|0,c[x>>2]=d[b+77|0]|0,x)|0)|0;aA(32,e|0)|0;bN(e|0,34744,(x=i,i=i+8|0,c[x>>2]=d[b+78|0]|0,x)|0)|0;aA(32,e|0)|0;bN(e|0,34744,(x=i,i=i+8|0,c[x>>2]=d[b+79|0]|0,x)|0)|0;aA(32,e|0)|0;bN(e|0,34744,(x=i,i=i+8|0,c[x>>2]=d[b+80|0]|0,x)|0)|0;aA(45,e|0)|0;bN(e|0,34744,(x=i,i=i+8|0,c[x>>2]=d[b+81|0]|0,x)|0)|0;aB(34480,2,1,e|0)|0;ax(e|0)|0;i=f;return}function qw(b,d){b=b|0;d=d|0;var e=0,f=0;do{if((d|0)!=0){e=b+48|0;if((c[e>>2]|0)==0){break}qG(b);f=b+952|0;zp(c[e>>2]|0,c[b+948>>2]|0,c[f>>2]|0);zq(c[e>>2]|0,c[b+960>>2]|0,0,c[f>>2]|0);zs(c[e>>2]|0)}}while(0);d=b+964|0;a[d]=a[d]|1;return}function qx(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[b+940>>2]|0;if(e>>>0<5e4){return}f=b+36|0;g=c[f>>2]|0;h=0;i=b+64|0;j=(d[(c[i>>2]|0)+28|0]|0)>>>2&3;if((j|0)==2|(j|0)==3){k=z4(g,h,28322e3,0)|0;l=G;m=k}else if((j|0)==0){k=z4(g,h,25175e3,0)|0;l=G;m=k}else if((j|0)==1){j=z4(g,h,28322e3,0)|0;l=G;m=j}else{l=h;m=g}if((a[b+69|0]&8)==0){g=z5(m,l,1193182,0)|0;n=g}else{g=z5(m,l,2386364,0)|0;n=g}if(n>>>0<(c[b+944>>2]|0)>>>0){g=b+964|0;a[g]=a[g]&-3;return}do{if(n>>>0>=e>>>0){c[f>>2]=0;c[b+40>>2]=0;c[b+44>>2]=0;c[b+900>>2]=a[b+101|0]&15;g=d[b+115|0]<<8|d[b+116|0];l=b+896|0;if((c[l>>2]|0)==(g|0)){break}c[l>>2]=g;g=b+964|0;a[g]=a[g]|1}}while(0);f=b+964|0;e=a[f]|0;if((e&2)!=0){return}n=b+924|0;g=c[n>>2]|0;do{if((g|0)==0){o=e}else{l=g-1|0;c[n>>2]=l;if((l|0)!=0){o=e;break}c[n>>2]=c[b+928>>2];l=b+921|0;a[l]=(a[l]|0)==0|0;l=d[b+98|0]|0;if((l&1|0)==0){m=e|1;a[f]=m;o=m;break}if((l&8|0)==0){o=e;break}l=e|1;a[f]=l;o=l}}while(0);e=b+48|0;n=c[e>>2]|0;if((n|0)!=0){if((o&1)==0){p=n}else{qG(b);n=b+952|0;zp(c[e>>2]|0,c[b+948>>2]|0,c[n>>2]|0);zq(c[e>>2]|0,c[b+960>>2]|0,0,c[n>>2]|0);p=c[e>>2]|0}zs(p)}a[f]=2;if((a[b+120|0]&32)!=0){return}f=b+976|0;if((a[f]|0)==1){return}p=(c[i>>2]|0)+18|0;a[p]=a[p]|-128;a[f]=1;f=c[b+972>>2]|0;if((f|0)==0){return}b3[f&511](c[b+968>>2]|0,1);return}function qy(b,d,e){b=b|0;d=d|0;e=e|0;if((a[(c[b+64>>2]|0)+28|0]&2)==0){return}qt(b,d,e&255);qt(b,d+1|0,(e&65535)>>>8&255);return}function qz(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((a[(c[b+64>>2]|0)+28|0]&2)==0){f=-1;return f|0}g=(d[b+79|0]|0)>>>2&3;do{if((g|0)==3){h=e-98304|0;if(h>>>0>32767){f=-1}else{i=h;break}return f|0}else if((g|0)==1){if(e>>>0>65535){f=-1}else{i=e;break}return f|0}else if((g|0)==2){h=e-65536|0;if(h>>>0>32767){f=-1}else{i=h;break}return f|0}else{i=e}}while(0);e=i&3;g=d[b+72|0]|0;h=(g&8|0)==0;if(h){j=(g>>>2|65534)&i}else{j=i&65532}k=a[b+78|0]|0;l=c[b+56>>2]|0;m=a[l+j|0]|0;a[b+917|0]=m;n=a[l+(j|65536)|0]|0;a[b+918|0]=n;o=a[l+(j|131072)|0]|0;a[b+919|0]=o;p=a[l+(j|196608)|0]|0;a[b+920|0]=p;if((k&8)==0){k=d[b+77|0]|0;do{if(h){if((g&4|0)!=0){q=k&3;break}q=k&2|i&1}else{q=e}}while(0);f=a[b+917+q|0]|0;return f|0}else{q=m&255;m=n&255;n=o&255;o=p&255;p=a[b+80|0]|0;e=a[b+75|0]|0;b=128;i=0;while(1){if((((((m&b|0)!=0?2:0)|(q&b|0)!=0|((n&b|0)!=0?4:0)|((o&b|0)!=0?8:0))^e)&p)<<24>>24==0){r=(i&255|b)&255}else{r=i}k=b>>>1;if((k|0)==0){f=r;break}else{b=k;i=r}}return f|0}return 0}function qA(b,d){b=b|0;d=d|0;var e=0,f=0;if((a[(c[b+64>>2]|0)+28|0]&2)==0){e=0;return e|0}f=qz(b,d)|0;e=((qz(b,d+1|0)|0)&255)<<8|f&255;return e|0}function qB(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;do{if(e>>>0<16){if((a[(c[b+64>>2]|0)+28|0]&1)==0){g=e+32|0;break}else{return}}else{if(e>>>0<=32){g=e;break}if((a[(c[b+64>>2]|0)+28|0]&1)!=0){g=e;break}return}}while(0);if((g|0)==21){e=b+64|0;a[(c[e>>2]|0)+21|0]=f;h=a[(c[e>>2]|0)+20|0]&63;if(h>>>0>4){return}if((a[b+68+h|0]|0)==f<<24>>24){return}if((h|0)==0){a[b+68|0]=f;return}else if((h|0)==4){a[b+72|0]=f;return}else if((h|0)==1){a[b+69|0]=f;e=b+964|0;a[e]=a[e]|1;return}else if((h|0)==3){a[b+71|0]=f;e=b+964|0;a[e]=a[e]|1;return}else if((h|0)==2){a[b+70|0]=f;return}else{return}}else if((g|0)==17){h=b+904|0;e=(c[b+64>>2]|0)+16|0;do{if((a[h]|0)==0){a[e]=f;i=1}else{j=a[e]&31;if(j>>>0>20){i=0;break}k=b+82+j|0;if((a[k]|0)==f<<24>>24){i=0;break}a[k]=f;k=b+964|0;a[k]=a[k]|1;i=0}}while(0);a[h]=i;return}else if((g|0)==31){i=b+64|0;a[(c[i>>2]|0)+31|0]=f;h=a[(c[i>>2]|0)+30|0]&63;if(h>>>0>8){return}i=b+73+h|0;if((a[i]|0)==f<<24>>24){return}a[i]=f;if((h|0)!=5){return}h=b+964|0;a[h]=a[h]|1;return}else if((g|0)==23){c[b+908>>2]=(f&255)*3|0;h=b+916|0;a[h]=a[h]|3;return}else if((g|0)==24){c[b+912>>2]=(f&255)*3|0;h=b+916|0;a[h]=a[h]&-4;return}else if((g|0)==25){if((a[b+916|0]&3)!=0){return}h=(f&255)>>>4&3|f<<2;i=b+912|0;e=c[i>>2]|0;k=b+128+e|0;if((a[k]|0)==h<<24>>24){l=e}else{a[k]=h;h=b+964|0;a[h]=a[h]|1;l=c[i>>2]|0}h=l+1|0;c[i>>2]=h;if(h>>>0<=767){return}c[i>>2]=0;return}else if((g|0)==20){a[(c[b+64>>2]|0)+20|0]=f;return}else if((g|0)==36){a[(c[b+64>>2]|0)+36|0]=f;return}else if((g|0)==18){a[(c[b+64>>2]|0)+28|0]=f;i=b+964|0;a[i]=a[i]|1;return}else if((g|0)==30){a[(c[b+64>>2]|0)+30|0]=f;return}else if((g|0)==16){i=b+904|0;h=(c[b+64>>2]|0)+16|0;do{if((a[i]|0)==0){a[h]=f;m=1}else{l=a[h]&31;if(l>>>0>20){m=0;break}k=b+82+l|0;if((a[k]|0)==f<<24>>24){m=0;break}a[k]=f;k=b+964|0;a[k]=a[k]|1;m=0}}while(0);a[i]=m;return}else if((g|0)==37){g=b+64|0;a[(c[g>>2]|0)+37|0]=f;m=c[g>>2]|0;g=a[m+36|0]&63;if(g>>>0>24){return}do{if(g>>>0<8){if((a[b+120|0]|0)>=0){n=3438;break}if((g|0)==7){o=a[b+110|0]&-17|f&16;break}else{return}}else{n=3438}}while(0);do{if((n|0)==3438){if((g|0)!=17){o=f;break}if((f&16)!=0){o=f;break}i=b+976|0;if((a[i]|0)==0){o=f;break}h=m+18|0;a[h]=a[h]&127;a[i]=0;i=c[b+972>>2]|0;if((i|0)==0){o=f;break}b3[i&511](c[b+968>>2]|0,0);o=f}}while(0);f=b+103+g|0;if((a[f]|0)==o<<24>>24){return}a[f]=o;o=(a[b+69|0]&1)==0?9:8;f=d[b+110|0]|0;g=ac((d[b+103|0]|0)+5|0,o)|0;m=b+932|0;n=(c[m>>2]|0)!=(g|0)|0;c[m>>2]=g;m=ac((d[b+104|0]|0)+1|0,o)|0;o=b+936|0;i=(c[o>>2]|0)!=(m|0)|n;c[o>>2]=m;m=ac((f<<4&512|f<<8&256|d[b+109|0])+2|0,g)|0;o=b+940|0;n=i|(c[o>>2]|0)!=(m|0);c[o>>2]=m;m=ac((f<<3&512|f<<7&256|d[b+121|0])+1|0,g)|0;g=b+944|0;f=n|(c[g>>2]|0)!=(m|0);c[g>>2]=m;m=b+964|0;b=a[m]|0;if((f|0)==0){p=b}else{f=b|1;a[m]=f;p=f}a[m]=p|1;return}else{return}}function qC(a,b,c){a=a|0;b=b|0;c=c|0;qB(a,b,c&255);qB(a,b+1|0,(c&65535)>>>8&255);return}function qD(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;do{if(e>>>0<16){if((a[(c[b+64>>2]|0)+28|0]&1)==0){f=e+32|0;break}else{g=-1;return g|0}}else{if(e>>>0<=32){f=e;break}if((a[(c[b+64>>2]|0)+28|0]&1)==0){g=-1}else{f=e;break}return g|0}}while(0);if((f|0)==25){if((a[b+916|0]&3)==0){g=0;return g|0}e=b+908|0;h=c[e>>2]|0;i=(d[b+128+h|0]|0)>>>2;j=h+1|0;c[e>>2]=j>>>0>767?0:j;g=i;return g|0}else if((f|0)==37){i=a[(c[b+64>>2]|0)+36|0]&31;if(i>>>0>24){g=-1;return g|0}g=a[b+103+i|0]|0;return g|0}else if((f|0)==30){g=a[(c[b+64>>2]|0)+30|0]|0;return g|0}else if((f|0)==24){g=(((c[b+912>>2]|0)>>>0)/3|0)&255;return g|0}else if((f|0)==17){i=a[(c[b+64>>2]|0)+16|0]&31;if(i>>>0>20){g=-1;return g|0}g=a[b+82+i|0]|0;return g|0}else if((f|0)==21){i=a[(c[b+64>>2]|0)+20|0]&7;if(i>>>0>4){g=-1;return g|0}g=a[b+68+i|0]|0;return g|0}else if((f|0)==36){g=a[(c[b+64>>2]|0)+36|0]|0;return g|0}else if((f|0)==28){g=a[(c[b+64>>2]|0)+28|0]|0;return g|0}else if((f|0)==20){g=a[(c[b+64>>2]|0)+20|0]|0;return g|0}else if((f|0)==23){g=a[b+916|0]|0;return g|0}else if((f|0)==42){qx(b,0);a[b+904|0]=0;i=c[b+36>>2]|0;j=0;e=c[b+64>>2]|0;h=(d[e+28|0]|0)>>>2&3;if((h|0)==0){k=z4(i,j,25175e3,0)|0;l=G;m=k}else if((h|0)==1){k=z4(i,j,28322e3,0)|0;l=G;m=k}else if((h|0)==2|(h|0)==3){h=z4(i,j,28322e3,0)|0;l=G;m=h}else{l=j;m=i}if((a[b+69|0]&8)==0){i=z5(m,l,1193182,0)|0;n=i}else{i=z5(m,l,2386364,0)|0;n=i}i=e+42|0;e=a[i]|0;if(n>>>0<(c[b+944>>2]|0)>>>0){o=((n>>>0)%((c[b+932>>2]|0)>>>0)|0)>>>0>=(c[b+936>>2]|0)>>>0|e&-10}else{o=e|9}e=o+16&48|o&-49;a[i]=e;g=e;return g|0}else if((f|0)==16){g=a[(c[b+64>>2]|0)+16|0]|0;return g|0}else if((f|0)==31){e=a[(c[b+64>>2]|0)+30|0]&15;if(e>>>0>8){g=-1;return g|0}g=a[b+73+e|0]|0;return g|0}else if((f|0)==18){f=(d[b+128|0]|0)>>>2;e=(d[b+129|0]|0)>>>2;i=(d[b+130|0]|0)>>>2;do{if((f<<24>>24|0)==18){if(e<<24>>24!=18){p=3501;break}if(i<<24>>24==18){q=0}else{r=0;p=3493}}else if((f<<24>>24|0)==20){if(e<<24>>24!=20){s=0;p=3496;break}if(i<<24>>24==20){q=0}else{r=1;p=3493}}else{r=0;p=3493}}while(0);do{if((p|0)==3493){if(f<<24>>24==45){if(e<<24>>24==20&i<<24>>24==20){q=1;break}else{t=1}}else{t=0}if(r){s=t;p=3496;break}if(t&e<<24>>24==45&i<<24>>24==45){q=1}else{p=3501}}}while(0);do{if((p|0)==3496){if((e<<24>>24|0)==45){if(i<<24>>24==20){q=1;break}}else if((e<<24>>24|0)==20){if(i<<24>>24==45){q=1;break}else{p=3501;break}}if(s&e<<24>>24==45&i<<24>>24==45){q=1}else{p=3501}}}while(0);if((p|0)==3501){q=0}p=b+64|0;b=(c[p>>2]|0)+18|0;i=a[b]|0;a[b]=q?i&-17:i|16;g=a[(c[p>>2]|0)+18|0]|0;return g|0}else{g=-1;return g|0}return 0}function qE(a,b){a=a|0;b=b|0;var c=0;c=qD(a,b)|0;return((qD(a,b+1|0)|0)&255)<<8|c&255|0}function qF(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;yi(b,41496,e,944)|0;yi(b,40768,f,655360)|0;yj(b,33216,g,0)|0;b=c[f>>2]|0;xv(2,31112,29064,(x=i,i=i+16|0,c[x>>2]=c[e>>2],c[x+8>>2]=b,x)|0);b=c[e>>2]|0;e=c[f>>2]|0;f=zH(980)|0;if((f|0)==0){h=0;i=d;return h|0}qp(f,b,e);e=c[g>>2]|0;a[f+921|0]=1;c[f+924>>2]=e;c[f+928>>2]=e;h=f;i=d;return h|0}function qG(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0;e=i;i=i+8|0;f=e|0;g=a[b+69|0]|0;h=g&1;j=ac((d[b+104|0]|0)+1|0,h<<24>>24!=0?8:9)|0;k=a[b+110|0]|0;l=k&255;m=(l<<7&256|d[b+121|0]|l<<3&512)+1|0;do{if((g&32)==0){if((a[b+68|0]&3)!=3){break}if(j>>>0<16|m>>>0<16){break}if((a[b+79|0]&1)!=0){l=f|0;n=h<<24>>24==0?9:8;o=a[b+112|0]|0;p=o&255;q=(p&31)+1|0;r=d[b+127|0]|0;s=(k&16)==0?r:r|256;r=(o&64)==0?s:s|512;s=o<<24>>24<0;o=s?2:1;do{if(s){if((m&1|0)!=0){t=r;u=m;v=o;break}t=r>>>1;u=m>>>1;v=1}else{t=r;u=m;v=o}}while(0);o=b+78|0;do{if((a[o]&64)==0){w=j;x=n}else{if((n&1|0)!=0){w=j;x=n;break}r=j&1;w=j>>>((r^1)>>>0);x=(r|0)==0?4:n}}while(0);n=b+126|0;do{if((a[n]&1)==0){y=u;z=q}else{if((p&1|0)==0){y=u;z=q;break}if((u&1|0)!=0){y=u;z=q;break}y=u>>>1;z=q>>>1}}while(0);q=w*3|0;p=ac(y,q)|0;r=b+956|0;do{if(p>>>0>(c[r>>2]|0)>>>0){s=b+960|0;A=zJ(c[s>>2]|0,p)|0;if((A|0)==0){i=e;return}else{c[s>>2]=A;c[r>>2]=p;break}}}while(0);c[b+948>>2]=w;c[b+952>>2]=y;p=b+98|0;if((a[p]&8)==0){B=0;C=0}else{B=(a[b+921|0]|0)!=0?255:0;C=255}r=c[b+56>>2]|0;A=b+960|0;s=d[o]|0;D=(s&64|0)!=0;E=(s&32|0)!=0;s=a[b+122|0]|0;F=(s&255)<<1;if((y|0)==0){i=e;return}G=b+123|0;H=f+1|0;I=f+2|0;J=f+3|0;K=(w|0)==0;L=s<<24>>24==0;s=b+100|0;M=b+102|0;N=0;O=0;P=c[b+896>>2]|0;Q=c[b+900>>2]|0;R=0;S=0;while(1){if((S|0)==(t|0)){T=(a[p]&32)==0?Q:0;U=0}else{T=Q;U=P}V=c[A>>2]|0;W=V+(ac(S,q)|0)|0;do{if((a[G]&64)==0){V=a[n]|0;if((V&64)!=0){X=U;Y=V;break}X=(U<<1|U>>>15)&65535;Y=V}else{X=(U<<2|U>>>14)&65535;Y=a[n]|0}}while(0);if((Y&1)==0){Z=X&-8193|O<<13&8192}else{Z=X}a[l]=a[r+Z|0]|0;a[H]=a[r+(Z+65536)|0]|0;a[I]=a[r+(Z+131072)|0]|0;a[J]=(d[r+(Z+196608)|0]^C|B)&255;V=128>>>((T&7)>>>0);do{if(D){_=T>>>1&3}else{if(!E){_=R;break}_=T<<1&6}}while(0);if(K){$=U;aa=_}else{ab=O<<13&8192;ad=T;ae=U;af=V;ag=_;ah=0;ai=W;while(1){if(ad>>>0<x>>>0){aj=ag;ak=af;al=ae;am=ad}else{an=ae+1&65535;do{if((a[G]&64)==0){ao=a[n]|0;if((ao&64)!=0){ap=an;aq=ao;break}ap=an<<1&65534|an>>>15;aq=ao}else{ap=an<<2&65532|an>>>14;aq=a[n]|0}}while(0);if((aq&1)==0){ar=ap&-8193|ab}else{ar=ap}a[l]=a[r+ar|0]|0;a[H]=a[r+(ar+65536)|0]|0;a[I]=a[r+(ar+131072)|0]|0;a[J]=(d[r+(ar+196608)|0]^C|B)&255;aj=0;ak=128;al=an;am=0}do{if(D){as=d[f+(aj&3)|0]|0;at=aj+1|0;au=ak}else{ao=d[l]|0;if(!E){as=((d[H]&ak|0)!=0?2:0)|(ao&ak|0)!=0|((d[I]&ak|0)!=0?4:0)|((d[J]&ak|0)!=0?8:0);at=aj;au=ak>>>1;break}av=ao>>>((6-aj|0)>>>0)&3;ao=aj+2|0;if(ao>>>0<=6){as=av;at=ao;au=ak;break}a[l]=a[H]|0;a[H]=0;as=av;at=0;au=ak}}while(0);an=ai+1|0;av=ai+2|0;if((a[o]&64)==0){ao=d[(as&15&d[s])+(b+82)|0]|0;if((a[p]|0)<0){aw=a[M]|0;ax=(aw&255)<<4&48|ao&15;ay=aw}else{ax=ao;ay=a[M]|0}az=(ay&255)<<4&3072|ax&63}else{az=as&255}ao=az*3|0;a[ai]=a[b+128+ao|0]|0;a[an]=a[ao+1+(b+128)|0]|0;a[av]=a[ao+2+(b+128)|0]|0;ao=ah+1|0;if(ao>>>0<w>>>0){ad=am+1|0;ae=al;af=au;ag=at;ah=ao;ai=ai+3|0}else{$=al;aa=at;break}}}ai=N+1|0;do{if(ai>>>0<v>>>0){aA=U;aB=O;aC=ai}else{ah=O+1|0;ag=ah>>>0<z>>>0;if(ag|L){aA=ag?U:$;aB=ag?ah:0;aC=0;break}aA=U+F&65535;aB=0;aC=0}}while(0);ai=S+1|0;if(ai>>>0<y>>>0){N=aC;O=aB;P=aA;Q=T;R=aa;S=ai}else{break}}i=e;return}S=h<<24>>24==0?9:8;R=(a[b+112|0]&31)+1|0;Q=j*3|0;P=ac(m,Q)|0;O=b+956|0;N=b+960|0;do{if(P>>>0>(c[O>>2]|0)>>>0){F=zJ(c[N>>2]|0,P)|0;if((F|0)==0){i=e;return}else{c[N>>2]=F;c[O>>2]=P;break}}}while(0);c[b+948>>2]=j;c[b+952>>2]=m;P=b+56|0;O=c[P>>2]|0;F=a[b+122|0]|0;L=(F&255)<<1;M=d[b+117|0]<<8|d[b+118|0];p=(j|0)==0;s=F<<24>>24==0;F=b+123|0;o=b+126|0;H=b+98|0;l=b+78|0;J=b+100|0;I=b+102|0;E=b+113|0;D=b+114|0;r=b+71|0;n=b+921|0;G=c[b+896>>2]|0;K=0;while(1){q=m-K|0;A=q>>>0>R>>>0?R:q;q=c[N>>2]|0;ai=ac(K,j)|0;if(p){aD=G}else{ah=(A|0)==0;ag=G;af=0;while(1){ae=j-af|0;ad=ae>>>0>S>>>0?S:ae;ae=a[F]|0;do{if((ae&64)==0){ab=a[o]|0;if((ab&64)!=0){aE=ag;aF=ab;break}aE=(ag<<1|ag>>>15)&65535;aF=ab}else{aE=(ag<<2|ag>>>14)&65535;aF=a[o]|0}}while(0);ab=(aF&1)==0?aE&-8193:aE;W=q+((af+ai|0)*3|0)|0;V=d[O+ab|0]|0;ao=d[O+(ab+65536)|0]|0;ab=a[H]|0;if((ab&8)==0){aG=0;aH=ao}else{if((ao&128|0)==0){aI=0}else{aI=(a[n]|0)==0|0}aG=aI;aH=ao&127}ao=aH&15;av=(a[l]&64)==0;if(av){an=d[(d[J]&ao)+(b+82)|0]|0;if(ab<<24>>24<0){aw=a[I]|0;aJ=(aw&255)<<4&48|an&15;aK=aw}else{aJ=an;aK=a[I]|0}aL=(aK&255)<<4&3072|aJ&63}else{aL=ao}ao=aL*3|0;an=a[b+128+ao|0]|0;aw=a[ao+1+(b+128)|0]|0;aM=a[ao+2+(b+128)|0]|0;ao=aH>>>4;if(av){av=d[(d[J]&ao)+(b+82)|0]|0;if(ab<<24>>24<0){aN=a[I]|0;aO=(aN&255)<<4&48|av&15;aP=aN}else{aO=av;aP=a[I]|0}aQ=(aP&255)<<4&3072|aO&63}else{aQ=ao}ao=aQ*3|0;av=a[b+128+ao|0]|0;aN=a[ao+1+(b+128)|0]|0;aR=a[ao+2+(b+128)|0]|0;ao=a[E]&31;aS=a[D]&31;if(ao>>>0>aS>>>0|(ag|0)!=(M|0)){aT=0}else{aT=(a[n]|0)!=0}if((ab&4)==0){aU=0}else{aU=(V-192|0)>>>0<32|0}do{if((ab&2)==0){aV=65535}else{if((aH&7|0)!=1){aV=65535;break}aV=ae&31}}while(0);ae=d[r]|0;if((aH&8|0)==0){aW=ae<<1&6|ae>>>4&1}else{aW=ae>>>1&6|ae>>>5&1}ae=c[P>>2]|0;ab=(aW<<13)+131072|V<<5;L4641:do{if(!ah){aX=(aU|0)==0;aY=(ad|0)!=0;if((aG|0)==0){aZ=0;a_=0;a$=W;while(1){do{if((aZ|0)==(aV|0)){a0=65535}else{a1=d[ae+(aZ+ab)|0]|0;a2=a1<<1;if(aX){a0=a2;break}a0=a2|a1&1}}while(0);do{if(aT){if((aZ|0)==(ao|0)){a3=(a_|0)==0|0}else{a3=a_}a1=(a3|0)!=0;a2=a1?65535:a0;if((aZ|0)!=(aS|0)){a4=a3;a5=a2;break}a4=a1&1^1;a5=a2}else{a4=a_;a5=a0}}while(0);if(aY){a2=0;a1=a5;while(1){a6=a2*3|0;a7=a$+a6|0;if((a1&256|0)==0){a[a7]=av;a[a$+(a6+1)|0]=aN;a[a$+(a6+2)|0]=aR}else{a[a7]=an;a[a$+(a6+1)|0]=aw;a[a$+(a6+2)|0]=aM}a6=a2+1|0;if(a6>>>0<ad>>>0){a2=a6;a1=a1<<1}else{break}}}a1=aZ+1|0;if(a1>>>0<A>>>0){aZ=a1;a_=a4;a$=a$+Q|0}else{break}}}else{if(aT){a8=0;a9=0;ba=W}else{a$=0;a_=W;while(1){if(aY){aZ=0;do{aX=aZ*3|0;a[a_+aX|0]=av;a[a_+(aX+1)|0]=aN;a[a_+(aX+2)|0]=aR;aZ=aZ+1|0;}while(aZ>>>0<ad>>>0)}aZ=a$+1|0;if(aZ>>>0<A>>>0){a$=aZ;a_=a_+Q|0}else{break L4641}}}while(1){if((a8|0)==(ao|0)){bb=(a9|0)==0|0}else{bb=a9}a_=(bb|0)!=0;if((a8|0)==(aS|0)){bc=a_&1^1}else{bc=bb}if(aY){a$=0;aZ=a_?65535:0;while(1){a_=a$*3|0;aX=ba+a_|0;if((aZ&256|0)==0){a[aX]=av;a[ba+(a_+1)|0]=aN;a[ba+(a_+2)|0]=aR}else{a[aX]=an;a[ba+(a_+1)|0]=aw;a[ba+(a_+2)|0]=aM}a_=a$+1|0;if(a_>>>0<ad>>>0){a$=a_;aZ=aZ<<1}else{break}}}aZ=a8+1|0;if(aZ>>>0<A>>>0){a8=aZ;a9=bc;ba=ba+Q|0}else{break}}}}}while(0);aM=ag+1&65535;aw=ad+af|0;if(aw>>>0<j>>>0){ag=aM;af=aw}else{aD=aM;break}}}if(s){bd=aD}else{bd=G+L&65535}af=A+K|0;if(af>>>0<m>>>0){G=bd;K=af}else{break}}i=e;return}}while(0);bd=b+948|0;m=c[bd>>2]|0;if((m|0)==0){be=3562}else{aD=c[b+952>>2]|0;if((aD|0)==0){be=3562}else{bf=aD;bg=m}}L4698:do{if((be|0)==3562){m=b+956|0;do{if((c[m>>2]|0)>>>0<192e3){aD=b+960|0;j=zJ(c[aD>>2]|0,192e3)|0;if((j|0)!=0){c[aD>>2]=j;c[m>>2]=192e3;break}j=c[b+952>>2]|0;if((j|0)==0){i=e;return}else{bf=j;bg=c[bd>>2]|0;break L4698}}}while(0);c[bd>>2]=320;c[b+952>>2]=200;bf=200;bg=320}}while(0);be=b+952|0;m=0;j=c[b+960>>2]|0;b=bg;bg=bf;while(1){bf=(m&8)>>>0<8;if((b|0)==0){bh=j;bi=0;bj=bg}else{aD=0;ba=j;do{bc=(aD&8)>>>0<8^bf?32:0;a[ba]=bc;a[ba+1|0]=bc;a[ba+2|0]=bc;ba=ba+3|0;aD=aD+1|0;bk=c[bd>>2]|0;}while(aD>>>0<bk>>>0);bh=ba;bi=bk;bj=c[be>>2]|0}aD=m+1|0;if(aD>>>0<bj>>>0){m=aD;j=bh;b=bi;bg=bj}else{break}}i=e;return}function qH(a){a=a|0;zP(a|0,0,48);return}function qI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+8|0;f=e|0;do{if((xz(41264,b)|0)==0){g=c[a+4>>2]|0;if((g|0)==0){h=-1;break}h=b4[g&127](c[a+32>>2]|0,b,d)|0}else{if((xD(d,f)|0)!=0){h=1;break}g=c[a+24>>2]|0;if((g|0)==0){h=0;break}b3[g&511](c[a+32>>2]|0,c[f>>2]|0);h=0}}while(0);i=e;return h|0}function qJ(a,b){a=a|0;b=b|0;var d=0;d=c[a+8>>2]|0;if((d|0)==0){return}b3[d&511](c[a+32>>2]|0,b);return}function qK(a){a=a|0;var b=0,d=0;b=c[a+12>>2]|0;if((b|0)==0){d=0;return d|0}d=b1[b&1023](c[a+32>>2]|0)|0;return d|0}function qL(a){a=a|0;var b=0,d=0;b=c[a+16>>2]|0;if((b|0)==0){d=0;return d|0}d=b1[b&1023](c[a+32>>2]|0)|0;return d|0}function qM(a,b){a=a|0;b=b|0;var d=0;d=c[a+20>>2]|0;if((d|0)==0){return}b3[d&511](c[a+32>>2]|0,b);return}function qN(a,b){a=a|0;b=b|0;var d=0,e=0;d=a+36|0;e=(c[d>>2]|0)+b|0;c[d>>2]=e;d=a+44|0;b=c[d>>2]|0;c[d>>2]=e;d=c[a+28>>2]|0;if((d|0)==0){return}b3[d&511](c[a+32>>2]|0,e-b|0);return}function qO(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=e&255;if((d|0)==9){a[(c[b+68>>2]|0)+9|0]=f;return}else if((d|0)==11){e=(c[b+68>>2]|0)+11|0;if((a[e]|0)==f<<24>>24){return}a[e]=f;e=b+2208|0;a[e]=a[e]|1;return}else if((d|0)==4){do{if(f<<24>>24==0){e=(c[b+68>>2]|0)+11|0;if((a[e]|0)==0){break}a[e]=0;e=b+2208|0;a[e]=a[e]|1}}while(0);o0(b,4,f);return}else if((d|0)==10){a[(c[b+68>>2]|0)+10|0]=f;return}else{o0(b,d,f);return}}function qP(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;if((d|0)==9){a[(c[b+68>>2]|0)+9|0]=e;return}else if((d|0)==4){do{if(e<<24>>24==0){f=(c[b+68>>2]|0)+11|0;if((a[f]|0)==0){break}a[f]=0;f=b+2208|0;a[f]=a[f]|1}}while(0);o0(b,4,e);return}else if((d|0)==10){a[(c[b+68>>2]|0)+10|0]=e;return}else if((d|0)==11){f=(c[b+68>>2]|0)+11|0;if((a[f]|0)==e<<24>>24){return}a[f]=e;f=b+2208|0;a[f]=a[f]|1;return}else{o0(b,d,e);return}}function qQ(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;aB(24448,14,1,b|0)|0;f=oW(a)|0;g=oX(a)|0;h=a+68|0;j=d[(c[h>>2]|0)+5|0]|0;bN(b|0,22832,(x=i,i=i+32|0,c[x>>2]=f,c[x+8>>2]=g,c[x+16>>2]=j&15,c[x+24>>2]=j>>>5&1,x)|0)|0;j=c[h>>2]|0;g=d[j+5|0]|0;f=d[j+6|0]|0;k=d[a+94|0]|0;l=d[a+95|0]|0;m=d[a+96|0]|0;n=d[a+97|0]|0;bN(b|0,21648,(x=i,i=i+56|0,c[x>>2]=d[j+4|0]|0,c[x+8>>2]=g,c[x+16>>2]=f,c[x+24>>2]=k,c[x+32>>2]=l,c[x+40>>2]=m,c[x+48>>2]=n,x)|0)|0;n=c[h>>2]|0;h=d[n+9|0]|0;m=d[n+10|0]|0;bN(b|0,41728,(x=i,i=i+24|0,c[x>>2]=d[n+11|0]|0,c[x+8>>2]=h,c[x+16>>2]=m,x)|0)|0;bN(b|0,40648,(x=i,i=i+8|0,c[x>>2]=d[a+76|0]|0,x)|0)|0;m=1;do{aA(((m&7|0)!=0?32:45)|0,b|0)|0;bN(b|0,37128,(x=i,i=i+8|0,c[x>>2]=d[a+76+m|0]|0,x)|0)|0;m=m+1|0;}while(m>>>0<18);aB(35216,2,1,b|0)|0;ax(b|0)|0;i=e;return}function qR(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;if(d>>>0<65536){f=(a[(c[b+68>>2]|0)+11|0]&2)==0?d:d+65536|0}else{f=d&32767}d=(c[b+60>>2]|0)+f|0;if((a[d]|0)==e<<24>>24){return}a[d]=e;e=b+2208|0;a[e]=a[e]|1;return}function qS(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=e&255;if(d>>>0<65536){g=(a[(c[b+68>>2]|0)+11|0]&2)==0?d:d+65536|0}else{g=d&32767}h=b+60|0;i=(c[h>>2]|0)+g|0;if((a[i]|0)!=f<<24>>24){a[i]=f;f=b+2208|0;a[f]=a[f]|1}f=d+1|0;if(f>>>0>=(c[(c[b+56>>2]|0)+40>>2]|0)>>>0){return}i=(e&65535)>>>8&255;if(f>>>0<65536){j=(a[(c[b+68>>2]|0)+11|0]&2)==0?f:d+65537|0}else{j=f&32767}f=(c[h>>2]|0)+j|0;if((a[f]|0)==i<<24>>24){return}a[f]=i;i=b+2208|0;a[i]=a[i]|1;return}function qT(b,d){b=b|0;d=d|0;var e=0;if(d>>>0<65536){e=(a[(c[b+68>>2]|0)+11|0]&1)==0?d:d+65536|0}else{e=d&32767}return a[(c[b+60>>2]|0)+e|0]|0}function qU(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if(e>>>0<65536){f=(a[(c[b+68>>2]|0)+11|0]&1)==0?e:e+65536|0}else{f=e&32767}g=c[b+60>>2]|0;h=d[g+f|0]|0;f=e+1|0;if(f>>>0>=(c[(c[b+56>>2]|0)+40>>2]|0)>>>0){i=h;return i|0}if(f>>>0<65536){j=(a[(c[b+68>>2]|0)+11|0]&1)==0?f:e+65537|0}else{j=f&32767}i=(d[g+j|0]|0)<<8|h;return i|0}function qV(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0;e=i;f=d[(c[b+68>>2]|0)+11|0]|0;if((f&8|0)==0){o$(b);i=e;return}g=f&240;if((g|0)==192){if((o_(b,1280,800)|0)!=0){i=e;return}h=b+60|0;j=0;k=0;l=c[b+2204>>2]|0;while(1){m=c[h>>2]|0;if((j&1|0)==0){n=k;o=k}else{n=k+65536|0;o=k+160|0}p=0;r=l;while(1){s=d[m+(p+n)|0]|0;if((s&128|0)==0){a[r]=0;a[r+1|0]=0;a[r+2|0]=0}else{a[r]=-1;a[r+1|0]=-1;a[r+2|0]=-1}t=r+3|0;if((s&64|0)==0){a[t]=0;a[r+4|0]=0;a[r+5|0]=0}else{a[t]=-1;a[r+4|0]=-1;a[r+5|0]=-1}t=r+6|0;if((s&32|0)==0){a[t]=0;a[r+7|0]=0;a[r+8|0]=0}else{a[t]=-1;a[r+7|0]=-1;a[r+8|0]=-1}t=r+9|0;if((s&16|0)==0){a[t]=0;a[r+10|0]=0;a[r+11|0]=0}else{a[t]=-1;a[r+10|0]=-1;a[r+11|0]=-1}t=r+12|0;if((s&8|0)==0){a[t]=0;a[r+13|0]=0;a[r+14|0]=0}else{a[t]=-1;a[r+13|0]=-1;a[r+14|0]=-1}t=r+15|0;if((s&4|0)==0){a[t]=0;a[r+16|0]=0;a[r+17|0]=0}else{a[t]=-1;a[r+16|0]=-1;a[r+17|0]=-1}t=r+18|0;if((s&2|0)==0){a[t]=0;a[r+19|0]=0;a[r+20|0]=0}else{a[t]=-1;a[r+19|0]=-1;a[r+20|0]=-1}t=r+21|0;if((s&1|0)==0){a[t]=0;a[r+22|0]=0;a[r+23|0]=0}else{a[t]=-1;a[r+22|0]=-1;a[r+23|0]=-1}t=p+1|0;if(t>>>0<160){p=t;r=r+24|0}else{break}}r=j+1|0;if(r>>>0<800){j=r;k=o;l=l+3840|0}else{break}}i=e;return}else if((g|0)==160){if((o_(b,1280,400)|0)!=0){i=e;return}l=b+60|0;o=0;k=0;j=c[b+2204>>2]|0;while(1){n=c[l>>2]|0;h=0;r=j;while(1){p=d[n+(h+k)|0]|0;if((p&128|0)==0){a[r]=0;a[r+1|0]=0;a[r+2|0]=0}else{a[r]=-1;a[r+1|0]=-1;a[r+2|0]=-1}m=r+3|0;if((p&64|0)==0){a[m]=0;a[r+4|0]=0;a[r+5|0]=0}else{a[m]=-1;a[r+4|0]=-1;a[r+5|0]=-1}m=r+6|0;if((p&32|0)==0){a[m]=0;a[r+7|0]=0;a[r+8|0]=0}else{a[m]=-1;a[r+7|0]=-1;a[r+8|0]=-1}m=r+9|0;if((p&16|0)==0){a[m]=0;a[r+10|0]=0;a[r+11|0]=0}else{a[m]=-1;a[r+10|0]=-1;a[r+11|0]=-1}m=r+12|0;if((p&8|0)==0){a[m]=0;a[r+13|0]=0;a[r+14|0]=0}else{a[m]=-1;a[r+13|0]=-1;a[r+14|0]=-1}m=r+15|0;if((p&4|0)==0){a[m]=0;a[r+16|0]=0;a[r+17|0]=0}else{a[m]=-1;a[r+16|0]=-1;a[r+17|0]=-1}m=r+18|0;if((p&2|0)==0){a[m]=0;a[r+19|0]=0;a[r+20|0]=0}else{a[m]=-1;a[r+19|0]=-1;a[r+20|0]=-1}m=r+21|0;if((p&1|0)==0){a[m]=0;a[r+22|0]=0;a[r+23|0]=0}else{a[m]=-1;a[r+22|0]=-1;a[r+23|0]=-1}m=h+1|0;if(m>>>0<160){h=m;r=r+24|0}else{break}}r=o+1|0;if(r>>>0<400){o=r;k=k+160|0;j=j+3840|0}else{break}}i=e;return}else if((g|0)==128){if((o_(b,640,400)|0)!=0){i=e;return}g=b+60|0;j=0;k=0;o=c[b+2204>>2]|0;while(1){b=c[g>>2]|0;l=0;r=o;while(1){h=d[b+(l+k)|0]|0;if((h&128|0)==0){a[r]=0;a[r+1|0]=0;a[r+2|0]=0}else{a[r]=-1;a[r+1|0]=-1;a[r+2|0]=-1}n=r+3|0;if((h&64|0)==0){a[n]=0;a[r+4|0]=0;a[r+5|0]=0}else{a[n]=-1;a[r+4|0]=-1;a[r+5|0]=-1}n=r+6|0;if((h&32|0)==0){a[n]=0;a[r+7|0]=0;a[r+8|0]=0}else{a[n]=-1;a[r+7|0]=-1;a[r+8|0]=-1}n=r+9|0;if((h&16|0)==0){a[n]=0;a[r+10|0]=0;a[r+11|0]=0}else{a[n]=-1;a[r+10|0]=-1;a[r+11|0]=-1}n=r+12|0;if((h&8|0)==0){a[n]=0;a[r+13|0]=0;a[r+14|0]=0}else{a[n]=-1;a[r+13|0]=-1;a[r+14|0]=-1}n=r+15|0;if((h&4|0)==0){a[n]=0;a[r+16|0]=0;a[r+17|0]=0}else{a[n]=-1;a[r+16|0]=-1;a[r+17|0]=-1}n=r+18|0;if((h&2|0)==0){a[n]=0;a[r+19|0]=0;a[r+20|0]=0}else{a[n]=-1;a[r+19|0]=-1;a[r+20|0]=-1}n=r+21|0;if((h&1|0)==0){a[n]=0;a[r+22|0]=0;a[r+23|0]=0}else{a[n]=-1;a[r+22|0]=-1;a[r+23|0]=-1}n=l+1|0;if(n>>>0<80){l=n;r=r+24|0}else{break}}r=j+1|0;if(r>>>0<400){j=r;k=k+80|0;o=o+1920|0}else{break}}i=e;return}else{bN(c[q>>2]|0,25688,(x=i,i=i+8|0,c[x>>2]=f,x)|0)|0;i=e;return}}function qW(b,d){b=b|0;d=d|0;var e=0;if((d|0)==11){e=a[(c[b+68>>2]|0)+11|0]|0;return e|0}else{e=o3(b,d)|0;return e|0}return 0}function qX(b,d){b=b|0;d=d|0;var e=0,f=0;if((d|0)==11){e=a[(c[b+68>>2]|0)+11|0]|0;f=e&255;return f|0}else{e=o3(b,d)|0;f=e&255;return f|0}return 0}function qY(a,b,d){a=a|0;b=b|0;d=d|0;c[a>>2]=0;c[a+4>>2]=1;c[a+8>>2]=d;c[a+12>>2]=0;c[a+16>>2]=0;c[a+20>>2]=0;c[a+24>>2]=b;return}function qZ(a,b){a=a|0;b=b|0;c[a+12604>>2]=b;return}function q_(a,b,d){a=a|0;b=b|0;d=d|0;if(b>>>0>=4){return}c[a+12608+(b<<2)>>2]=d;return}function q$(a,b){a=a|0;b=b|0;var d=0;if(b>>>0>=4){d=65535;return d|0}d=c[a+12608+(b<<2)>>2]|0;return d|0}function q0(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+32|0;d=b|0;e=b+8|0;f=b+16|0;g=b+24|0;yi(a,41144,d,980)|0;yi(a,40752,e,655360)|0;yi(a,33208,f,131072)|0;yj(a,31104,g,0)|0;a=c[f>>2]|0;if(a>>>0<131072){c[f>>2]=131072;h=131072}else{h=a}a=c[e>>2]|0;xv(2,29056,27272,(x=i,i=i+24|0,c[x>>2]=c[d>>2],c[x+8>>2]=a,c[x+16>>2]=h,x)|0);h=c[d>>2]|0;d=c[e>>2]|0;e=c[f>>2]|0;f=zH(2212)|0;a=f;if((f|0)==0){j=0;i=b;return j|0}o7(a,h,d,e>>>0<131072?131072:e);c[f+20>>2]=22;c[f+52>>2]=36;e=f+64|0;c[(c[e>>2]|0)+12>>2]=28;c[(c[e>>2]|0)+16>>2]=84;c[c[e>>2]>>2]=132;c[(c[e>>2]|0)+4>>2]=116;e=f+56|0;c[(c[e>>2]|0)+12>>2]=8;c[(c[e>>2]|0)+16>>2]=42;c[c[e>>2]>>2]=12;c[(c[e>>2]|0)+4>>2]=26;oV(a,c[g>>2]|0);j=f;i=b;return j|0}function q1(a){a=a|0;var b=0,d=0,e=0,f=0;b=zH(12624)|0;if((b|0)==0){d=0;return d|0}qY(b,b,40936);c[b+16>>2]=98;c[b+20>>2]=154;e=b+28|0;f=e;oj(f);ob(f,b,82);f=b+12556|0;r$(f,a,8,0)|0;rJ(f,e,108,0,0,12,0,0);c[b+12608>>2]=65535;c[b+12612>>2]=65535;c[b+12616>>2]=65535;c[b+12620>>2]=65535;d=b;return d|0}function q2(a){a=a|0;var b=0;b=c[a+24>>2]|0;if((b|0)==0){return}r1(b+12556|0);n5(b+28|0);zI(b);return}function q3(a,b){a=a|0;b=b|0;os(a+28|0,b);return}function q4(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;g=i;i=i+552|0;h=g|0;j=g+8|0;k=g+16|0;l=g+24|0;m=g+32|0;n=g+40|0;if((e|0)==0){o=ts(c[b+12604>>2]|0,c[b+12608+((a[f|0]&3)<<2)>>2]|0)|0;if((o|0)==0){c[f+12>>2]=0;p=4;i=g;return p|0}if((ta(o)|0)!=6){q=f+12|0;if((c[q>>2]|0)>>>0<512){c[q>>2]=0;p=1;i=g;return p|0}if((tu(o,c[f+8>>2]|0,d[f+1|0]|0,d[f+2|0]|0,d[f+6|0]|0,1)|0)==0){c[q>>2]=512;p=0;i=g;return p|0}else{c[q>>2]=0;p=4;i=g;return p|0}}q=sX(c[o+64>>2]|0,c[f+8>>2]|0,f+12|0,d[f+1|0]|0,d[f+2|0]|0,d[f+3|0]|0,1)|0;o=q&1;r=(o|0)==0?q:q&-2;q=o<<1;if((r&2|0)==0){s=q;t=r}else{s=q|4;t=r&-3}if((t&4|0)==0){u=s;v=t}else{u=s|8;v=t&-5}if((v&8|0)==0){w=u;x=v}else{w=u|16;x=v&-9}if((x&16|0)==0){y=w;z=x}else{y=w|32;z=x&-17}if((z&32|0)==0){A=y;B=z}else{A=y|64;B=z&-33}if((B&64|0)==0){C=A;D=B}else{C=A|128;D=B&-65}p=(D|0)!=0|C;i=g;return p|0}else if((e|0)==1){C=ts(c[b+12604>>2]|0,c[b+12608+((a[f|0]&3)<<2)>>2]|0)|0;if((C|0)==0){c[f+12>>2]=0;p=4;i=g;return p|0}if((ta(C)|0)!=6){D=f+12|0;if((c[D>>2]|0)!=512){p=1;i=g;return p|0}if((tw(C,c[f+8>>2]|0,d[f+1|0]|0,d[f+2|0]|0,d[f+6|0]|0,1)|0)==0){p=0;i=g;return p|0}c[D>>2]=0;p=1;i=g;return p|0}D=sY(c[C+64>>2]|0,c[f+8>>2]|0,f+12|0,d[f+1|0]|0,d[f+2|0]|0,d[f+3|0]|0,1)|0;C=D&1;B=(C|0)==0?D:D&-2;D=C<<1;if((B&2|0)==0){E=D;F=B}else{E=D|4;F=B&-3}if((F&4|0)==0){G=E;H=F}else{G=E|8;H=F&-5}if((H&8|0)==0){I=G;J=H}else{I=G|16;J=H&-9}if((J&16|0)==0){K=I;L=J}else{K=I|32;L=J&-17}if((L&32|0)==0){M=K;N=L}else{M=K|64;N=L&-33}if((N&64|0)==0){O=M;P=N}else{O=M|128;P=N&-65}p=(P|0)!=0|O;i=g;return p|0}else if((e|0)==3){O=n|0;P=ts(c[b+12604>>2]|0,c[b+12608+((a[f|0]&3)<<2)>>2]|0)|0;if((P|0)==0){p=4;i=g;return p|0}N=128<<d[f+7|0];if((ta(P)|0)!=6){if((N|0)!=512){p=1;i=g;return p|0}zP(O|0,a[f+16|0]|0,512);p=(tw(P,O,d[f+1|0]|0,d[f+2|0]|0,(d[f+3|0]|0)+1|0,1)|0)!=0|0;i=g;return p|0}O=P+64|0;if((a[f+3|0]|0)==0){P=c[O>>2]|0;M=f+1|0;L=d[M]|0;K=f+2|0;J=d[K]|0;sZ(P,L,J)|0;Q=M;R=K}else{Q=f+1|0;R=f+2|0}p=(s_(c[O>>2]|0,d[Q]|0,d[R]|0,d[f+4|0]|0,d[f+5|0]|0,d[f+6|0]|0,N,d[f+16|0]|0)|0)!=0|0;i=g;return p|0}else if((e|0)==4){e=ts(c[b+12604>>2]|0,c[b+12608+((a[f|0]&3)<<2)>>2]|0)|0;if((e|0)==0){p=2;i=g;return p|0}if((ta(e)|0)!=6){b=f+1|0;N=f+2|0;R=f+3|0;if((tu(e,n|0,d[b]|0,d[N]|0,(d[R]|0)+1|0,1)|0)!=0){p=2;i=g;return p|0}a[f+4|0]=a[b]|0;a[f+5|0]=a[N]|0;a[f+6|0]=(a[R]|0)+1&255;a[f+7|0]=2;p=0;i=g;return p|0}if((s$(c[e+64>>2]|0,d[f+1|0]|0,d[f+2|0]|0,d[f+3|0]|0,h,j,k,l,m)|0)!=0){p=2;i=g;return p|0}a[f+4|0]=c[h>>2]&255;a[f+5|0]=c[j>>2]&255;a[f+6|0]=c[k>>2]&255;k=f+7|0;a[k]=0;f=c[m>>2]|0;if(f>>>0>128){S=f;T=0}else{p=0;i=g;return p|0}while(1){U=S>>>1;V=T+1&255;if(S>>>0>257){S=U;T=V}else{break}}c[m>>2]=U;a[k]=V;p=0;i=g;return p|0}else{p=1;i=g;return p|0}return 0}function q5(a,b){a=a|0;b=b|0;r7(b,a+12556|0,0);return}function q6(a){a=a|0;ok(a+28|0);return}function q7(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=d+48|0;f=a[e]|0;g=f&255;if((g&1|0)==0){h=0;return h|0}if((g&4|0)!=0){g=a[d+51|0]|0;i=f&-33;a[e]=i;j=d+708|0;do{if((a[j]|0)==0){k=i}else{a[j]=0;l=c[d+716>>2]|0;if((l|0)==0){k=i;break}b3[l&511](c[d+712>>2]|0,0);k=a[e]|0}}while(0);b[d+52>>1]=0;b[d+54>>1]=0;a[e]=k&-12;h=g;return h|0}g=d+62|0;k=b[g>>1]|0;i=b[d+64>>1]|0;if((k&65535)>=(i&65535)){h=0;return h|0}j=k+1&65535;b[g>>1]=j;g=a[(k&65535)+(d+66)|0]|0;if((j&65535)<(i&65535)){h=g;return h|0}a[e]=f&-17;f=d+720|0;do{if((a[f]|0)!=0){a[f]=0;if((a[d+50|0]&1)==0){break}e=c[d+728>>2]|0;if((e|0)==0){break}b3[e&511](c[d+724>>2]|0,0)}}while(0);f=c[d+704>>2]|0;if((f|0)==0){h=g;return h|0}b2[f&255](d);h=g;return h|0}function q8(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=i;i=i+512|0;j=h|0;k=f+48|0;l=d[k]|0;if((l&1|0)==0){i=h;return}if((l&4|0)==0){l=f+62|0;m=b[l>>1]|0;n=f+64|0;o=b[n>>1]|0;if((m&65535)<(o&65535)){b[l>>1]=m+1&65535;a[(m&65535)+(f+66)|0]=g;p=b[l>>1]|0;r=b[n>>1]|0}else{p=m;r=o}if((p&65535)<(r&65535)){i=h;return}a[k]=a[k]&-17;r=f+720|0;do{if((a[r]|0)!=0){a[r]=0;if((a[f+50|0]&1)==0){break}p=c[f+728>>2]|0;if((p|0)==0){break}b3[p&511](c[f+724>>2]|0,0)}}while(0);r=c[f+704>>2]|0;if((r|0)==0){i=h;return}b2[r&255](f);i=h;return}r=f+52|0;p=b[r>>1]|0;o=f+54|0;if(p<<16>>16==0){b[o>>1]=6}b[r>>1]=p+1&65535;a[(p&65535)+(f+56)|0]=g;if((e[r>>1]|0)<(e[o>>1]|0)){i=h;return}o=a[k]|0;a[k]=o&-2;r=d[f+56|0]|0;if((r|0)==26){b[f+684>>1]=(a[f+57|0]&255)>>>5&1;c[f+700>>2]=4096;c[f+704>>2]=2;i=h;return}else if((r|0)==224){g=b[f+684>>1]&1;p=g<<5;a[f+51|0]=p&255;a[f+652+(g<<4)+4|0]=0;a[f+652+(g<<4)+5|0]=(b[f+688>>1]&31|p)&255;p=b[f+686>>1]|0;a[f+652+(g<<4)+6|0]=(p&65535)>>>2&255&-64;a[f+652+(g<<4)+7|0]=p&255;c[f+700>>2]=4096;c[f+704>>2]=6;i=h;return}else if((r|0)==228){p=b[f+684>>1]&1;g=p<<5;a[f+51|0]=g&255;a[f+652+(p<<4)+4|0]=0;a[f+652+(p<<4)+5|0]=(b[f+688>>1]&31|g)&255;g=b[f+686>>1]|0;a[f+652+(p<<4)+6|0]=(g&65535)>>>2&255&-64;a[f+652+(p<<4)+7|0]=g&255;c[f+700>>2]=4096;c[f+704>>2]=6;i=h;return}else if((r|0)==251){b[f+684>>1]=(a[f+57|0]&255)>>>5&1;c[f+700>>2]=4096;c[f+704>>2]=52;i=h;return}else if((r|0)==3){b[f+684>>1]=(a[f+57|0]&255)>>>5&1;c[f+700>>2]=256;c[f+704>>2]=174;i=h;return}else if((r|0)==12){b[f+684>>1]=(a[f+57|0]&255)>>>5&1;b[f+62>>1]=0;b[f+64>>1]=8;c[f+700>>2]=512;c[f+704>>2]=28;i=h;return}else if((r|0)==5){g=d[f+57|0]|0;b[f+684>>1]=(g&65535)>>>5&1;p=d[f+58|0]|0;b[f+686>>1]=p<<2&768|d[f+59|0];b[f+688>>1]=g&31;b[f+690>>1]=p&63;b[f+692>>1]=d[f+60|0]|0;a[f+51|0]=0;c[f+700>>2]=65536;c[f+704>>2]=6;i=h;return}else if((r|0)==6){p=j|0;j=d[f+57|0]|0;g=(j&65535)>>>5;m=g&1;n=f+684|0;b[n>>1]=m;l=f+686|0;b[l>>1]=d[f+58|0]<<2&768|d[f+59|0];s=f+688|0;b[s>>1]=j&31;b[f+692>>1]=a[f+60|0]&31;j=g&1;g=c[f+652+(j<<4)>>2]|0;do{if((g|0)==65535){t=m}else{u=ts(c[f+696>>2]|0,g)|0;if((u|0)==0){t=b[n>>1]|0;break}if((a[f+61|0]&64)==0){zP(p|0,108,512)}else{v=f+66|0;zO(p|0,v|0,512)|0}v=f+652+(j<<4)+12|0;w=0;do{if(w>>>0>=(e[v>>1]|0)>>>0){y=4108;break}w=w+1|0;}while((tw(u,p,e[l>>1]|0,e[s>>1]|0,w,1)|0)==0);if((y|0)==4108){a[f+51|0]=0;c[f+700>>2]=65536;c[f+704>>2]=6;i=h;return}bN(c[q>>2]|0,24416,(x=i,i=i+8|0,c[x>>2]=e[n>>1]|0,x)|0)|0;w=b[n>>1]|0;u=w&1;v=u<<5;if(w<<16>>16==0){z=v&255}else{z=(v|2)&255}a[f+51|0]=z;a[f+652+(u<<4)+4|0]=-125;a[f+652+(u<<4)+5|0]=(b[s>>1]&31|v)&255;v=b[l>>1]|0;a[f+652+(u<<4)+6|0]=(v&65535)>>>2&255&-64;a[f+652+(u<<4)+7|0]=v&255;v=a[k]|0;c[f+700>>2]=0;c[f+704>>2]=0;u=v&-32|15;a[k]=u;v=f+720|0;do{if((a[v]|0)==0){A=u;B=f+50|0}else{a[v]=0;w=f+50|0;if((a[w]&1)==0){A=u;B=w;break}C=c[f+728>>2]|0;if((C|0)==0){A=u;B=w;break}b3[C&511](c[f+724>>2]|0,0);A=a[k]|0;B=w}}while(0);u=(d[B]|0)>>>1&1;a[k]=u<<24>>24==0?A&-33:A|32;v=f+708|0;if((a[v]|0)==u<<24>>24){i=h;return}a[v]=u;v=c[f+716>>2]|0;if((v|0)==0){i=h;return}b3[v&511](c[f+712>>2]|0,u);i=h;return}}while(0);bN(c[q>>2]|0,24416,(x=i,i=i+8|0,c[x>>2]=t&65535,x)|0)|0;t=b[n>>1]|0;n=t&1;A=n<<5;if(t<<16>>16==0){D=A&255}else{D=(A|2)&255}a[f+51|0]=D;a[f+652+(n<<4)+4|0]=-124;a[f+652+(n<<4)+5|0]=(b[s>>1]&31|A)&255;A=b[l>>1]|0;a[f+652+(n<<4)+6|0]=(A&65535)>>>2&255&-64;a[f+652+(n<<4)+7|0]=A&255;A=a[k]|0;c[f+700>>2]=0;c[f+704>>2]=0;n=A&-32|15;a[k]=n;A=f+720|0;do{if((a[A]|0)==0){E=n;F=f+50|0}else{a[A]=0;l=f+50|0;if((a[l]&1)==0){E=n;F=l;break}s=c[f+728>>2]|0;if((s|0)==0){E=n;F=l;break}b3[s&511](c[f+724>>2]|0,0);E=a[k]|0;F=l}}while(0);n=(d[F]|0)>>>1&1;a[k]=n<<24>>24==0?E&-33:E|32;E=f+708|0;if((a[E]|0)==n<<24>>24){i=h;return}a[E]=n;E=c[f+716>>2]|0;if((E|0)==0){i=h;return}b3[E&511](c[f+712>>2]|0,n);i=h;return}else if((r|0)==8){n=d[f+57|0]|0;b[f+684>>1]=(n&65535)>>>5&1;E=d[f+58|0]|0;b[f+686>>1]=E<<2&768|d[f+59|0];b[f+688>>1]=n&31;b[f+690>>1]=E&63;E=a[f+60|0]|0;b[f+692>>1]=E<<24>>24==0?256:E&255;c[f+700>>2]=4096;c[f+704>>2]=16;i=h;return}else if((r|0)==10){E=d[f+57|0]|0;b[f+684>>1]=(E&65535)>>>5&1;n=d[f+58|0]|0;b[f+686>>1]=n<<2&768|d[f+59|0];b[f+688>>1]=E&31;b[f+690>>1]=n&63;n=a[f+60|0]|0;b[f+692>>1]=n<<24>>24==0?256:n&255;c[f+700>>2]=4096;c[f+704>>2]=142;i=h;return}else if((r|0)==17){n=(a[f+57|0]&255)>>>5;b[f+684>>1]=n&1;E=n&1;n=E<<5;a[f+51|0]=n&255;a[f+652+(E<<4)+4|0]=0;a[f+652+(E<<4)+5|0]=(n|b[f+688>>1]&31)&255;n=b[f+686>>1]|0;a[f+652+(E<<4)+6|0]=(n&65535)>>>2&255&-64;a[f+652+(E<<4)+7|0]=n&255;c[f+700>>2]=4096;c[f+704>>2]=6;i=h;return}else if((r|0)==21){b[f+684>>1]=(a[f+57|0]&255)>>>5&1;c[f+700>>2]=2048;c[f+704>>2]=182;a[k]=o&-18;o=f+720|0;if((a[o]|0)==0){i=h;return}a[o]=0;if((a[f+50|0]&1)==0){i=h;return}o=c[f+728>>2]|0;if((o|0)==0){i=h;return}b3[o&511](c[f+724>>2]|0,0);i=h;return}else if((r|0)==4){o=d[f+57|0]|0;b[f+684>>1]=(o&65535)>>>5&1;b[f+686>>1]=d[f+58|0]<<2&768|d[f+59|0];b[f+688>>1]=o&31;b[f+692>>1]=a[f+60|0]&31;a[f+51|0]=0;c[f+700>>2]=4096;c[f+704>>2]=56;i=h;return}else if((r|0)==252){o=(a[f+57|0]&255)>>>5;b[f+684>>1]=o&1;n=o&1;o=n<<5;a[f+51|0]=o&255;a[f+652+(n<<4)+4|0]=0;a[f+652+(n<<4)+5|0]=(o|b[f+688>>1]&31)&255;o=b[f+686>>1]|0;a[f+652+(n<<4)+6|0]=(o&65535)>>>2&255&-64;a[f+652+(n<<4)+7|0]=o&255;c[f+700>>2]=4096;c[f+704>>2]=6;i=h;return}else if((r|0)==253){o=(a[f+57|0]&255)>>>5;b[f+684>>1]=o&1;n=o&1;o=n<<5;a[f+51|0]=o&255;a[f+652+(n<<4)+4|0]=0;a[f+652+(n<<4)+5|0]=(o|b[f+688>>1]&31)&255;o=b[f+686>>1]|0;a[f+652+(n<<4)+6|0]=(o&65535)>>>2&255&-64;a[f+652+(n<<4)+7|0]=o&255;c[f+700>>2]=4096;c[f+704>>2]=6;i=h;return}else if((r|0)==254){o=(a[f+57|0]&255)>>>5;b[f+684>>1]=o&1;b[f+62>>1]=0;b[f+64>>1]=64;n=o&1;o=n<<5;a[f+51|0]=o&255;a[f+652+(n<<4)+4|0]=0;a[f+652+(n<<4)+5|0]=(o|b[f+688>>1]&31)&255;o=b[f+686>>1]|0;a[f+652+(n<<4)+6|0]=(o&65535)>>>2&255&-64;a[f+652+(n<<4)+7|0]=o&255;c[f+700>>2]=0;c[f+704>>2]=44;a[k]=a[k]&-32|25;o=f+720|0;if((a[o]|0)==1){i=h;return}a[o]=1;if((a[f+50|0]&1)==0){i=h;return}o=c[f+728>>2]|0;if((o|0)==0){i=h;return}b3[o&511](c[f+724>>2]|0,1);i=h;return}else if((r|0)==0){o=(a[f+57|0]&255)>>>5;n=o&1;E=f+684|0;b[E>>1]=n;F=c[f+652+((o&1)<<4)>>2]|0;do{if((F|0)==65535){G=n;y=4068}else{o=(ts(c[f+696>>2]|0,F)|0)==0;A=b[E>>1]|0;if(o){G=A;y=4068;break}o=A&1;A=o<<5;a[f+51|0]=A&255;a[f+652+(o<<4)+4|0]=0;a[f+652+(o<<4)+5|0]=(b[f+688>>1]&31|A)&255;A=b[f+686>>1]|0;a[f+652+(o<<4)+6|0]=(A&65535)>>>2&255&-64;a[f+652+(o<<4)+7|0]=A&255;c[f+700>>2]=4096}}while(0);if((y|0)==4068){E=G&1;G=E<<5;a[f+51|0]=(G|2)&255;a[f+652+(E<<4)+4|0]=32;a[f+652+(E<<4)+5|0]=(b[f+688>>1]&31|G)&255;G=b[f+686>>1]|0;a[f+652+(E<<4)+6|0]=(G&65535)>>>2&255&-64;a[f+652+(E<<4)+7|0]=G&255;c[f+700>>2]=256}c[f+704>>2]=6;i=h;return}else if((r|0)==15){b[f+62>>1]=0;b[f+64>>1]=512;G=b[f+684>>1]&1;E=G<<5;a[f+51|0]=E&255;a[f+652+(G<<4)+4|0]=0;a[f+652+(G<<4)+5|0]=(b[f+688>>1]&31|E)&255;E=b[f+686>>1]|0;a[f+652+(G<<4)+6|0]=(E&65535)>>>2&255&-64;a[f+652+(G<<4)+7|0]=E&255;c[f+700>>2]=0;c[f+704>>2]=6;a[k]=a[k]&-32|25;E=f+720|0;if((a[E]|0)==1){i=h;return}a[E]=1;if((a[f+50|0]&1)==0){i=h;return}E=c[f+728>>2]|0;if((E|0)==0){i=h;return}b3[E&511](c[f+724>>2]|0,1);i=h;return}else if((r|0)==255){b[f+684>>1]=(a[f+57|0]&255)>>>5&1;c[f+700>>2]=4096;c[f+704>>2]=62;i=h;return}else if((r|0)==1){E=(a[f+57|0]&255)>>>5;G=E&1;F=f+684|0;b[F>>1]=G;n=c[f+652+((E&1)<<4)>>2]|0;do{if((n|0)==65535){H=G;y=4073}else{E=(ts(c[f+696>>2]|0,n)|0)==0;A=b[F>>1]|0;if(E){H=A;y=4073;break}E=A&1;A=E<<5;a[f+51|0]=A&255;a[f+652+(E<<4)+4|0]=0;a[f+652+(E<<4)+5|0]=(b[f+688>>1]&31|A)&255;A=b[f+686>>1]|0;a[f+652+(E<<4)+6|0]=(A&65535)>>>2&255&-64;a[f+652+(E<<4)+7|0]=A&255;c[f+700>>2]=65536}}while(0);if((y|0)==4073){F=H&1;H=F<<5;a[f+51|0]=(H|2)&255;a[f+652+(F<<4)+4|0]=32;a[f+652+(F<<4)+5|0]=(b[f+688>>1]&31|H)&255;H=b[f+686>>1]|0;a[f+652+(F<<4)+6|0]=(H&65535)>>>2&255&-64;a[f+652+(F<<4)+7|0]=H&255;c[f+700>>2]=512}c[f+704>>2]=6;i=h;return}else if((r|0)==14){b[f+62>>1]=0;b[f+64>>1]=512;H=b[f+684>>1]&1;F=H<<5;a[f+51|0]=F&255;a[f+652+(H<<4)+4|0]=0;a[f+652+(H<<4)+5|0]=(b[f+688>>1]&31|F)&255;F=b[f+686>>1]|0;a[f+652+(H<<4)+6|0]=(F&65535)>>>2&255&-64;a[f+652+(H<<4)+7|0]=F&255;c[f+700>>2]=0;c[f+704>>2]=6;a[k]=a[k]&-32|27;k=f+720|0;if((a[k]|0)==1){i=h;return}a[k]=1;if((a[f+50|0]&1)==0){i=h;return}k=c[f+728>>2]|0;if((k|0)==0){i=h;return}b3[k&511](c[f+724>>2]|0,1);i=h;return}else if((r|0)==11){k=d[f+57|0]|0;F=(k&65535)>>>5;H=F&1;n=f+684|0;b[n>>1]=H;G=a[f+59|0]|0;A=d[f+58|0]<<2&768|G&255;E=f+686|0;b[E>>1]=A;o=f+688|0;b[o>>1]=k&31;k=c[f+652+((F&1)<<4)>>2]|0;do{if((k|0)==65535){I=H;J=(A&65535)>>>2&255;K=G;y=4114}else{F=(ts(c[f+696>>2]|0,k)|0)==0;l=b[n>>1]|0;if(F){F=b[E>>1]|0;I=l;J=(F&65535)>>>2&255;K=F&255;y=4114;break}else{F=l&1;l=F<<5;a[f+51|0]=l&255;a[f+652+(F<<4)+4|0]=0;a[f+652+(F<<4)+5|0]=(b[o>>1]&31|l)&255;l=b[E>>1]|0;a[f+652+(F<<4)+6|0]=(l&65535)>>>2&255&-64;a[f+652+(F<<4)+7|0]=l&255;c[f+700>>2]=65536;break}}}while(0);if((y|0)==4114){y=I&1;I=y<<5;a[f+51|0]=(I|2)&255;a[f+652+(y<<4)+4|0]=4;a[f+652+(y<<4)+5|0]=(b[o>>1]&31|I)&255;a[f+652+(y<<4)+6|0]=J&-64;a[f+652+(y<<4)+7|0]=K;c[f+700>>2]=512}c[f+704>>2]=6;i=h;return}else{K=d[f+57|0]|0;y=d[f+58|0]|0;J=d[f+59|0]|0;I=d[f+60|0]|0;o=d[f+61|0]|0;bN(c[q>>2]|0,40680,(x=i,i=i+56|0,c[x>>2]=r,c[x+8>>2]=r,c[x+16>>2]=K,c[x+24>>2]=y,c[x+32>>2]=J,c[x+40>>2]=I,c[x+48>>2]=o,x)|0)|0;o=b[f+684>>1]&1;I=o<<5;a[f+51|0]=(I|2)&255;a[f+652+(o<<4)+4|0]=32;a[f+652+(o<<4)+5|0]=(b[f+688>>1]&31|I)&255;I=b[f+686>>1]|0;a[f+652+(o<<4)+6|0]=(I&65535)>>>2&255&-64;a[f+652+(o<<4)+7|0]=I&255;c[f+700>>2]=4096;c[f+704>>2]=6;i=h;return}}function q9(a,b){a=a|0;b=b|0;return 0}function ra(a,b,c){a=a|0;b=b|0;c=c|0;return}function rb(a,b,d){a=a|0;b=b|0;d=d|0;c[a+716>>2]=d;c[a+712>>2]=b;return}function rc(a,b,d){a=a|0;b=b|0;d=d|0;c[a+728>>2]=d;c[a+724>>2]=b;return}function rd(b,c){b=b|0;c=c|0;a[b+49|0]=c&255;return}function re(a,b){a=a|0;b=b|0;c[a+648>>2]=b;return}function rf(a,b){a=a|0;b=b|0;c[a+696>>2]=b;return}function rg(a,b,d){a=a|0;b=b|0;d=d|0;if(b>>>0>=2){return}c[a+652+(b<<4)>>2]=d;return}function rh(b){b=b|0;var d=0,e=0,f=0;d=zH(732)|0;if((d|0)==0){e=0;return e|0}f=d;r$(f,b,4,0)|0;rJ(f,d,88,94,0,24,118,0);a[d+49|0]=0;zP(d+582|0,0,64);c[d+648>>2]=17;c[d+652>>2]=65535;c[d+668>>2]=65535;c[d+712>>2]=0;c[d+716>>2]=0;a[d+720|0]=0;c[d+724>>2]=0;c[d+728>>2]=0;zP(d+696|0,0,13);e=d;return e|0}function ri(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;if((d|0)==0){f=q7(b)|0}else if((d|0)==1){f=a[b+48|0]|0}else if((d|0)==2){f=a[b+49|0]|0}else{bN(c[q>>2]|0,40864,(x=i,i=i+8|0,c[x>>2]=d,x)|0)|0;f=0}i=e;return f|0}function rj(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if((e|0)==0){q8(d,f);return}else if((e|0)==1){rm(d);return}else if((e|0)==2){c[d+700>>2]=0;c[d+704>>2]=0;g=d+48|0;h=a[g]&-17;a[g]=h;i=d+720|0;do{if((a[i]|0)==0){j=h}else{a[i]=0;if((a[d+50|0]&1)==0){j=h;break}k=c[d+728>>2]|0;if((k|0)==0){j=h;break}b3[k&511](c[d+724>>2]|0,0);j=a[g]|0}}while(0);h=j&-33;a[g]=h;j=d+708|0;do{if((a[j]|0)==0){l=h}else{a[j]=0;i=c[d+716>>2]|0;if((i|0)==0){l=h;break}b3[i&511](c[d+712>>2]|0,0);l=a[g]|0}}while(0);b[d+52>>1]=0;a[g]=l&-16|13;return}else if((e|0)==3){a[d+50|0]=f;return}else{return}}function rk(a,b){a=a|0;b=b|0;r7(b,a|0,0);return}function rl(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0;zP(b+582|0,0,64);e=d>>>0>8?8:d;if((e|0)==0){return}else{f=0}do{a[b+582+f|0]=a[c+f|0]|0;f=f+1|0;}while(f>>>0<e>>>0);return}function rm(d){d=d|0;var e=0,f=0,g=0;e=d+48|0;a[e]=0;a[d+50|0]=0;f=b[d+684>>1]&1;g=f<<5;a[d+51|0]=g&255;a[d+652+(f<<4)+4|0]=0;a[d+652+(f<<4)+5|0]=(b[d+688>>1]&31|g)&255;g=b[d+686>>1]|0;a[d+652+(f<<4)+6|0]=(g&65535)>>>2&255&-64;a[d+652+(f<<4)+7|0]=g&255;b[d+52>>1]=0;b[d+54>>1]=0;b[d+62>>1]=0;b[d+64>>1]=0;b[d+660>>1]=306;b[d+662>>1]=4;g=c[d+648>>2]&65535;b[d+664>>1]=g;f=d+656|0;y=0;a[f]=y&255;y=y>>8;a[f+1|0]=y&255;y=y>>8;a[f+2|0]=y&255;y=y>>8;a[f+3|0]=y&255;b[d+676>>1]=306;b[d+678>>1]=4;b[d+680>>1]=g;c[d+700>>2]=0;c[d+704>>2]=0;g=d+672|0;y=0;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;a[e]=a[e]&-33;e=d+708|0;if((a[e]|0)==0){return}a[e]=0;e=c[d+716>>2]|0;if((e|0)==0){return}b3[e&511](c[d+712>>2]|0,0);return}function rn(a,b){a=a|0;b=b|0;var d=0,e=0;d=a+700|0;e=c[d>>2]|0;if((e|0)==0){return}if(e>>>0>b>>>0){c[d>>2]=e-b;return}c[d>>2]=0;d=c[a+704>>2]|0;if((d|0)==0){return}b2[d&255](a);return}function ro(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b+48|0;f=a[e]|0;c[b+700>>2]=0;c[b+704>>2]=0;g=f&-32|15;a[e]=g;f=b+720|0;do{if((a[f]|0)==0){h=g;i=b+50|0}else{a[f]=0;j=b+50|0;if((a[j]&1)==0){h=g;i=j;break}k=c[b+728>>2]|0;if((k|0)==0){h=g;i=j;break}b3[k&511](c[b+724>>2]|0,0);h=a[e]|0;i=j}}while(0);g=(d[i]|0)>>>1&1;a[e]=g<<24>>24==0?h&-33:h|32;h=b+708|0;if((a[h]|0)==g<<24>>24){return}a[h]=g;h=c[b+716>>2]|0;if((h|0)==0){return}b3[h&511](c[b+712>>2]|0,g);return}function rp(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=d+684|0;g=ts(c[d+696>>2]|0,c[d+652+(e[f>>1]<<4)>>2]|0)|0;if((g|0)==0){h=0;i=d+648|0;j=0}else{h=c[g+32>>2]&65535;i=g+40|0;j=c[g+36>>2]&255}g=c[i>>2]|0;b[d+652+(e[f>>1]<<4)+12>>1]=g&65535;i=d+66|0;k=d+582|0;zO(i|0,k|0,64)|0;rQ(i,8,h);rO(i,10,j);rQ(i,11,h);rQ(i,13,h);rO(i,15,5);rO(i,22,g&255);rO(i,24,-128);rO(i,25,0);rO(i,26,-1);rO(i,27,-1);rO(i,28,-1);rO(i,29,-1);rO(i,30,-1);rO(i,31,-1);b[d+62>>1]=0;b[d+64>>1]=64;i=b[f>>1]&1;f=i<<5;a[d+51|0]=f&255;a[d+652+(i<<4)+4|0]=0;a[d+652+(i<<4)+5|0]=(b[d+688>>1]&31|f)&255;f=b[d+686>>1]|0;a[d+652+(i<<4)+6|0]=(f&65535)>>>2&255&-64;a[d+652+(i<<4)+7|0]=f&255;c[d+700>>2]=0;c[d+704>>2]=6;f=d+48|0;a[f]=a[f]&-32|27;f=d+720|0;if((a[f]|0)==1){return}a[f]=1;if((a[d+50|0]&1)==0){return}f=c[d+728>>2]|0;if((f|0)==0){return}b3[f&511](c[d+724>>2]|0,1);return}function rq(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b+48|0;f=a[e]|0;c[b+700>>2]=0;c[b+704>>2]=0;g=f&-32|15;a[e]=g;f=b+720|0;do{if((a[f]|0)==0){h=g;i=b+50|0}else{a[f]=0;j=b+50|0;if((a[j]&1)==0){h=g;i=j;break}k=c[b+728>>2]|0;if((k|0)==0){h=g;i=j;break}b3[k&511](c[b+724>>2]|0,0);h=a[e]|0;i=j}}while(0);g=(d[i]|0)>>>1&1;a[e]=g<<24>>24==0?h&-33:h|32;h=b+708|0;if((a[h]|0)==g<<24>>24){return}a[h]=g;h=c[b+716>>2]|0;if((h|0)==0){return}b3[h&511](c[b+712>>2]|0,g);return}function rr(d){d=d|0;var f=0,g=0,h=0,i=0,j=0;f=d+684|0;g=ts(c[d+696>>2]|0,c[d+652+(e[f>>1]<<4)>>2]|0)|0;if((g|0)==0){h=0;i=d+648|0;j=0}else{h=(c[g+32>>2]|0)-1|0;i=g+40|0;j=(c[g+36>>2]|0)+255&255}g=c[i>>2]|0;i=e[f>>1]|0;b[d+652+(i<<4)+12>>1]=g&65535;a[d+66|0]=h&255;a[d+67|0]=(h>>>2&192|g&63)&255;a[d+68|0]=j;a[d+69|0]=0;b[d+62>>1]=0;b[d+64>>1]=4;j=i&1;i=j<<5;a[d+51|0]=i&255;a[d+652+(j<<4)+4|0]=0;a[d+652+(j<<4)+5|0]=(b[d+688>>1]&31|i)&255;i=b[d+686>>1]|0;a[d+652+(j<<4)+6|0]=(i&65535)>>>2&255&-64;a[d+652+(j<<4)+7|0]=i&255;c[d+700>>2]=0;c[d+704>>2]=6;i=d+48|0;a[i]=a[i]&-32|27;i=d+720|0;if((a[i]|0)==1){return}a[i]=1;if((a[d+50|0]&1)==0){return}i=c[d+728>>2]|0;if((i|0)==0){return}b3[i&511](c[d+724>>2]|0,1);return}function rs(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=d+684|0;g=ts(c[d+696>>2]|0,c[d+652+(e[f>>1]<<4)>>2]|0)|0;if((g|0)==0){h=0;i=d+648|0;j=0;k=0}else{l=c[g+36>>2]|0;h=c[g+32>>2]&65535;i=g+40|0;j=l&65535;k=l&255}l=c[i>>2]|0;i=e[f>>1]|0;b[d+652+(i<<4)+8>>1]=h;b[d+652+(i<<4)+10>>1]=j;b[d+652+(i<<4)+12>>1]=l&65535;l=d+66|0;rO(l,0,2);rP(l,1,h);rO(l,3,k);rP(l,4,h);rP(l,6,h);rO(l,8,8);rO(l,9,0);rO(l,10,3);rO(l,11,1);b[d+62>>1]=0;b[d+64>>1]=12;l=b[f>>1]&1;f=l<<5;a[d+51|0]=f&255;a[d+652+(l<<4)+4|0]=0;a[d+652+(l<<4)+5|0]=(b[d+688>>1]&31|f)&255;f=b[d+686>>1]|0;a[d+652+(l<<4)+6|0]=(f&65535)>>>2&255&-64;a[d+652+(l<<4)+7|0]=f&255;c[d+700>>2]=0;c[d+704>>2]=6;f=d+48|0;a[f]=a[f]&-32|27;f=d+720|0;if((a[f]|0)==1){return}a[f]=1;if((a[d+50|0]&1)==0){return}f=c[d+728>>2]|0;if((f|0)==0){return}b3[f&511](c[d+724>>2]|0,1);return}function rt(d){d=d|0;var e=0;b[d+62>>1]=0;b[d+64>>1]=12;c[d+700>>2]=0;c[d+704>>2]=106;e=d+48|0;a[e]=a[e]&-32|25;e=d+720|0;if((a[e]|0)==1){return}a[e]=1;if((a[d+50|0]&1)==0){return}e=c[d+728>>2]|0;if((e|0)==0){return}b3[e&511](c[d+724>>2]|0,1);return}function ru(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;h=f+684|0;j=e[h>>1]|0;k=f+66|0;l=(rS(k,1)|0)&65535;m=(rR(k,3)|0)&255;n=e[f+652+(j<<4)+12>>1]|0;o=(rS(k,4)|0)&65535;p=(rS(k,6)|0)&65535;q=(rR(k,8)|0)&255;r=(rR(k,10)|0)&255;k=ac(ac(m,l)|0,n)|0;xv(2,33200,31024,(x=i,i=i+80|0,c[x>>2]=j,c[x+8>>2]=l,c[x+16>>2]=m,c[x+24>>2]=n,c[x+32>>2]=o,c[x+40>>2]=p,c[x+48>>2]=q,c[x+56>>2]=r,c[x+64>>2]=k>>>1,c[x+72>>2]=(k&1|0)!=0?5:0,x)|0);k=b[h>>1]&1;h=k<<5;a[f+51|0]=h&255;a[f+652+(k<<4)+4|0]=0;a[f+652+(k<<4)+5|0]=(b[f+688>>1]&31|h)&255;h=b[f+686>>1]|0;a[f+652+(k<<4)+6|0]=(h&65535)>>>2&255&-64;a[f+652+(k<<4)+7|0]=h&255;h=f+48|0;k=a[h]|0;c[f+700>>2]=0;c[f+704>>2]=0;r=k&-32|15;a[h]=r;k=f+720|0;do{if((a[k]|0)==0){s=r;t=f+50|0}else{a[k]=0;q=f+50|0;if((a[q]&1)==0){s=r;t=q;break}p=c[f+728>>2]|0;if((p|0)==0){s=r;t=q;break}b3[p&511](c[f+724>>2]|0,0);s=a[h]|0;t=q}}while(0);r=(d[t]|0)>>>1&1;a[h]=r<<24>>24==0?s&-33:s|32;s=f+708|0;if((a[s]|0)==r<<24>>24){i=g;return}a[s]=r;s=c[f+716>>2]|0;if((s|0)==0){i=g;return}b3[s&511](c[f+712>>2]|0,r);i=g;return}function rv(b){b=b|0;var d=0;c[b+700>>2]=0;c[b+704>>2]=26;d=b+48|0;a[d]=a[d]&-32|25;d=b+720|0;if((a[d]|0)==1){return}a[d]=1;if((a[b+50|0]&1)==0){return}d=c[b+728>>2]|0;if((d|0)==0){return}b3[d&511](c[b+724>>2]|0,1);return}function rw(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;h=(d[f+57|0]|0)>>>5&1;j=d[f+66|0]<<8|d[f+67|0];k=a[f+68|0]|0;l=k&255;m=e[f+652+(h<<4)+12>>1]|0;n=d[f+69|0]<<8|d[f+70|0];o=d[f+71|0]<<8|d[f+72|0];p=d[f+73|0]|0;q=ac(ac(j,l)|0,m)|0;xv(2,33200,28992,(x=i,i=i+72|0,c[x>>2]=h,c[x+8>>2]=j,c[x+16>>2]=l,c[x+24>>2]=m,c[x+32>>2]=n,c[x+40>>2]=o,c[x+48>>2]=p,c[x+56>>2]=q>>>1,c[x+64>>2]=(q&1|0)!=0?5:0,x)|0);b[f+652+(h<<4)+8>>1]=j&65535;b[f+652+(h<<4)+10>>1]=k&255;k=b[f+684>>1]&1;h=k<<5;a[f+51|0]=h&255;a[f+652+(k<<4)+4|0]=0;a[f+652+(k<<4)+5|0]=(b[f+688>>1]&31|h)&255;h=b[f+686>>1]|0;a[f+652+(k<<4)+6|0]=(h&65535)>>>2&255&-64;a[f+652+(k<<4)+7|0]=h&255;h=f+48|0;k=a[h]|0;c[f+700>>2]=0;c[f+704>>2]=0;j=k&-32|15;a[h]=j;k=f+720|0;do{if((a[k]|0)==0){r=j;s=f+50|0}else{a[k]=0;q=f+50|0;if((a[q]&1)==0){r=j;s=q;break}p=c[f+728>>2]|0;if((p|0)==0){r=j;s=q;break}b3[p&511](c[f+724>>2]|0,0);r=a[h]|0;s=q}}while(0);j=(d[s]|0)>>>1&1;a[h]=j<<24>>24==0?r&-33:r|32;r=f+708|0;if((a[r]|0)==j<<24>>24){i=g;return}a[r]=j;r=c[f+716>>2]|0;if((r|0)==0){i=g;return}b3[r&511](c[f+712>>2]|0,j);i=g;return}function rx(d){d=d|0;var e=0;b[d+62>>1]=0;b[d+64>>1]=512;c[d+700>>2]=0;c[d+704>>2]=190;e=d+48|0;a[e]=a[e]&-32|25;e=d+720|0;if((a[e]|0)==1){return}a[e]=1;if((a[d+50|0]&1)==0){return}e=c[d+728>>2]|0;if((e|0)==0){return}b3[e&511](c[d+724>>2]|0,1);return}function ry(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=f+684|0;h=f+686|0;i=b[h>>1]|0;j=f+688|0;k=b[j>>1]|0;l=f+690|0;m=b[l>>1]|0;n=c[f+652+((b[g>>1]&1)<<4)>>2]|0;do{if((n|0)!=65535){o=ts(c[f+696>>2]|0,n)|0;if((o|0)==0){break}if((tw(o,f+66|0,i&65535,k&65535,(m&65535)+1|0,1)|0)!=0){rz(f,18);return}o=b[g>>1]&1;p=(b[l>>1]|0)+1&65535;b[l>>1]=p;do{if((p&65535)>=(e[f+652+(o<<4)+12>>1]|0)){b[l>>1]=0;q=(b[j>>1]|0)+1&65535;b[j>>1]=q;if((q&65535)<(e[f+652+(o<<4)+10>>1]|0)){break}b[j>>1]=0;b[h>>1]=(b[h>>1]|0)+1&65535}}while(0);o=f+692|0;p=(b[o>>1]|0)-1&65535;b[o>>1]=p;if(p<<16>>16!=0){c[f+700>>2]=2048;c[f+704>>2]=142;p=f+48|0;a[p]=a[p]&-17;p=f+720|0;if((a[p]|0)==0){return}a[p]=0;if((a[f+50|0]&1)==0){return}p=c[f+728>>2]|0;if((p|0)==0){return}b3[p&511](c[f+724>>2]|0,0);return}p=f+48|0;o=a[p]|0;c[f+700>>2]=0;c[f+704>>2]=0;q=o&-32|15;a[p]=q;o=f+720|0;do{if((a[o]|0)==0){r=q;s=f+50|0}else{a[o]=0;t=f+50|0;if((a[t]&1)==0){r=q;s=t;break}u=c[f+728>>2]|0;if((u|0)==0){r=q;s=t;break}b3[u&511](c[f+724>>2]|0,0);r=a[p]|0;s=t}}while(0);q=(d[s]|0)>>>1&1;a[p]=q<<24>>24==0?r&-33:r|32;o=f+708|0;if((a[o]|0)==q<<24>>24){return}a[o]=q;o=c[f+716>>2]|0;if((o|0)==0){return}b3[o&511](c[f+712>>2]|0,q);return}}while(0);rz(f,4);return}function rz(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0;h=i;j=f+684|0;bN(c[q>>2]|0,27240,(x=i,i=i+8|0,c[x>>2]=e[j>>1]|0,x)|0)|0;k=b[j>>1]&1;j=k<<5;a[f+51|0]=(j|2)&255;a[f+652+(k<<4)+4|0]=(g|128)&255;a[f+652+(k<<4)+5|0]=(b[f+688>>1]&31|j)&255;j=b[f+686>>1]|0;a[f+652+(k<<4)+6|0]=(j&65535)>>>2&255&-64;a[f+652+(k<<4)+7|0]=j&255;j=f+48|0;k=a[j]|0;c[f+700>>2]=0;c[f+704>>2]=0;g=k&-32|15;a[j]=g;k=f+720|0;do{if((a[k]|0)==0){l=g;m=f+50|0}else{a[k]=0;n=f+50|0;if((a[n]&1)==0){l=g;m=n;break}o=c[f+728>>2]|0;if((o|0)==0){l=g;m=n;break}b3[o&511](c[f+724>>2]|0,0);l=a[j]|0;m=n}}while(0);g=(d[m]|0)>>>1&1;a[j]=g<<24>>24==0?l&-33:l|32;l=f+708|0;if((a[l]|0)==g<<24>>24){i=h;return}a[l]=g;l=c[f+716>>2]|0;if((l|0)==0){i=h;return}b3[l&511](c[f+712>>2]|0,g);i=h;return}function rA(d){d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=d+684|0;g=d+686|0;h=b[g>>1]|0;i=d+688|0;j=b[i>>1]|0;k=d+690|0;l=b[k>>1]|0;m=c[d+652+((b[f>>1]&1)<<4)>>2]|0;do{if((m|0)!=65535){n=ts(c[d+696>>2]|0,m)|0;if((n|0)==0){break}if((tu(n,d+66|0,h&65535,j&65535,(l&65535)+1|0,1)|0)!=0){rB(d,18);return}b[d+62>>1]=0;b[d+64>>1]=512;n=b[f>>1]&1;o=(b[k>>1]|0)+1&65535;b[k>>1]=o;do{if((o&65535)>=(e[d+652+(n<<4)+12>>1]|0)){b[k>>1]=0;p=(b[i>>1]|0)+1&65535;b[i>>1]=p;if((p&65535)<(e[d+652+(n<<4)+10>>1]|0)){break}b[i>>1]=0;b[g>>1]=(b[g>>1]|0)+1&65535}}while(0);n=d+692|0;b[n>>1]=(b[n>>1]|0)-1&65535;c[d+700>>2]=0;c[d+704>>2]=54;n=d+48|0;a[n]=a[n]&-32|27;n=d+720|0;if((a[n]|0)==1){return}a[n]=1;if((a[d+50|0]&1)==0){return}n=c[d+728>>2]|0;if((n|0)==0){return}b3[n&511](c[d+724>>2]|0,1);return}}while(0);rB(d,4);return}function rB(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0;h=i;j=f+684|0;bN(c[q>>2]|0,25664,(x=i,i=i+8|0,c[x>>2]=e[j>>1]|0,x)|0)|0;k=b[j>>1]&1;j=k<<5;a[f+51|0]=(j|2)&255;a[f+652+(k<<4)+4|0]=(g|128)&255;a[f+652+(k<<4)+5|0]=(b[f+688>>1]&31|j)&255;j=b[f+686>>1]|0;a[f+652+(k<<4)+6|0]=(j&65535)>>>2&255&-64;a[f+652+(k<<4)+7|0]=j&255;j=f+48|0;k=a[j]|0;c[f+700>>2]=0;c[f+704>>2]=0;g=k&-32|15;a[j]=g;k=f+720|0;do{if((a[k]|0)==0){l=g;m=f+50|0}else{a[k]=0;n=f+50|0;if((a[n]&1)==0){l=g;m=n;break}o=c[f+728>>2]|0;if((o|0)==0){l=g;m=n;break}b3[o&511](c[f+724>>2]|0,0);l=a[j]|0;m=n}}while(0);g=(d[m]|0)>>>1&1;a[j]=g<<24>>24==0?l&-33:l|32;l=f+708|0;if((a[l]|0)==g<<24>>24){i=h;return}a[l]=g;l=c[f+716>>2]|0;if((l|0)==0){i=h;return}b3[l&511](c[f+712>>2]|0,g);i=h;return}function rC(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=e+48|0;a[f]=a[f]&-17;g=e+720|0;do{if((a[g]|0)!=0){a[g]=0;if((a[e+50|0]&1)==0){break}h=c[e+728>>2]|0;if((h|0)==0){break}b3[h&511](c[e+724>>2]|0,0)}}while(0);if((b[e+692>>1]|0)!=0){c[e+700>>2]=2048;c[e+704>>2]=16;return}h=a[f]|0;c[e+700>>2]=0;c[e+704>>2]=0;i=h&-32|15;a[f]=i;do{if((a[g]|0)==0){j=i;k=e+50|0}else{a[g]=0;h=e+50|0;if((a[h]&1)==0){j=i;k=h;break}l=c[e+728>>2]|0;if((l|0)==0){j=i;k=h;break}b3[l&511](c[e+724>>2]|0,0);j=a[f]|0;k=h}}while(0);i=(d[k]|0)>>>1&1;a[f]=i<<24>>24==0?j&-33:j|32;j=e+708|0;if((a[j]|0)==i<<24>>24){return}a[j]=i;j=c[e+716>>2]|0;if((j|0)==0){return}b3[j&511](c[e+712>>2]|0,i);return}function rD(a,b){a=a|0;b=b|0;return 0}function rE(a,b){a=a|0;b=b|0;return 0}function rF(a,b){a=a|0;b=b|0;return 0}function rG(a,b,c){a=a|0;b=b|0;c=c|0;return}function rH(a,b,c){a=a|0;b=b|0;c=c|0;return}function rI(a,b,c){a=a|0;b=b|0;c=c|0;return}function rJ(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;c[a+24>>2]=b;b=a|0;c[b>>2]=d;j=a+4|0;c[j>>2]=e;k=a+8|0;c[k>>2]=f;l=a+12|0;c[l>>2]=g;m=a+16|0;c[m>>2]=h;n=a+20|0;c[n>>2]=i;if((c[a+44>>2]|0)!=0){return}if((d|0)==0){c[b>>2]=66}if((e|0)==0){c[j>>2]=78}if((f|0)==0){c[k>>2]=6}if((g|0)==0){c[l>>2]=34}if((h|0)==0){c[m>>2]=120}if((i|0)!=0){return}c[n>>2]=80;return}function rK(b,c){b=b|0;c=c|0;a[b+29|0]=(c|0)!=0|0;return}function rL(a){a=a|0;return c[a+32>>2]|0}function rM(a){a=a|0;return c[a+40>>2]|0}function rN(a,b){a=a|0;b=b|0;c[a+40>>2]=b;c[a+36>>2]=b-1+(c[a+32>>2]|0);return}function rO(b,c,d){b=b|0;c=c|0;d=d|0;a[b+c|0]=d;return}function rP(b,c,d){b=b|0;c=c|0;d=d|0;a[b+c|0]=(d&65535)>>>8&255;a[b+(c+1)|0]=d&255;return}function rQ(b,c,d){b=b|0;c=c|0;d=d|0;a[b+c|0]=d&255;a[b+(c+1)|0]=(d&65535)>>>8&255;return}function rR(b,c){b=b|0;c=c|0;return a[b+c|0]|0}function rS(a,b){a=a|0;b=b|0;return(d[a+b|0]|0)<<8|(d[a+(b+1)|0]|0)|0}function rT(b,d){b=b|0;d=d|0;return a[(c[b+44>>2]|0)+d|0]|0}function rU(a,b){a=a|0;b=b|0;var e=0;e=c[a+44>>2]|0;return(d[e+b|0]|0)<<8|(d[e+(b+1)|0]|0)|0}function rV(a,b){a=a|0;b=b|0;var e=0;e=c[a+44>>2]|0;return(d[e+(b+1)|0]|0)<<8|(d[e+b|0]|0)|0}function rW(a,b){a=a|0;b=b|0;var e=0;e=c[a+44>>2]|0;return(((d[e+b|0]|0)<<8|(d[e+(b+1)|0]|0))<<8|(d[e+(b+2)|0]|0))<<8|(d[e+(b+3)|0]|0)|0}function rX(a,b){a=a|0;b=b|0;var e=0;e=c[a+44>>2]|0;return(((d[e+(b+3)|0]|0)<<8|(d[e+(b+2)|0]|0))<<8|(d[e+(b+1)|0]|0))<<8|(d[e+b|0]|0)|0}function rY(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;c[a+24>>2]=b;c[a+28>>2]=d;c[a+32>>2]=e;c[a+36>>2]=f;c[a+40>>2]=g;c[a+44>>2]=h;c[a+48>>2]=i;return}function rZ(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;g=i;i=i+512|0;h=g|0;j=h|0;k=f+684|0;l=b[k>>1]|0;m=l&1;n=f+686|0;o=b[n>>1]|0;p=o&65535;r=f+688|0;s=e[r>>1]|0;t=e[f+652+(m<<4)+8>>1]|0;u=e[f+652+(m<<4)+10>>1]|0;v=e[f+652+(m<<4)+12>>1]|0;w=c[f+652+(m<<4)>>2]|0;do{if((w|0)==65535){y=l}else{m=ts(c[f+696>>2]|0,w)|0;if((m|0)==0){y=b[k>>1]|0;break}if((a[f+61|0]&64)==0){zP(j|0,108,512)}else{z=f+66|0;zO(j|0,z|0,512)|0}z=h|0;A=0;do{if(A>>>0>=v>>>0){B=4534;break}A=A+1|0;}while((tw(m,z,p,s,A,1)|0)==0);if((B|0)==4534){c[f+700>>2]=8192;A=f+704|0;c[A>>2]=56;z=s+1|0;do{if(z>>>0<u>>>0){C=o;D=z&65535}else{m=p+1|0;E=m&65535;if(m>>>0<t>>>0){C=E;D=0;break}c[A>>2]=6;C=E;D=0}}while(0);b[n>>1]=C;b[r>>1]=D;i=g;return}bN(c[q>>2]|0,22800,(x=i,i=i+8|0,c[x>>2]=e[k>>1]|0,x)|0)|0;A=b[k>>1]|0;z=A&1;E=z<<5;if(A<<16>>16==0){F=E&255}else{F=(E|2)&255}a[f+51|0]=F;a[f+652+(z<<4)+4|0]=-125;a[f+652+(z<<4)+5|0]=(b[r>>1]&31|E)&255;E=b[n>>1]|0;a[f+652+(z<<4)+6|0]=(E&65535)>>>2&255&-64;a[f+652+(z<<4)+7|0]=E&255;E=f+48|0;z=a[E]|0;c[f+700>>2]=0;c[f+704>>2]=0;A=z&-32|15;a[E]=A;z=f+720|0;do{if((a[z]|0)==0){G=A;H=f+50|0}else{a[z]=0;m=f+50|0;if((a[m]&1)==0){G=A;H=m;break}I=c[f+728>>2]|0;if((I|0)==0){G=A;H=m;break}b3[I&511](c[f+724>>2]|0,0);G=a[E]|0;H=m}}while(0);A=(d[H]|0)>>>1&1;a[E]=A<<24>>24==0?G&-33:G|32;z=f+708|0;if((a[z]|0)==A<<24>>24){i=g;return}a[z]=A;z=c[f+716>>2]|0;if((z|0)==0){i=g;return}b3[z&511](c[f+712>>2]|0,A);i=g;return}}while(0);bN(c[q>>2]|0,22800,(x=i,i=i+8|0,c[x>>2]=y&65535,x)|0)|0;y=b[k>>1]|0;k=y&1;G=k<<5;if(y<<16>>16==0){J=G&255}else{J=(G|2)&255}a[f+51|0]=J;a[f+652+(k<<4)+4|0]=-124;a[f+652+(k<<4)+5|0]=(b[r>>1]&31|G)&255;G=b[n>>1]|0;a[f+652+(k<<4)+6|0]=(G&65535)>>>2&255&-64;a[f+652+(k<<4)+7|0]=G&255;G=f+48|0;k=a[G]|0;c[f+700>>2]=0;c[f+704>>2]=0;n=k&-32|15;a[G]=n;k=f+720|0;do{if((a[k]|0)==0){K=n;L=f+50|0}else{a[k]=0;r=f+50|0;if((a[r]&1)==0){K=n;L=r;break}J=c[f+728>>2]|0;if((J|0)==0){K=n;L=r;break}b3[J&511](c[f+724>>2]|0,0);K=a[G]|0;L=r}}while(0);n=(d[L]|0)>>>1&1;a[G]=n<<24>>24==0?K&-33:K|32;K=f+708|0;if((a[K]|0)==n<<24>>24){i=g;return}a[K]=n;K=c[f+716>>2]|0;if((K|0)==0){i=g;return}b3[K&511](c[f+712>>2]|0,n);i=g;return}function r_(e){e=e|0;var f=0,g=0;f=(d[e+57|0]|0)>>>5&1;a[e+66|0]=a[e+652+(f<<4)+4|0]|0;a[e+67|0]=a[e+652+(f<<4)+5|0]|0;a[e+68|0]=a[e+652+(f<<4)+6|0]|0;a[e+69|0]=a[e+652+(f<<4)+7|0]|0;b[e+62>>1]=0;b[e+64>>1]=4;f=b[e+684>>1]&1;g=f<<5;a[e+51|0]=g&255;a[e+652+(f<<4)+4|0]=0;a[e+652+(f<<4)+5|0]=(b[e+688>>1]&31|g)&255;g=b[e+686>>1]|0;a[e+652+(f<<4)+6|0]=(g&65535)>>>2&255&-64;a[e+652+(f<<4)+7|0]=g&255;c[e+700>>2]=0;c[e+704>>2]=6;g=e+48|0;a[g]=a[g]&-32|27;g=e+720|0;if((a[g]|0)==1){return}a[g]=1;if((a[e+50|0]&1)==0){return}g=c[e+728>>2]|0;if((g|0)==0){return}b3[g&511](c[e+724>>2]|0,1);return}function r$(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;do{if((f|0)==0){c[b+44>>2]=0;g=0}else{h=zH(e+16|0)|0;c[b+44>>2]=h;if((h|0)==0){i=1}else{g=h;break}return i|0}}while(0);zP(b|0,0,24);c[b+24>>2]=b;a[b+28|0]=1;a[b+29|0]=0;a[b+30|0]=(g|0)!=0|0;c[b+32>>2]=d;c[b+36>>2]=d-1+e;c[b+40>>2]=e;i=0;return i|0}function r0(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=zH(48)|0;g=f;if((f|0)==0){h=0;return h|0}do{if((e|0)==0){c[f+44>>2]=0;i=0}else{j=zH(d+16|0)|0;c[f+44>>2]=j;if((j|0)!=0){i=j;break}zI(f);h=0;return h|0}}while(0);zP(f|0,0,24);c[f+24>>2]=f;a[f+28|0]=1;a[f+29|0]=0;a[f+30|0]=(i|0)!=0|0;c[f+32>>2]=b;c[f+36>>2]=b-1+d;c[f+40>>2]=d;h=g;return h|0}function r1(b){b=b|0;if((b|0)==0){return}if((a[b+30|0]|0)==0){return}zI(c[b+44>>2]|0);return}function r2(b){b=b|0;if((b|0)==0){return}if((a[b+30|0]|0)!=0){zI(c[b+44>>2]|0)}zI(b);return}function r3(a,b){a=a|0;b=b|0;var d=0;d=c[a+44>>2]|0;if((d|0)==0){return}zP(d|0,b|0,c[a+40>>2]|0);return}function r4(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=b+30|0;g=b+44|0;if((a[f]|0)!=0){zI(c[g>>2]|0)}c[g>>2]=d;if((d|0)==0){h=0;a[f]=h;return}h=(e|0)!=0|0;a[f]=h;return}function r5(){var a=0,b=0;a=zH(56)|0;if((a|0)==0){b=0;return b|0}zP(a|0,0,52);c[a+52>>2]=-1;b=a;return b|0}function r6(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=b|0;if((c[f>>2]|0)==0){i=e;return}g=b+4|0;b=0;do{h=c[(c[g>>2]|0)+(b<<3)>>2]|0;j=c[h+32>>2]|0;k=c[h+36>>2]|0;l=c[h+40>>2]|0;m=(a[h+29|0]|0)!=0|0;bN(d|0,40256,(x=i,i=i+40|0,c[x>>2]=b,c[x+8>>2]=j,c[x+16>>2]=k,c[x+24>>2]=l,c[x+32>>2]=m,x)|0)|0;b=b+1|0;}while(b>>>0<(c[f>>2]|0)>>>0);i=e;return}function r7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;if((b|0)==0){return}e=a+4|0;f=a|0;g=zJ(c[e>>2]|0,(c[f>>2]<<3)+8|0)|0;h=g;if((g|0)==0){return}c[e>>2]=h;e=c[f>>2]|0;c[f>>2]=e+1;c[h+(e<<3)>>2]=b;c[h+(e<<3)+4>>2]=(d|0)!=0;zP(a+8|0,0,16);return}function r8(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b+8|0;f=c[e>>2]|0;do{if((f|0)==0){g=4620}else{h=c[f>>2]|0;if((a[h+28|0]|0)==0){g=4620;break}if((c[h+32>>2]|0)>>>0>d>>>0){g=4620;break}if((c[h+36>>2]|0)>>>0<d>>>0){g=4620}else{i=h}}}while(0);do{if((g|0)==4620){f=c[b>>2]|0;if((f|0)==0){return}h=0;j=c[b+4>>2]|0;L5843:while(1){k=c[j>>2]|0;do{if((a[k+28|0]|0)!=0){if((c[k+32>>2]|0)>>>0>d>>>0){break}if((c[k+36>>2]|0)>>>0>=d>>>0){g=4625;break L5843}}}while(0);l=h+1|0;if(l>>>0<f>>>0){h=l;j=j+8|0}else{g=4636;break}}if((g|0)==4636){return}else if((g|0)==4625){c[e>>2]=j;i=k;break}}}while(0);if((i|0)==0){return}k=c[b>>2]|0;e=b+4|0;b=0;while(1){if(b>>>0>=k>>>0){g=4639;break}m=c[e>>2]|0;if((c[m+(b<<3)>>2]|0)==(i|0)){break}else{b=b+1|0}}if((g|0)==4639){return}if((b|0)==0){n=m}else{g=b;b=m;while(1){m=g-1|0;c[b+(g<<3)>>2]=c[b+(m<<3)>>2];k=c[e>>2]|0;if((m|0)==0){n=k;break}else{g=m;b=k}}}c[n>>2]=i;return}function r9(a,b){a=a|0;b=b|0;var d=0;d=a|0;c[(c[d>>2]|0)+12>>2]=122;a=(c[d>>2]|0)+16|0;if((b|0)==0){c[a>>2]=104;c[(c[d>>2]|0)+20>>2]=114;c[c[d>>2]>>2]=102;c[(c[d>>2]|0)+4>>2]=20;c[(c[d>>2]|0)+8>>2]=128;return}else{c[a>>2]=38;c[(c[d>>2]|0)+20>>2]=78;c[c[d>>2]>>2]=102;c[(c[d>>2]|0)+4>>2]=100;c[(c[d>>2]|0)+8>>2]=48;return}}function sa(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b+12|0;f=c[e>>2]|0;do{if((f|0)==0){g=4650}else{h=c[f>>2]|0;if((a[h+28|0]|0)==0){g=4650;break}if((c[h+32>>2]|0)>>>0>d>>>0){g=4650;break}if((c[h+36>>2]|0)>>>0<d>>>0){g=4650}else{i=h;g=4657}}}while(0);L5878:do{if((g|0)==4650){f=c[b>>2]|0;if((f|0)==0){break}h=0;j=c[b+4>>2]|0;L5881:while(1){k=c[j>>2]|0;do{if((a[k+28|0]|0)!=0){if((c[k+32>>2]|0)>>>0>d>>>0){break}if((c[k+36>>2]|0)>>>0>=d>>>0){break L5881}}}while(0);l=h+1|0;if(l>>>0<f>>>0){h=l;j=j+8|0}else{break L5878}}c[e>>2]=j;i=k;g=4657}}while(0);do{if((g|0)==4657){if((i|0)==0){break}k=d-(c[i+32>>2]|0)|0;e=c[i>>2]|0;if((e|0)==0){m=a[(c[i+44>>2]|0)+k|0]|0;return m|0}else{m=b8[e&255](c[i+24>>2]|0,k)|0;return m|0}}}while(0);i=c[b+28>>2]|0;if((i|0)==0){m=c[b+52>>2]&255;return m|0}else{m=b8[i&255](c[b+24>>2]|0,d)|0;return m|0}return 0}function sb(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b+12|0;g=c[f>>2]|0;do{if((g|0)==0){h=4673}else{i=c[g>>2]|0;if((a[i+28|0]|0)==0){h=4673;break}if((c[i+32>>2]|0)>>>0>e>>>0){h=4673;break}if((c[i+36>>2]|0)>>>0<e>>>0){h=4673}else{j=i;h=4680}}}while(0);L5907:do{if((h|0)==4673){g=c[b>>2]|0;if((g|0)==0){break}i=0;k=c[b+4>>2]|0;L5910:while(1){l=c[k>>2]|0;do{if((a[l+28|0]|0)!=0){if((c[l+32>>2]|0)>>>0>e>>>0){break}if((c[l+36>>2]|0)>>>0>=e>>>0){break L5910}}}while(0);m=i+1|0;if(m>>>0<g>>>0){i=m;k=k+8|0}else{break L5907}}c[f>>2]=k;j=l;h=4680}}while(0);do{if((h|0)==4680){if((j|0)==0){break}l=e+1|0;if(l>>>0>(c[j+36>>2]|0)>>>0){f=sa(b,e)|0;n=((sa(b,l)|0)&255)<<8|f&255;return n|0}f=e-(c[j+32>>2]|0)|0;l=c[j+4>>2]|0;if((l|0)==0){i=c[j+44>>2]|0;n=d[i+(f+1)|0]<<8|d[i+f|0];return n|0}else{n=b8[l&255](c[j+24>>2]|0,f)|0;return n|0}}}while(0);j=c[b+32>>2]|0;if((j|0)==0){n=c[b+52>>2]&65535;return n|0}else{n=b8[j&255](c[b+24>>2]|0,e)|0;return n|0}return 0}function sc(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b+8|0;g=c[f>>2]|0;do{if((g|0)==0){h=4699}else{i=c[g>>2]|0;if((a[i+28|0]|0)==0){h=4699;break}if((c[i+32>>2]|0)>>>0>d>>>0){h=4699;break}if((c[i+36>>2]|0)>>>0<d>>>0){h=4699}else{j=i;h=4706}}}while(0);L5940:do{if((h|0)==4699){g=c[b>>2]|0;if((g|0)==0){break}i=0;k=c[b+4>>2]|0;L5943:while(1){l=c[k>>2]|0;do{if((a[l+28|0]|0)!=0){if((c[l+32>>2]|0)>>>0>d>>>0){break}if((c[l+36>>2]|0)>>>0>=d>>>0){break L5943}}}while(0);m=i+1|0;if(m>>>0<g>>>0){i=m;k=k+8|0}else{break L5940}}c[f>>2]=k;j=l;h=4706}}while(0);do{if((h|0)==4706){if((j|0)==0){break}l=d-(c[j+32>>2]|0)|0;f=c[j+12>>2]|0;if((f|0)==0){a[(c[j+44>>2]|0)+l|0]=e;return}else{b5[f&255](c[j+24>>2]|0,l,e);return}}}while(0);j=c[b+40>>2]|0;if((j|0)==0){return}b5[j&255](c[b+24>>2]|0,d,e);return}function sd(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b+16|0;g=c[f>>2]|0;do{if((g|0)==0){h=4721}else{i=c[g>>2]|0;if((a[i+28|0]|0)==0){h=4721;break}if((c[i+32>>2]|0)>>>0>d>>>0){h=4721;break}if((c[i+36>>2]|0)>>>0<d>>>0){h=4721}else{j=i;h=4728}}}while(0);L5968:do{if((h|0)==4721){g=c[b>>2]|0;if((g|0)==0){break}i=0;k=c[b+4>>2]|0;L5971:while(1){l=c[k>>2]|0;do{if((a[l+28|0]|0)!=0){if((c[l+32>>2]|0)>>>0>d>>>0){break}if((c[l+36>>2]|0)>>>0>=d>>>0){break L5971}}}while(0);m=i+1|0;if(m>>>0<g>>>0){i=m;k=k+8|0}else{break L5968}}c[f>>2]=k;j=l;h=4728}}while(0);do{if((h|0)==4728){if((j|0)==0){break}if((a[j+29|0]|0)!=0){return}l=d-(c[j+32>>2]|0)|0;f=c[j+12>>2]|0;if((f|0)==0){a[(c[j+44>>2]|0)+l|0]=e;return}else{b5[f&255](c[j+24>>2]|0,l,e);return}}}while(0);j=c[b+40>>2]|0;if((j|0)==0){return}b5[j&255](c[b+24>>2]|0,d,e);return}function se(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b+16|0;g=c[f>>2]|0;do{if((g|0)==0){h=4745}else{i=c[g>>2]|0;if((a[i+28|0]|0)==0){h=4745;break}if((c[i+32>>2]|0)>>>0>d>>>0){h=4745;break}if((c[i+36>>2]|0)>>>0<d>>>0){h=4745}else{j=i;h=4752}}}while(0);L5999:do{if((h|0)==4745){g=c[b>>2]|0;if((g|0)==0){break}i=0;k=c[b+4>>2]|0;L6002:while(1){l=c[k>>2]|0;do{if((a[l+28|0]|0)!=0){if((c[l+32>>2]|0)>>>0>d>>>0){break}if((c[l+36>>2]|0)>>>0>=d>>>0){break L6002}}}while(0);m=i+1|0;if(m>>>0<g>>>0){i=m;k=k+8|0}else{break L5999}}c[f>>2]=k;j=l;h=4752}}while(0);do{if((h|0)==4752){if((j|0)==0){break}l=d+1|0;if(l>>>0>(c[j+36>>2]|0)>>>0){sd(b,d,e&255);sd(b,l,(e&65535)>>>8&255);return}if((a[j+29|0]|0)!=0){return}l=d-(c[j+32>>2]|0)|0;f=c[j+16>>2]|0;if((f|0)==0){i=j+44|0;a[(c[i>>2]|0)+l|0]=e&255;a[(c[i>>2]|0)+(l+1)|0]=(e&65535)>>>8&255;return}else{b5[f&255](c[j+24>>2]|0,l,e);return}}}while(0);j=c[b+44>>2]|0;if((j|0)==0){return}b5[j&255](c[b+24>>2]|0,d,e);return}function sf(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=zH(12)|0;if((d|0)==0){e=0;return e|0}f=r0(a,b,1)|0;b=d;c[b>>2]=f;c[f+24>>2]=d;c[(c[b>>2]|0)+12>>2]=122;c[(c[b>>2]|0)+16>>2]=38;c[(c[b>>2]|0)+20>>2]=78;c[c[b>>2]>>2]=102;c[(c[b>>2]|0)+4>>2]=100;c[(c[b>>2]|0)+8>>2]=48;r3(c[b>>2]|0,0);c[d+4>>2]=0;c[d+8>>2]=0;e=d;return e|0}function sg(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=b|0;a[(c[(c[f>>2]|0)+44>>2]|0)+d|0]=e;e=b+4|0;b=c[e>>2]|0;if((b|0)==0){return}if((bS(b|0,d|0,0)|0)!=0){return}aA(a[(c[(c[f>>2]|0)+44>>2]|0)+d|0]|0,c[e>>2]|0)|0;ax(c[e>>2]|0)|0;return}function sh(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=b|0;a[(c[(c[f>>2]|0)+44>>2]|0)+d|0]=(e&65535)>>>8&255;a[(c[(c[f>>2]|0)+44>>2]|0)+(d+1)|0]=e&255;e=b+4|0;b=c[e>>2]|0;if((b|0)==0){return}if((bS(b|0,d|0,0)|0)!=0){return}aB((c[(c[f>>2]|0)+44>>2]|0)+d|0,1,2,c[e>>2]|0)|0;ax(c[e>>2]|0)|0;return}function si(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=b|0;a[(c[(c[f>>2]|0)+44>>2]|0)+d|0]=e>>>24&255;a[(c[(c[f>>2]|0)+44>>2]|0)+(d+1)|0]=e>>>16&255;a[(c[(c[f>>2]|0)+44>>2]|0)+(d+2)|0]=e>>>8&255;a[(c[(c[f>>2]|0)+44>>2]|0)+(d+3)|0]=e&255;e=b+4|0;b=c[e>>2]|0;if((b|0)==0){return}if((bS(b|0,d|0,0)|0)!=0){return}aB((c[(c[f>>2]|0)+44>>2]|0)+d|0,1,4,c[e>>2]|0)|0;ax(c[e>>2]|0)|0;return}function sj(a,b){a=a|0;b=b|0;return rT(c[a>>2]|0,b)|0}function sk(a,b){a=a|0;b=b|0;return rU(c[a>>2]|0,b)|0}function sl(a,b){a=a|0;b=b|0;return rW(c[a>>2]|0,b)|0}function sm(a){a=a|0;return c[a>>2]|0}function sn(b,c){b=b|0;c=c|0;var d=0;if((c|0)==0){d=a[b+54|0]|0}else if((c|0)==1){d=a[b+52|0]|0}else if((c|0)==2){d=a[b+53|0]|0}else{d=-1}return d|0}function so(b,c){b=b|0;c=c|0;var d=0;if((c|0)==0){d=a[b+54|0]|0}else if((c|0)==2){d=a[b+53|0]|0}else if((c|0)==1){d=a[b+52|0]|0}else{d=-1}return d&255|0}function sp(a){a=a|0;return a|0}function sq(a,b){a=a|0;b=b|0;c[a+1248>>2]=1;return}function sr(a,b){a=a|0;b=b|0;c[a+1252>>2]=1;return}function ss(a){a=a|0;return a|0}function st(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=b|0;a[(c[(c[f>>2]|0)+44>>2]|0)+d|0]=e&255;a[(c[(c[f>>2]|0)+44>>2]|0)+(d+1)|0]=(e&65535)>>>8&255;e=b+4|0;b=c[e>>2]|0;if((b|0)==0){return}if((bS(b|0,d|0,0)|0)!=0){return}aB((c[(c[f>>2]|0)+44>>2]|0)+d|0,1,2,c[e>>2]|0)|0;ax(c[e>>2]|0)|0;return}function su(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=b|0;a[(c[(c[f>>2]|0)+44>>2]|0)+d|0]=e&255;a[(c[(c[f>>2]|0)+44>>2]|0)+(d+1)|0]=e>>>8&255;a[(c[(c[f>>2]|0)+44>>2]|0)+(d+2)|0]=e>>>16&255;a[(c[(c[f>>2]|0)+44>>2]|0)+(d+3)|0]=e>>>24&255;e=b+4|0;b=c[e>>2]|0;if((b|0)==0){return}if((bS(b|0,d|0,0)|0)!=0){return}aB((c[(c[f>>2]|0)+44>>2]|0)+d|0,1,4,c[e>>2]|0)|0;ax(c[e>>2]|0)|0;return}function sv(a,b){a=a|0;b=b|0;return rV(c[a>>2]|0,b)|0}function sw(a,b){a=a|0;b=b|0;return rX(c[a>>2]|0,b)|0}function sx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=a+8|0;f=a+4|0;if((c[e>>2]|0)!=0){g=c[f>>2]|0;au(g|0)|0}if((b|0)==0){c[f>>2]=0;c[e>>2]=0;h=0;return h|0}c[f>>2]=b;c[e>>2]=d;if((bS(b|0,0,0)|0)==0){g=a|0;r3(c[g>>2]|0,0);a=c[g>>2]|0;g=c[a+44>>2]|0;i=c[a+40>>2]|0;a=c[f>>2]|0;bK(g|0,1,i|0,a|0)|0;h=0;return h|0}c[f>>2]=0;c[e>>2]=0;if((d|0)==0){h=1;return h|0}au(b|0)|0;h=1;return h|0}function sy(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=bl(b|0,39376|0)|0;do{if((c|0)==0){d=bl(b|0,40440|0)|0;if((d|0)==0){e=1}else{f=d;break}return e|0}else{f=c}}while(0);e=sx(a,f,1)|0;return e|0}function sz(b,d,e){b=b|0;d=d|0;e=e|0;if((d|0)==0){a[b+54|0]=e;return}else if((d|0)==2){a[b+53|0]=e;if((e&1)==0){e=b+52|0;a[e]=a[e]|64;return}else{e=c[b+56>>2]|0;d=b+54|0;ul(e,d,1)|0;d=b+52|0;a[d]=a[d]&63|-128;return}}else{return}}function sA(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=e&255;if((d|0)==0){a[b+54|0]=f;return}else if((d|0)==2){a[b+53|0]=f;if((f&1)==0){f=b+52|0;a[f]=a[f]|64;return}else{f=c[b+56>>2]|0;d=b+54|0;ul(f,d,1)|0;d=b+52|0;a[d]=a[d]&63|-128;return}}else{return}}function sB(b){b=b|0;var d=0,e=0;d=zH(60)|0;if((d|0)==0){e=0;return e|0}c[d+48>>2]=b;r$(d,b,4,0)|0;c[d+24>>2]=d;c[d>>2]=60;c[d+12>>2]=106;c[d+4>>2]=62;c[d+16>>2]=110;a[d+52|0]=-33;a[d+53|0]=0;a[d+54|0]=0;c[d+56>>2]=0;e=d;return e|0}function sC(b,d){b=b|0;d=d|0;var e=0,f=0;e=b+56|0;f=c[e>>2]|0;if((f|0)!=0){uj(f)}f=uq(d)|0;c[e>>2]=f;e=(f|0)==0;f=b+52|0;b=a[f]|0;a[f]=e?b&103:b|-104;return e&1|0}function sD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;c[a+688>>2]=b;c[a+692>>2]=d;e=a+48|0;m8(e);f=a;mU(e,f,152);mV(e,f,346);mW(e,f,184);mX(e,f,40);mY(e,1,1);mZ(e,10);r$(a|0,b,8<<d,0)|0;c[a+24>>2]=f;c[a>>2]=76;c[a+12>>2]=60;c[a+4>>2]=24;c[a+16>>2]=20;c[a+8>>2]=134;c[a+20>>2]=86;c[a+696>>2]=2400;c[a+700>>2]=8;c[a+704>>2]=1;c[a+984>>2]=0;c[a+988>>2]=0;c[a+1248>>2]=0;zP(a+708|0,0,20);c[a+1252>>2]=1;c[a+1256>>2]=0;na(e,1);nb(e,1);return}function sE(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=a+48|0;d=a+696|0;c[d>>2]=m_(b)|0;e=a+700|0;c[e>>2]=m$(b)|0;f=a+704|0;c[f>>2]=m0(b)|0;g=m1(b)|0;c[a+708>>2]=g;h=a+1256|0;up(c[h>>2]|0,c[d>>2]|0,c[e>>2]|0,g,c[f>>2]|0)|0;f=a+712|0;c[f>>2]=m2(b)|0;g=m3(b)|0;c[a+716>>2]=g;uo(c[h>>2]|0,(c[f>>2]|0)!=0|((g|0)!=0?2:0))|0;return}function sF(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;i=i+8|0;d=b|0;if((um(c[a+1256>>2]|0,d)|0)==0){e=(c[d>>2]|0)>>>8&1}else{c[d>>2]=1792;e=1}f=a+48|0;na(f,e);nb(f,(c[d>>2]|0)>>>9&1);nc(f,(c[d>>2]|0)>>>10&1);nd(f,(c[d>>2]|0)>>>11&1);i=b;return}function sG(a,b){a=a|0;b=b|0;return nh(a+48|0,b>>>((c[a+692>>2]|0)>>>0))|0}function sH(a,b,d){a=a|0;b=b|0;d=d|0;ni(a+48|0,b>>>((c[a+692>>2]|0)>>>0),d);return}function sI(a,b){a=a|0;b=b|0;return(nh(a+48|0,b>>>((c[a+692>>2]|0)>>>0))|0)&255|0}function sJ(a,b,d){a=a|0;b=b|0;d=d|0;ni(a+48|0,b>>>((c[a+692>>2]|0)>>>0),d&255);return}function sK(a,b){a=a|0;b=b|0;return(nh(a+48|0,b>>>((c[a+692>>2]|0)>>>0))|0)&255|0}function sL(a,b,d){a=a|0;b=b|0;d=d|0;ni(a+48|0,b>>>((c[a+692>>2]|0)>>>0),d&255);return}function sM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=zH(1260)|0;d=c;if((c|0)==0){e=0}else{sD(d,a,b);e=d}return e|0}function sN(a,b){a=a|0;b=b|0;var d=0;d=a+1256|0;a=c[d>>2]|0;if((a|0)!=0){uj(a)}a=uq(b)|0;c[d>>2]=a;return(a|0)==0|0}function sO(a,b){a=a|0;b=b|0;var d=0,e=0;d=c[a+1256>>2]|0;if((d|0)==0){e=1;return e|0}e=ug(d,b)|0;return e|0}function sP(a){a=a|0;var b=0;b=a+48|0;nj(b);c[a+696>>2]=2400;c[a+700>>2]=8;c[a+704>>2]=1;c[a+984>>2]=0;c[a+988>>2]=0;c[a+1248>>2]=0;zP(a+708|0,0,20);c[a+1252>>2]=1;na(b,1);nb(b,1);return}function sQ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=b+1248|0;do{if((c[d>>2]|0)!=0){e=b+724|0;f=c[e>>2]|0;if((f|0)==0){g=c[b+720>>2]|0}else{h=b+720|0;i=ul(c[b+1256>>2]|0,(c[h>>2]|0)+(b+728)|0,f)|0;c[h>>2]=(c[h>>2]|0)+i;f=c[e>>2]|0;c[e>>2]=f-i;if((f|0)!=(i|0)){break}c[h>>2]=0;g=0}h=b+48|0;i=b+720|0;f=(m5(h,b+728+g|0,1)|0)==0;j=c[e>>2]|0;L6184:do{if(f){k=b+1256|0;l=j;while(1){m=l+1|0;c[e>>2]=m;n=c[i>>2]|0;do{if((n+m|0)>>>0>255){if((m|0)==0){o=n;p=0;break}q=ul(c[k>>2]|0,b+728+n|0,m)|0;c[i>>2]=(c[i>>2]|0)+q;r=c[e>>2]|0;c[e>>2]=r-q;if((r|0)!=(q|0)){break L6184}c[i>>2]=0;o=0;p=0}else{o=n;p=m}}while(0);m=(m5(h,o+p+(b+728)|0,1)|0)==0;n=c[e>>2]|0;if(m){l=n}else{s=n;t=4906;break}}}else{s=j;t=4906}}while(0);do{if((t|0)==4906){if((s|0)==0){break}j=ul(c[b+1256>>2]|0,(c[i>>2]|0)+(b+728)|0,s)|0;c[i>>2]=(c[i>>2]|0)+j;f=c[e>>2]|0;c[e>>2]=f-j;if((f|0)!=(j|0)){break}c[i>>2]=0}}while(0);if((m6(h)|0)==0){u=1}else{u=(c[e>>2]|0)!=0|0}c[d>>2]=u}}while(0);u=b+1252|0;if((c[u>>2]|0)==0){sF(b);return}d=b+984|0;s=b+48|0;L6205:do{if((m4(s)|0)==0){t=b+988|0;p=b+1256|0;o=b+992|0;do{if((c[t>>2]|0)==0){c[d>>2]=0;g=uk(c[p>>2]|0,o,256)|0;i=(c[t>>2]|0)+g|0;c[t>>2]=i;if((i|0)==0){break L6205}}ng(s,a[(c[d>>2]|0)+(b+992)|0]|0)|0;c[d>>2]=(c[d>>2]|0)+1;c[t>>2]=(c[t>>2]|0)-1;}while((m4(s)|0)==0)}}while(0);c[u>>2]=(m4(s)|0)==0;sF(b);return}function sR(a,b){a=a|0;b=b|0;return(((d[a+b|0]|0)<<8|(d[a+(b+1)|0]|0))<<8|(d[a+(b+2)|0]|0))<<8|(d[a+(b+3)|0]|0)|0}function sS(b,c,d){b=b|0;c=c|0;d=d|0;a[b+c|0]=d>>>24&255;a[b+(c+1)|0]=d>>>16&255;a[b+(c+2)|0]=d>>>8&255;a[b+(c+3)|0]=d&255;return}function sT(a,b){a=a|0;b=b|0;return(((d[a+(b+3)|0]|0)<<8|(d[a+(b+2)|0]|0))<<8|(d[a+(b+1)|0]|0))<<8|(d[a+b|0]|0)|0}function sU(a,b){a=a|0;b=b|0;var c=0,e=0,f=0,g=0,h=0,i=0,j=0;c=d[a+(b+7)|0]|0;e=c<<8|0>>>24|(d[a+(b+6)|0]|0);f=e<<8|0>>>24|(d[a+(b+5)|0]|0);g=f<<8|0>>>24|(d[a+(b+4)|0]|0);h=g<<8|0>>>24|(d[a+(b+3)|0]|0);i=h<<8|0>>>24|(d[a+(b+2)|0]|0);j=i<<8|0>>>24|(d[a+(b+1)|0]|0);return(G=((((((0<<8|c>>>24)<<8|e>>>24)<<8|f>>>24)<<8|g>>>24)<<8|h>>>24)<<8|i>>>24)<<8|j>>>24|0,j<<8|0>>>24|(d[a+b|0]|0))|0}function sV(b,c,d){b=b|0;c=c|0;d=d|0;a[b+c|0]=d&255;a[b+(c+1)|0]=d>>>8&255;a[b+(c+2)|0]=d>>>16&255;a[b+(c+3)|0]=d>>>24&255;return}function sW(b,c,d,e){b=b|0;c=c|0;d=d|0;e=e|0;a[b+c|0]=d&255;a[b+(c+1)|0]=(d>>>8|e<<24)&255;a[b+(c+2)|0]=(d>>>16|e<<16)&255;a[b+(c+3)|0]=(d>>>24|e<<8)&255;a[b+(c+4)|0]=e&255;a[b+(c+5)|0]=(e>>>8|0<<24)&255;a[b+(c+6)|0]=(e>>>16|0<<16)&255;a[b+(c+7)|0]=(e>>>24|0<<8)&255;return}function sX(a,b,d,f,g,h,i){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;j=c[a+68>>2]|0;if((j|0)==0){c[d>>2]=0;k=1;return k|0}a=u6(j,f,g,h,i)|0;if((a|0)==0){c[d>>2]=0;k=1;return k|0}i=a+20|0;h=uL(a,c[i>>2]|0)|0;if((h|0)==0){c[i>>2]=0;l=a}else{l=h}h=c[d>>2]|0;g=e[l+10>>1]|0;if(h>>>0>g>>>0){c[d>>2]=g;m=32;n=g}else{m=0;n=h}if((n|0)!=0){h=c[l+24>>2]|0;zO(b|0,h|0,n)|0}n=c[l+12>>2]|0;l=(n&8|0)==0?m:m|2;m=(n&1|0)==0?l:l|4;l=(n&2|0)==0?m:m|8;m=(n&4|0)==0?l:l|16;if((c[a>>2]|0)==0){k=m;return k|0}c[i>>2]=(c[i>>2]|0)+1;k=m;return k|0}function sY(b,d,f,g,h,i,j){b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0;k=c[b+68>>2]|0;if((k|0)==0){c[f>>2]=0;l=1;return l|0}if((a[b+56|0]|0)!=0){l=64;return l|0}m=u6(k,g,h,i,j)|0;if((m|0)==0){c[f>>2]=0;l=1;return l|0}j=m+12|0;if((c[j>>2]&8|0)!=0){l=2;return l|0}a[b+72|0]=1;b=c[f>>2]|0;i=e[m+10>>1]|0;if(b>>>0>i>>>0){c[f>>2]=i;n=32;o=i}else{n=0;o=b}if((o|0)!=0){b=c[m+24>>2]|0;zO(b|0,d|0,o)|0}c[j>>2]=c[j>>2]&-3;j=m|0;o=c[j>>2]|0;if((o|0)==0){l=n;return l|0}uX(o);c[j>>2]=0;c[m+20>>2]=0;l=n;return l|0}function sZ(b,d,f){b=b|0;d=d|0;f=f|0;var g=0,h=0,i=0;g=c[b+68>>2]|0;if((g|0)==0){h=1;return h|0}if((a[b+56|0]|0)!=0){h=1;return h|0}i=u4(g,d,f,0)|0;if((i|0)==0){h=0;return h|0}a[b+72|0]=1;f=b+28|0;c[f>>2]=(c[f>>2]|0)-(e[i+2>>1]|0);uZ(i);h=0;return h|0}function s_(b,d,e,f,g,h,i,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=c[b+68>>2]|0;if((k|0)==0){l=1;return l|0}if((a[b+56|0]|0)!=0){l=1;return l|0}m=u4(k,d,e,1)|0;if((m|0)==0){l=1;return l|0}a[b+72|0]=1;e=uW(f,g,h,i)|0;if((e|0)==0){l=1;return l|0}uM(e,j);if((u_(m,e)|0)==0){uP(e,c[b+76>>2]|0);m=b+28|0;c[m>>2]=(c[m>>2]|0)+1;l=0;return l|0}else{uX(e);l=1;return l|0}return 0}function s$(b,d,f,g,h,i,j,k,l){b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0,n=0;m=c[b+68>>2]|0;if((m|0)==0){n=1;return n|0}b=u6(m,d,f,g,1)|0;if((b|0)==0){n=1;return n|0}c[h>>2]=e[b+4>>1]|0;c[i>>2]=e[b+6>>1]|0;c[j>>2]=e[b+8>>1]|0;j=b+10|0;c[k>>2]=e[j>>1]|0;c[l>>2]=e[j>>1]|0;if((a[b+46|0]|0)==0){n=0;return n|0}j=uR(b)|0;if(j>>>0>=9){n=0;return n|0}c[l>>2]=128<<j;n=0;return n|0}function s0(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=zH(88)|0;if((h|0)==0){i=0;return i|0}j=h;tk(j,h,0,0,0,0);tb(j,6);td(j,g);c[h+4>>2]=64;c[h+8>>2]=28;c[h+12>>2]=22;c[h+20>>2]=28;a[h+72|0]=0;c[h+76>>2]=2;c[h+80>>2]=f;c[h+84>>2]=0;g=uG(d,f)|0;c[h+68>>2]=g;if((g|0)==0){s1(j);i=0;return i|0}h=b[g>>1]|0;f=h&65535;if(h<<16>>16==0){i=j;return i|0}h=c[g+4>>2]|0;g=0;d=0;k=0;while(1){l=c[h+(k<<2)>>2]|0;m=b[l+2>>1]|0;n=m&65535;o=n+g|0;if(m<<16>>16==0){p=d}else{m=c[l+4>>2]|0;l=d;q=0;while(1){r=(e[(c[m+(q<<2)>>2]|0)+2>>1]|0)+l|0;s=q+1|0;if(s>>>0<n>>>0){l=r;q=s}else{p=r;break}}}q=k+1|0;if(q>>>0<f>>>0){g=o;d=p;k=q}else{break}}if((o|0)==0|(p|0)==0){i=j;return i|0}k=(((((o>>>0)/(f>>>0)|0)>>>1)+o|0)>>>0)/(f>>>0)|0;d=(((((p>>>0)/(o>>>0)|0)>>>1)+p|0)>>>0)/(o>>>0)|0;if((te(j,p,f,k,d)|0)!=0){i=j;return i|0}tf(j,f,k,d);i=j;return i|0}function s1(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=c[b+64>>2]|0;L123:do{if((a[e+72|0]|0)!=0){f=c[q>>2]|0;g=b+24|0;h=c[g>>2]|0;bN(f|0,28920,(x=i,i=i+8|0,c[x>>2]=h,x)|0)|0;h=e+84|0;do{if((c[h>>2]|0)!=0){f=e+68|0;if((c[f>>2]|0)==0){break}if((tc(e)|0)!=0){break}if((uJ(c[h>>2]|0,c[f>>2]|0,c[e+80>>2]|0)|0)==0){break L123}}}while(0);h=c[q>>2]|0;f=c[g>>2]|0;bN(h|0,27168,(x=i,i=i+8|0,c[x>>2]=f,x)|0)|0}}while(0);b=c[e+68>>2]|0;if((b|0)==0){j=e+84|0;k=j;l=c[k>>2]|0;zI(l);zI(e);i=d;return}u2(b);j=e+84|0;k=j;l=c[k>>2]|0;zI(l);zI(e);i=d;return}function s2(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+32|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=c[a+64>>2]|0;a=l;m=l+68|0;if((e|0)==0){n=0;i=f;return n|0}else{o=d;p=e;q=b}while(1){if((u8(c[m>>2]|0,o,g,h,j)|0)!=0){n=1;r=113;break}c[k>>2]=512;b=(sX(a,q,k,c[g>>2]|0,c[h>>2]|0,c[j>>2]|0,1)|0)==0;if(!(b&(c[k>>2]|0)==512)){n=1;r=114;break}b=p-1|0;if((b|0)==0){n=0;r=115;break}else{o=o+1|0;p=b;q=q+512|0}}if((r|0)==114){i=f;return n|0}else if((r|0)==115){i=f;return n|0}else if((r|0)==113){i=f;return n|0}return 0}function s3(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+24|0;j=h|0;k=h+8|0;l=h+16|0;L147:do{if((a[d+56|0]|0)==0){m=c[d+64>>2]|0;n=m+68|0;o=m+56|0;if((g|0)==0){p=0;break}q=m+72|0;m=f;r=g;s=e;while(1){if((u8(c[n>>2]|0,m,j,k,l)|0)!=0){p=1;break L147}t=c[n>>2]|0;if((t|0)==0){p=1;break L147}if((a[o]|0)!=0){p=1;break L147}u=u6(t,c[j>>2]|0,c[k>>2]|0,c[l>>2]|0,1)|0;if((u|0)==0){p=1;break L147}t=u+12|0;if((c[t>>2]&8|0)!=0){p=1;break L147}a[q]=1;v=b[u+10>>1]|0;if((v&65535)<512){if(v<<16>>16==0){w=0;x=32}else{y=v&65535;z=32;A=126}}else{y=512;z=0;A=126}if((A|0)==126){A=0;v=c[u+24>>2]|0;zO(v|0,s|0,y)|0;w=y;x=z}c[t>>2]=c[t>>2]&-3;t=u|0;v=c[t>>2]|0;if((v|0)!=0){uX(v);c[t>>2]=0;c[u+20>>2]=0}if(!((x|0)==0&(w|0)==512)){p=1;break L147}u=r-1|0;if((u|0)==0){p=0;break}else{m=m+1|0;r=u;s=s+512|0}}}else{p=1}}while(0);i=h;return p|0}function s4(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;e=c[b+64>>2]|0;if((aP(d|0,30976)|0)!=0){f=1;return f|0}d=e+84|0;if((c[d>>2]|0)==0){f=1;return f|0}b=e+68|0;if((c[b>>2]|0)==0){f=1;return f|0}if((tc(e)|0)!=0){f=1;return f|0}if((uJ(c[d>>2]|0,c[b>>2]|0,c[e+80>>2]|0)|0)!=0){f=1;return f|0}a[e+72|0]=0;f=0;return f|0}
function s5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;do{if((b|0)==0){e=uH(a)|0;if((e|0)!=0){f=e;break}e=uF(a)|0;if((e|0)==0){g=0}else{f=e;break}return g|0}else{f=b}}while(0);do{if((d|0)==0){b=bl(a|0,40392)|0;if((b|0)!=0){h=0;i=b;break}j=bl(a|0,38960)|0;k=1;l=152}else{j=bl(a|0,38960)|0;k=d;l=152}}while(0);do{if((l|0)==152){if((j|0)==0){g=0}else{h=k;i=j;break}return g|0}}while(0);j=s0(i,f,h)|0;au(i|0)|0;if((j|0)==0){g=0;return g|0}i=c[j+64>>2]|0;h=zH((zN(a|0)|0)+1|0)|0;c[i+84>>2]=h;if((h|0)!=0){zQ(h|0,a|0)|0}tm(j,a);g=j;return g|0}function s6(a){a=a|0;return uH(a)|0}function s7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=0;if(d>>>0>g>>>0|d>>>0==g>>>0&c>>>0>2147483647>>>0){h=1;return h|0}if((bS(a|0,c|0,0)|0)!=0){h=1;return h|0}c=bK(b|0,1,e|0,a|0)|0;a=c;g=0;if(!(g>>>0<f>>>0|g>>>0==f>>>0&a>>>0<e>>>0)){h=0;return h|0}d=zX(e,f,a,g)|0;zP(b+c|0,0,d|0);h=0;return h|0}function s8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=0;if(d>>>0>g>>>0|d>>>0==g>>>0&c>>>0>2147483647>>>0){h=1;return h|0}if((bS(a|0,c|0,0)|0)!=0){h=1;return h|0}h=((aB(b|0,1,e|0,a|0)|0)!=(e|0)|0!=(f|0))&1;return h|0}function s9(a,b){a=a|0;b=b|0;c[a+24>>2]=b;return}function ta(a){a=a|0;return c[a>>2]|0}function tb(a,b){a=a|0;b=b|0;c[a>>2]=b;return}function tc(b){b=b|0;return(a[b+56|0]|0)!=0|0}function td(b,c){b=b|0;c=c|0;a[b+56|0]=(c|0)!=0|0;return}function te(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;do{if((b|0)==0){g=ac(ac(e,d)|0,f)|0;if((g|0)==0){h=1}else{i=g;break}return h|0}else{i=b}}while(0);do{if((d|0)==0){b=(f|0)==0?63:f;g=(e|0)==0?16:e;j=b;k=(i>>>0)/((ac(b,g)|0)>>>0)|0;l=g}else{g=(f|0)==0;if((e|0)==0){b=g?63:f;j=b;k=d;l=(i>>>0)/((ac(b,d)|0)>>>0)|0;break}if(!g){j=f;k=d;l=e;break}j=(i>>>0)/((ac(e,d)|0)>>>0)|0;k=d;l=e}}while(0);c[a+28>>2]=i;c[a+32>>2]=k;c[a+36>>2]=l;c[a+40>>2]=j;h=0;return h|0}function tf(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[a+44>>2]=b;c[a+48>>2]=d;c[a+52>>2]=e;return}function tg(a){a=a|0;return c[a+24>>2]|0}function th(a){a=a|0;return c[a+28>>2]|0}function ti(a,b){a=a|0;b=b|0;var d=0,e=0;if((bS(a|0,0,2)|0)!=0){d=1;return d|0}e=a$(a|0)|0;if((e|0)==-1){d=1;return d|0}c[b>>2]=e;c[b+4>>2]=(e|0)<0?-1:0;d=0;return d|0}function tj(a,b,c){a=a|0;b=b|0;c=c|0;ax(a|0)|0;return(a7(aK(a|0)|0,b|0)|0)!=0|0}function tk(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;zP(b|0,0,28);if((e|0)==0){i=ac(ac(g,f)|0,h)|0;if((i|0)==0){j=h;k=g;l=f;m=0}else{n=i;o=209}}else{n=e;o=209}do{if((o|0)==209){if((f|0)==0){e=(h|0)==0?63:h;i=(g|0)==0?16:g;j=e;k=i;l=(n>>>0)/((ac(e,i)|0)>>>0)|0;m=n;break}i=(h|0)==0;if((g|0)==0){e=i?63:h;j=e;k=(n>>>0)/((ac(e,f)|0)>>>0)|0;l=f;m=n;break}if(!i){j=h;k=g;l=f;m=n;break}j=(n>>>0)/((ac(g,f)|0)>>>0)|0;k=g;l=f;m=n}}while(0);c[b+28>>2]=m;c[b+32>>2]=l;c[b+36>>2]=k;c[b+40>>2]=j;c[b+44>>2]=l;c[b+48>>2]=k;c[b+52>>2]=j;a[b+56|0]=0;c[b+60>>2]=0;c[b+64>>2]=d;return}function tl(a){a=a|0;var b=0;if((a|0)==0){return}zI(c[a+60>>2]|0);b=c[a+4>>2]|0;if((b|0)==0){return}b2[b&255](a);return}function tm(a,b){a=a|0;b=b|0;var d=0;d=a+60|0;a=c[d>>2]|0;if((a|0)!=0){zI(a)}if((b|0)==0){c[d>>2]=0;return}a=zH((zN(b|0)|0)+1|0)|0;c[d>>2]=a;if((a|0)==0){return}zQ(a|0,b|0)|0;return}function tn(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;e=i;i=i+512|0;f=e|0;g=f|0;h=b+8|0;j=c[h>>2]|0;L290:do{if((j|0)!=0){if((b7[j&63](b,g,0,1)|0)!=0){break}if((a[f+510|0]|0)!=85){break}if((a[f+511|0]|0)==-86){k=0;l=0;m=0;n=0}else{break}while(1){o=l<<4;do{if((a[f+(o+446)|0]&127)==0){p=d[f+(o+448)|0]|0;q=a[f+(o+447)|0]|0;r=p&63;s=((d[f+(o+457)|0]<<8|d[f+(o+456)|0])<<8|d[f+(o+455)|0])<<8|d[f+(o+454)|0];t=d[f+(o+452)|0]|0;u=t&63;v=((d[f+(o+461)|0]<<8|d[f+(o+460)|0])<<8|d[f+(o+459)|0])<<8|d[f+(o+458)|0];if((r|0)==0|(u|0)==0|(s|0)==0|(v|0)==0){w=n;x=m;y=k;break}z=r-1|0;r=u-1|0;u=s-1+v|0;if(!(s>>>0>z>>>0&u>>>0>r>>>0)){w=n;x=m;y=k;break}v=p<<2&768|d[f+(o+449)|0];p=0;A=u-r|0;r=0;u=t<<2&768|d[f+(o+453)|0];t=0;B=d[f+(o+451)|0]|0;C=0;D=z4(B,C,v,p)|0;E=G;F=z4(u,t,q&255,0)|0;q=G;if((D|0)==(F|0)&(E|0)==(q|0)){w=n;x=m;y=k;break}H=z4(u,t,s-z|0,0)|0;z=G;s=z4(A,r,v,p)|0;p=G;v=zX(D,E,F,q)|0;q=G;F=zX(s,p,H,z)|0;z=z2(F,G,v,q)|0;q=z;v=z|0;z=G&0;F=z4(v,z,u,t)|0;t=G;if((F|0)==0&(t|0)==0){I=k}else{u=z4(v,z,B,C)|0;C=zX(A,r,u,G)|0;u=z2(C,G,F,t)|0;t=u;if((t|0)==0){w=n;x=m;y=0;break}if((q|0)==0){w=n;x=m;y=t;break}else{I=t}}if(!((m|0)==0|(m|0)==(I|0))){break L290}if((n|0)==0|(n|0)==(q|0)){w=q;x=I;y=I}else{break L290}}else{w=n;x=m;y=k}}while(0);o=l+1|0;if(o>>>0<4){k=y;l=o;m=x;n=w}else{break}}if((x|0)==0|(w|0)==0){break}o=b+28|0;q=c[o>>2]|0;t=ac(w,x)|0;u=(q>>>0)/(t>>>0)|0;do{if((q|0)==0){F=ac(u,t)|0;if((F|0)!=0){J=F;break}i=e;return 0}else{J=q}}while(0);if((u|0)==0){K=(J>>>0)/(t>>>0)|0}else{K=u}c[o>>2]=J;c[b+32>>2]=K;c[b+36>>2]=x;c[b+40>>2]=w;i=e;return 0}}while(0);w=c[h>>2]|0;do{if((w|0)!=0){if((b7[w&63](b,g,0,1)|0)!=0){break}if((a[f+510|0]|0)!=85){break}if((a[f+511|0]|0)!=-86){break}if((d[f+12|0]<<8|d[f+11|0])<<16>>16!=512){break}x=d[f+27|0]<<8|d[f+26|0];K=x&65535;J=d[f+25|0]<<8|d[f+24|0];n=J&65535;if(x<<16>>16==0|(x&65535)>255){break}if(J<<16>>16==0|(J&65535)>255){break}J=b+28|0;x=c[J>>2]|0;m=ac(n,K)|0;l=(x>>>0)/(m>>>0)|0;do{if((x|0)==0){y=ac(l,m)|0;if((y|0)!=0){L=y;break}i=e;return 0}else{L=x}}while(0);if((l|0)==0){M=(L>>>0)/(m>>>0)|0}else{M=l}c[J>>2]=L;c[b+32>>2]=M;c[b+36>>2]=K;c[b+40>>2]=n;i=e;return 0}}while(0);M=c[h>>2]|0;do{if((M|0)!=0){if((b7[M&63](b,g,0,1)|0)!=0){break}if((d[f+508|0]<<8|d[f+509|0])<<16>>16==-9538){N=0;O=0}else{break}while(1){P=d[f+N|0]<<8^O;Q=d[f+(N|1)|0]|0;h=N+2|0;if(h>>>0<512){N=h;O=P^Q}else{break}}if((P|0)!=(Q|0)){break}if((((d[f+128|0]<<8|d[f+129|0])<<8|d[f+130|0])<<8|d[f+131|0]|0)!=1){break}if(((d[f+140|0]<<8|d[f+141|0])&65535)>8){break}n=d[f+422|0]<<8|d[f+423|0];K=n&65535;J=d[f+436|0]<<8|d[f+437|0];l=J&65535;m=d[f+438|0]<<8|d[f+439|0];h=m&65535;L=b+28|0;w=c[L>>2]|0;do{if((w|0)==0){x=ac(ac(l,K)|0,h)|0;if((x|0)!=0){R=x;break}i=e;return 0}else{R=w}}while(0);do{if(n<<16>>16==0){w=m<<16>>16==0?63:h;x=J<<16>>16==0?16:l;S=w;T=(R>>>0)/((ac(w,x)|0)>>>0)|0;U=x}else{x=m<<16>>16==0;if(J<<16>>16==0){w=x?63:h;S=w;T=K;U=(R>>>0)/((ac(w,K)|0)>>>0)|0;break}if(!x){S=h;T=K;U=l;break}S=(R>>>0)/((ac(l,K)|0)>>>0)|0;T=K;U=l}}while(0);c[L>>2]=R;c[b+32>>2]=T;c[b+36>>2]=U;c[b+40>>2]=S;i=e;return 0}}while(0);S=b+28|0;U=c[S>>2]|0;if((U|0)==320){c[S>>2]=320;c[b+32>>2]=40;c[b+36>>2]=1;c[b+40>>2]=8;i=e;return 0}else if((U|0)==360){c[S>>2]=360;c[b+32>>2]=40;c[b+36>>2]=1;c[b+40>>2]=9;i=e;return 0}else if((U|0)==640){c[S>>2]=640;c[b+32>>2]=40;c[b+36>>2]=2;c[b+40>>2]=8;i=e;return 0}else if((U|0)==720){c[S>>2]=720;c[b+32>>2]=40;c[b+36>>2]=2;c[b+40>>2]=9;i=e;return 0}else if((U|0)==800){c[S>>2]=800;c[b+32>>2]=40;c[b+36>>2]=2;c[b+40>>2]=10;i=e;return 0}else if((U|0)==1440){c[S>>2]=1440;c[b+32>>2]=80;c[b+36>>2]=2;c[b+40>>2]=9;i=e;return 0}else if((U|0)==1600){c[S>>2]=1600;c[b+32>>2]=80;c[b+36>>2]=2;c[b+40>>2]=10;i=e;return 0}else if((U|0)==2400){c[S>>2]=2400;c[b+32>>2]=80;c[b+36>>2]=2;c[b+40>>2]=15;i=e;return 0}else if((U|0)==2880){c[S>>2]=2880;c[b+32>>2]=80;c[b+36>>2]=2;c[b+40>>2]=18;i=e;return 0}else if((U|0)==5760){c[S>>2]=5760;c[b+32>>2]=80;c[b+36>>2]=2;c[b+40>>2]=36;i=e;return 0}else{T=b+32|0;R=c[T>>2]|0;f=b+36|0;Q=c[f>>2]|0;P=b+40|0;b=c[P>>2]|0;do{if((U|0)==0){O=ac(ac(Q,R)|0,b)|0;if((O|0)!=0){V=O;break}i=e;return 0}else{V=U}}while(0);do{if((R|0)==0){U=(b|0)==0?63:b;O=(Q|0)==0?16:Q;W=U;X=(V>>>0)/((ac(U,O)|0)>>>0)|0;Y=O}else{O=(b|0)==0;if((Q|0)==0){U=O?63:b;W=U;X=R;Y=(V>>>0)/((ac(U,R)|0)>>>0)|0;break}if(!O){W=b;X=R;Y=Q;break}W=(V>>>0)/((ac(Q,R)|0)>>>0)|0;X=R;Y=Q}}while(0);c[S>>2]=V;c[T>>2]=X;c[f>>2]=Y;c[P>>2]=W;i=e;return 0}return 0}function to(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if((tN(a)|0)!=0){e=tM(a,d)|0;return e|0}if((tX(a)|0)!=0){e=tT(a,d)|0;return e|0}if((tG(a)|0)!=0){e=tF(a,d)|0;return e|0}f=s6(a)|0;if((f|0)!=0){e=s5(a,f,d)|0;return e|0}f=uF(a)|0;if((f|0)==10|(f|0)==0){e=t2(a,b,c,d)|0;return e|0}else{e=s5(a,f,d)|0;return e|0}return 0}function tp(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 1}function tq(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;do{if((e|0)==0){g=1}else{h=c[a+40>>2]|0;if(h>>>0<e>>>0){g=1;break}i=c[a+36>>2]|0;if(i>>>0<=d>>>0){g=1;break}if((c[a+32>>2]|0)>>>0<=b>>>0){g=1;break}c[f>>2]=e-1+(ac((ac(i,b)|0)+d|0,h)|0);g=0}}while(0);return g|0}function tr(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a|0;e=c[d>>2]|0;if((e|0)==0){f=0;g=0;c[d>>2]=g;return f|0}h=a+4|0;a=0;i=0;j=0;k=e;while(1){e=c[h>>2]|0;l=c[e+(i<<2)>>2]|0;if((l|0)==(b|0)){m=j;n=1;o=k}else{c[e+(j<<2)>>2]=l;m=j+1|0;n=a;o=c[d>>2]|0}l=i+1|0;if(l>>>0<o>>>0){a=n;i=l;j=m;k=o}else{f=n;g=m;break}}c[d>>2]=g;return f|0}function ts(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=a+4|0;e=c[a>>2]|0;a=0;while(1){if(a>>>0>=e>>>0){f=0;g=358;break}h=c[(c[d>>2]|0)+(a<<2)>>2]|0;if((c[h+24>>2]|0)==(b|0)){f=h;g=357;break}else{a=a+1|0}}if((g|0)==358){return f|0}else if((g|0)==357){return f|0}return 0}function tt(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=c[a+8>>2]|0;if((f|0)==0){g=1;return g|0}g=b7[f&63](a,b,d,e)|0;return g|0}function tu(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((f|0)==0){h=1;return h|0}i=c[a+40>>2]|0;if(i>>>0<f>>>0){h=1;return h|0}j=c[a+36>>2]|0;if(j>>>0<=e>>>0){h=1;return h|0}if((c[a+32>>2]|0)>>>0<=d>>>0){h=1;return h|0}k=c[a+8>>2]|0;if((k|0)==0){h=1;return h|0}l=f-1+(ac((ac(j,d)|0)+e|0,i)|0)|0;h=b7[k&63](a,b,l,g)|0;return h|0}function tv(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=c[a+12>>2]|0;if((f|0)==0){g=1;return g|0}g=b7[f&63](a,b,d,e)|0;return g|0}function tw(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0;if((f|0)==0){h=1;return h|0}i=c[a+40>>2]|0;if(i>>>0<f>>>0){h=1;return h|0}j=c[a+36>>2]|0;if(j>>>0<=e>>>0){h=1;return h|0}if((c[a+32>>2]|0)>>>0<=d>>>0){h=1;return h|0}k=c[a+12>>2]|0;if((k|0)==0){h=1;return h|0}l=f-1+(ac((ac(j,d)|0)+e|0,i)|0)|0;h=b7[k&63](a,b,l,g)|0;return h|0}function tx(){var a=0,b=0;a=zH(8)|0;if((a|0)==0){b=0;return b|0}c[a>>2]=0;c[a+4>>2]=0;b=a;return b|0}function ty(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a|0;e=c[d>>2]|0;f=a+4|0;a=b+24|0;g=0;while(1){if(g>>>0>=e>>>0){break}if((c[(c[(c[f>>2]|0)+(g<<2)>>2]|0)+24>>2]|0)==(c[a>>2]|0)){h=1;i=408;break}else{g=g+1|0}}if((i|0)==408){return h|0}i=e+1|0;e=zJ(c[f>>2]|0,i<<2)|0;g=e;if((e|0)==0){h=1;return h|0}c[g+(c[d>>2]<<2)>>2]=b;c[d>>2]=i;c[f>>2]=g;h=0;return h|0}function tz(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=a|0;d=c[b>>2]|0;if((d|0)==0){e=0;return e|0}f=a+4|0;a=0;g=0;h=d;while(1){d=c[(c[f>>2]|0)+(a<<2)>>2]|0;i=c[d+20>>2]|0;if((i|0)==0){j=g;k=h}else{l=(b4[i&127](d,38728,44512)|0)==0?g:1;j=l;k=c[b>>2]|0}l=a+1|0;if(l>>>0<k>>>0){a=l;g=j;h=k}else{e=j;break}}return e|0}function tA(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=a+4|0;g=c[a>>2]|0;a=0;while(1){if(a>>>0>=g>>>0){h=1;i=426;break}j=c[(c[f>>2]|0)+(a<<2)>>2]|0;if((c[j+24>>2]|0)==(b|0)){break}else{a=a+1|0}}if((i|0)==426){return h|0}if((j|0)==0){h=1;return h|0}i=c[j+20>>2]|0;if((i|0)==0){h=1;return h|0}h=b4[i&127](j,d,(e|0)==0?44512:e)|0;return h|0}function tB(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+32|0;e=d|0;if((s7(a,e,0,0,23,0)|0)!=0){f=0;i=d;return f|0}if((zS(e|0,38408,7)|0)!=0){f=0;i=d;return f|0}g=sT(e,15)|0;h=sT(e,7)|0;j=sT(e,11)|0;k=sT(e,19)|0;if(k>>>0<23){f=0;i=d;return f|0}e=zH(80)|0;if((e|0)==0){f=0;i=d;return f|0}l=e;tk(l,e,0,g,h,j);tb(l,4);td(l,b);c[e+4>>2]=144;c[e+8>>2]=38;c[e+12>>2]=40;b=e+72|0;c[b>>2]=k;c[b+4>>2]=0;c[e+68>>2]=a;f=l;i=d;return f|0}function tC(a){a=a|0;var b=0;b=c[a+64>>2]|0;au(c[b+68>>2]|0)|0;zI(b);return}function tD(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;if((e+d|0)>>>0>(c[a+28>>2]|0)>>>0){f=1;return f|0}g=c[a+64>>2]|0;a=g+72|0;h=d;d=zW(c[a>>2]|0,c[a+4>>2]|0,h<<9|0>>>23,0<<9|h>>>23)|0;h=e;f=(s7(c[g+68>>2]|0,b,d,G,h<<9|0>>>23,0<<9|h>>>23)|0)!=0|0;return f|0}function tE(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((a[b+56|0]|0)!=0){g=1;return g|0}if((f+e|0)>>>0>(c[b+28>>2]|0)>>>0){g=1;return g|0}h=c[b+64>>2]|0;b=h+72|0;i=e;e=zW(c[b>>2]|0,c[b+4>>2]|0,i<<9|0>>>23,0<<9|i>>>23)|0;i=f;f=h+68|0;if((s8(c[f>>2]|0,d,e,G,i<<9|0>>>23,0<<9|i>>>23)|0)!=0){g=1;return g|0}ax(c[f>>2]|0)|0;g=0;return g|0}function tF(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;do{if((b|0)==0){c=bl(a|0,33056|0)|0;if((c|0)!=0){d=0;e=c;break}f=bl(a|0,40248|0)|0;g=1;h=458}else{f=bl(a|0,40248|0)|0;g=b;h=458}}while(0);do{if((h|0)==458){if((f|0)==0){i=0}else{d=g;e=f;break}return i|0}}while(0);f=tB(e,d)|0;if((f|0)==0){au(e|0)|0;i=0;return i|0}else{tm(f,a);i=f;return i|0}return 0}function tG(a){a=a|0;var b=0,c=0,d=0,e=0;b=i;i=i+8|0;c=bl(a|0,40248)|0;if((c|0)==0){d=0;i=b;return d|0}a=b|0;if((s7(c,a,0,0,8,0)|0)==0){e=(zS(a|0,38408,7)|0)==0|0}else{e=0}au(c|0)|0;d=e;i=b;return d|0}function tH(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+32|0;e=d|0;if((bK(e|0,1,32,a|0)|0)!=32){f=0;i=d;return f|0}if((sR(e,0)|0)!=1346981191){f=0;i=d;return f|0}if((sR(e,4)|0)!=0){f=0;i=d;return f|0}if((sR(e,28)|0)!=512){f=0;i=d;return f|0}g=sR(e,12)|0;h=sR(e,16)|0;j=sR(e,20)|0;k=sR(e,24)|0;l=zH(80)|0;if((l|0)==0){f=0;i=d;return f|0}m=l;tk(m,l,g,h,j,k);tb(m,3);td(m,b);c[l+68>>2]=a;c[l+4>>2]=102;c[l+8>>2]=34;c[l+12>>2]=42;c[l+16>>2]=6;c[l+20>>2]=24;c[l+72>>2]=sR(e,8)|0;c[l+76>>2]=sR(e,28)|0;f=m;i=d;return f|0}function tI(a){a=a|0;var b=0;b=c[a+64>>2]|0;a=c[b+68>>2]|0;if((a|0)==0){zI(b);return}au(a|0)|0;zI(b);return}function tJ(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=c[a+64>>2]|0;if((e+d|0)>>>0>(c[f+28>>2]|0)>>>0){g=1;return g|0}a=d;d=zW(c[f+72>>2]|0,0,a<<9|0>>>23,0<<9|a>>>23)|0;a=e;g=(s7(c[f+68>>2]|0,b,d,G,a<<9|0>>>23,0<<9|a>>>23)|0)!=0|0;return g|0}function tK(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=c[b+64>>2]|0;if((a[b+56|0]|0)!=0){h=1;return h|0}if((f+e|0)>>>0>(c[b+28>>2]|0)>>>0){h=1;return h|0}b=e;e=zW(c[g+72>>2]|0,0,b<<9|0>>>23,0<<9|b>>>23)|0;b=f;f=g+68|0;if((s8(c[f>>2]|0,d,e,G,b<<9|0>>>23,0<<9|b>>>23)|0)!=0){h=1;return h|0}ax(c[f>>2]|0)|0;h=0;return h|0}function tL(a,b,c){a=a|0;b=b|0;c=c|0;return(aP(b|0,30968)|0)!=0|0}function tM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;do{if((b|0)==0){c=bl(a|0,40240|0)|0;if((c|0)!=0){d=0;e=c;break}f=bl(a|0,38352|0)|0;g=1;h=510}else{f=bl(a|0,38352|0)|0;g=b;h=510}}while(0);do{if((h|0)==510){if((f|0)==0){i=0}else{d=g;e=f;break}return i|0}}while(0);f=tH(e,d)|0;if((f|0)==0){au(e|0)|0;i=0;return i|0}else{tm(f,a);i=f;return i|0}return 0}function tN(a){a=a|0;var b=0,c=0,d=0,e=0;b=i;i=i+8|0;c=bl(a|0,38352)|0;if((c|0)==0){d=0;i=b;return d|0}a=b|0;if((s7(c,a,0,0,4,0)|0)==0){e=(sR(a,0)|0)==1346981191|0}else{e=0}au(c|0)|0;d=e;i=b;return d|0}function tO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 1}function tP(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;e=i;f=zH(4280)|0;if((f|0)==0){g=0;i=e;return g|0}h=f+4276|0;c[h>>2]=b;c[f+68>>2]=0;j=f+4264|0;c[j>>2]=0;k=f+4268|0;c[k>>2]=0;l=f+4272|0;c[l>>2]=0;m=f+152|0;do{if((s7(b,m,0,0,4096,0)|0)==0){if((sT(m,0)|0)!=4474193){break}n=f+4248|0;a[n]=0;o=f+72|0;c[o>>2]=sT(m,4)|0;p=f+76|0;c[p>>2]=sT(m,8)|0;r=sT(m,12)|0;c[f+80>>2]=r;s=c[o>>2]|0;t=s-1|0;if((t&s|0)!=0){break}u=c[p>>2]|0;if((u-1&u|0)!=0|(r|0)==0){break}r=f+128|0;c[r>>2]=ac(u,s)|0;s=f+136|0;c[s>>2]=t;c[s+4>>2]=0;t=sU(m,16)|0;u=f+88|0;c[u>>2]=t;c[u+4>>2]=G;t=sU(m,24)|0;p=f+96|0;c[p>>2]=t;c[p+4>>2]=G;p=sU(m,32)|0;t=G;v=f+104|0;c[v>>2]=p;c[v+4>>2]=t;w=c[u>>2]&-6;y=c[u+4>>2]|0;if(!((w|0)==0&(y|0)==0)){u=c[q>>2]|0;z=28880;bN(u|0,z|0,(x=i,i=i+16|0,c[x>>2]=w,c[x+8>>2]=y,x)|0)|0;break}if(!((p|0)==0&(t|0)==0)){a[n]=1;c[v>>2]=0;c[v+4>>2]=0;sW(m,32,0,0)}v=sU(m,40)|0;t=f+112|0;c[t>>2]=v;c[t+4>>2]=G;v=f+4256|0;c[v>>2]=0;c[v+4>>2]=0;v=sU(m,48)|0;p=G;y=f+120|0;c[y>>2]=v;c[y+4>>2]=p;if(!((c[s>>2]&c[t>>2]|0)==0&(c[s+4>>2]&c[t+4>>2]|0)==0)){break}if(!((v&511|0)==0&(p&0|0)==0)){break}p=f+144|0;if((ti(c[h>>2]|0,p)|0)!=0){break}v=c[o>>2]|0;w=zW(c[p>>2]|0,c[p+4>>2]|0,-1,-1)|0;z=zW(w,G,v,0)|0;v=G&~c[s+4>>2];c[p>>2]=z&~c[s>>2];c[p+4>>2]=v;do{if((a[n]|0)!=0&(d|0)==0){if((s8(c[h>>2]|0,m,0,0,4096,0)|0)==0){v=c[h>>2]|0;ax(v|0)|0;break}zI(f);g=0;i=e;return g|0}}while(0);n=f;tk(n,f,(c[y>>2]|0)>>>9|c[y+4>>2]<<23,0,0,0);tb(n,7);td(n,d);c[f+4>>2]=180;c[f+8>>2]=26;c[f+12>>2]=14;v=c[r>>2]|0;p=zH(v)|0;c[j>>2]=p;do{if((p|0)!=0){s=zH(v)|0;c[k>>2]=s;if((s|0)==0){break}s=zH(c[o>>2]|0)|0;c[l>>2]=s;if((s|0)==0){break}if((s7(c[h>>2]|0,p,c[t>>2]|0,c[t+4>>2]|0,v,0)|0)==0){tn(n)|0;g=n;i=e;return g|0}s=c[f+64>>2]|0;z=c[s+68>>2]|0;if((z|0)!=0){tl(z)}zI(c[s+4272>>2]|0);zI(c[s+4268>>2]|0);zI(c[s+4264>>2]|0);z=c[s+4276>>2]|0;au(z|0)|0;zI(s);g=0;i=e;return g|0}}while(0);n=c[f+64>>2]|0;v=c[n+68>>2]|0;if((v|0)!=0){tl(v)}zI(c[n+4272>>2]|0);zI(c[n+4268>>2]|0);zI(c[n+4264>>2]|0);v=c[n+4276>>2]|0;au(v|0)|0;zI(n);g=0;i=e;return g|0}}while(0);zI(f);g=0;i=e;return g|0}function tQ(a){a=a|0;var b=0;b=c[a+64>>2]|0;a=c[b+68>>2]|0;if((a|0)!=0){tl(a)}zI(c[b+4272>>2]|0);zI(c[b+4268>>2]|0);zI(c[b+4264>>2]|0);au(c[b+4276>>2]|0)|0;zI(b);return}function tR(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+8|0;g=f|0;if((e+d|0)>>>0>(c[a+28>>2]|0)>>>0){h=1;i=f;return h|0}j=c[a+64>>2]|0;a=j;k=j+72|0;l=j+4276|0;if((e|0)==0){h=0;i=f;return h|0}m=j+68|0;j=d;d=e;e=b;L694:while(1){b=(c[k>>2]|0)>>>9;n=b-((j>>>0)%(b>>>0)|0)|0;b=n>>>0>d>>>0?d:n;n=j;c[g>>2]=n<<9|0>>>23;c[g+4>>2]=0<<9|n>>>23;if((t0(a,g,0)|0)!=0){h=1;o=576;break}n=c[g>>2]|0;p=c[g+4>>2]|0;do{if((n|0)==0&(p|0)==0){q=c[m>>2]|0;if((q|0)==0){r=b<<9;zP(e|0,0,r|0);s=r;break}if((tt(q,e,j,b)|0)!=0){h=1;o=578;break L694}s=b<<9}else{q=b<<9;if((s7(c[l>>2]|0,e,n,p,q,0)|0)==0){s=q}else{h=1;o=580;break L694}}}while(0);if((d|0)==(b|0)){h=0;o=579;break}else{j=b+j|0;d=d-b|0;e=e+s|0}}if((o|0)==576){i=f;return h|0}else if((o|0)==578){i=f;return h|0}else if((o|0)==579){i=f;return h|0}else if((o|0)==580){i=f;return h|0}return 0}function tS(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+8|0;g=f|0;if((e+d|0)>>>0>(c[a+28>>2]|0)>>>0){h=1;i=f;return h|0}j=c[a+64>>2]|0;a=j;k=j+72|0;l=j+4276|0;if((e|0)==0){h=0;i=f;return h|0}else{m=d;n=e;o=b}while(1){b=(c[k>>2]|0)>>>9;e=b-((m>>>0)%(b>>>0)|0)|0;b=e>>>0>n>>>0?n:e;e=m;c[g>>2]=e<<9|0>>>23;c[g+4>>2]=0<<9|e>>>23;if((t0(a,g,1)|0)!=0){h=1;p=590;break}e=b<<9;if((s8(c[l>>2]|0,o,c[g>>2]|0,c[g+4>>2]|0,e,0)|0)!=0){h=1;p=592;break}if((n|0)==(b|0)){h=0;p=588;break}else{m=b+m|0;n=n-b|0;o=o+e|0}}if((p|0)==592){i=f;return h|0}else if((p|0)==590){i=f;return h|0}else if((p|0)==588){i=f;return h|0}return 0}function tT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;do{if((b|0)==0){c=bl(a|0,40232|0)|0;if((c|0)!=0){d=0;e=c;break}f=bl(a|0,38240|0)|0;g=1;h=597}else{f=bl(a|0,38240|0)|0;g=b;h=597}}while(0);do{if((h|0)==597){if((f|0)==0){i=0}else{d=g;e=f;break}return i|0}}while(0);f=tP(e,d)|0;if((f|0)==0){au(e|0)|0;i=0;return i|0}else{tm(f,a);i=f;return i|0}return 0}function tU(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=bl(b|0,40232)|0;do{if((d|0)==0){if((c[a>>2]|0)==7){e=c[(c[a+64>>2]|0)+72>>2]|0}else{e=0}f=c[a+28>>2]|0;g=bl(b|0,33048)|0;if((g|0)==0){h=0;return h|0}i=tW(g,f,e)|0;au(g|0)|0;if((i|0)==0){break}else{h=0}return h|0}else{au(d|0)|0}}while(0);d=bl(b|0,40232)|0;do{if((d|0)==0){e=bl(b|0,38240)|0;if((e|0)==0){h=0}else{j=1;k=e;break}return h|0}else{j=0;k=d}}while(0);d=tP(k,j)|0;if((d|0)==0){au(k|0)|0;h=0;return h|0}tm(d,b);k=c[d+64>>2]|0;c[k+68>>2]=a;c[d+16>>2]=8;c[d+20>>2]=12;c[d+24>>2]=c[a+24>>2];j=k+152|0;e=sU(j,16)|0;i=(c[a>>2]|0)==1;sW(j,16,(i?5:1)|e,(i?0:0)|G);i=a+60|0;e=c[i>>2]|0;if((e|0)==0){l=0}else{l=zN(e|0)|0}e=l>>>0>1024?0:l;sV(j,56,64);sV(j,60,e);if((e|0)!=0){l=k+216|0;g=c[i>>2]|0;zO(l|0,g|0,e)|0}e=k+4276|0;if((s8(c[e>>2]|0,j,0,0,4096,0)|0)==0){j=c[e>>2]|0;ax(j|0)|0}te(d,c[a+28>>2]|0,c[a+32>>2]|0,c[a+36>>2]|0,c[a+40>>2]|0)|0;tf(d,c[a+44>>2]|0,c[a+48>>2]|0,c[a+52>>2]|0);tm(d,b);h=d;return h|0}function tV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;if((aP(b|0,30960)|0)!=0){e=1;return e|0}b=c[a+64>>2]|0;a=b+68|0;if((c[a>>2]|0)==0){e=1;return e|0}d=b+128|0;f=c[d>>2]|0;g=f>>>3;h=b+72|0;i=(c[h>>2]|0)>>>9;do{if((g|0)==0){j=f;k=b+4276|0;l=b+4264|0}else{m=b+4264|0;n=ac(i,g)|0;o=b+136|0;p=b+4256|0;q=b+4276|0;r=b+4268|0;s=b+4272|0;t=0;u=0;L777:while(1){v=u<<3;w=sU(c[m>>2]|0,v)|0;x=G;if((w|0)==0&(x|0)==0){y=t+n|0}else{z=w&~c[o>>2];w=x&~c[o+4>>2];if((c[p>>2]|0)==(z|0)&(c[p+4>>2]|0)==(w|0)){A=0;B=t}else{if((s7(c[q>>2]|0,c[r>>2]|0,z,w,c[d>>2]|0,0)|0)!=0){e=1;C=654;break}c[p>>2]=z;c[p+4>>2]=w;A=0;B=t}while(1){w=sU(c[r>>2]|0,A<<3)|0;z=G;if((w|0)==0&(z|0)==0){D=B+i|0}else{if((s7(c[q>>2]|0,c[s>>2]|0,w&~c[o>>2],z&~c[o+4>>2],c[h>>2]|0,0)|0)!=0){e=1;C=652;break L777}z=B+i|0;w=c[a>>2]|0;x=c[w+28>>2]|0;if((tv(w,c[s>>2]|0,B,z>>>0>x>>>0?x-B|0:i)|0)==0){D=z}else{e=1;C=653;break L777}}z=A+1|0;if(z>>>0<g>>>0){A=z;B=D}else{break}}sW(c[m>>2]|0,v,0,0);y=D}z=u+1|0;if(z>>>0<g>>>0){t=y;u=z}else{C=645;break}}if((C|0)==645){j=c[d>>2]|0;k=q;l=m;break}else if((C|0)==652){return e|0}else if((C|0)==653){return e|0}else if((C|0)==654){return e|0}}}while(0);C=b+112|0;if((s8(c[k>>2]|0,c[l>>2]|0,c[C>>2]|0,c[C+4>>2]|0,j,0)|0)!=0){e=1;return e|0}ax(c[k>>2]|0)|0;j=zW(c[d>>2]|0,0,c[C>>2]|0,c[C+4>>2]|0)|0;C=G;d=b+144|0;c[d>>2]=j;c[d+4>>2]=C;tj(c[k>>2]|0,j,C)|0;e=0;return e|0}function tW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b;b=d<<9|0>>>23;e=0<<9|d>>>23;do{if(c>>>0<4097){f=4096}else{if(c>>>0>134217727){f=134217728;break}d=(c<<1)-1|0;while(1){g=d-1&d;if((g|0)==0){f=d;break}else{d=g}}}}while(0);c=f>>>3;d=0;g=c<<1|0>>>31;h=d<<1|c>>>31;i=z4(g,h,g,h)|0;h=f;g=0;j=z4(i,G,h,g)|0;i=G;if(i>>>0<e>>>0|i>>>0==e>>>0&j>>>0<b>>>0){k=2;while(1){l=k<<1;m=z4(l,0,c,d)|0;n=G;o=z4(m,n,m,n)|0;n=z4(o,G,h,g)|0;o=G;if((o>>>0<e>>>0|o>>>0==e>>>0&n>>>0<b>>>0)&l>>>0<16){k=l}else{p=l;q=o;r=n;break}}}else{p=2;q=i;r=j}j=q>>>0<e>>>0|q>>>0==e>>>0&r>>>0<b>>>0;if(j&f>>>0<134217728){r=p;q=0;i=f;while(1){k=i<<1;g=z4(i>>>2&536870911,0,r,q)|0;h=G;d=z4(g,h,k,0)|0;c=z4(d,G,g,h)|0;h=G;g=h>>>0<e>>>0|h>>>0==e>>>0&c>>>0<b>>>0;if(g&k>>>0<134217728){i=k}else{s=k;t=g;break}}}else{s=f;t=j}if(t){u=1;return u|0}t=zH(s)|0;if((t|0)==0){u=1;return u|0}zP(t|0,0,s|0);sV(t,0,4474193);sV(t,4,s);sV(t,8,p);sV(t,12,1);sW(t,16,0,0);sW(t,24,0,0);sW(t,32,0,0);j=s;f=0;sW(t,40,j,f);sW(t,48,b,e);if((s8(a,t,0,0,j,f)|0)!=0){zI(t);u=1;return u|0}zP(t|0,0,s|0);s=p|1;p=1;while(1){if(p>>>0>=s>>>0){v=673;break}e=z4(p,0,j,f)|0;if((s8(a,t,e,G,j,f)|0)==0){p=p+1|0}else{v=672;break}}if((v|0)==672){zI(t);u=1;return u|0}else if((v|0)==673){zI(t);u=0;return u|0}return 0}function tX(a){a=a|0;var b=0,c=0,d=0,e=0;b=i;i=i+8|0;c=bl(a|0,38240)|0;if((c|0)==0){d=0;i=b;return d|0}a=b|0;if((s7(c,a,0,0,4,0)|0)==0){e=(sT(a,0)|0)==4474193|0}else{e=0}au(c|0)|0;d=e;i=b;return d|0}function tY(a,b,c){a=a|0;b=b|0;c=c|0;return c|0}function tZ(a,b){a=a|0;b=b|0;c[b>>2]=1792;return 0}function t_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return 0}function t$(b,d){b=b|0;d=d|0;var e=0,f=0;e=c[b>>2]|0;b=d&1;f=d&2;d=e+348|0;do{if(!((c[e+80>>2]|0)!=0|(f|0)==0|(b|0)==0)){if((a[d]|0)!=0){if((a[e+349|0]|0)!=0){break}}c[e+352>>2]=0;c[e+356>>2]=0;c[e+372>>2]=0;c[e+384>>2]=0;c[e+84>>2]=1;c[e+88>>2]=0;a[e+92|0]=77}}while(0);a[d]=b&255;a[e+349|0]=f>>>1&255;return 0}function t0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0;e=a+72|0;f=c[e>>2]|0;g=ac(f>>>3,c[a+76>>2]|0)|0;h=z5(c[b>>2]|0,c[b+4>>2]|0,f,0)|0;f=G;i=g;j=0;k=z5(h,f,i,j)|0;l=k;k=z6(h,f,i,j)|0;j=k;k=a+4264|0;i=l<<3;f=sU((c[k>>2]|0)+i|0,0)|0;h=G;m=c[b>>2]|0;n=c[b+4>>2]|0;o=a+136|0;p=c[o>>2]|0;q=c[o+4>>2]|0;r=p&m;s=q&n;if(l>>>0>=g>>>0){t=1;return t|0}if((f|0)==0&(h|0)==0){if((d|0)==0){c[b>>2]=0;c[b+4>>2]=0;t=0;return t|0}g=a+144|0;l=a+128|0;u=zW(c[l>>2]|0,0,c[g>>2]|0,c[g+4>>2]|0)|0;v=G;w=a+68|0;x=c[w>>2]|0;do{if((x|0)==0){zP(c[a+4272>>2]|0,0,c[e>>2]|0)}else{y=((p^-512)&m)>>>9|((q^511)&n)<<23;z=c[e>>2]|0;A=z>>>9;B=a+4272|0;if((A+y|0)>>>0>(c[x+28>>2]|0)>>>0){zP(c[B>>2]|0,0,z|0);z=c[w>>2]|0;C=(c[z+28>>2]|0)-y|0;D=z}else{C=A;D=x}if((tt(D,c[B>>2]|0,y,C)|0)==0){break}else{t=1}return t|0}}while(0);C=a+4276|0;if((s8(c[C>>2]|0,c[a+4272>>2]|0,u,v,c[e>>2]|0,0)|0)!=0){t=1;return t|0}D=a+4268|0;zP(c[D>>2]|0,0,c[l>>2]|0);sW((c[D>>2]|0)+(j<<3)|0,0,u,v);x=c[g>>2]|0;w=c[g+4>>2]|0;if((s8(c[C>>2]|0,c[D>>2]|0,x,w,c[l>>2]|0,0)|0)!=0){t=1;return t|0}D=c[C>>2]|0;ax(D|0)|0;D=a+4256|0;c[D>>2]=x;c[D+4>>2]=w;sW((c[k>>2]|0)+i|0,0,c[g>>2]|0,c[g+4>>2]|0);i=a+112|0;if((s8(c[C>>2]|0,c[k>>2]|0,c[i>>2]|0,c[i+4>>2]|0,c[l>>2]|0,0)|0)!=0){t=1;return t|0}l=c[C>>2]|0;ax(l|0)|0;l=zW(u,v,r|0,s&0)|0;c[b>>2]=l;c[b+4>>2]=G;l=zW(c[e>>2]|0,0,u,v)|0;c[g>>2]=l;c[g+4>>2]=G;t=0;return t|0}g=f&~p;p=h&~q;q=a+4256|0;do{if((c[q>>2]|0)==(g|0)&(c[q+4>>2]|0)==(p|0)){E=a+4268|0}else{h=a+4268|0;if((s7(c[a+4276>>2]|0,c[h>>2]|0,g,p,c[a+128>>2]|0,0)|0)==0){c[q>>2]=g;c[q+4>>2]=p;E=h;break}else{t=1;return t|0}}}while(0);h=j<<3;j=sU((c[E>>2]|0)+h|0,0)|0;f=G;if(!((j|0)==0&(f|0)==0)){l=zW(j&~c[o>>2],f&~c[o+4>>2],r|0,s&0)|0;c[b>>2]=l;c[b+4>>2]=G;t=0;return t|0}if((d|0)==0){c[b>>2]=0;c[b+4>>2]=0;t=0;return t|0}d=a+68|0;l=c[d>>2]|0;do{if((l|0)==0){zP(c[a+4272>>2]|0,0,c[e>>2]|0)}else{f=((c[o>>2]^-512)&c[b>>2])>>>9|((c[o+4>>2]^511)&c[b+4>>2])<<23;j=c[e>>2]|0;v=j>>>9;u=a+4272|0;if((f+v|0)>>>0>(c[l+28>>2]|0)>>>0){zP(c[u>>2]|0,0,j|0);j=c[d>>2]|0;F=(c[j+28>>2]|0)-f|0;H=j}else{F=v;H=l}if((tt(H,c[u>>2]|0,f,F)|0)==0){break}else{t=1}return t|0}}while(0);F=a+4276|0;H=a+144|0;if((s8(c[F>>2]|0,c[a+4272>>2]|0,c[H>>2]|0,c[H+4>>2]|0,c[e>>2]|0,0)|0)!=0){t=1;return t|0}sW((c[E>>2]|0)+h|0,0,c[H>>2]|0,c[H+4>>2]|0);if((s8(c[F>>2]|0,c[E>>2]|0,g,p,c[a+128>>2]|0,0)|0)!=0){t=1;return t|0}ax(c[F>>2]|0)|0;c[q>>2]=g;c[q+4>>2]=p;p=zW(c[H>>2]|0,c[H+4>>2]|0,r|0,s&0)|0;c[b>>2]=p;c[b+4>>2]=G;b=zW(c[H>>2]|0,c[H+4>>2]|0,c[e>>2]|0,0)|0;c[H>>2]=b;c[H+4>>2]=G;t=0;return t|0}function t1(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+8|0;g=f|0;if((ti(a,g)|0)!=0){h=0;i=f;return h|0}j=c[g>>2]|0;k=c[g+4>>2]|0;if(!(k>>>0>d>>>0|k>>>0==d>>>0&j>>>0>b>>>0)){h=0;i=f;return h|0}l=zX(j,k,b,d)|0;k=G;j=l>>>9|k<<23;l=k>>>9|0<<23;c[g>>2]=j;c[g+4>>2]=l;if((j|0)==0&(l|0)==0){h=0;i=f;return h|0}l=zH(80)|0;if((l|0)==0){h=0;i=f;return h|0}g=l;tk(g,l,j,0,0,0);tb(g,1);td(g,e);c[l+4>>2]=50;c[l+8>>2]=12;c[l+12>>2]=18;e=l+72|0;c[e>>2]=b;c[e+4>>2]=d;c[l+68>>2]=a;tn(g)|0;h=g;i=f;return h|0}function t2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;do{if((d|0)==0){e=bl(a|0,40216|0)|0;if((e|0)!=0){f=0;g=e;break}h=bl(a|0,38144|0)|0;i=1;j=754}else{h=bl(a|0,38144|0)|0;i=d;j=754}}while(0);do{if((j|0)==754){if((h|0)==0){k=0}else{f=i;g=h;break}return k|0}}while(0);h=t1(g,b,c,f)|0;if((h|0)==0){au(g|0)|0;k=0;return k|0}else{tm(h,a);k=h;return k|0}return 0}function t3(a){a=a|0;var b=0;b=c[a+64>>2]|0;au(c[b+68>>2]|0)|0;zI(b);return}function t4(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;if((e+d|0)>>>0>(c[a+28>>2]|0)>>>0){f=1;return f|0}g=c[a+64>>2]|0;a=g+72|0;h=d;d=zW(c[a>>2]|0,c[a+4>>2]|0,h<<9|0>>>23,0<<9|h>>>23)|0;h=e;f=(s7(c[g+68>>2]|0,b,d,G,h<<9|0>>>23,0<<9|h>>>23)|0)!=0|0;return f|0}function t5(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((a[b+56|0]|0)!=0){g=1;return g|0}if((f+e|0)>>>0>(c[b+28>>2]|0)>>>0){g=1;return g|0}h=c[b+64>>2]|0;b=h+72|0;i=e;e=zW(c[b>>2]|0,c[b+4>>2]|0,i<<9|0>>>23,0<<9|i>>>23)|0;i=f;f=h+68|0;if((s8(c[f>>2]|0,d,e,G,i<<9|0>>>23,0<<9|i>>>23)|0)!=0){g=1;return g|0}ax(c[f>>2]|0)|0;g=0;return g|0}function t6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((c[11084]|0)==0){return}else{e=0}do{f=c[44344+(e<<2)>>2]|0;g=f+360|0;h=c[g>>2]|0;i=ac(c[f+364>>2]|0,a)|0;j=f+372|0;k=i+(c[j>>2]|0)|0;i=c[f+368>>2]|0;l=(k|0)/(i|0)|0;c[j>>2]=k-(ac(l,i)|0);i=ac(c[f+376>>2]|0,b)|0;k=f+384|0;j=i+(c[k>>2]|0)|0;i=c[f+380>>2]|0;m=(j|0)/(i|0)|0;c[k>>2]=j-(ac(m,i)|0);i=f+352|0;c[i>>2]=(c[i>>2]|0)+l;l=f+356|0;c[l>>2]=(c[l>>2]|0)+m;c[g>>2]=d;if(((h^d)&3|0)!=0){uf(f)}e=e+1|0;}while(e>>>0<(c[11084]|0)>>>0);return}function t7(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=zH(388)|0;if((d|0)==0){e=0;return e|0}f=d;g=d;ui(g,d);c[d+56>>2]=4;c[d+60>>2]=22;c[d+64>>2]=46;c[d+68>>2]=110;c[d+72>>2]=122;c[d+76>>2]=2;h=d+80|0;c[h>>2]=0;c[d+84>>2]=0;c[d+88>>2]=0;a[d+348|0]=0;a[d+349|0]=0;c[d+352>>2]=0;c[d+356>>2]=0;c[d+360>>2]=0;i=wp(b,38120)|0;if((i|0)!=0){do{if((aP(i|0,40200)|0)==0){j=0}else{if((aP(i|0,33040)|0)==0){j=1;break}zI(i);zI(d);e=0;return e|0}}while(0);c[h>>2]=j;zI(i)}c[d+364>>2]=ww(b,30952,1)|0;i=ww(b,28872,1)|0;j=d+368|0;c[j>>2]=i;c[d+372>>2]=0;if((i|0)==0){c[j>>2]=1}c[d+376>>2]=ww(b,27160,1)|0;j=ww(b,25584,1)|0;b=d+380|0;c[b>>2]=j;c[d+384>>2]=0;if((j|0)==0){c[b>>2]=1}b=c[11084]|0;j=b+1|0;if(j>>>0>=8){e=g;return e|0}c[11084]=j;c[44344+(b<<2)>>2]=f;e=g;return e|0}function t8(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a>>2]|0;a=b;d=c[11084]|0;if((d|0)==0){e=0;c[11084]=e;zI(b);return}else{f=0;g=0}while(1){h=c[44344+(g<<2)>>2]|0;if((h|0)==(a|0)){i=f}else{c[44344+(f<<2)>>2]=h;i=f+1|0}h=g+1|0;if(h>>>0<d>>>0){f=i;g=h}else{e=i;break}}c[11084]=e;zI(b);return}function t9(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=c[b>>2]|0;b=f;g=f+84|0;h=c[g>>2]|0;i=f+88|0;j=c[i>>2]|0;if((h|0)==(j|0)){do{if((c[f+352>>2]|0)==0){if((c[f+356>>2]|0)==0){k=0}else{break}return k|0}}while(0);uf(b);l=c[g>>2]|0;m=c[i>>2]|0}else{l=h;m=j}if((l|0)==(m|0)){k=0;return k|0}j=l-m&255;l=j>>>0>e>>>0?e:j;if((l|0)==0){k=0;return k|0}else{n=0;o=m}while(1){a[d+n|0]=a[f+(o+92)|0]|0;m=(c[i>>2]|0)+1&255;c[i>>2]=m;j=n+1|0;if(j>>>0<l>>>0){n=j;o=m}else{k=l;break}}return k|0}function ua(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function ub(a,b,c){a=a|0;b=b|0;c=c|0;return c|0}function uc(a,b){a=a|0;b=b|0;c[b>>2]=1792;return 0}function ud(a,b){a=a|0;b=b|0;return 0}function ue(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return 0}function uf(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[b+80>>2]|0;if((d|0)==1){e=b+84|0;f=c[e>>2]|0;if((256-(f-(c[b+88>>2]|0)&255)|0)>>>0<5){return}g=c[b+360>>2]|0;h=g>>>1;a[b+92+f|0]=((h&1|g<<2&4|h&2)^135)&255;h=(c[e>>2]|0)+1&255;c[e>>2]=h;g=b+352|0;f=b+356|0;i=c[g>>2]|0;if((i|0)<-127){j=-127}else{j=(i|0)>127?127:i}c[g>>2]=i-j;a[b+92+h|0]=j&255;j=(c[e>>2]|0)+1&255;c[e>>2]=j;h=c[f>>2]|0;if((h|0)<-127){k=-127}else{k=(h|0)>127?127:h}c[f>>2]=h-k;a[b+92+j|0]=-k&255;k=(c[e>>2]|0)+1&255;c[e>>2]=k;j=c[g>>2]|0;if((j|0)<-127){l=-127}else{l=(j|0)>127?127:j}c[g>>2]=j-l;a[b+92+k|0]=l&255;l=(c[e>>2]|0)+1&255;c[e>>2]=l;k=c[f>>2]|0;if((k|0)<-127){m=-127}else{m=(k|0)>127?127:k}c[f>>2]=k-m;a[b+92+l|0]=-m&255;c[e>>2]=(c[e>>2]|0)+1&255;return}else if((d|0)==0){d=b+84|0;e=c[d>>2]|0;if((256-(e-(c[b+88>>2]|0)&255)|0)>>>0<3){return}m=b+352|0;l=c[m>>2]|0;if((l|0)<-127){n=-127}else{n=(l|0)>127?127:l}c[m>>2]=l-n;l=b+356|0;m=c[l>>2]|0;if((m|0)<-127){o=-127}else{o=(m|0)>127?127:m}c[l>>2]=m-o;m=c[b+360>>2]|0;a[b+92+e|0]=(n>>>6&3|o>>>4&12|m<<3&16|m<<5&32|64)&255;m=(c[d>>2]|0)+1&255;c[d>>2]=m;a[b+92+m|0]=n&63;n=(c[d>>2]|0)+1&255;c[d>>2]=n;a[b+92+n|0]=o&63;c[d>>2]=(c[d>>2]|0)+1&255;return}else{return}}function ug(a,b){a=a|0;b=b|0;var d=0;d=a+52|0;if((c[d>>2]|0)!=0){uh(a);a=c[d>>2]|0;au(a|0)|0}a=bl(b|0,25576)|0;c[d>>2]=a;return(a|0)==0|0}function uh(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;f=b+28|0;g=c[f>>2]|0;h=b+48|0;if((g|0)==0){c[f>>2]=0;c[h>>2]=0;i=e;return}j=b+52|0;k=(c[h>>2]|0)!=0?33192:32480;l=g;g=b+32|0;while(1){b=l>>>0<16;m=b?l:16;n=d[g]|0;bN(c[j>>2]|0,33608,(x=i,i=i+16|0,c[x>>2]=k,c[x+8>>2]=n,x)|0)|0;if(m>>>0>1){n=1;do{bN(c[j>>2]|0,32224,(x=i,i=i+8|0,c[x>>2]=d[g+n|0]|0,x)|0)|0;n=n+1|0;}while(n>>>0<m>>>0)}n=c[j>>2]|0;if(b){o=m;p=n;while(1){aB(32032,3,1,p|0)|0;q=o+1|0;r=c[j>>2]|0;if(q>>>0<16){o=q;p=r}else{s=r;break}}}else{s=n}aB(31872,2,1,s|0)|0;if((m|0)!=0){p=0;do{o=a[g+p|0]|0;aA(((o-32&255)>94?46:o&255)|0,c[j>>2]|0)|0;p=p+1|0;}while(p>>>0<m>>>0)}aA(10,c[j>>2]|0)|0;if((l|0)==(m|0)){break}else{l=l-m|0;g=g+m|0}}ax(c[j>>2]|0)|0;c[f>>2]=0;c[h>>2]=0;i=e;return}function ui(a,b){a=a|0;b=b|0;c[a>>2]=b;zP(a+4|0,0,28);zP(a+48|0,0,32);return}function uj(a){a=a|0;var b=0,d=0;if((a|0)==0){return}b=a+52|0;if((c[b>>2]|0)!=0){uh(a);d=c[b>>2]|0;au(d|0)|0}d=c[a+56>>2]|0;if((d|0)==0){return}b2[d&255](a);return}function uk(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a|0)==0){e=0;return e|0}f=c[a+60>>2]|0;if((f|0)==0){e=0;return e|0}g=b4[f&127](a,b,d)|0;if((c[a+52>>2]|0)==0|(g|0)==0){e=g;return e|0}d=a+28|0;f=a+48|0;do{if((c[d>>2]|0)!=0){if((c[f>>2]|0)==0){break}uh(a)}}while(0);h=b;b=g;while(1){i=c[d>>2]|0;j=16-i|0;k=b>>>0<j>>>0?b:j;j=a+32+i|0;zO(j|0,h|0,k)|0;j=k+(c[d>>2]|0)|0;c[d>>2]=j;c[f>>2]=0;if(j>>>0>15){uh(a)}if((b|0)==(k|0)){e=g;break}h=h+k|0;b=b-k|0}return e|0}function ul(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a|0)==0){e=d;return e|0}f=c[a+64>>2]|0;if((f|0)==0){e=d;return e|0}g=b4[f&127](a,b,d)|0;if((c[a+52>>2]|0)==0|(g|0)==0){e=g;return e|0}d=a+28|0;f=a+48|0;do{if((c[d>>2]|0)!=0){if((c[f>>2]|0)==1){break}uh(a)}}while(0);h=b;b=g;while(1){i=c[d>>2]|0;j=16-i|0;k=b>>>0<j>>>0?b:j;j=a+32+i|0;zO(j|0,h|0,k)|0;j=k+(c[d>>2]|0)|0;c[d>>2]=j;c[f>>2]=1;if(j>>>0>15){uh(a)}if((b|0)==(k|0)){e=g;break}h=h+k|0;b=b-k|0}return e|0}function um(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a|0)==0){d=1;return d|0}e=c[a+68>>2]|0;do{if((e|0)==0){c[b>>2]=1024;f=a+24|0;g=c[f>>2]|0;if((g&1|0)==0){h=g;i=1024}else{c[b>>2]=1280;h=c[f>>2]|0;i=1280}if((h&2|0)==0){j=i;break}f=i|512;c[b>>2]=f;j=f}else{if((b8[e&255](a,b)|0)==0){j=c[b>>2]|0;break}else{d=1;return d|0}}}while(0);e=a+20|0;un(a,c[e>>2]|0,j);c[e>>2]=c[b>>2];d=0;return d|0}function un(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=a+52|0;if((c[f>>2]|0)==0|(b|0)==(d|0)){i=e;return}uh(a);a=d^b;if((a&512|0)!=0){b=c[f>>2]|0;g=d>>>9&1;bN(b|0,34e3,(x=i,i=i+16|0,c[x>>2]=38008,c[x+8>>2]=g,x)|0)|0}if((a&1|0)!=0){g=c[f>>2]|0;b=d&1;bN(g|0,34e3,(x=i,i=i+16|0,c[x>>2]=37112,c[x+8>>2]=b,x)|0)|0}if((a&2|0)!=0){b=c[f>>2]|0;g=d>>>1&1;bN(b|0,34e3,(x=i,i=i+16|0,c[x>>2]=35152,c[x+8>>2]=g,x)|0)|0}if((a&256|0)!=0){g=c[f>>2]|0;b=d>>>8&1;bN(g|0,34e3,(x=i,i=i+16|0,c[x>>2]=34736,c[x+8>>2]=b,x)|0)|0}if((a&1024|0)!=0){b=c[f>>2]|0;g=d>>>10&1;bN(b|0,34e3,(x=i,i=i+16|0,c[x>>2]=34472,c[x+8>>2]=g,x)|0)|0}if((a&2048|0)==0){i=e;return}bN(c[f>>2]|0,34e3,(x=i,i=i+16|0,c[x>>2]=34208,c[x+8>>2]=d>>>11&1,x)|0)|0;i=e;return}function uo(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if((a|0)==0){d=1}else{e=a+24|0;f=c[e>>2]|0;if((f|0)==(b|0)){d=0;break}un(a,f,b);c[e>>2]=b;e=c[a+72>>2]|0;if((e|0)==0){d=0;break}d=b8[e&255](a,b)|0}}while(0);return d|0}function up(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;if((a|0)==0){h=1;i=g;return h|0}j=a+4|0;k=a+8|0;do{if((c[j>>2]|0)==(b|0)){if((c[k>>2]|0)!=(d|0)){break}if((c[a+12>>2]|0)!=(e|0)){break}if((c[a+16>>2]|0)==(f|0)){h=0}else{break}i=g;return h|0}}while(0);c[j>>2]=b;c[k>>2]=d;l=a+12|0;c[l>>2]=e;m=a+16|0;c[m>>2]=f;n=a+52|0;if((c[n>>2]|0)!=0){uh(a);o=c[l>>2]|0;if((o|0)==0){p=22776}else if((o|0)==1){p=21616}else if((o|0)==2){p=41680}else{p=40624}o=c[n>>2]|0;l=c[j>>2]|0;j=c[k>>2]|0;k=c[m>>2]|0;bN(o|0,39040,(x=i,i=i+32|0,c[x>>2]=l,c[x+8>>2]=j,c[x+16>>2]=p,c[x+24>>2]=k,x)|0)|0;k=c[n>>2]|0;ax(k|0)|0}k=c[a+76>>2]|0;if((k|0)==0){h=1;i=g;return h|0}h=b9[k&7](a,b,d,e,f)|0;i=g;return h|0}function uq(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[3602]|0;if((d|0)==0){e=0;return e|0}else{f=0;g=d}while(1){d=a[g]|0;L1203:do{if(d<<24>>24==0){h=b;i=964}else{j=b;k=g;l=d;while(1){if(l<<24>>24!=(a[j]|0)){break}m=k+1|0;n=j+1|0;o=a[m]|0;if(o<<24>>24==0){h=n;i=964;break L1203}else{j=n;k=m;l=o}}if(l<<24>>24==0){h=j;i=964}}}while(0);if((i|0)==964){i=0;d=a[h]|0;if((d<<24>>24|0)==58|(d<<24>>24|0)==0){break}}d=f+1|0;k=c[14408+(d<<3)>>2]|0;if((k|0)==0){e=0;i=973;break}else{f=d;g=k}}if((i|0)==973){return e|0}i=b1[c[14412+(f<<3)>>2]&1023](b)|0;if((i|0)==0){e=0;return e|0}f=wp(b,24376)|0;if((f|0)==0){e=i;return e|0}b=i+52|0;if((c[b>>2]|0)!=0){uh(i);g=c[b>>2]|0;au(g|0)|0}c[b>>2]=bl(f|0,25576)|0;zI(f);e=i;return e|0}function ur(a){a=a|0;var b=0,d=0;a=zH(80)|0;if((a|0)==0){b=0;return b|0}d=a;ui(d,a);c[a+56>>2]=42;c[a+60>>2]=42;c[a+64>>2]=90;c[a+68>>2]=42;c[a+72>>2]=96;c[a+76>>2]=4;b=d;return b|0}function us(a){a=a|0;zI(c[a>>2]|0);return}function ut(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function uu(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;d=zH(100)|0;if((d|0)==0){e=0;i=b;return e|0}f=d;ui(f,d);c[d+56>>2]=20;c[d+60>>2]=68;c[d+64>>2]=86;g=d+80|0;c[g>>2]=0;h=d+84|0;c[h>>2]=0;j=d+88|0;c[j>>2]=0;k=d+92|0;c[k>>2]=-1;l=d+96|0;c[l>>2]=-1;d=wp(a,37480)|0;c[g>>2]=d;L1235:do{if((d|0)==0){c[h>>2]=wp(a,40160)|0;m=wp(a,33008)|0;c[j>>2]=m;n=c[g>>2]|0;if((n|0)!=0){o=n;p=987;break}n=c[h>>2]|0;do{if((n|0)==0){if((m|0)!=0){q=m;break}if((aQ(a|0,27144,6)|0)!=0){e=f;i=b;return e|0}c[k>>2]=0;c[l>>2]=1;e=f;i=b;return e|0}else{if((aP(n|0,30936)|0)==0){c[k>>2]=0;r=m}else{s=bm(n|0,32768,(x=i,i=i+8|0,c[x>>2]=0,x)|0)|0;c[k>>2]=s;if((s|0)<0){break L1235}r=c[j>>2]|0}if((r|0)==0){e=f}else{q=r;break}i=b;return e|0}}while(0);if((aP(q|0,30936)|0)==0){c[l>>2]=1;e=f;i=b;return e|0}if((aP(q|0,28856)|0)==0){c[l>>2]=2;e=f;i=b;return e|0}else{n=bm(q|0,34305,(x=i,i=i+8|0,c[x>>2]=420,x)|0)|0;c[l>>2]=n;if((n|0)<0){break}else{e=f}i=b;return e|0}}else{o=d;p=987}}while(0);do{if((p|0)==987){if((aP(o|0,30936)|0)==0){c[k>>2]=0;c[l>>2]=1;e=f;i=b;return e|0}if((aP(o|0,28856)|0)==0){c[k>>2]=0;c[l>>2]=2;e=f;i=b;return e|0}d=bm(o|0,34306,(x=i,i=i+8|0,c[x>>2]=420,x)|0)|0;c[k>>2]=d;if((d|0)<0){break}c[l>>2]=d;e=f;i=b;return e|0}}while(0);uv(f);e=0;i=b;return e|0}function uv(a){a=a|0;var b=0,d=0;b=c[a>>2]|0;a=b+96|0;d=c[a>>2]|0;if((d|0)>2){aU(d|0)|0}d=c[b+92>>2]|0;do{if((d|0)>2){if((d|0)==(c[a>>2]|0)){break}aU(d|0)|0}}while(0);d=c[b+88>>2]|0;if((d|0)!=0){zI(d)}d=c[b+84>>2]|0;if((d|0)!=0){zI(d)}d=c[b+80>>2]|0;if((d|0)==0){zI(b);return}zI(d);zI(b);return}function uw(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+8|0;g=f|0;h=(c[a>>2]|0)+92|0;a=c[h>>2]|0;if((a|0)<0){i=f;return 0}c[g>>2]=a;b[g+4>>1]=1;if((aY(g|0,1,0)|0)<0){i=f;return 0}if((b[g+6>>1]&3)==0){i=f;return 0}else{g=aJ(c[h>>2]|0,d|0,((e|0)<0?2147483647:e)|0)|0;i=f;return((g|0)>0?g:0)|0}return 0}function ux(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;h=(c[a>>2]|0)+96|0;a=c[h>>2]|0;if((a|0)<0){j=e;i=f;return j|0}c[g>>2]=a;b[g+4>>1]=2;if((aY(g|0,1,0)|0)<0){j=0;i=f;return j|0}if((b[g+6>>1]&3)==0){j=0;i=f;return j|0}else{j=bT(c[h>>2]|0,d|0,((e|0)<0?2147483647:e)|0)|0;i=f;return((j|0)>0?j:0)|0}return 0}function uy(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+48|0;d=b|0;e=zH(92)|0;if((e|0)==0){f=0;i=b;return f|0}g=e;ui(g,e);c[e+56>>2]=118;c[e+60>>2]=94;c[e+64>>2]=96;h=e+84|0;c[h>>2]=0;j=e+88|0;c[j>>2]=wp(a,37432)|0;a=bQ(32770)|0;k=e+80|0;c[k>>2]=a;do{if((a|0)>=0){if((a_(a|0)|0)!=0){break}if((bi(a|0)|0)!=0){break}l=aC(a|0)|0;m=l;if((l|0)==0){break}if((zN(m|0)|0)>>>0>255){break}l=bu(m|0)|0;c[h>>2]=l;m=c[q>>2]|0;bN(m|0,32960,(x=i,i=i+8|0,c[x>>2]=l,x)|0)|0;l=c[k>>2]|0;m=a2(l|0,1,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0)|0;if((m|0)!=-1){n=m|16384;a2(l|0,4,(x=i,i=i+8|0,c[x>>2]=n,x)|0)|0}n=c[k>>2]|0;do{if((aX(n|0,d|0)|0)==0){l=d|0;c[l>>2]=c[l>>2]&-449;l=d+12|0;c[l>>2]=c[l>>2]&-11;if((aV(n|0,0,d|0)|0)!=0){break}aE(n|0,3)|0}}while(0);n=c[j>>2]|0;if((n|0)==0){f=g;i=b;return f|0}if((a6(c[h>>2]|0,n|0)|0)==0){f=g;i=b;return f|0}n=c[q>>2]|0;l=c[h>>2]|0;m=c[j>>2]|0;bN(n|0,40120,(x=i,i=i+16|0,c[x>>2]=l,c[x+8>>2]=m,x)|0)|0;f=g;i=b;return f|0}}while(0);g=c[e>>2]|0;e=g+88|0;j=c[e>>2]|0;if((j|0)!=0){bZ(j|0)|0;zI(c[e>>2]|0)}e=c[g+84>>2]|0;if((e|0)!=0){zI(e)}e=c[g+80>>2]|0;if((e|0)>-1){aU(e|0)|0}zI(g);f=0;i=b;return f|0}function uz(a){a=a|0;var b=0,d=0;b=c[a>>2]|0;a=b+88|0;d=c[a>>2]|0;if((d|0)!=0){bZ(d|0)|0;zI(c[a>>2]|0)}a=c[b+84>>2]|0;if((a|0)!=0){zI(a)}a=c[b+80>>2]|0;if((a|0)<=-1){zI(b);return}aU(a|0)|0;zI(b);return}function uA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=c[(c[a>>2]|0)+80>>2]|0;if((e|0)<0){return 0}else{a=aJ(e|0,b|0,((d|0)<0?2147483647:d)|0)|0;return((a|0)>0?a:0)|0}return 0}function uB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=c[(c[a>>2]|0)+80>>2]|0;if((e|0)<0){return d|0}else{a=bT(e|0,b|0,((d|0)<0?2147483647:d)|0)|0;return((a|0)>0?a:0)|0}return 0}function uC(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=zH(92)|0;if((b|0)==0){d=0;return d|0}e=b;ui(e,b);c[b+56>>2]=122;c[b+60>>2]=4;c[b+64>>2]=16;f=b+88|0;c[f>>2]=0;g=b+80|0;c[g>>2]=wp(a,37400)|0;c[b+84>>2]=wq(a,40112,1)|0;a=c[g>>2]|0;if((a|0)==0){d=e;return d|0}if((aP(a|0,32952)|0)==0){c[f>>2]=c[o>>2];d=e;return d|0}g=bl(a|0,30920)|0;c[f>>2]=g;if((g|0)!=0){d=e;return d|0}e=c[b>>2]|0;b=c[e+80>>2]|0;if((b|0)!=0){zI(b)}b=c[e+88>>2]|0;if(!((b|0)==0|(b|0)==(c[p>>2]|0)|(b|0)==(c[o>>2]|0)|(b|0)==(c[q>>2]|0))){au(b|0)|0}zI(e);d=0;return d|0}function uD(a){a=a|0;var b=0;b=c[a>>2]|0;a=c[b+80>>2]|0;if((a|0)!=0){zI(a)}a=c[b+88>>2]|0;if((a|0)==0|(a|0)==(c[p>>2]|0)|(a|0)==(c[o>>2]|0)|(a|0)==(c[q>>2]|0)){zI(b);return}au(a|0)|0;zI(b);return}function uE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=c[a>>2]|0;a=e+88|0;f=c[a>>2]|0;if((f|0)==0){g=d;return g|0}h=aB(b|0,1,d|0,f|0)|0;if((c[e+84>>2]|0)==0){g=h;return g|0}ax(c[a>>2]|0)|0;g=h;return g|0}function uF(b){b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=44496;d=0;while(1){e=b+d|0;f=a[e]|0;if((f<<24>>24|0)==46){g=e}else if((f<<24>>24|0)==0){break}else{g=c}c=g;d=d+1|0}do{if((zV(c|0,40104)|0)==0){h=1}else{if((zV(c|0,32944)|0)==0){h=2;break}if((zV(c|0,30912)|0)==0){h=3;break}if((zV(c|0,28848)|0)==0){h=10;break}if((zV(c|0,27136)|0)==0){h=4;break}if((zV(c|0,25568)|0)==0){h=10;break}if((zV(c|0,24368)|0)==0){h=10;break}if((zV(c|0,22768)|0)==0){h=11;break}if((zV(c|0,21608)|0)==0){h=12;break}h=(zV(c|0,41672)|0)==0?13:5}}while(0);return h|0}function uG(a,b){a=a|0;b=b|0;var c=0;if((b|0)==1){c=vc(a)|0}else if((b|0)==3){c=vg(a)|0}else if((b|0)==4){c=vl(a)|0}else if((b|0)==10){c=vF(a)|0}else if((b|0)==12){c=vM(a)|0}else if((b|0)==5|(b|0)==6|(b|0)==7|(b|0)==8|(b|0)==9){c=vo(a)|0}else if((b|0)==11){c=vJ(a)|0}else if((b|0)==2){c=vf(a)|0}else if((b|0)==13){c=vX(a)|0}else{c=0}return c|0}function uH(a){a=a|0;var b=0,c=0,d=0;b=bl(a|0,40616)|0;if((b|0)==0){c=0;return c|0}do{if((vq(b)|0)==0){if((vO(b)|0)!=0){d=12;break}if((vn(b)|0)!=0){d=4;break}if((vi(b)|0)!=0){d=3;break}d=(vH(b)|0)==0?0:10}else{d=5}}while(0);au(b|0)|0;c=d;return c|0}function uI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((c|0)==3){d=vh(a,b)|0}else if((c|0)==6){d=vp(a,b,0)|0}else if((c|0)==12){d=vN(a,b)|0}else if((c|0)==1){d=vd(a,b)|0}else if((c|0)==5){d=vp(a,b,-1)|0}else if((c|0)==8){d=vp(a,b,2)|0}else if((c|0)==13){d=vY(a,b)|0}else if((c|0)==10){d=vG(a,b)|0}else if((c|0)==2){d=ve(a,b)|0}else if((c|0)==9){d=vp(a,b,4)|0}else if((c|0)==4){d=vm(a,b)|0}else if((c|0)==7){d=vp(a,b,1)|0}else{d=1}return d|0}function uJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if((c|0)==0){d=uF(a)|0}else{d=c}c=bl(a|0,39024|0)|0;if((c|0)==0){e=1;return e|0}a=uI(c,b,d)|0;au(c|0)|0;e=a;return e|0}function uK(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;do{e=d|0;d=c[e>>2]|0;}while((d|0)!=0);c[e>>2]=b;return}function uL(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;L1474:do{if((b|0)==0){d=a}else{e=a;f=b;while(1){if((e|0)==0){d=0;break L1474}g=c[e>>2]|0;h=f-1|0;if((h|0)==0){d=g;break}else{e=g;f=h}}}}while(0);return d|0}function uM(d,f){d=d|0;f=f|0;var g=0,h=0;g=d+10|0;if((b[g>>1]|0)==0){return}h=f&255;f=d+24|0;d=0;do{a[(c[f>>2]|0)+d|0]=h;d=d+1|0;}while(d>>>0<(e[g>>1]|0)>>>0);return}function uN(b){b=b|0;var d=0,f=0,g=0,h=0,i=0;d=b+24|0;f=e[b+10>>1]|0;b=1;while(1){if(b>>>0>=f>>>0){g=1;h=1197;break}i=c[d>>2]|0;if((a[i]|0)==(a[i+b|0]|0)){b=b+1|0}else{g=0;h=1196;break}}if((h|0)==1197){return g|0}else if((h|0)==1196){return g|0}return 0}function uO(a,b,d){a=a|0;b=b|0;d=d|0;if((d|0)==0){d=a+12|0;c[d>>2]=c[d>>2]&~b;return}else{d=a+12|0;c[d>>2]=c[d>>2]|b;return}}function uP(a,d){a=a|0;d=d|0;var e=0;if((a|0)==0){return}e=d&65535;d=a;do{b[d+16>>1]=e;d=c[d>>2]|0;}while((d|0)!=0);return}function uQ(b,c){b=b|0;c=c|0;a[b+46|0]=1;a[b+47|0]=c;return}function uR(b){b=b|0;var c=0,f=0;if((a[b+46|0]|0)!=0){c=d[b+47|0]|0;return c|0}f=e[b+10>>1]|0;b=0;while(1){if((128<<b|0)<(f|0)){b=b+1|0}else{c=b;break}}return c|0}function uS(b,c){b=b|0;c=c|0;a[b+48|0]=1;a[b+49|0]=c;return}function uT(b){b=b|0;var c=0;if((a[b+48|0]|0)==0){c=0;return c|0}c=d[b+49|0]|0;return c|0}function uU(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0;f=e>>>0>16?16:e;b[c+28>>1]=f&65535;if((f|0)==0){return f|0}else{g=0}do{a[c+30+g|0]=a[d+g|0]|0;g=g+1|0;}while(g>>>0<f>>>0);return f|0}function uV(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=b[a+2>>1]|0;h=g&65535;if(g<<16>>16==0){i=0;return i|0}if((f|0)!=0){if(h>>>0<=d>>>0){i=0;return i|0}i=c[(c[a+4>>2]|0)+(d<<2)>>2]|0;return i|0}f=a+4|0;a=0;j=d;d=g;L1538:while(1){k=c[f>>2]|0;l=d&65535;m=0;n=0;o=0;while(1){p=b[(c[k+(m<<2)>>2]|0)+8>>1]|0;do{if((p&65535)>>>0<a>>>0){q=o;r=n}else{if((o|0)==0){q=1;r=m;break}s=b[(c[k+(n<<2)>>2]|0)+8>>1]|0;if((p&65535)<(s&65535)){q=1;r=m;break}q=(p<<16>>16==s<<16>>16)+o|0;r=n}}while(0);p=m+1|0;if(p>>>0<l>>>0){m=p;n=r;o=q}else{break}}if((q|0)==0){i=0;t=1252;break}do{if(j>>>0<q>>>0){if(d<<16>>16==0){u=j;v=0;break}o=c[f>>2]|0;n=b[(c[o+(r<<2)>>2]|0)+8>>1]|0;m=j;l=0;while(1){k=c[o+(l<<2)>>2]|0;if((b[k+8>>1]|0)==n<<16>>16){if((m|0)==0){i=k;t=1254;break L1538}w=m-1|0}else{w=m}k=l+1|0;if(k>>>0<h>>>0){m=w;l=k}else{u=w;v=g;break}}}else{u=j-q|0;v=d}}while(0);a=(e[(c[(c[f>>2]|0)+(r<<2)>>2]|0)+8>>1]|0)+1|0;j=u;d=v}if((t|0)==1252){return i|0}else if((t|0)==1254){return i|0}return 0}function uW(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;h=zH(52)|0;i=h;if((h|0)==0){j=0;return j|0}c[h>>2]=0;b[h+4>>1]=d&65535;b[h+6>>1]=e&65535;b[h+8>>1]=f&65535;b[h+10>>1]=g&65535;c[h+12>>2]=0;b[h+16>>1]=2;c[h+20>>2]=0;do{if((g|0)==0){c[h+24>>2]=0}else{f=zH(g)|0;c[h+24>>2]=f;if((f|0)!=0){break}zI(h);j=0;return j|0}}while(0);b[h+28>>1]=0;a[h+46|0]=0;a[h+48|0]=0;j=i;return j|0}function uX(a){a=a|0;var b=0;if((a|0)==0){return}else{b=a}while(1){a=c[b>>2]|0;zI(c[b+24>>2]|0);zI(b);if((a|0)==0){break}else{b=a}}return}function uY(b,c,d){b=b|0;c=c|0;d=d|0;var f=0,g=0,h=0;f=e[b+28>>1]|0;g=f>>>0>d>>>0?d:f;if((g|0)!=0){h=0;do{a[c+h|0]=a[b+30+h|0]|0;h=h+1|0;}while(h>>>0<g>>>0)}if(g>>>0>=d>>>0){return g|0}h=~d;b=~f;f=h>>>0>b>>>0?h:b;zP(c+~f|0,0,f+d+1|0);return g|0}function uZ(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=a+2|0;e=b[d>>1]|0;f=a+4|0;a=c[f>>2]|0;if(e<<16>>16==0){g=a;h=g;zI(h);b[d>>1]=0;c[f>>2]=0;return}else{i=0;j=a;k=e}while(1){e=c[j+(i<<2)>>2]|0;if((e|0)==0){l=k;m=j}else{a=e;while(1){e=c[a>>2]|0;zI(c[a+24>>2]|0);zI(a);if((e|0)==0){break}else{a=e}}l=b[d>>1]|0;m=c[f>>2]|0}a=i+1|0;if(a>>>0<(l&65535)>>>0){i=a;j=m;k=l}else{g=m;break}}h=g;zI(h);b[d>>1]=0;c[f>>2]=0;return}function u_(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,i=0;f=a+4|0;g=a+2|0;a=zJ(c[f>>2]|0,((e[g>>1]|0)<<2)+4|0)|0;h=a;if((a|0)==0){i=1;return i|0}c[f>>2]=h;f=b[g>>1]|0;c[h+((f&65535)<<2)>>2]=d;b[g>>1]=f+1&65535;i=0;return i|0}function u$(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b[a+2>>1]|0;g=f&65535;if((f&65535)<2){h=0;return h|0}f=zH(g<<2)|0;i=f;if((f|0)==0){h=1;return h|0}j=a+4|0;k=0;do{l=(c[j>>2]|0)+(k<<2)|0;m=c[l>>2]|0;c[l>>2]=0;L1614:do{if((k|0)==0){n=0}else{l=b[m+8>>1]|0;o=k;while(1){p=o-1|0;q=c[i+(p<<2)>>2]|0;if((l&65535)>=(e[q+8>>1]|0)){n=o;break L1614}c[i+(o<<2)>>2]=q;if((p|0)==0){n=0;break}else{o=p}}}}while(0);c[i+(n<<2)>>2]=m;k=k+1|0;}while(k>>>0<g>>>0);k=a+4|0;a=0;n=0;while(1){j=c[k>>2]|0;o=j+(a<<2)|0;if((c[o>>2]|0)==0){r=a;s=o}else{o=a;while(1){l=((o+1|0)>>>0)%(g>>>0)|0;p=j+(l<<2)|0;if((c[p>>2]|0)==0){r=l;s=p;break}else{o=l}}}c[s>>2]=c[i+(n<<2)>>2];o=n+1|0;if(o>>>0<g>>>0){a=((r+d|0)>>>0)%(g>>>0)|0;n=o}else{break}}zI(f);h=0;return h|0}function u0(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=a+2|0;e=b[d>>1]|0;f=a+4|0;a=c[f>>2]|0;if(e<<16>>16==0){g=a;h=g;zI(h);b[d>>1]=0;c[f>>2]=0;return}else{i=0;j=a;k=e}while(1){e=c[j+(i<<2)>>2]|0;if((e|0)==0){l=k;m=j}else{a=e+2|0;n=b[a>>1]|0;o=e+4|0;p=c[o>>2]|0;if(n<<16>>16==0){q=p}else{r=0;s=p;p=n;while(1){n=c[s+(r<<2)>>2]|0;if((n|0)==0){t=p;u=s}else{v=n;while(1){n=c[v>>2]|0;zI(c[v+24>>2]|0);zI(v);if((n|0)==0){break}else{v=n}}t=b[a>>1]|0;u=c[o>>2]|0}v=r+1|0;if(v>>>0<(t&65535)>>>0){r=v;s=u;p=t}else{q=u;break}}}zI(q);zI(e);l=b[d>>1]|0;m=c[f>>2]|0}p=i+1|0;if(p>>>0<(l&65535)>>>0){i=p;j=m;k=l}else{g=m;break}}h=g;zI(h);b[d>>1]=0;c[f>>2]=0;return}function u1(){var a=0,d=0;a=zH(16)|0;if((a|0)==0){d=0;return d|0}b[a>>1]=0;c[a+4>>2]=0;c[a+8>>2]=0;c[a+12>>2]=0;d=a;return d|0}function u2(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a|0)==0){return}d=a|0;e=b[d>>1]|0;f=a+4|0;g=c[f>>2]|0;if(e<<16>>16==0){h=g}else{i=0;j=g;g=e;while(1){e=c[j+(i<<2)>>2]|0;if((e|0)==0){k=g;l=j}else{u0(e);zI(e);k=b[d>>1]|0;l=c[f>>2]|0}e=i+1|0;if(e>>>0<(k&65535)>>>0){i=e;j=l;g=k}else{h=l;break}}}zI(h);b[d>>1]=0;c[f>>2]=0;zI(c[a+12>>2]|0);zI(a);return}function u3(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0;h=u4(a,f,g,1)|0;if((h|0)==0){i=1;return i|0}g=h+4|0;f=h+2|0;h=zJ(c[g>>2]|0,((e[f>>1]|0)<<2)+4|0)|0;a=h;if((h|0)==0){i=1;return i|0}c[g>>2]=a;g=b[f>>1]|0;c[a+((g&65535)<<2)>>2]=d;b[f>>1]=g+1&65535;i=0;return i|0}function u4(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=a|0;i=e[h>>1]|0;L1673:do{if(i>>>0>d>>>0){j=c[a+4>>2]|0}else{if((g|0)==0){k=0;return k|0}l=a+4|0;m=i;n=c[l>>2]|0;while(1){o=zJ(n,(m<<2)+4|0)|0;if((o|0)==0){k=0;p=1361;break}q=o;c[l>>2]=q;o=b[h>>1]|0;r=zH(8)|0;if((r|0)==0){k=0;p=1365;break}b[r>>1]=o;b[r+2>>1]=0;c[r+4>>2]=0;c[q+((o&65535)<<2)>>2]=r;r=o+1&65535;b[h>>1]=r;o=r&65535;if(o>>>0>d>>>0){j=q;break L1673}else{m=o;n=q}}if((p|0)==1361){return k|0}else if((p|0)==1365){return k|0}}}while(0);h=c[j+(d<<2)>>2]|0;if((h|0)==0){k=0;return k|0}d=h+2|0;j=e[d>>1]|0;if(j>>>0>f>>>0){k=c[(c[h+4>>2]|0)+(f<<2)>>2]|0;return k|0}if((g|0)==0){k=0;return k|0}g=h+4|0;h=j;j=c[g>>2]|0;while(1){i=zJ(j,(h<<2)+4|0)|0;if((i|0)==0){k=0;p=1364;break}s=i;c[g>>2]=s;i=b[d>>1]|0;a=zH(8)|0;if((a|0)==0){k=0;p=1363;break}b[a>>1]=i;b[a+2>>1]=0;c[a+4>>2]=0;c[s+((i&65535)<<2)>>2]=a;a=i+1&65535;b[d>>1]=a;i=a&65535;if(i>>>0>f>>>0){p=1356;break}else{h=i;j=s}}if((p|0)==1356){k=c[s+(f<<2)>>2]|0;return k|0}else if((p|0)==1363){return k|0}else if((p|0)==1364){return k|0}return 0}function u5(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=a|0;g=b[f>>1]|0;if(g<<16>>16==0){return}h=a+4|0;a=0;i=g;while(1){g=c[(c[h>>2]|0)+(a<<2)>>2]|0;j=g+2|0;if((b[j>>1]|0)==0){k=i}else{l=g+4|0;g=0;do{m=c[(c[l>>2]|0)+(g<<2)>>2]|0;n=m+2|0;o=b[n>>1]|0;if(o<<16>>16==0){p=0}else{q=m+4|0;m=0;r=0;s=o;while(1){o=c[q>>2]|0;t=c[o+(m<<2)>>2]|0;if((t|0)==(d|0)){u=r;v=s}else{c[o+(r<<2)>>2]=t;u=r+1|0;v=b[n>>1]|0}t=m+1|0;if(t>>>0<(v&65535)>>>0){m=t;r=u;s=v}else{break}}p=u&65535}b[n>>1]=p;g=g+1|0;}while(g>>>0<(e[j>>1]|0)>>>0);k=b[f>>1]|0}j=a+1|0;if(j>>>0<(k&65535)>>>0){a=j;i=k}else{break}}return}function u6(a,b,d,f,g){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((e[a>>1]|0)>>>0<=b>>>0){h=0;return h|0}i=c[(c[a+4>>2]|0)+(b<<2)>>2]|0;if((i|0)==0){h=0;return h|0}if((e[i+2>>1]|0)>>>0<=d>>>0){h=0;return h|0}b=c[(c[i+4>>2]|0)+(d<<2)>>2]|0;if((b|0)==0){h=0;return h|0}if((g|0)!=0){if((e[b+2>>1]|0)>>>0<=f>>>0){h=0;return h|0}h=c[(c[b+4>>2]|0)+(f<<2)>>2]|0;return h|0}g=b+4|0;d=e[b+2>>1]|0;b=0;while(1){if(b>>>0>=d>>>0){h=0;j=1397;break}i=c[(c[g>>2]|0)+(b<<2)>>2]|0;if((e[i+8>>1]|0|0)==(f|0)){h=i;j=1400;break}else{b=b+1|0}}if((j|0)==1400){return h|0}else if((j|0)==1397){return h|0}return 0}function u7(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[a>>1]|0;if(d<<16>>16==0){e=0;return e|0}f=c[a+4>>2]|0;a=d&65535;d=0;g=0;while(1){h=c[f+(d<<2)>>2]|0;i=b[h+2>>1]|0;if(i<<16>>16==0){j=g}else{k=c[h+4>>2]|0;h=i&65535;i=0;l=g;while(1){m=c[k+(i<<2)>>2]|0;n=b[m+2>>1]|0;if(n<<16>>16==0){o=l}else{p=c[m+4>>2]|0;m=n&65535;n=0;q=l;while(1){r=c[p+(n<<2)>>2]|0;if((r|0)==0){s=q}else{t=q;u=r;while(1){r=t+1|0;v=c[u>>2]|0;if((v|0)==0){s=r;break}else{t=r;u=v}}}u=n+1|0;if(u>>>0<m>>>0){n=u;q=s}else{o=s;break}}}q=i+1|0;if(q>>>0<h>>>0){i=q;l=o}else{j=o;break}}}l=d+1|0;if(l>>>0<a>>>0){d=l;g=j}else{e=j;break}}return e|0}function u8(a,d,f,g,h){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;i=b[a>>1]|0;if(i<<16>>16==0){j=1;return j|0}k=c[a+4>>2]|0;a=0;l=d;L1779:while(1){d=c[k+(a<<2)>>2]|0;m=b[d+2>>1]|0;if(m<<16>>16==0){n=l}else{o=c[d+4>>2]|0;p=0;q=l;while(1){r=c[o+(p<<2)>>2]|0;s=r+2|0;d=e[s>>1]|0;if(q>>>0<d>>>0){break L1779}t=q-d|0;d=p+1|0;if(d>>>0<(m&65535)>>>0){p=d;q=t}else{n=t;break}}}m=a+1|0;if(m>>>0<(i&65535)>>>0){a=m;l=n}else{j=1;u=1430;break}}if((u|0)==1430){return j|0}n=uV(r,q,0)|0;if((n|0)==0){j=1;return j|0}c[f>>2]=a;c[g>>2]=p;c[h>>2]=0;p=r+4|0;if((b[s>>1]|0)==0){j=1;return j|0}else{v=0;w=0}while(1){if((c[(c[p>>2]|0)+(v<<2)>>2]|0)==(n|0)){j=0;u=1431;break}r=w+1|0;c[h>>2]=r;g=v+1|0;if(g>>>0<(e[s>>1]|0)>>>0){v=g;w=r}else{j=1;u=1428;break}}if((u|0)==1428){return j|0}else if((u|0)==1431){return j|0}return 0}function u9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=a+12|0;f=a+8|0;a=zJ(c[e>>2]|0,(c[f>>2]|0)+d|0)|0;if((a|0)==0){g=1;return g|0}h=c[f>>2]|0;i=a+h|0;zO(i|0,b|0,d)|0;c[f>>2]=h+d;c[e>>2]=a;g=0;return g|0}function va(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=a+12|0;zI(c[e>>2]|0);f=a+8|0;c[f>>2]=0;c[e>>2]=0;if((b|0)==0|(d|0)==0){g=0;return g|0}a=zJ(0,d)|0;if((a|0)==0){g=1;return g|0}h=c[f>>2]|0;i=a+h|0;zO(i|0,b|0,d)|0;c[f>>2]=h+d;c[e>>2]=a;g=0;return g|0}function vb(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b+8|0;e=c[d>>2]|0;f=b+12|0;b=c[f>>2]|0;g=0;while(1){if(g>>>0>=e>>>0){h=0;break}if((a[b+g|0]|0)==10){g=g+1|0}else{i=0;j=g;k=1449;break}}if((k|0)==1449){while(1){k=0;g=a[b+j|0]|0;do{if((g<<24>>24|0)==0){a[b+i|0]=10;l=j;m=i+1|0}else if((g<<24>>24|0)==13){n=i+1|0;a[b+i|0]=10;o=j+1|0;if(o>>>0>=e>>>0){l=j;m=n;break}l=(a[b+o|0]|0)==10?o:j;m=n}else{a[b+i|0]=g;l=j;m=i+1|0}}while(0);g=l+1|0;if(g>>>0<e>>>0){i=m;j=g;k=1449}else{h=m;break}}}while(1){if((h|0)==0){k=1458;break}m=h-1|0;if((a[b+m|0]|0)==10){h=m}else{k=1457;break}}if((k|0)==1458){c[d>>2]=0;zI(c[f>>2]|0);c[f>>2]=0;return}else if((k|0)==1457){c[d>>2]=h;return}}function vc(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;i=i+8|0;f=e|0;g=u1()|0;if((g|0)==0){h=0;i=e;return h|0}j=f|0;k=f+1|0;l=f+7|0;m=f+6|0;n=f+2|0;o=f+3|0;p=f+4|0;q=f+5|0;do{f=bK(j|0,1,8,b|0)|0;if((f|0)==0){h=g;r=1472;break}else if((f|0)!=8){break}f=a[j]|0;s=a[k]|0;t=(d[l]|0)<<8|(d[m]|0);u=uW(d[n]|0,d[o]|0,d[p]|0,t)|0;if((u|0)==0){break}uQ(u,a[q]|0);if((u3(g,u,f&255,s&255)|0)!=0){r=1467;break}}while((bK(c[u+24>>2]|0,1,t|0,b|0)|0)==(t|0));if((r|0)==1472){i=e;return h|0}else if((r|0)==1467){uX(u)}u2(g);h=0;i=e;return h|0}function vd(d,f){d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;g=i;i=i+8|0;h=g|0;j=f|0;k=b[j>>1]|0;L1850:do{if(k<<16>>16!=0){l=f+4|0;m=h|0;n=h+1|0;o=h+2|0;p=h+3|0;q=h+4|0;r=h+5|0;s=h+6|0;t=h+7|0;u=0;v=k;L1852:while(1){w=c[(c[l>>2]|0)+(u<<2)>>2]|0;x=w+2|0;if((b[x>>1]|0)==0){y=v}else{z=w+4|0;w=u&255;A=0;do{B=c[(c[z>>2]|0)+(A<<2)>>2]|0;C=B+2|0;D=B+4|0;B=A&255;E=0;while(1){if(E>>>0>=(e[C>>1]|0)>>>0){break}F=c[(c[D>>2]|0)+(E<<2)>>2]|0;G=uR(F)|0;a[m]=w;a[n]=B;a[o]=b[F+4>>1]&255;a[p]=b[F+6>>1]&255;a[q]=b[F+8>>1]&255;a[r]=G&255;G=F+10|0;H=b[G>>1]|0;a[s]=H&255;a[t]=(H&65535)>>>8&255;if((aB(m|0,1,8,d|0)|0)!=8){I=1;J=1488;break L1852}H=aB(c[F+24>>2]|0,1,e[G>>1]|0,d|0)|0;if((H|0)==(e[G>>1]|0)){E=E+1|0}else{I=1;J=1487;break L1852}}A=A+1|0;}while(A>>>0<(e[x>>1]|0)>>>0);y=b[j>>1]|0}x=u+1|0;if(x>>>0<(y&65535)>>>0){u=x;v=y}else{break L1850}}if((J|0)==1488){i=g;return I|0}else if((J|0)==1487){i=g;return I|0}}}while(0);ax(d|0)|0;I=0;i=g;return I|0}function ve(a,b){a=a|0;b=b|0;return 1}function vf(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;e=i;i=i+432|0;f=e|0;g=e+8|0;h=e+400|0;j=u1()|0;if((j|0)==0){k=0;i=e;return k|0}l=h|0;L1875:do{if((v_(b,0,l,30)|0)==0){if((zS(l|0,1152,16)|0)!=0){m=c[q>>2]|0;aB(25544,20,1,m|0)|0;break}m=h+16|0;n=0;while(1){if((n|0)==5){o=1498;break}if((zS(m|0,c[1128+(n<<2)>>2]|0,14)|0)==0){break}else{n=n+1|0}}if((o|0)==1498){n=c[q>>2]|0;aB(24328,34,1,n|0)|0}n=g|0;m=f|0;p=f+1|0;r=g+3|0;s=g+2|0;t=g+1|0;u=30;L1886:while(1){if((v_(b,u,m,2)|0)!=0){k=j;o=1554;break}v=d[p]<<8|d[m];if((v|0)==0){k=j;o=1555;break}w=u+2|0;if((v_(b,v+w|0,m,2)|0)!=0){break L1875}y=d[p]<<8|d[m];z=v+4|0;if(v>>>0>=387){A=z+u|0;B=0;C=387;while(1){if((v_(b,B+w|0,n,387)|0)!=0){break L1875}D=a[s]|0;E=D&255;if(D<<24>>24!=0){if((D&255)>24){break L1875}D=u4(j,d[n]|0,d[t]|0,1)|0;if((D|0)==0){break L1875}else{F=r;G=0}while(1){H=c[q>>2]|0;I=G+1|0;J=F+9|0;K=F+8|0;L=d[J]<<8|d[K];M=F+2|0;do{if((a[M]&-106)<<24>>24==0){if((a[F+10|0]|0)!=0){o=1516;break}if((a[F+11|0]|0)!=0){o=1516;break}if((a[F+14|0]&127)!=0){o=1516;break}if((a[F+15|0]|0)!=0){o=1516;break}N=a[F+7|0]|0;if((N&255)<7&L>>>0>5804){O=N}else{o=1516}}else{o=1516}}while(0);if((o|0)==1516){o=0;L=d[n]|0;N=d[t]|0;bN(H|0,40040,(x=i,i=i+24|0,c[x>>2]=L,c[x+8>>2]=N,c[x+16>>2]=I,x)|0)|0;N=0;do{do{if((N|0)==8){aB(32920,2,1,H|0)|0}else{if((N&3|0)!=0){break}aA(32,H|0)|0}}while(0);bN(H|0,28832,(x=i,i=i+8|0,c[x>>2]=d[F+N|0]|0,x)|0)|0;N=N+1|0;}while(N>>>0<16);aA(10,H|0)|0;ax(H|0)|0;O=a[F+7|0]|0}if((O&255)<7){P=128<<(O&255)}else{P=0}Q=uW(d[F+4|0]|0,d[F+5|0]|0,d[F+6|0]|0,P)|0;if((Q|0)==0){break L1875}uQ(Q,a[F+7|0]|0);if((u_(D,Q)|0)!=0){o=1527;break L1886}N=d[J]<<8|d[K];do{if((a[F+14|0]&50)==0){L=F+3|0;if((a[L]&1)!=0){uM(Q,0);R=L;break}if((P-256|0)>>>0>3840){uM(Q,0);R=L;break}if(N>>>0<5805){uM(Q,0);R=L;break}S=N-5805|0;if((S+P|0)>>>0>y>>>0){T=c[q>>2]|0;U=d[n]|0;V=d[t]|0;bN(T|0,35824,(x=i,i=i+32|0,c[x>>2]=U,c[x+8>>2]=V,c[x+16>>2]=I,c[x+24>>2]=P,x)|0)|0;uM(Q,0);R=L;break}else{if((v_(b,A+S|0,c[Q+24>>2]|0,P)|0)==0){R=L;break}else{break L1875}}}else{uM(Q,0);R=F+3|0}}while(0);do{if((a[M]&32)!=0){if((a[R]&32)==0){uO(Q,1,1);break}else{uO(Q,2,1);break}}}while(0);M=a[R]|0;if((M&1)==0){W=M}else{uO(Q,8,1);W=a[R]|0}if((W&64)!=0){uO(Q,4,1)}if(I>>>0<E>>>0){F=F+16|0;G=I}else{break}}}E=C+387|0;if(E>>>0>v>>>0){break}else{B=C;C=E}}}C=y+z|0;if((C|0)==0){k=j;o=1552;break}else{u=C+u|0}}if((o|0)==1527){uX(Q);break}else if((o|0)==1552){i=e;return k|0}else if((o|0)==1554){i=e;return k|0}else if((o|0)==1555){i=e;return k|0}}}while(0);u2(j);k=0;i=e;return k|0}function vg(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0;g=i;i=i+152|0;h=g|0;j=g+16|0;k=g+24|0;l=u1()|0;if((l|0)==0){m=0;i=g;return m|0}n=k|0;L1964:do{if((vZ(f,n,84)|0)==0){o=(vP(n,82)|0)!=256;if(o|(d[n]|0)>63){break}o=vQ(n,64)|0;p=vQ(n,68)|0;r=vQ(n,72)|0;s=vQ(n,76)|0;t=a[k+81|0]|0;if((o|0)==1474560){u=vk(f,l,18,j)|0}else if((o|0)==819200){u=vj(f,l,2,j,t&255)|0}else if((o|0)==737280){u=vk(f,l,9,j)|0}else if((o|0)==409600){u=vj(f,l,1,j,t&255)|0}else{break}if((u|0)!=0){break}if((r|0)!=(c[j>>2]|0)){r=c[q>>2]|0;aB(32888,26,1,r|0)|0;break}if((p|0)==0){m=l;i=g;return m|0}r=h|0;c[j>>2]=0;t=l|0;o=b[t>>1]|0;if(o<<16>>16==0){v=p;w=0}else{x=l+4|0;y=h+1|0;z=h+2|0;A=h+3|0;B=h+4|0;C=h+5|0;D=h+6|0;E=h+7|0;F=h+8|0;G=h+9|0;H=h+10|0;I=h+11|0;J=0;K=p;p=o;o=0;while(1){L=c[(c[x>>2]|0)+(J<<2)>>2]|0;M=L+2|0;N=b[M>>1]|0;if(N<<16>>16==0){O=K;P=p;Q=o}else{R=L+4|0;L=0;S=K;T=N;N=o;while(1){U=(c[(c[R>>2]|0)+(L<<2)>>2]|0)+2|0;if((b[U>>1]|0)==0){V=S;W=T;X=N}else{Y=L|J;Z=0;_=S;$=N;while(1){aa=u6(l,J,L,Z,0)|0;if((aa|0)==0|_>>>0<12){break L1964}if((vZ(f,r,12)|0)!=0){break L1964}uU(aa,r,12)|0;if((Y|Z|0)==0){ab=$}else{aa=(d[r]<<8|d[y])+$|0;ac=(aa>>>1|aa<<31)+(d[z]<<8|d[A])|0;aa=(ac>>>1|ac<<31)+(d[B]<<8|d[C])|0;ac=(aa>>>1|aa<<31)+(d[D]<<8|d[E])|0;aa=(ac>>>1|ac<<31)+(d[F]<<8|d[G])|0;ac=(aa>>>1|aa<<31)+(d[H]<<8|d[I])|0;aa=ac>>>1|ac<<31;c[j>>2]=aa;ab=aa}ad=_-12|0;aa=Z+1|0;if(aa>>>0<(e[U>>1]|0)>>>0){Z=aa;_=ad;$=ab}else{break}}V=ad;W=b[M>>1]|0;X=ab}$=L+1|0;if($>>>0<(W&65535)>>>0){L=$;S=V;T=W;N=X}else{break}}O=V;P=b[t>>1]|0;Q=X}N=J+1|0;if(N>>>0<(P&65535)>>>0){J=N;K=O;p=P;o=Q}else{v=O;w=Q;break}}}if((v|0)!=0){break}if((s|0)==(w|0)){m=l;i=g;return m|0}else{o=c[q>>2]|0;aB(30864,25,1,o|0)|0;break}}}while(0);u2(l);m=0;i=g;return m|0}function vh(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;h=i;i=i+144|0;j=h|0;k=h+16|0;if((b[g>>1]|0)!=80){l=1;i=h;return l|0}m=c[g+4>>2]|0;n=0;L2012:while(1){o=c[m+(n<<2)>>2]|0;if((b[o+2>>1]|0)!=1){p=0;q=1608;break}r=12-(n>>>4)|0;s=c[c[o+4>>2]>>2]|0;if((e[s+2>>1]|0)!=(r|0)){p=0;q=1608;break}o=s+4|0;s=0;while(1){if(s>>>0>=r>>>0){break}t=c[(c[o>>2]|0)+(s<<2)>>2]|0;if((b[t+10>>1]|0)!=512){p=0;q=1608;break L2012}if((e[t+8>>1]|0)>>>0<r>>>0){s=s+1|0}else{p=0;q=1608;break L2012}}s=n+1|0;if(s>>>0<80){n=s}else{u=0;q=1601;break}}L2021:do{if((q|0)==1601){while(1){q=0;n=c[m+(u<<2)>>2]|0;s=b[n+2>>1]|0;if(s<<16>>16!=0){r=c[n+4>>2]|0;n=s&65535;s=0;do{o=c[r+(s<<2)>>2]|0;t=e[o+2>>1]|0;v=o+4|0;o=0;while(1){if(o>>>0>=t>>>0){break}if((b[(c[(c[v>>2]|0)+(o<<2)>>2]|0)+28>>1]|0)==0){o=o+1|0}else{w=9600;x=409600;y=2;z=0;A=1;break L2021}}s=s+1|0;}while(s>>>0<n>>>0)}n=u+1|0;if(n>>>0<80){u=n;q=1601}else{w=0;x=409600;y=2;z=0;A=1;break}}}else if((q|0)==1608){L2033:while(1){q=0;n=c[m+(p<<2)>>2]|0;if((b[n+2>>1]|0)!=2){B=0;break}s=12-(p>>>4)|0;r=c[n+4>>2]|0;n=c[r>>2]|0;if((e[n+2>>1]|0)!=(s|0)){B=0;break}o=n+4|0;n=0;while(1){if(n>>>0>=s>>>0){break}v=c[(c[o>>2]|0)+(n<<2)>>2]|0;if((b[v+10>>1]|0)!=512){B=0;break L2033}if((e[v+8>>1]|0)>>>0<s>>>0){n=n+1|0}else{B=0;break L2033}}n=c[r+4>>2]|0;if((e[n+2>>1]|0)!=(s|0)){B=0;break}o=n+4|0;n=0;while(1){if(n>>>0>=s>>>0){break}v=c[(c[o>>2]|0)+(n<<2)>>2]|0;if((b[v+10>>1]|0)!=512){B=0;break L2033}if((e[v+8>>1]|0)>>>0<s>>>0){n=n+1|0}else{B=0;break L2033}}n=p+1|0;if(n>>>0<80){p=n;q=1608}else{C=0;q=1615;break}}if((q|0)==1615){while(1){q=0;n=c[m+(C<<2)>>2]|0;s=b[n+2>>1]|0;if(s<<16>>16!=0){o=c[n+4>>2]|0;n=s&65535;s=0;do{r=c[o+(s<<2)>>2]|0;v=e[r+2>>1]|0;t=r+4|0;r=0;while(1){if(r>>>0>=v>>>0){break}if((b[(c[(c[t>>2]|0)+(r<<2)>>2]|0)+28>>1]|0)==0){r=r+1|0}else{w=19200;x=819200;y=290;z=0;A=2;break L2021}}s=s+1|0;}while(s>>>0<n>>>0)}n=C+1|0;if(n>>>0<80){C=n;q=1615}else{w=0;x=819200;y=290;z=0;A=2;break L2021}}}L2060:while(1){n=c[m+(B<<2)>>2]|0;if((b[n+2>>1]|0)!=2){D=0;break}s=c[n+4>>2]|0;n=c[s>>2]|0;if((b[n+2>>1]|0)!=9){D=0;break}o=n+4|0;n=0;while(1){if(n>>>0>=9){break}r=c[(c[o>>2]|0)+(n<<2)>>2]|0;if((b[r+10>>1]|0)!=512){D=0;break L2060}t=b[r+8>>1]|0;if(t<<16>>16==0|(t&65535)>9){D=0;break L2060}else{n=n+1|0}}n=c[s+4>>2]|0;if((b[n+2>>1]|0)!=9){D=0;break}o=n+4|0;n=0;while(1){if(n>>>0>=9){break}t=c[(c[o>>2]|0)+(n<<2)>>2]|0;if((b[t+10>>1]|0)!=512){D=0;break L2060}r=b[t+8>>1]|0;if(r<<16>>16==0|(r&65535)>9){D=0;break L2060}else{n=n+1|0}}n=B+1|0;if(n>>>0<80){B=n}else{w=0;x=737280;y=546;z=9;A=2;break L2021}}L2075:while(1){n=c[m+(D<<2)>>2]|0;if((b[n+2>>1]|0)!=2){l=1;q=1709;break}o=c[n+4>>2]|0;n=c[o>>2]|0;if((b[n+2>>1]|0)!=18){l=1;q=1710;break}s=n+4|0;n=0;while(1){if(n>>>0>=18){break}r=c[(c[s>>2]|0)+(n<<2)>>2]|0;if((b[r+10>>1]|0)!=512){l=1;q=1702;break L2075}t=b[r+8>>1]|0;if(t<<16>>16==0|(t&65535)>18){l=1;q=1701;break L2075}else{n=n+1|0}}n=c[o+4>>2]|0;if((b[n+2>>1]|0)!=18){l=1;q=1708;break}s=n+4|0;n=0;while(1){if(n>>>0>=18){break}t=c[(c[s>>2]|0)+(n<<2)>>2]|0;if((b[t+10>>1]|0)!=512){l=1;q=1711;break L2075}r=b[t+8>>1]|0;if(r<<16>>16==0|(r&65535)>18){l=1;q=1703;break L2075}else{n=n+1|0}}n=D+1|0;if(n>>>0<80){D=n}else{w=0;x=1474560;y=802;z=18;A=2;break L2021}}if((q|0)==1701){i=h;return l|0}else if((q|0)==1702){i=h;return l|0}else if((q|0)==1703){i=h;return l|0}else if((q|0)==1708){i=h;return l|0}else if((q|0)==1709){i=h;return l|0}else if((q|0)==1710){i=h;return l|0}else if((q|0)==1711){i=h;return l|0}}}while(0);D=j|0;m=(z|0)==0;B=m&1^1;C=z+1|0;z=j+1|0;p=j+2|0;u=j+3|0;n=j+4|0;s=j+5|0;o=j+6|0;r=j+7|0;t=j+8|0;v=j+9|0;E=j+10|0;F=j+11|0;j=0;G=0;H=0;L2099:while(1){if(m){I=12-(j>>>4)|0}else{I=C}J=B>>>0<I>>>0;K=0;L=G;M=H;while(1){if(J){N=K|j;O=B;P=L;Q=M;while(1){R=u6(g,j,K,O,0)|0;if((R|0)==0){l=1;q=1704;break L2099}S=(e[R+10>>1]|0)>>>1;if((S|0)==0){T=Q}else{U=Q;V=S;S=c[R+24>>2]|0;while(1){W=(d[S]<<8|d[S+1|0])+U|0;X=W>>>1|W<<31;W=V-1|0;if((W|0)==0){T=X;break}else{U=X;V=W;S=S+2|0}}}if((N|O|0)==0){Y=P}else{uY(R,D,12)|0;S=(d[D]<<8|d[z])+P|0;V=(S>>>1|S<<31)+(d[p]<<8|d[u])|0;S=(V>>>1|V<<31)+(d[n]<<8|d[s])|0;V=(S>>>1|S<<31)+(d[o]<<8|d[r])|0;S=(V>>>1|V<<31)+(d[t]<<8|d[v])|0;V=(S>>>1|S<<31)+(d[E]<<8|d[F])|0;Y=V>>>1|V<<31}V=O+1|0;if(V>>>0<I>>>0){O=V;P=Y;Q=T}else{Z=Y;_=T;break}}}else{Z=L;_=M}Q=K+1|0;if(Q>>>0<A>>>0){K=Q;L=Z;M=_}else{break}}M=j+1|0;if(M>>>0<80){j=M;G=Z;H=_}else{break}}if((q|0)==1704){i=h;return l|0}H=k|0;zP(H|0,0,128);G=u6(g,0,0,m?2:3,0)|0;do{if((G|0)==0){$=40024}else{j=c[G+24>>2]|0;T=a[j]|0;if((T<<24>>24|0)==66){$=(a[j+1|0]|0)==68?j+36|0:40024;break}else if((T<<24>>24|0)==(-46|0)){$=(a[j+1|0]|0)==-41?j+36|0:40024;break}else{$=40024;break}}}while(0);G=a[$]|0;j=(G&255)>63?63:G&255;if((j|0)!=0){G=0;do{G=G+1|0;a[k+G|0]=a[$+G|0]|0;}while(G>>>0<j>>>0)}a[H]=j&255;vS(H,64,x);vS(H,68,w);vS(H,72,_);vS(H,76,Z);vR(H,80,y);vR(H,82,256);if((v$(f,H,84)|0)!=0){l=1;i=h;return l|0}L2137:do{if(m){H=0;L2138:while(1){y=12-(H>>>4)|0;Z=0;do{_=B;while(1){if(_>>>0>=y>>>0){break}x=u6(g,H,Z,_,0)|0;if((x|0)==0){l=1;q=1705;break L2138}if((v$(f,c[x+24>>2]|0,e[x+10>>1]|0)|0)==0){_=_+1|0}else{l=1;q=1706;break L2138}}Z=Z+1|0;}while(Z>>>0<A>>>0);H=H+1|0;if(H>>>0>=80){break L2137}}if((q|0)==1705){i=h;return l|0}else if((q|0)==1706){i=h;return l|0}}else{H=0;L2151:while(1){Z=0;do{y=B;while(1){if(y>>>0>=C>>>0){break}_=u6(g,H,Z,y,0)|0;if((_|0)==0){l=1;q=1712;break L2151}if((v$(f,c[_+24>>2]|0,e[_+10>>1]|0)|0)==0){y=y+1|0}else{l=1;q=1713;break L2151}}Z=Z+1|0;}while(Z>>>0<A>>>0);H=H+1|0;if(H>>>0>=80){break L2137}}if((q|0)==1712){i=h;return l|0}else if((q|0)==1713){i=h;return l|0}}}while(0);L2165:do{if((w|0)!=0){H=0;L2166:while(1){if(m){aa=12-(H>>>4)|0}else{aa=C}Z=0;do{y=B;while(1){if(y>>>0>=aa>>>0){break}_=u6(g,H,Z,y,0)|0;if((_|0)==0){l=1;q=1714;break L2166}uY(_,D,12)|0;if((v$(f,D,12)|0)==0){y=y+1|0}else{l=1;q=1715;break L2166}}Z=Z+1|0;}while(Z>>>0<A>>>0);H=H+1|0;if(H>>>0>=80){break L2165}}if((q|0)==1714){i=h;return l|0}else if((q|0)==1715){i=h;return l|0}}}while(0);ax(f|0)|0;l=0;i=h;return l|0}function vi(a){a=a|0;var b=0,c=0,e=0;b=i;i=i+128|0;do{if((bS(a|0,0,0)|0)==0){c=b|0;if((vZ(a,c,84)|0)!=0){e=0;break}if((vP(c,82)|0)!=256){e=0;break}e=(d[c]|0)<64|0}else{e=0}}while(0);i=b;return e|0}function vj(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;c[f>>2]=0;h=(e|0)==0;i=g&255;g=0;L2191:while(1){j=g>>>4;k=12-j|0;L2193:do{if(!h){if((j|0)==12){l=0;while(1){m=u4(b,g,l,0)|0;if((m|0)!=0){u$(m,2)|0}l=l+1|0;if(l>>>0>=e>>>0){break L2193}}}else{n=0}do{l=0;do{o=uW(g,n,l,512)|0;if((o|0)==0){p=1;q=1743;break L2191}uS(o,i);uP(o,3);if((u3(b,o,g,n)|0)!=0){q=1735;break L2191}m=o+24|0;if((vZ(a,c[m>>2]|0,512)|0)!=0){p=1;q=1744;break L2191}r=c[f>>2]|0;s=256;t=c[m>>2]|0;while(1){m=((d[t]|0)<<8|(d[t+1|0]|0))+r|0;u=m>>>1|m<<31;m=s-1|0;if((m|0)==0){break}else{r=u;s=m;t=t+2|0}}c[f>>2]=u;l=l+1|0;}while(l>>>0<k>>>0);l=u4(b,g,n,0)|0;if((l|0)!=0){u$(l,2)|0}n=n+1|0;}while(n>>>0<e>>>0)}}while(0);k=g+1|0;if(k>>>0<80){g=k}else{p=0;q=1742;break}}if((q|0)==1735){uX(o);p=1;return p|0}else if((q|0)==1742){return p|0}else if((q|0)==1743){return p|0}else if((q|0)==1744){return p|0}return 0}function vk(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;c[f>>2]=0;g=e>>>0<14?2:32770;h=(e|0)==0;i=0;L2223:while(1){do{if(!h){j=0;do{j=j+1|0;k=uW(i,0,j,512)|0;if((k|0)==0){l=1;m=1768;break L2223}uP(k,g);if((u3(b,k,i,0)|0)!=0){n=k;m=1749;break L2223}o=k+24|0;if((vZ(a,c[o>>2]|0,512)|0)!=0){l=1;m=1767;break L2223}k=c[f>>2]|0;p=256;q=c[o>>2]|0;while(1){o=((d[q]|0)<<8|(d[q+1|0]|0))+k|0;r=o>>>1|o<<31;o=p-1|0;if((o|0)==0){break}else{k=r;p=o;q=q+2|0}}c[f>>2]=r;}while(j>>>0<e>>>0);if(h){break}else{s=0}do{s=s+1|0;j=uW(i,1,s,512)|0;if((j|0)==0){l=1;m=1764;break L2223}uP(j,g);if((u3(b,j,i,1)|0)!=0){n=j;m=1749;break L2223}q=j+24|0;if((vZ(a,c[q>>2]|0,512)|0)!=0){l=1;m=1763;break L2223}j=c[f>>2]|0;p=256;k=c[q>>2]|0;while(1){q=((d[k]|0)<<8|(d[k+1|0]|0))+j|0;t=q>>>1|q<<31;q=p-1|0;if((q|0)==0){break}else{j=t;p=q;k=k+2|0}}c[f>>2]=t;}while(s>>>0<e>>>0)}}while(0);k=i+1|0;if(k>>>0<80){i=k}else{l=0;m=1765;break}}if((m|0)==1764){return l|0}else if((m|0)==1765){return l|0}else if((m|0)==1749){uX(n);l=1;return l|0}else if((m|0)==1767){return l|0}else if((m|0)==1768){return l|0}else if((m|0)==1763){return l|0}return 0}function vl(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;f=i;i=i+784|0;g=f|0;h=f+8|0;j=f+264|0;k=f+520|0;l=f+776|0;m=u1()|0;if((m|0)==0){n=0;i=f;return n|0}o=l|0;L2256:do{if((bK(o|0,1,4,b|0)|0)==4){if((vQ(o,0)|0)!=1229800480){break}u9(m,o,4)|0;while(1){p=aS(b|0)|0;if((p|0)==26){break}else if((p|0)==(-1|0)){break L2256}a[o]=p&255;u9(m,o,1)|0}vb(m);p=h|0;q=j|0;r=k|0;s=l+1|0;t=l+2|0;u=l+3|0;v=l+4|0;L2263:while(1){w=bK(o|0,1,5,b|0)|0;if((w|0)==0){n=m;x=1811;break}else if((w|0)!=5){break L2256}w=d[s]|0;y=a[t]&1;z=a[u]|0;A=z&255;B=a[v]|0;if(z<<24>>24==0){continue}if((B&255)>6){break L2256}z=128<<(B&255);if((bK(p|0,1,A|0,b|0)|0)!=(A|0)){break L2256}C=a[t]|0;if(C<<24>>24<0){if((bK(q|0,1,A|0,b|0)|0)!=(A|0)){break L2256}D=a[t]|0}else{D=C}if((D&64)==0){E=0}else{if((bK(r|0,1,A|0,b|0)|0)==(A|0)){E=0}else{break L2256}}while(1){C=a[t]|0;if(C<<24>>24<0){F=d[j+E|0]|0}else{F=w}if((C&64)==0){G=y}else{G=d[k+E|0]|0}C=a[h+E|0]|0;if((bK(g|0,1,1,b|0)|0)!=1){break L2256}H=uW(F,G,C&255,z)|0;if((H|0)==0){break L2256}uQ(H,B);if((u3(m,H,w,y)|0)!=0){x=1792;break L2263}C=d[o]|0;if((C|0)==3){I=32770}else if((C|0)==4){I=2}else if((C|0)==5){I=2}else if((C|0)==0){I=32769}else if((C|0)==1){I=1}else if((C|0)==2){I=1}else{break L2256}uP(H,I);C=a[g]|0;if((C-5&255)<4){uO(H,2,1)}if((C<<24>>24|0)==2|(C<<24>>24|0)==6){x=1804}else if((C<<24>>24|0)==1|(C<<24>>24|0)==5){x=1806}else if((C<<24>>24|0)==3|(C<<24>>24|0)==4|(C<<24>>24|0)==7|(C<<24>>24|0)==8){uO(H,4,1);if((C<<24>>24|0)==4|(C<<24>>24|0)==6|(C<<24>>24|0)==8){x=1804}else if((C<<24>>24|0)==3|(C<<24>>24|0)==5|(C<<24>>24|0)==7){x=1806}else{break L2256}}else if((C<<24>>24|0)==0){uO(H,2,1);uM(H,0)}else{break L2256}if((x|0)==1804){x=0;if((bK(g|0,1,1,b|0)|0)!=1){break L2256}uM(H,d[g]|0)}else if((x|0)==1806){x=0;C=H+10|0;J=bK(c[H+24>>2]|0,1,e[C>>1]|0|0,b|0)|0;if((J|0)!=(e[C>>1]|0|0)){break L2256}}C=E+1|0;if(C>>>0<A>>>0){E=C}else{continue L2263}}}if((x|0)==1811){i=f;return n|0}else if((x|0)==1792){uX(H);break}}}while(0);u2(m);n=0;i=f;return n|0}function vm(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;h=i;i=i+784|0;j=h|0;k=h+776|0;l=g+12|0;m=c[l>>2]|0;n=g+8|0;do{if((c[n>>2]|0)>>>0<29){o=1822}else{if((a[m]|0)!=73){o=1822;break}if((a[m+1|0]|0)!=77){o=1822;break}if((a[m+2|0]|0)!=68){o=1822;break}if((a[m+12|0]|0)!=47){o=1822;break}if((a[m+15|0]|0)!=47){o=1822;break}if((a[m+20|0]|0)!=32){o=1822;break}v$(f,m,29)|0;if((c[n>>2]|0)>>>0<=29){p=29;break}p=(a[(c[l>>2]|0)+29|0]|0)==10?30:29}}while(0);if((o|0)==1822){c[k>>2]=b0(0)|0;m=aH(k|0)|0;k=c[m+12>>2]|0;q=(c[m+16>>2]|0)+1|0;r=(c[m+20>>2]|0)+1900|0;s=c[m+8>>2]|0;t=c[m+4>>2]|0;u=c[m>>2]|0;bN(f|0,39984,(x=i,i=i+48|0,c[x>>2]=k,c[x+8>>2]=q,c[x+16>>2]=r,c[x+24>>2]=s,c[x+32>>2]=t,c[x+40>>2]=u,x)|0)|0;p=0}aA(13,f|0)|0;aA(10,f|0)|0;if(p>>>0<(c[n>>2]|0)>>>0){u=p;do{p=a[(c[l>>2]|0)+u|0]|0;if(p<<24>>24==10){aA(13,f|0)|0;aA(10,f|0)|0}else{t=p&255;aA(t|0,f|0)|0}u=u+1|0;}while(u>>>0<(c[n>>2]|0)>>>0)}aA(26,f|0)|0;n=g|0;u=b[n>>1]|0;L2330:do{if(u<<16>>16!=0){l=g+4|0;t=j|0;p=j+1|0;s=j+2|0;r=j+3|0;q=j+4|0;k=0;m=u;L2332:while(1){v=c[(c[l>>2]|0)+(k<<2)>>2]|0;w=v+2|0;if((b[w>>1]|0)==0){y=m}else{z=v+4|0;v=k&255;A=0;do{B=c[(c[z>>2]|0)+(A<<2)>>2]|0;C=b[B+2>>1]|0;D=C&65535;if(C<<16>>16!=0){E=B+4|0;B=c[E>>2]|0;F=0;G=0;H=1;while(1){if(H>>>0>=D>>>0){break}I=c[B+(H<<2)>>2]|0;J=c[B>>2]|0;if((b[I+10>>1]|0)!=(b[J+10>>1]|0)){K=1;o=1872;break L2332}if((b[I+16>>1]|0)==(b[J+16>>1]|0)){F=(e[I+6>>1]|0)==(A|0)?F:1;G=(e[I+4>>1]|0)==(k|0)?G:1;H=H+1|0}else{K=1;o=1873;break L2332}}H=c[B>>2]|0;I=e[H+16>>1]|0;if((I|0)==1){a[t]=2}else if((I|0)==32769){a[t]=0}else if((I|0)==2){a[t]=5}else if((I|0)==32770){a[t]=3}else{a[t]=5}a[p]=v;I=A&255;a[s]=I;a[r]=C&255;J=b[H+10>>1]|0;H=J&65535;if((H+65535&H|0)!=0|(J&65535)>8192){K=1;o=1877;break L2332}a[q]=0;if((J&65535)>255){J=H;H=0;while(1){L=H+1&255;if(J>>>0>511){J=J>>>1;H=L}else{break}}a[q]=L}H=D+5|0;if((G|0)==0){M=0;N=H;O=I}else{J=I|-128;a[s]=J;M=j+H|0;N=H+D|0;O=J}if((F|0)==0){P=0;Q=N}else{a[s]=O|64;P=j+N|0;Q=N+D|0}J=(P|0)==0;if((M|0)==0){if(J){H=0;do{a[j+(H+5)|0]=b[(c[B+(H<<2)>>2]|0)+8>>1]&255;H=H+1|0;}while(H>>>0<D>>>0)}else{H=0;do{F=c[B+(H<<2)>>2]|0;a[j+(H+5)|0]=b[F+8>>1]&255;a[P+H|0]=b[F+6>>1]&255;H=H+1|0;}while(H>>>0<D>>>0)}}else{if(J){H=0;do{F=c[B+(H<<2)>>2]|0;a[j+(H+5)|0]=b[F+8>>1]&255;a[M+H|0]=b[F+4>>1]&255;H=H+1|0;}while(H>>>0<D>>>0)}else{H=0;do{J=c[B+(H<<2)>>2]|0;a[j+(H+5)|0]=b[J+8>>1]&255;a[M+H|0]=b[J+4>>1]&255;a[P+H|0]=b[J+6>>1]&255;H=H+1|0;}while(H>>>0<D>>>0)}}if((aB(t|0,1,Q|0,f|0)|0)==(Q|0)){R=0}else{K=1;o=1874;break L2332}do{H=c[(c[E>>2]|0)+(R<<2)>>2]|0;if((uN(H)|0)==0){S=0}else{S=(b[H+10>>1]|0)!=0}B=c[H+12>>2]|0;J=(B&6|0)==6;if(J|(B&2|0)!=0){T=J?7:5}else{T=B>>>1&2|1}aA(T+(S&1)|0,f|0)|0;B=c[H+24>>2]|0;if(S){J=d[B]|0;aA(J|0,f|0)|0}else{J=H+10|0;H=aB(B|0,1,e[J>>1]|0,f|0)|0;if((H|0)!=(e[J>>1]|0)){K=1;o=1875;break L2332}}R=R+1|0;}while(R>>>0<D>>>0)}A=A+1|0;}while(A>>>0<(e[w>>1]|0)>>>0);y=b[n>>1]|0}w=k+1|0;if(w>>>0<(y&65535)>>>0){k=w;m=y}else{break L2330}}if((o|0)==1872){i=h;return K|0}else if((o|0)==1873){i=h;return K|0}else if((o|0)==1874){i=h;return K|0}else if((o|0)==1875){i=h;return K|0}else if((o|0)==1877){i=h;return K|0}}}while(0);ax(f|0)|0;K=0;i=h;return K|0}function vn(a){a=a|0;var b=0,c=0,d=0;b=i;i=i+16|0;do{if((bS(a|0,0,0)|0)==0){c=b|0;if((bK(c|0,1,4,a|0)|0)!=4){d=0;break}d=(vQ(c,0)|0)==1229800480|0}else{d=0}}while(0);i=b;return d|0}function vo(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+8|0;c=u1()|0;if((c|0)==0){d=0;i=b;return d|0}e=b|0;do{if((vZ(a,e,8)|0)==0){f=vQ(e,0)|0;g=vQ(e,4)|0;if((f|0)!=1346782275){break}if((g|0)==0){h=vr(a,c,1346782275,0)|0}else if((g|0)==131072){h=vw(a,c,1346782275,131072)|0}else if((g|0)==65536){h=vt(a,c,1346782275,65536)|0}else{h=vA(a,c,1346782275,g)|0}if((h|0)==0){d=c}else{break}i=b;return d|0}}while(0);u2(c);d=0;i=b;return d|0}function vp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((c|0)==2){d=vx(a,b)|0}else if((c|0)==0){d=vs(a,b)|0}else if((c|0)==1){d=vu(a,b)|0}else{d=vB(a,b)|0}return d|0}function vq(a){a=a|0;var b=0,c=0,d=0;b=i;i=i+8|0;c=b|0;if((v_(a,0,c,4)|0)!=0){d=0;i=b;return d|0}d=(vQ(c,0)|0)==1346782275|0;i=b;return d|0}function vr(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=i;i=i+24|0;f=g|0;aB(35600,49,1,c[q>>2]|0)|0;h=g+16|0;if((vZ(b,h,8)|0)!=0){j=1;i=g;return j|0}k=vQ(h,0)|0;l=vQ(h,4)|0;if(l>>>0<16){j=1;i=g;return j|0}if((v1(b,l-16|0)|0)!=0){j=1;i=g;return j|0}if((k|0)==0){j=0;i=g;return j|0}l=f|0;h=f+1|0;m=f+5|0;n=f+2|0;o=f+3|0;p=f+4|0;r=f+12|0;f=0;while(1){if((vZ(b,l,12)|0)!=0){j=1;s=1931;break}t=a[l]|0;u=a[h]|0;v=d[m]|0;w=vP(l,6)|0;x=uW(d[n]|0,d[o]|0,d[p]|0,w)|0;if((x|0)==0){j=1;s=1932;break}if((u3(e,x,t&255,u&255)|0)!=0){s=1915;break}vQ(l,8)|0;uP(x,(v&1|0)==0?v&2:1);if((v&4|0)!=0){u=x+12|0;c[u>>2]=c[u>>2]|1}if((v&8|0)!=0){u=x+12|0;c[u>>2]=c[u>>2]|2}if((v&16|0)!=0){u=x+12|0;c[u>>2]=c[u>>2]|4}if((v&128|0)==0){if((vZ(b,c[x+24>>2]|0,w)|0)!=0){j=1;s=1936;break}}else{if((vZ(b,r,1)|0)!=0){j=1;s=1929;break}uM(x,d[r]|0)}w=f+1|0;if(w>>>0<k>>>0){f=w}else{j=0;s=1937;break}}if((s|0)==1915){uX(x);j=1;i=g;return j|0}else if((s|0)==1929){i=g;return j|0}else if((s|0)==1931){i=g;return j|0}else if((s|0)==1932){i=g;return j|0}else if((s|0)==1936){i=g;return j|0}else if((s|0)==1937){i=g;return j|0}return 0}function vs(d,f){d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;g=i;i=i+32|0;h=g|0;j=u7(f)|0;k=g+16|0;vS(k,0,1346782275);vS(k,4,0);vS(k,8,j);vS(k,12,16);if((v$(d,k,16)|0)!=0){l=1;i=g;return l|0}k=f|0;j=b[k>>1]|0;L2478:do{if(j<<16>>16!=0){m=f+4|0;n=h|0;o=h+1|0;p=h+2|0;q=h+3|0;r=h+4|0;s=h+5|0;t=h+6|0;u=h+7|0;v=h+12|0;w=0;x=j;L2480:while(1){y=c[(c[m>>2]|0)+(w<<2)>>2]|0;z=y+2|0;A=b[z>>1]|0;if(A<<16>>16==0){B=x}else{C=y+4|0;y=w&255;D=0;E=A;while(1){A=c[(c[C>>2]|0)+(D<<2)>>2]|0;F=A+2|0;if((b[F>>1]|0)==0){G=E}else{H=A+4|0;A=D&255;I=0;do{J=c[(c[H>>2]|0)+(I<<2)>>2]|0;K=e[J+16>>1]|0;if((K|0)==2){L=25e4;M=2}else if((K|0)==32769){L=25e4;M=1}else if((K|0)==16386){L=1e6;M=2}else if((K|0)==32770){L=5e5;M=2}else if((K|0)==1){L=125e3;M=1}else{L=0;M=0}K=c[J+12>>2]|0;N=(K&1|0)==0?M:M|4;O=(K&2|0)==0?N:N|8;a[n]=y;a[o]=A;a[p]=b[J+4>>1]&255;a[q]=b[J+6>>1]&255;a[r]=b[J+8>>1]&255;a[s]=((K&4|0)==0?O:O|16)&255;O=J+10|0;K=b[O>>1]|0;a[t]=(K&65535)>>>8&255;a[u]=K&255;vS(n,8,L);do{if((uN(J)|0)==0){P=1954}else{if((b[O>>1]|0)==0){P=1954;break}a[s]=a[s]|-128;a[v]=a[c[J+24>>2]|0]|0;if((v$(d,n,13)|0)!=0){l=1;P=1965;break L2480}}}while(0);if((P|0)==1954){P=0;if((v$(d,n,12)|0)!=0){l=1;P=1964;break L2480}if((v$(d,c[J+24>>2]|0,e[O>>1]|0)|0)!=0){l=1;P=1963;break L2480}}I=I+1|0;}while(I>>>0<(e[F>>1]|0)>>>0);G=b[z>>1]|0}F=D+1|0;if(F>>>0<(G&65535)>>>0){D=F;E=G}else{break}}B=b[k>>1]|0}E=w+1|0;if(E>>>0<(B&65535)>>>0){w=E;x=B}else{break L2478}}if((P|0)==1963){i=g;return l|0}else if((P|0)==1964){i=g;return l|0}else if((P|0)==1965){i=g;return l|0}}}while(0);ax(d|0)|0;l=0;i=g;return l|0}function vt(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=i;i=i+40|0;f=g|0;aB(35536,49,1,c[q>>2]|0)|0;h=g+32|0;if((vZ(b,h,8)|0)!=0){j=1;i=g;return j|0}k=vQ(h,0)|0;l=vQ(h,4)|0;if(l>>>0<16){j=1;i=g;return j|0}if((v1(b,l-16|0)|0)!=0){j=1;i=g;return j|0}if((k|0)==0){j=0;i=g;return j|0}l=f|0;h=f+1|0;m=f+2|0;n=f+3|0;o=f+4|0;p=f+5|0;r=f+8|0;s=f+16|0;f=0;t=0;while(1){u=(vZ(b,l,16)|0)==0;if(!(u&(a[l]|0)==83)){j=1;v=1996;break}u=d[h]|0;w=d[m]|0;x=vP(l,6)|0;y=uW(d[n]|0,d[o]|0,d[p]|0,x)|0;if((y|0)==0){j=1;v=2001;break}z=vQ(l,12)|0;A=(vQ(l,8)|0)&16777215;if((z&4|0)!=0){B=y+12|0;c[B>>2]=c[B>>2]|1}if((z&8|0)!=0){B=y+12|0;c[B>>2]=c[B>>2]|2}if((z&16|0)!=0){B=y+12|0;c[B>>2]=c[B>>2]|4}B=d[r]|0;if((B|0)==2){C=A>>>0<375e3?2:32770}else if((B|0)==1){C=A>>>0<375e3?1:32769}else{C=0}uP(y,C);if((z&1|0)==0){if((u3(e,y,u,w)|0)!=0){v=1989;break}}else{if((f|0)==0){v=1986;break}uK(f,y)}if((z&128|0)==0){if((vZ(b,c[y+24>>2]|0,x)|0)!=0){j=1;v=2005;break}}else{if((vZ(b,s,1)|0)!=0){j=1;v=2004;break}uM(y,d[s]|0)}x=t+1|0;if(x>>>0<k>>>0){f=y;t=x}else{j=0;v=2006;break}}if((v|0)==2006){i=g;return j|0}else if((v|0)==1986){uX(y);j=1;i=g;return j|0}else if((v|0)==1996){i=g;return j|0}else if((v|0)==1989){uX(y);j=1;i=g;return j|0}else if((v|0)==2004){i=g;return j|0}else if((v|0)==2005){i=g;return j|0}else if((v|0)==2001){i=g;return j|0}return 0}function vu(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+16|0;g=u7(d)|0;h=f|0;vS(h,0,1346782275);vR(h,4,1);vR(h,6,0);vS(h,8,g);vS(h,12,16);if((v$(a,h,16)|0)!=0){j=1;i=f;return j|0}h=d|0;g=b[h>>1]|0;L2568:do{if(g<<16>>16!=0){k=d+4|0;l=0;m=g;L2570:while(1){n=c[(c[k>>2]|0)+(l<<2)>>2]|0;o=n+2|0;p=b[o>>1]|0;if(p<<16>>16==0){q=m}else{r=n+4|0;n=0;s=p;while(1){p=c[(c[r>>2]|0)+(n<<2)>>2]|0;t=p+2|0;if((b[t>>1]|0)==0){u=s}else{v=p+4|0;p=0;do{w=c[(c[v>>2]|0)+(p<<2)>>2]|0;if((vv(a,w,l,n,0)|0)==0){x=w}else{j=1;y=2025;break L2570}while(1){w=c[x>>2]|0;if((w|0)==0){break}if((vv(a,w,l,n,1)|0)==0){x=w}else{j=1;y=2024;break L2570}}p=p+1|0;}while(p>>>0<(e[t>>1]|0)>>>0);u=b[o>>1]|0}t=n+1|0;if(t>>>0<(u&65535)>>>0){n=t;s=u}else{break}}q=b[h>>1]|0}s=l+1|0;if(s>>>0<(q&65535)>>>0){l=s;m=q}else{break L2568}}if((y|0)==2025){i=f;return j|0}else if((y|0)==2024){i=f;return j|0}}}while(0);ax(a|0)|0;j=0;i=f;return j|0}function vv(d,f,g,h,j){d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=i;i=i+32|0;l=k|0;m=c[f+12>>2]|0;n=m<<2&4;o=(m&2|0)==0?n:n|8;n=(m&4|0)==0?o:o|16;if((uN(f)|0)==0){p=n}else{p=(b[f+10>>1]|0)==0?n:n|128}n=p|(j|0)!=0;j=e[f+16>>1]|0;if((j|0)==2){q=25e4;r=2}else if((j|0)==1){q=125e3;r=1}else if((j|0)==32770){q=5e5;r=2}else if((j|0)==16386){q=1e6;r=2}else if((j|0)==32769){q=25e4;r=1}else{q=0;r=0}j=l|0;vS(j,8,q);a[j]=83;a[l+1|0]=g&255;a[l+2|0]=h&255;a[l+3|0]=b[f+4>>1]&255;a[l+4|0]=b[f+6>>1]&255;a[l+5|0]=b[f+8>>1]&255;h=f+10|0;g=b[h>>1]|0;a[l+6|0]=(g&65535)>>>8&255;a[l+7|0]=g&255;a[l+8|0]=r;vS(j,12,n);do{if((p&128|0)==0){if((v$(d,j,16)|0)!=0){s=1;i=k;return s|0}if((v$(d,c[f+24>>2]|0,e[h>>1]|0)|0)==0){break}else{s=1}i=k;return s|0}else{a[l+16|0]=a[c[f+24>>2]|0]|0;if((v$(d,j,17)|0)==0){break}else{s=1}i=k;return s|0}}while(0);s=0;i=k;return s|0}function vw(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0;j=i;i=i+568|0;k=j|0;l=j+32|0;m=j+288|0;n=j+296|0;o=j+552|0;aB(35400,49,1,c[q>>2]|0)|0;p=o|0;vS(p,0,g);vS(p,4,h);h=-1;g=8;r=p;while(1){s=d[r]<<24^h;t=s<<1;u=(s|0)<0?t^79764919:t;t=u<<1;s=(u|0)<0?t^79764919:t;t=s<<1;u=(s|0)<0?t^79764919:t;t=u<<1;s=(u|0)<0?t^79764919:t;t=s<<1;u=(s|0)<0?t^79764919:t;t=u<<1;s=(u|0)<0?t^79764919:t;t=s<<1;u=(s|0)<0?t^79764919:t;t=u<<1;v=(u|0)<0?t^79764919:t;t=g-1|0;if((t|0)==0){break}else{h=v;g=t;r=r+1|0}}c[11074]=v;v=o+8|0;if((vZ(b,v,8)|0)!=0){w=1;i=j;return w|0}o=c[11074]|0;r=8;g=v;while(1){v=d[g]<<24^o;h=v<<1;t=(v|0)<0?h^79764919:h;h=t<<1;v=(t|0)<0?h^79764919:h;h=v<<1;t=(v|0)<0?h^79764919:h;h=t<<1;v=(t|0)<0?h^79764919:h;h=v<<1;t=(v|0)<0?h^79764919:h;h=t<<1;v=(t|0)<0?h^79764919:h;h=v<<1;t=(v|0)<0?h^79764919:h;h=t<<1;x=(t|0)<0?h^79764919:h;h=r-1|0;if((h|0)==0){break}else{o=x;r=h;g=g+1|0}}c[11074]=x;x=vQ(p,12)|0;if(x>>>0<16){w=1;i=j;return w|0}g=x-16|0;x=n|0;L2627:do{if((g|0)!=0){n=g;while(1){r=n>>>0<256?n:256;if((vZ(b,x,r)|0)!=0){w=1;break}o=c[11074]|0;if((r|0)==0){y=o}else{h=o;o=r;t=x;while(1){v=d[t]<<24^h;u=v<<1;s=(v|0)<0?u^79764919:u;u=s<<1;v=(s|0)<0?u^79764919:u;u=v<<1;s=(v|0)<0?u^79764919:u;u=s<<1;v=(s|0)<0?u^79764919:u;u=v<<1;s=(v|0)<0?u^79764919:u;u=s<<1;v=(s|0)<0?u^79764919:u;u=v<<1;s=(v|0)<0?u^79764919:u;u=s<<1;v=(s|0)<0?u^79764919:u;u=o-1|0;if((u|0)==0){y=v;break}else{h=v;o=u;t=t+1|0}}}c[11074]=y;if((n|0)==(r|0)){break L2627}else{n=n-r|0}}i=j;return w|0}}while(0);y=m|0;m=l|0;l=k|0;g=k+1|0;n=k+2|0;t=k+3|0;o=k+4|0;h=k+5|0;u=k+8|0;k=0;L2637:while(1){if((vZ(b,y,4)|0)!=0){w=1;z=2183;break}v=(k|0)==0;while(1){s=c[11074]|0;A=4;B=y;while(1){C=d[B]<<24^s;D=C<<1;E=(C|0)<0?D^79764919:D;D=E<<1;C=(E|0)<0?D^79764919:D;D=C<<1;E=(C|0)<0?D^79764919:D;D=E<<1;C=(E|0)<0?D^79764919:D;D=C<<1;E=(C|0)<0?D^79764919:D;D=E<<1;C=(E|0)<0?D^79764919:D;D=C<<1;E=(C|0)<0?D^79764919:D;D=E<<1;F=(E|0)<0?D^79764919:D;D=A-1|0;if((D|0)==0){break}else{s=F;A=D;B=B+1|0}}c[11074]=F;B=vP(y,0)|0;G=vP(y,2)|0;A=0;s=4;r=y;while(1){D=d[r]<<24^A;E=D<<1;C=(D|0)<0?E^79764919:E;E=C<<1;D=(C|0)<0?E^79764919:E;E=D<<1;C=(D|0)<0?E^79764919:E;E=C<<1;D=(C|0)<0?E^79764919:E;E=D<<1;C=(D|0)<0?E^79764919:E;E=C<<1;D=(C|0)<0?E^79764919:E;E=D<<1;C=(D|0)<0?E^79764919:E;E=C<<1;H=(C|0)<0?E^79764919:E;E=s-1|0;if((E|0)==0){break}else{A=H;s=E;r=r+1|0}}if((B|0)==17742){z=2065;break L2637}else if((B|0)==21315){break}else if((B|0)==21575){if(v){w=1;z=2207;break L2637}r=G>>>0<256?G:256;if((vZ(b,x,r)|0)!=0){w=1;z=2208;break L2637}s=c[11074]|0;if((r|0)==0){c[11074]=s;I=H}else{A=s;s=r;E=x;while(1){C=d[E]<<24^A;D=C<<1;J=(C|0)<0?D^79764919:D;D=J<<1;C=(J|0)<0?D^79764919:D;D=C<<1;J=(C|0)<0?D^79764919:D;D=J<<1;C=(J|0)<0?D^79764919:D;D=C<<1;J=(C|0)<0?D^79764919:D;D=J<<1;C=(J|0)<0?D^79764919:D;D=C<<1;J=(C|0)<0?D^79764919:D;D=J<<1;K=(J|0)<0?D^79764919:D;D=s-1|0;if((D|0)==0){break}else{A=K;s=D;E=E+1|0}}c[11074]=K;E=H;s=r;A=x;while(1){D=d[A]<<24^E;J=D<<1;C=(D|0)<0?J^79764919:J;J=C<<1;D=(C|0)<0?J^79764919:J;J=D<<1;C=(D|0)<0?J^79764919:J;J=C<<1;D=(C|0)<0?J^79764919:J;J=D<<1;C=(D|0)<0?J^79764919:J;J=C<<1;D=(C|0)<0?J^79764919:J;J=D<<1;C=(D|0)<0?J^79764919:J;J=C<<1;D=(C|0)<0?J^79764919:J;J=s-1|0;if((J|0)==0){I=D;break}else{E=D;s=J;A=A+1|0}}}uU(k,x,r)|0;if((r|0)==(G|0)){L=I}else{A=G-r|0;s=I;while(1){E=A>>>0<256?A:256;if((vZ(b,m,E)|0)!=0){w=1;z=2189;break L2637}J=c[11074]|0;if((E|0)==0){c[11074]=J;M=s}else{D=J;J=E;C=m;while(1){N=d[C]<<24^D;O=N<<1;P=(N|0)<0?O^79764919:O;O=P<<1;N=(P|0)<0?O^79764919:O;O=N<<1;P=(N|0)<0?O^79764919:O;O=P<<1;N=(P|0)<0?O^79764919:O;O=N<<1;P=(N|0)<0?O^79764919:O;O=P<<1;N=(P|0)<0?O^79764919:O;O=N<<1;P=(N|0)<0?O^79764919:O;O=P<<1;Q=(P|0)<0?O^79764919:O;O=J-1|0;if((O|0)==0){break}else{D=Q;J=O;C=C+1|0}}c[11074]=Q;C=s;J=E;D=m;while(1){O=d[D]<<24^C;P=O<<1;N=(O|0)<0?P^79764919:P;P=N<<1;O=(N|0)<0?P^79764919:P;P=O<<1;N=(O|0)<0?P^79764919:P;P=N<<1;O=(N|0)<0?P^79764919:P;P=O<<1;N=(O|0)<0?P^79764919:P;P=N<<1;O=(N|0)<0?P^79764919:P;P=O<<1;N=(O|0)<0?P^79764919:P;P=N<<1;O=(N|0)<0?P^79764919:P;P=J-1|0;if((P|0)==0){M=O;break}else{C=O;J=P;D=D+1|0}}}if((A|0)==(E|0)){L=M;break}else{A=A-E|0;s=M}}}if((vZ(b,m,4)|0)!=0){w=1;z=2200;break L2637}s=c[11074]|0;A=4;r=m;while(1){D=d[r]<<24^s;J=D<<1;C=(D|0)<0?J^79764919:J;J=C<<1;D=(C|0)<0?J^79764919:J;J=D<<1;C=(D|0)<0?J^79764919:J;J=C<<1;D=(C|0)<0?J^79764919:J;J=D<<1;C=(D|0)<0?J^79764919:J;J=C<<1;D=(C|0)<0?J^79764919:J;J=D<<1;C=(D|0)<0?J^79764919:J;J=C<<1;R=(C|0)<0?J^79764919:J;J=A-1|0;if((J|0)==0){break}else{s=R;A=J;r=r+1|0}}c[11074]=R;if((vQ(m,0)|0)!=(L|0)){w=1;z=2209;break L2637}}else if((B|0)==17229){if((G|0)==0){if((vZ(b,m,4)|0)!=0){w=1;z=2210;break L2637}r=c[11074]|0;A=4;s=m;while(1){J=d[s]<<24^r;C=J<<1;D=(J|0)<0?C^79764919:C;C=D<<1;J=(D|0)<0?C^79764919:C;C=J<<1;D=(J|0)<0?C^79764919:C;C=D<<1;J=(D|0)<0?C^79764919:C;C=J<<1;D=(J|0)<0?C^79764919:C;C=D<<1;J=(D|0)<0?C^79764919:C;C=J<<1;D=(J|0)<0?C^79764919:C;C=D<<1;S=(D|0)<0?C^79764919:C;C=A-1|0;if((C|0)==0){break}else{r=S;A=C;s=s+1|0}}c[11074]=S;T=(vQ(m,0)|0)!=(H|0)|0}else{U=zH(G)|0;if((U|0)==0){w=1;z=2205;break L2637}if((vZ(b,U,G)|0)!=0){z=2154;break L2637}s=c[11074]|0;A=G;r=U;while(1){B=d[r]<<24^s;C=B<<1;D=(B|0)<0?C^79764919:C;C=D<<1;B=(D|0)<0?C^79764919:C;C=B<<1;D=(B|0)<0?C^79764919:C;C=D<<1;B=(D|0)<0?C^79764919:C;C=B<<1;D=(B|0)<0?C^79764919:C;C=D<<1;B=(D|0)<0?C^79764919:C;C=B<<1;D=(B|0)<0?C^79764919:C;C=D<<1;V=(D|0)<0?C^79764919:C;C=A-1|0;if((C|0)==0){break}else{s=V;A=C;r=r+1|0}}c[11074]=V;r=H;A=G;s=U;while(1){C=d[s]<<24^r;D=C<<1;B=(C|0)<0?D^79764919:D;D=B<<1;C=(B|0)<0?D^79764919:D;D=C<<1;B=(C|0)<0?D^79764919:D;D=B<<1;C=(B|0)<0?D^79764919:D;D=C<<1;B=(C|0)<0?D^79764919:D;D=B<<1;C=(B|0)<0?D^79764919:D;D=C<<1;B=(C|0)<0?D^79764919:D;D=B<<1;W=(B|0)<0?D^79764919:D;D=A-1|0;if((D|0)==0){break}else{r=W;A=D;s=s+1|0}}s=(a[U]|0)==10;A=(s<<31>>31)+G|0;if((A|0)==0){X=0}else{r=A-1|0;X=(a[U+r|0]|0)==10?r:A}A=u9(f,U+(s&1)|0,X)|0;zI(U);if((vZ(b,m,4)|0)==0){s=c[11074]|0;r=4;D=m;while(1){B=d[D]<<24^s;C=B<<1;J=(B|0)<0?C^79764919:C;C=J<<1;B=(J|0)<0?C^79764919:C;C=B<<1;J=(B|0)<0?C^79764919:C;C=J<<1;B=(J|0)<0?C^79764919:C;C=B<<1;J=(B|0)<0?C^79764919:C;C=J<<1;B=(J|0)<0?C^79764919:C;C=B<<1;J=(B|0)<0?C^79764919:C;C=J<<1;Y=(J|0)<0?C^79764919:C;C=r-1|0;if((C|0)==0){break}else{s=Y;r=C;D=D+1|0}}c[11074]=Y;Z=(vQ(m,0)|0)!=(W|0)|0}else{Z=1}T=Z|A}if((T|0)!=0){w=1;z=2202;break L2637}}else{if((G|0)==0){_=H}else{D=G;r=H;while(1){s=D>>>0<256?D:256;if((vZ(b,m,s)|0)!=0){w=1;z=2204;break L2637}C=c[11074]|0;if((s|0)==0){c[11074]=C;$=r}else{J=C;C=s;B=m;while(1){P=d[B]<<24^J;O=P<<1;N=(P|0)<0?O^79764919:O;O=N<<1;P=(N|0)<0?O^79764919:O;O=P<<1;N=(P|0)<0?O^79764919:O;O=N<<1;P=(N|0)<0?O^79764919:O;O=P<<1;N=(P|0)<0?O^79764919:O;O=N<<1;P=(N|0)<0?O^79764919:O;O=P<<1;N=(P|0)<0?O^79764919:O;O=N<<1;aa=(N|0)<0?O^79764919:O;O=C-1|0;if((O|0)==0){break}else{J=aa;C=O;B=B+1|0}}c[11074]=aa;B=r;C=s;J=m;while(1){E=d[J]<<24^B;O=E<<1;N=(E|0)<0?O^79764919:O;O=N<<1;E=(N|0)<0?O^79764919:O;O=E<<1;N=(E|0)<0?O^79764919:O;O=N<<1;E=(N|0)<0?O^79764919:O;O=E<<1;N=(E|0)<0?O^79764919:O;O=N<<1;E=(N|0)<0?O^79764919:O;O=E<<1;N=(E|0)<0?O^79764919:O;O=N<<1;E=(N|0)<0?O^79764919:O;O=C-1|0;if((O|0)==0){$=E;break}else{B=E;C=O;J=J+1|0}}}if((D|0)==(s|0)){_=$;break}else{D=D-s|0;r=$}}}if((vZ(b,m,4)|0)!=0){w=1;z=2213;break L2637}r=c[11074]|0;D=4;A=m;while(1){J=d[A]<<24^r;C=J<<1;B=(J|0)<0?C^79764919:C;C=B<<1;J=(B|0)<0?C^79764919:C;C=J<<1;B=(J|0)<0?C^79764919:C;C=B<<1;J=(B|0)<0?C^79764919:C;C=J<<1;B=(J|0)<0?C^79764919:C;C=B<<1;J=(B|0)<0?C^79764919:C;C=J<<1;B=(J|0)<0?C^79764919:C;C=B<<1;ab=(B|0)<0?C^79764919:C;C=D-1|0;if((C|0)==0){break}else{r=ab;D=C;A=A+1|0}}c[11074]=ab;if((vQ(m,0)|0)!=(_|0)){w=1;z=2214;break L2637}}if((vZ(b,y,4)|0)!=0){w=1;z=2203;break L2637}}if(G>>>0<12){w=1;z=2186;break}if((vZ(b,l,12)|0)!=0){w=1;z=2187;break}A=c[11074]|0;D=12;r=l;while(1){C=d[r]<<24^A;B=C<<1;J=(C|0)<0?B^79764919:B;B=J<<1;C=(J|0)<0?B^79764919:B;B=C<<1;J=(C|0)<0?B^79764919:B;B=J<<1;C=(J|0)<0?B^79764919:B;B=C<<1;J=(C|0)<0?B^79764919:B;B=J<<1;C=(J|0)<0?B^79764919:B;B=C<<1;J=(C|0)<0?B^79764919:B;B=J<<1;ac=(J|0)<0?B^79764919:B;B=D-1|0;if((B|0)==0){break}else{A=ac;D=B;r=r+1|0}}c[11074]=ac;r=d[l]|0;D=d[g]|0;A=d[n]|0;B=vP(l,6)|0;ad=uW(d[t]|0,d[o]|0,d[h]|0,B)|0;if((ad|0)==0){w=1;z=2199;break}J=(vQ(l,8)|0)&16777215;if((r&1|0)!=0){C=ad+12|0;c[C>>2]=c[C>>2]|1}if((r&2|0)!=0){C=ad+12|0;c[C>>2]=c[C>>2]|2}if((r&4|0)!=0){C=ad+12|0;c[C>>2]=c[C>>2]|4}if((r&8|0)!=0){C=ad+12|0;c[C>>2]=c[C>>2]|8}C=d[u]|0;if((C|0)==3){ae=3}else if((C|0)==1){ae=J>>>0<375e3?1:32769}else if((C|0)==2){ae=J>>>0<375e3?2:32770}else{ae=0}uP(ad,ae);if((r&64|0)==0){if((u3(f,ad,D,A)|0)==0){af=H;ag=12;ah=l}else{z=2099;break}}else{if(v){z=2096;break}uK(k,ad);af=H;ag=12;ah=l}while(1){A=d[ah]<<24^af;D=A<<1;J=(A|0)<0?D^79764919:D;D=J<<1;A=(J|0)<0?D^79764919:D;D=A<<1;J=(A|0)<0?D^79764919:D;D=J<<1;A=(J|0)<0?D^79764919:D;D=A<<1;J=(A|0)<0?D^79764919:D;D=J<<1;A=(J|0)<0?D^79764919:D;D=A<<1;J=(A|0)<0?D^79764919:D;D=J<<1;ai=(J|0)<0?D^79764919:D;D=ag-1|0;if((D|0)==0){break}else{af=ai;ag=D;ah=ah+1|0}}v=G-12|0;if((r&128|0)==0){D=ad+10|0;if(v>>>0<(e[D>>1]|0)>>>0){w=1;z=2198;break}J=ad+24|0;A=c[J>>2]|0;if((vZ(b,A,B)|0)!=0){w=1;z=2201;break}C=c[11074]|0;if((B|0)==0){c[11074]=C;aj=ai}else{O=C;C=B;E=A;while(1){A=d[E]<<24^O;N=A<<1;P=(A|0)<0?N^79764919:N;N=P<<1;A=(P|0)<0?N^79764919:N;N=A<<1;P=(A|0)<0?N^79764919:N;N=P<<1;A=(P|0)<0?N^79764919:N;N=A<<1;P=(A|0)<0?N^79764919:N;N=P<<1;A=(P|0)<0?N^79764919:N;N=A<<1;P=(A|0)<0?N^79764919:N;N=P<<1;ak=(P|0)<0?N^79764919:N;N=C-1|0;if((N|0)==0){break}else{O=ak;C=N;E=E+1|0}}c[11074]=ak;E=ai;C=B;O=c[J>>2]|0;while(1){r=d[O]<<24^E;N=r<<1;P=(r|0)<0?N^79764919:N;N=P<<1;r=(P|0)<0?N^79764919:N;N=r<<1;P=(r|0)<0?N^79764919:N;N=P<<1;r=(P|0)<0?N^79764919:N;N=r<<1;P=(r|0)<0?N^79764919:N;N=P<<1;r=(P|0)<0?N^79764919:N;N=r<<1;P=(r|0)<0?N^79764919:N;N=P<<1;r=(P|0)<0?N^79764919:N;N=C-1|0;if((N|0)==0){aj=r;break}else{E=r;C=N;O=O+1|0}}}al=v-(e[D>>1]|0)|0;am=aj}else{if((v|0)==0){w=1;z=2196;break}if((vZ(b,l,1)|0)!=0){w=1;z=2197;break}O=d[l]|0;C=O<<24;E=C^c[11074];J=E<<1;B=(E|0)<0?J^79764919:J;J=B<<1;E=(B|0)<0?J^79764919:J;J=E<<1;B=(E|0)<0?J^79764919:J;J=B<<1;E=(B|0)<0?J^79764919:J;J=E<<1;B=(E|0)<0?J^79764919:J;J=B<<1;E=(B|0)<0?J^79764919:J;J=E<<1;B=(E|0)<0?J^79764919:J;J=B<<1;c[11074]=(B|0)<0?J^79764919:J;J=C^ai;C=J<<1;B=(J|0)<0?C^79764919:C;C=B<<1;J=(B|0)<0?C^79764919:C;C=J<<1;B=(J|0)<0?C^79764919:C;C=B<<1;J=(B|0)<0?C^79764919:C;C=J<<1;B=(J|0)<0?C^79764919:C;C=B<<1;J=(B|0)<0?C^79764919:C;C=J<<1;B=(J|0)<0?C^79764919:C;C=B<<1;uM(ad,O);al=G-13|0;am=(B|0)<0?C^79764919:C}if((al|0)==0){an=am}else{C=al;B=am;while(1){O=C>>>0<256?C:256;if((vZ(b,m,O)|0)!=0){w=1;z=2192;break L2637}J=c[11074]|0;if((O|0)==0){c[11074]=J;ao=B}else{E=J;J=O;N=m;while(1){r=d[N]<<24^E;P=r<<1;A=(r|0)<0?P^79764919:P;P=A<<1;r=(A|0)<0?P^79764919:P;P=r<<1;A=(r|0)<0?P^79764919:P;P=A<<1;r=(A|0)<0?P^79764919:P;P=r<<1;A=(r|0)<0?P^79764919:P;P=A<<1;r=(A|0)<0?P^79764919:P;P=r<<1;A=(r|0)<0?P^79764919:P;P=A<<1;ap=(A|0)<0?P^79764919:P;P=J-1|0;if((P|0)==0){break}else{E=ap;J=P;N=N+1|0}}c[11074]=ap;N=B;J=O;E=m;while(1){P=d[E]<<24^N;A=P<<1;r=(P|0)<0?A^79764919:A;A=r<<1;P=(r|0)<0?A^79764919:A;A=P<<1;r=(P|0)<0?A^79764919:A;A=r<<1;P=(r|0)<0?A^79764919:A;A=P<<1;r=(P|0)<0?A^79764919:A;A=r<<1;P=(r|0)<0?A^79764919:A;A=P<<1;r=(P|0)<0?A^79764919:A;A=r<<1;P=(r|0)<0?A^79764919:A;A=J-1|0;if((A|0)==0){ao=P;break}else{N=P;J=A;E=E+1|0}}}if((C|0)==(O|0)){an=ao;break}else{C=C-O|0;B=ao}}}if((vZ(b,m,4)|0)!=0){w=1;z=2185;break}B=c[11074]|0;C=4;v=m;while(1){D=d[v]<<24^B;E=D<<1;J=(D|0)<0?E^79764919:E;E=J<<1;D=(J|0)<0?E^79764919:E;E=D<<1;J=(D|0)<0?E^79764919:E;E=J<<1;D=(J|0)<0?E^79764919:E;E=D<<1;J=(D|0)<0?E^79764919:E;E=J<<1;D=(J|0)<0?E^79764919:E;E=D<<1;J=(D|0)<0?E^79764919:E;E=J<<1;aq=(J|0)<0?E^79764919:E;E=C-1|0;if((E|0)==0){break}else{B=aq;C=E;v=v+1|0}}c[11074]=aq;if((vQ(m,0)|0)==(an|0)){k=ad}else{w=1;z=2206;break}}if((z|0)==2065){L2789:do{if((G|0)==0){ar=H}else{k=G;an=H;while(1){aq=k>>>0<256?k:256;if((vZ(b,m,aq)|0)!=0){w=1;break}ao=c[11074]|0;if((aq|0)==0){c[11074]=ao;as=an}else{ap=ao;ao=aq;am=m;while(1){al=d[am]<<24^ap;ai=al<<1;l=(al|0)<0?ai^79764919:ai;ai=l<<1;al=(l|0)<0?ai^79764919:ai;ai=al<<1;l=(al|0)<0?ai^79764919:ai;ai=l<<1;al=(l|0)<0?ai^79764919:ai;ai=al<<1;l=(al|0)<0?ai^79764919:ai;ai=l<<1;al=(l|0)<0?ai^79764919:ai;ai=al<<1;l=(al|0)<0?ai^79764919:ai;ai=l<<1;at=(l|0)<0?ai^79764919:ai;ai=ao-1|0;if((ai|0)==0){break}else{ap=at;ao=ai;am=am+1|0}}c[11074]=at;am=an;ao=aq;ap=m;while(1){O=d[ap]<<24^am;ai=O<<1;l=(O|0)<0?ai^79764919:ai;ai=l<<1;O=(l|0)<0?ai^79764919:ai;ai=O<<1;l=(O|0)<0?ai^79764919:ai;ai=l<<1;O=(l|0)<0?ai^79764919:ai;ai=O<<1;l=(O|0)<0?ai^79764919:ai;ai=l<<1;O=(l|0)<0?ai^79764919:ai;ai=O<<1;l=(O|0)<0?ai^79764919:ai;ai=l<<1;O=(l|0)<0?ai^79764919:ai;ai=ao-1|0;if((ai|0)==0){as=O;break}else{am=O;ao=ai;ap=ap+1|0}}}if((k|0)==(aq|0)){ar=as;break L2789}else{k=k-aq|0;an=as}}i=j;return w|0}}while(0);if((vZ(b,m,4)|0)!=0){w=1;i=j;return w|0}as=c[11074]|0;at=4;H=m;while(1){G=d[H]<<24^as;an=G<<1;k=(G|0)<0?an^79764919:an;an=k<<1;G=(k|0)<0?an^79764919:an;an=G<<1;k=(G|0)<0?an^79764919:an;an=k<<1;G=(k|0)<0?an^79764919:an;an=G<<1;k=(G|0)<0?an^79764919:an;an=k<<1;G=(k|0)<0?an^79764919:an;an=G<<1;k=(G|0)<0?an^79764919:an;an=k<<1;au=(k|0)<0?an^79764919:an;an=at-1|0;if((an|0)==0){break}else{as=au;at=an;H=H+1|0}}c[11074]=au;if((vQ(m,0)|0)!=(ar|0)){w=1;i=j;return w|0}vb(f);f=c[11074]|0;if((vZ(b,p,4)|0)!=0){w=1;i=j;return w|0}b=c[11074]|0;ar=4;m=p;while(1){au=d[m]<<24^b;H=au<<1;at=(au|0)<0?H^79764919:H;H=at<<1;au=(at|0)<0?H^79764919:H;H=au<<1;at=(au|0)<0?H^79764919:H;H=at<<1;au=(at|0)<0?H^79764919:H;H=au<<1;at=(au|0)<0?H^79764919:H;H=at<<1;au=(at|0)<0?H^79764919:H;H=au<<1;at=(au|0)<0?H^79764919:H;H=at<<1;av=(at|0)<0?H^79764919:H;H=ar-1|0;if((H|0)==0){break}else{b=av;ar=H;m=m+1|0}}c[11074]=av;w=(vQ(p,0)|0)!=(f|0)|0;i=j;return w|0}else if((z|0)==2099){uX(ad);w=1;i=j;return w|0}else if((z|0)==2154){zI(U);w=1;i=j;return w|0}else if((z|0)==2096){uX(ad);w=1;i=j;return w|0}else if((z|0)==2183){i=j;return w|0}else if((z|0)==2185){i=j;return w|0}else if((z|0)==2186){i=j;return w|0}else if((z|0)==2187){i=j;return w|0}else if((z|0)==2189){i=j;return w|0}else if((z|0)==2192){i=j;return w|0}else if((z|0)==2196){i=j;return w|0}else if((z|0)==2197){i=j;return w|0}else if((z|0)==2198){i=j;return w|0}else if((z|0)==2199){i=j;return w|0}else if((z|0)==2200){i=j;return w|0}else if((z|0)==2201){i=j;return w|0}else if((z|0)==2202){i=j;return w|0}else if((z|0)==2203){i=j;return w|0}else if((z|0)==2204){i=j;return w|0}else if((z|0)==2205){i=j;return w|0}else if((z|0)==2206){i=j;return w|0}else if((z|0)==2207){i=j;return w|0}else if((z|0)==2208){i=j;return w|0}else if((z|0)==2209){i=j;return w|0}else if((z|0)==2210){i=j;return w|0}else if((z|0)==2213){i=j;return w|0}else if((z|0)==2214){i=j;return w|0}return 0}function vx(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=i;i=i+32|0;j=h|0;c[11074]=-1;k=h+16|0;vS(k,0,1346782275);vR(k,4,2);vR(k,6,0);vS(k,8,0);vS(k,12,16);if((v$(f,k,16)|0)!=0){l=1;i=h;return l|0}m=c[11074]|0;n=16;o=k;while(1){p=d[o]<<24^m;q=p<<1;r=(p|0)<0?q^79764919:q;q=r<<1;p=(r|0)<0?q^79764919:q;q=p<<1;r=(p|0)<0?q^79764919:q;q=r<<1;p=(r|0)<0?q^79764919:q;q=p<<1;r=(p|0)<0?q^79764919:q;q=r<<1;p=(r|0)<0?q^79764919:q;q=p<<1;r=(p|0)<0?q^79764919:q;q=r<<1;s=(r|0)<0?q^79764919:q;q=n-1|0;if((q|0)==0){break}else{m=s;n=q;o=o+1|0}}c[11074]=s;s=j|0;o=g+8|0;do{if((c[o>>2]|0)!=0){vR(s,0,17229);vR(s,2,(c[o>>2]|0)+2|0);n=j+4|0;a[n]=10;m=0;q=5;r=s;while(1){p=d[r]<<24^m;t=p<<1;u=(p|0)<0?t^79764919:t;t=u<<1;p=(u|0)<0?t^79764919:t;t=p<<1;u=(p|0)<0?t^79764919:t;t=u<<1;p=(u|0)<0?t^79764919:t;t=p<<1;u=(p|0)<0?t^79764919:t;t=u<<1;p=(u|0)<0?t^79764919:t;t=p<<1;u=(p|0)<0?t^79764919:t;t=u<<1;v=(u|0)<0?t^79764919:t;t=q-1|0;if((t|0)==0){break}else{m=v;q=t;r=r+1|0}}r=g+12|0;q=c[o>>2]|0;if((q|0)==0){w=v}else{m=v;t=q;q=c[r>>2]|0;while(1){u=d[q]<<24^m;p=u<<1;x=(u|0)<0?p^79764919:p;p=x<<1;u=(x|0)<0?p^79764919:p;p=u<<1;x=(u|0)<0?p^79764919:p;p=x<<1;u=(x|0)<0?p^79764919:p;p=u<<1;x=(u|0)<0?p^79764919:p;p=x<<1;u=(x|0)<0?p^79764919:p;p=u<<1;x=(u|0)<0?p^79764919:p;p=x<<1;u=(x|0)<0?p^79764919:p;p=t-1|0;if((p|0)==0){w=u;break}else{m=u;t=p;q=q+1|0}}}q=(w>>31)+335544320&-54452809^w<<1;t=q<<1;m=(q|0)<0?t^79764919:t;t=m<<1;q=(m|0)<0?t^79764919:t;t=q<<1;m=(q|0)<0?t^79764919:t;t=m<<1;q=(m|0)<0?t^79764919:t;t=q<<1;m=(q|0)<0?t^79764919:t;t=m<<1;q=(m|0)<0?t^79764919:t;t=q<<1;m=(q|0)<0?t^79764919:t;if((v$(f,s,5)|0)==0){t=c[11074]|0;q=5;p=s;while(1){u=d[p]<<24^t;x=u<<1;y=(u|0)<0?x^79764919:x;x=y<<1;u=(y|0)<0?x^79764919:x;x=u<<1;y=(u|0)<0?x^79764919:x;x=y<<1;u=(y|0)<0?x^79764919:x;x=u<<1;y=(u|0)<0?x^79764919:x;x=y<<1;u=(y|0)<0?x^79764919:x;x=u<<1;y=(u|0)<0?x^79764919:x;x=y<<1;z=(y|0)<0?x^79764919:x;x=q-1|0;if((x|0)==0){break}else{t=z;q=x;p=p+1|0}}c[11074]=z;A=0}else{A=1}p=c[r>>2]|0;q=c[o>>2]|0;if((v$(f,p,q)|0)==0){t=c[11074]|0;if((q|0)==0){B=t}else{x=t;t=q;q=p;while(1){p=d[q]<<24^x;y=p<<1;u=(p|0)<0?y^79764919:y;y=u<<1;p=(u|0)<0?y^79764919:y;y=p<<1;u=(p|0)<0?y^79764919:y;y=u<<1;p=(u|0)<0?y^79764919:y;y=p<<1;u=(p|0)<0?y^79764919:y;y=u<<1;p=(u|0)<0?y^79764919:y;y=p<<1;u=(p|0)<0?y^79764919:y;y=u<<1;p=(u|0)<0?y^79764919:y;y=t-1|0;if((y|0)==0){B=p;break}else{x=p;t=y;q=q+1|0}}}c[11074]=B;C=0}else{C=1}if((v$(f,n,1)|0)==0){q=d[n]<<24^c[11074];t=q<<1;x=(q|0)<0?t^79764919:t;t=x<<1;q=(x|0)<0?t^79764919:t;t=q<<1;x=(q|0)<0?t^79764919:t;t=x<<1;q=(x|0)<0?t^79764919:t;t=q<<1;x=(q|0)<0?t^79764919:t;t=x<<1;q=(x|0)<0?t^79764919:t;t=q<<1;x=(q|0)<0?t^79764919:t;t=x<<1;c[11074]=(x|0)<0?t^79764919:t;D=0}else{D=1}t=C|A|D;vS(s,0,m);if((v$(f,s,4)|0)==0){x=c[11074]|0;q=4;r=s;while(1){y=d[r]<<24^x;p=y<<1;u=(y|0)<0?p^79764919:p;p=u<<1;y=(u|0)<0?p^79764919:p;p=y<<1;u=(y|0)<0?p^79764919:p;p=u<<1;y=(u|0)<0?p^79764919:p;p=y<<1;u=(y|0)<0?p^79764919:p;p=u<<1;y=(u|0)<0?p^79764919:p;p=y<<1;u=(y|0)<0?p^79764919:p;p=u<<1;E=(u|0)<0?p^79764919:p;p=q-1|0;if((p|0)==0){break}else{x=E;q=p;r=r+1|0}}c[11074]=E;F=0}else{F=1}if((t|F|0)==0){break}else{l=1}i=h;return l|0}}while(0);F=g|0;E=b[F>>1]|0;L2889:do{if(E<<16>>16!=0){s=g+4|0;D=0;A=E;L2891:while(1){C=c[(c[s>>2]|0)+(D<<2)>>2]|0;B=C+2|0;o=b[B>>1]|0;if(o<<16>>16==0){G=A}else{z=C+4|0;C=0;w=o;while(1){o=c[(c[z>>2]|0)+(C<<2)>>2]|0;v=o+2|0;if((b[v>>1]|0)==0){H=w}else{j=o+4|0;o=0;do{r=c[(c[j>>2]|0)+(o<<2)>>2]|0;if((vz(f,r,D,C,0)|0)==0){I=r}else{l=1;J=2262;break L2891}while(1){r=c[I>>2]|0;if((r|0)==0){break}if((vz(f,r,D,C,1)|0)==0){I=r}else{l=1;J=2266;break L2891}}o=o+1|0;}while(o>>>0<(e[v>>1]|0)>>>0);H=b[B>>1]|0}v=C+1|0;if(v>>>0<(H&65535)>>>0){C=v;w=H}else{break}}G=b[F>>1]|0}w=D+1|0;if(w>>>0<(G&65535)>>>0){D=w;A=G}else{break L2889}}if((J|0)==2262){i=h;return l|0}else if((J|0)==2266){i=h;return l|0}}}while(0);if((vy(f,17742,0,0)|0)!=0){l=1;i=h;return l|0}vS(k,0,c[11074]|0);if((v$(f,k,4)|0)!=0){l=1;i=h;return l|0}J=c[11074]|0;G=4;F=k;while(1){k=d[F]<<24^J;H=k<<1;I=(k|0)<0?H^79764919:H;H=I<<1;k=(I|0)<0?H^79764919:H;H=k<<1;I=(k|0)<0?H^79764919:H;H=I<<1;k=(I|0)<0?H^79764919:H;H=k<<1;I=(k|0)<0?H^79764919:H;H=I<<1;k=(I|0)<0?H^79764919:H;H=k<<1;I=(k|0)<0?H^79764919:H;H=I<<1;K=(I|0)<0?H^79764919:H;H=G-1|0;if((H|0)==0){break}else{J=K;G=H;F=F+1|0}}c[11074]=K;ax(f|0)|0;l=0;i=h;return l|0}function vy(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+8|0;h=g|0;vR(h,0,b);vR(h,2,e);b=0;j=4;k=h;while(1){l=(d[k]|0)<<24^b;m=l<<1;n=(l|0)<0?m^79764919:m;m=n<<1;l=(n|0)<0?m^79764919:m;m=l<<1;n=(l|0)<0?m^79764919:m;m=n<<1;l=(n|0)<0?m^79764919:m;m=l<<1;n=(l|0)<0?m^79764919:m;m=n<<1;l=(n|0)<0?m^79764919:m;m=l<<1;n=(l|0)<0?m^79764919:m;m=n<<1;o=(n|0)<0?m^79764919:m;m=j-1|0;if((m|0)==0){break}else{b=o;j=m;k=k+1|0}}if((v$(a,h,4)|0)!=0){p=1;i=g;return p|0}k=c[11074]|0;j=4;b=h;while(1){m=(d[b]|0)<<24^k;n=m<<1;l=(m|0)<0?n^79764919:n;n=l<<1;m=(l|0)<0?n^79764919:n;n=m<<1;l=(m|0)<0?n^79764919:n;n=l<<1;m=(l|0)<0?n^79764919:n;n=m<<1;l=(m|0)<0?n^79764919:n;n=l<<1;m=(l|0)<0?n^79764919:n;n=m<<1;l=(m|0)<0?n^79764919:n;n=l<<1;q=(l|0)<0?n^79764919:n;n=j-1|0;if((n|0)==0){break}else{k=q;j=n;b=b+1|0}}c[11074]=q;if((e|0)==0){r=o}else{q=o;o=e;b=f;while(1){j=(d[b]|0)<<24^q;k=j<<1;n=(j|0)<0?k^79764919:k;k=n<<1;j=(n|0)<0?k^79764919:k;k=j<<1;n=(j|0)<0?k^79764919:k;k=n<<1;j=(n|0)<0?k^79764919:k;k=j<<1;n=(j|0)<0?k^79764919:k;k=n<<1;j=(n|0)<0?k^79764919:k;k=j<<1;n=(j|0)<0?k^79764919:k;k=n<<1;s=(n|0)<0?k^79764919:k;k=o-1|0;if((k|0)==0){break}else{q=s;o=k;b=b+1|0}}if((v$(a,f,e)|0)!=0){p=1;i=g;return p|0}b=c[11074]|0;o=e;e=f;while(1){f=(d[e]|0)<<24^b;q=f<<1;k=(f|0)<0?q^79764919:q;q=k<<1;f=(k|0)<0?q^79764919:q;q=f<<1;k=(f|0)<0?q^79764919:q;q=k<<1;f=(k|0)<0?q^79764919:q;q=f<<1;k=(f|0)<0?q^79764919:q;q=k<<1;f=(k|0)<0?q^79764919:q;q=f<<1;k=(f|0)<0?q^79764919:q;q=k<<1;t=(k|0)<0?q^79764919:q;q=o-1|0;if((q|0)==0){break}else{b=t;o=q;e=e+1|0}}c[11074]=t;r=s}vS(h,0,r);if((v$(a,h,4)|0)!=0){p=1;i=g;return p|0}a=c[11074]|0;r=4;s=h;while(1){h=(d[s]|0)<<24^a;t=h<<1;e=(h|0)<0?t^79764919:t;t=e<<1;h=(e|0)<0?t^79764919:t;t=h<<1;e=(h|0)<0?t^79764919:t;t=e<<1;h=(e|0)<0?t^79764919:t;t=h<<1;e=(h|0)<0?t^79764919:t;t=e<<1;h=(e|0)<0?t^79764919:t;t=h<<1;e=(h|0)<0?t^79764919:t;t=e<<1;u=(e|0)<0?t^79764919:t;t=r-1|0;if((t|0)==0){break}else{a=u;r=t;s=s+1|0}}c[11074]=u;p=0;i=g;return p|0}function vz(e,f,g,h,j){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;k=i;i=i+256|0;l=k|0;m=c[f+12>>2]|0;n=m&1;o=(m&2|0)==0?n:n|2;n=(m&4|0)==0?o:o|4;o=(m&8|0)==0?n:n|8;n=o&255;m=(uN(f)|0)==0;p=b[f+10>>1]|0;do{if(m){q=n;r=(p&65535)+12|0}else{if(p<<16>>16==0){q=n;r=12;break}q=(o|128)&255;r=13}}while(0);o=(j|0)==0?q:q|64;q=l|0;vR(q,0,21315);vR(q,2,r);r=b[f+16>>1]|0;j=r&65535;if((j|0)==1){s=125e3;t=1}else if((j|0)==3){s=5e5;t=r&255}else if((j|0)==32769){s=25e4;t=1}else if((j|0)==16386){s=1e6;t=2}else if((j|0)==2){s=25e4;t=r&255}else if((j|0)==32770){s=5e5;t=2}else{s=0;t=0}vS(q,12,s);a[l+4|0]=o;a[l+5|0]=g&255;a[l+6|0]=h&255;a[l+7|0]=b[f+4>>1]&255;a[l+8|0]=b[f+6>>1]&255;a[l+9|0]=b[f+8>>1]&255;h=f+10|0;g=b[h>>1]|0;a[l+10|0]=(g&65535)>>>8&255;a[l+11|0]=g&255;a[l+12|0]=t;t=0;l=16;g=q;while(1){s=(d[g]|0)<<24^t;j=s<<1;r=(s|0)<0?j^79764919:j;j=r<<1;s=(r|0)<0?j^79764919:j;j=s<<1;r=(s|0)<0?j^79764919:j;j=r<<1;s=(r|0)<0?j^79764919:j;j=s<<1;r=(s|0)<0?j^79764919:j;j=r<<1;s=(r|0)<0?j^79764919:j;j=s<<1;r=(s|0)<0?j^79764919:j;j=r<<1;u=(r|0)<0?j^79764919:j;j=l-1|0;if((j|0)==0){break}else{t=u;l=j;g=g+1|0}}if((v$(e,q,16)|0)!=0){v=1;i=k;return v|0}g=c[11074]|0;l=16;t=q;while(1){j=(d[t]|0)<<24^g;r=j<<1;s=(j|0)<0?r^79764919:r;r=s<<1;j=(s|0)<0?r^79764919:r;r=j<<1;s=(j|0)<0?r^79764919:r;r=s<<1;j=(s|0)<0?r^79764919:r;r=j<<1;s=(j|0)<0?r^79764919:r;r=s<<1;j=(s|0)<0?r^79764919:r;r=j<<1;s=(j|0)<0?r^79764919:r;r=s<<1;w=(s|0)<0?r^79764919:r;r=l-1|0;if((r|0)==0){break}else{g=w;l=r;t=t+1|0}}c[11074]=w;w=c[f+24>>2]|0;do{if(o<<24>>24<0){t=a[w]|0;a[q]=t;l=(t&255)<<24^u;t=l<<1;g=(l|0)<0?t^79764919:t;t=g<<1;l=(g|0)<0?t^79764919:t;t=l<<1;g=(l|0)<0?t^79764919:t;t=g<<1;l=(g|0)<0?t^79764919:t;t=l<<1;g=(l|0)<0?t^79764919:t;t=g<<1;l=(g|0)<0?t^79764919:t;t=l<<1;g=(l|0)<0?t^79764919:t;t=g<<1;if((v$(e,q,1)|0)==0){l=(d[q]|0)<<24^c[11074];r=l<<1;s=(l|0)<0?r^79764919:r;r=s<<1;l=(s|0)<0?r^79764919:r;r=l<<1;s=(l|0)<0?r^79764919:r;r=s<<1;l=(s|0)<0?r^79764919:r;r=l<<1;s=(l|0)<0?r^79764919:r;r=s<<1;l=(s|0)<0?r^79764919:r;r=l<<1;s=(l|0)<0?r^79764919:r;r=s<<1;x=(g|0)<0?t^79764919:t;y=(s|0)<0?r^79764919:r;break}else{v=1;i=k;return v|0}}else{r=b[h>>1]|0;s=r<<16>>16==0;if(s){z=u;A=0}else{t=r&65535;r=u;g=t;l=w;while(1){j=(d[l]|0)<<24^r;n=j<<1;p=(j|0)<0?n^79764919:n;n=p<<1;j=(p|0)<0?n^79764919:n;n=j<<1;p=(j|0)<0?n^79764919:n;n=p<<1;j=(p|0)<0?n^79764919:n;n=j<<1;p=(j|0)<0?n^79764919:n;n=p<<1;j=(p|0)<0?n^79764919:n;n=j<<1;p=(j|0)<0?n^79764919:n;n=p<<1;j=(p|0)<0?n^79764919:n;n=g-1|0;if((n|0)==0){z=j;A=t;break}else{r=j;g=n;l=l+1|0}}}if((v$(e,w,A)|0)!=0){v=1;i=k;return v|0}l=c[11074]|0;if(s){x=z;y=l;break}else{B=l;C=A;D=w}while(1){l=(d[D]|0)<<24^B;g=l<<1;r=(l|0)<0?g^79764919:g;g=r<<1;l=(r|0)<0?g^79764919:g;g=l<<1;r=(l|0)<0?g^79764919:g;g=r<<1;l=(r|0)<0?g^79764919:g;g=l<<1;r=(l|0)<0?g^79764919:g;g=r<<1;l=(r|0)<0?g^79764919:g;g=l<<1;r=(l|0)<0?g^79764919:g;g=r<<1;l=(r|0)<0?g^79764919:g;g=C-1|0;if((g|0)==0){x=z;y=l;break}else{B=l;C=g;D=D+1|0}}}}while(0);c[11074]=y;vS(q,0,x);if((v$(e,q,4)|0)!=0){v=1;i=k;return v|0}x=c[11074]|0;y=4;D=q;while(1){C=(d[D]|0)<<24^x;B=C<<1;z=(C|0)<0?B^79764919:B;B=z<<1;C=(z|0)<0?B^79764919:B;B=C<<1;z=(C|0)<0?B^79764919:B;B=z<<1;C=(z|0)<0?B^79764919:B;B=C<<1;z=(C|0)<0?B^79764919:B;B=z<<1;C=(z|0)<0?B^79764919:B;B=C<<1;z=(C|0)<0?B^79764919:B;B=z<<1;E=(z|0)<0?B^79764919:B;B=y-1|0;if((B|0)==0){break}else{x=E;y=B;D=D+1|0}}c[11074]=E;E=uY(f,q,256)|0;do{if((E|0)!=0){if((vy(e,21575,E,q)|0)==0){break}else{v=1}i=k;return v|0}}while(0);v=0;i=k;return v|0}function vA(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0;j=i;i=i+560|0;k=j|0;l=j+256|0;m=j+288|0;n=j+296|0;o=j+552|0;p=o|0;vS(p,0,g);vS(p,4,h);if(!(a[776]|0)){g=0;do{r=g<<25;s=(g&128|0)!=0?r^517762881:r;r=s<<1;t=(s|0)<0?r^517762881:r;r=t<<1;s=(t|0)<0?r^517762881:r;r=s<<1;t=(s|0)<0?r^517762881:r;r=t<<1;s=(t|0)<0?r^517762881:r;r=s<<1;t=(s|0)<0?r^517762881:r;r=t<<1;s=(t|0)<0?r^517762881:r;r=s<<1;c[41880+(g<<2)>>2]=(s|0)<0?r^517762881:r;g=g+1|0;}while(g>>>0<256);a[776]=1}g=o+1|0;r=c[41880+(d[p]<<2)>>2]|0;s=o+2|0;t=c[41880+((d[g]^r>>>24)<<2)>>2]^r<<8;r=o+3|0;u=c[41880+((d[s]^t>>>24)<<2)>>2]^t<<8;t=o+4|0;v=c[41880+((d[r]^u>>>24)<<2)>>2]^u<<8;u=o+5|0;w=c[41880+((d[t]^v>>>24)<<2)>>2]^v<<8;v=o+6|0;y=c[41880+((d[u]^w>>>24)<<2)>>2]^w<<8;w=o+7|0;o=c[41880+((d[v]^y>>>24)<<2)>>2]^y<<8;y=c[41880+((d[w]^o>>>24)<<2)>>2]^o<<8;o=m|0;if(h>>>0<4){z=1;i=j;return z|0}if((bK(o|0,1,4,b|0)|0)!=4){z=1;i=j;return z|0}if(!(a[776]|0)){A=0;do{B=A<<25;C=(A&128|0)!=0?B^517762881:B;B=C<<1;D=(C|0)<0?B^517762881:B;B=D<<1;C=(D|0)<0?B^517762881:B;B=C<<1;D=(C|0)<0?B^517762881:B;B=D<<1;C=(D|0)<0?B^517762881:B;B=C<<1;D=(C|0)<0?B^517762881:B;B=D<<1;C=(D|0)<0?B^517762881:B;B=C<<1;c[41880+(A<<2)>>2]=(C|0)<0?B^517762881:B;A=A+1|0;}while(A>>>0<256);a[776]=1}A=c[41880+((d[o]^y>>>24)<<2)>>2]^y<<8;y=c[41880+((d[m+1|0]^A>>>24)<<2)>>2]^A<<8;A=c[41880+((d[m+2|0]^y>>>24)<<2)>>2]^y<<8;y=c[41880+((d[m+3|0]^A>>>24)<<2)>>2]^A<<8;A=vQ(o,0)|0;if((A|0)!=262144){o=c[q>>2]|0;bN(o|0,32832,(x=i,i=i+8|0,c[x>>2]=A,x)|0)|0;z=1;i=j;return z|0}A=h-4|0;h=n|0;L3023:do{if((A|0)==0){E=y}else{n=y;o=A;while(1){m=o>>>0<256?o:256;if((bK(h|0,1,m|0,b|0)|0)!=(m|0)){z=1;break}if(!(a[776]|0)){B=0;do{C=B<<25;D=(B&128|0)!=0?C^517762881:C;C=D<<1;F=(D|0)<0?C^517762881:C;C=F<<1;D=(F|0)<0?C^517762881:C;C=D<<1;F=(D|0)<0?C^517762881:C;C=F<<1;D=(F|0)<0?C^517762881:C;C=D<<1;F=(D|0)<0?C^517762881:C;C=F<<1;D=(F|0)<0?C^517762881:C;C=D<<1;c[41880+(B<<2)>>2]=(D|0)<0?C^517762881:C;B=B+1|0;}while(B>>>0<256);a[776]=1}if((m|0)==0){G=n}else{B=m;C=n;D=h;while(1){F=c[41880+((d[D]^C>>>24)<<2)>>2]^C<<8;H=B-1|0;if((H|0)==0){G=F;break}else{B=H;C=F;D=D+1|0}}}if((o|0)==(m|0)){E=G;break L3023}else{n=G;o=o-m|0}}i=j;return z|0}}while(0);if((bK(h|0,1,4,b|0)|0)!=4){z=1;i=j;return z|0}if((vQ(h,0)|0)!=(E|0)){E=c[q>>2]|0;aB(35272,16,1,E|0)|0;z=1;i=j;return z|0}E=k|0;k=l|0;G=l+12|0;A=l+13|0;l=0;L3045:while(1){if((bK(p|0,1,8,b|0)|0)!=8){z=1;I=2503;break}y=(l|0)==0;o=l+10|0;n=l+24|0;L3048:while(1){if(!(a[776]|0)){D=0;do{C=D<<25;B=(D&128|0)!=0?C^517762881:C;C=B<<1;F=(B|0)<0?C^517762881:C;C=F<<1;B=(F|0)<0?C^517762881:C;C=B<<1;F=(B|0)<0?C^517762881:C;C=F<<1;B=(F|0)<0?C^517762881:C;C=B<<1;F=(B|0)<0?C^517762881:C;C=F<<1;B=(F|0)<0?C^517762881:C;C=B<<1;c[41880+(D<<2)>>2]=(B|0)<0?C^517762881:C;D=D+1|0;}while(D>>>0<256);a[776]=1}D=c[41880+(d[p]<<2)>>2]|0;m=c[41880+((d[g]^D>>>24)<<2)>>2]^D<<8;D=c[41880+((d[s]^m>>>24)<<2)>>2]^m<<8;m=c[41880+((d[r]^D>>>24)<<2)>>2]^D<<8;D=c[41880+((d[t]^m>>>24)<<2)>>2]^m<<8;m=c[41880+((d[u]^D>>>24)<<2)>>2]^D<<8;D=c[41880+((d[v]^m>>>24)<<2)>>2]^m<<8;J=c[41880+((d[w]^D>>>24)<<2)>>2]^D<<8;D=vQ(p,0)|0;K=vQ(p,4)|0;do{if((D|0)==1413830740){if((K|0)==0){if((bK(h|0,1,4,b|0)|0)!=4){z=1;I=2472;break L3045}if((vQ(h,0)|0)==(J|0)){break}else{I=2444;break L3045}}L=zH(K)|0;if((L|0)==0){z=1;I=2481;break L3045}if((bK(L|0,1,K|0,b|0)|0)!=(K|0)){I=2451;break L3045}if(a[776]|0){M=K;N=J;O=L}else{m=0;do{C=m<<25;B=(m&128|0)!=0?C^517762881:C;C=B<<1;F=(B|0)<0?C^517762881:C;C=F<<1;B=(F|0)<0?C^517762881:C;C=B<<1;F=(B|0)<0?C^517762881:C;C=F<<1;B=(F|0)<0?C^517762881:C;C=B<<1;F=(B|0)<0?C^517762881:C;C=F<<1;B=(F|0)<0?C^517762881:C;C=B<<1;c[41880+(m<<2)>>2]=(B|0)<0?C^517762881:C;m=m+1|0;}while(m>>>0<256);a[776]=1;M=K;N=J;O=L}while(1){P=c[41880+((d[O]^N>>>24)<<2)>>2]^N<<8;m=M-1|0;if((m|0)==0){break}else{M=m;N=P;O=O+1|0}}m=(a[L]|0)==10;C=(m<<31>>31)+K|0;if((C|0)==0){Q=0}else{B=C-1|0;Q=(a[L+B|0]|0)==10?B:C}C=u9(f,L+(m&1)|0,Q)|0;zI(L);do{if((bK(h|0,1,4,b|0)|0)==4){if((vQ(h,0)|0)==(P|0)){R=0;break}m=c[q>>2]|0;aB(35272,16,1,m|0)|0;R=1}else{R=1}}while(0);if((R|C|0)!=0){z=1;I=2502;break L3045}}else if((D|0)==1145132097){if(y){z=1;I=2479;break L3045}m=e[o>>1]|0;B=m>>>0<K>>>0?m:K;if((B|0)==0){S=J}else{m=c[n>>2]|0;if((bK(m|0,1,B|0,b|0)|0)!=(B|0)){z=1;I=2480;break L3045}if(a[776]|0){T=B;U=J;V=m}else{F=0;do{H=F<<25;W=(F&128|0)!=0?H^517762881:H;H=W<<1;X=(W|0)<0?H^517762881:H;H=X<<1;W=(X|0)<0?H^517762881:H;H=W<<1;X=(W|0)<0?H^517762881:H;H=X<<1;W=(X|0)<0?H^517762881:H;H=W<<1;X=(W|0)<0?H^517762881:H;H=X<<1;W=(X|0)<0?H^517762881:H;H=W<<1;c[41880+(F<<2)>>2]=(W|0)<0?H^517762881:H;F=F+1|0;}while(F>>>0<256);a[776]=1;T=B;U=J;V=m}while(1){F=c[41880+((d[V]^U>>>24)<<2)>>2]^U<<8;C=T-1|0;if((C|0)==0){S=F;break}else{T=C;U=F;V=V+1|0}}}if((B|0)==(K|0)){Y=S}else{m=S;F=K-B|0;while(1){C=F>>>0<256?F:256;if((bK(h|0,1,C|0,b|0)|0)!=(C|0)){z=1;I=2507;break L3045}if(!(a[776]|0)){H=0;do{W=H<<25;X=(H&128|0)!=0?W^517762881:W;W=X<<1;Z=(X|0)<0?W^517762881:W;W=Z<<1;X=(Z|0)<0?W^517762881:W;W=X<<1;Z=(X|0)<0?W^517762881:W;W=Z<<1;X=(Z|0)<0?W^517762881:W;W=X<<1;Z=(X|0)<0?W^517762881:W;W=Z<<1;X=(Z|0)<0?W^517762881:W;W=X<<1;c[41880+(H<<2)>>2]=(X|0)<0?W^517762881:W;H=H+1|0;}while(H>>>0<256);a[776]=1}if((C|0)==0){_=m}else{H=C;W=m;X=h;while(1){Z=c[41880+((d[X]^W>>>24)<<2)>>2]^W<<8;$=H-1|0;if(($|0)==0){_=Z;break}else{H=$;W=Z;X=X+1|0}}}if((F|0)==(C|0)){Y=_;break}else{m=_;F=F-C|0}}}if((bK(h|0,1,4,b|0)|0)!=4){z=1;I=2500;break L3045}if((vQ(h,0)|0)!=(Y|0)){I=2421;break L3045}}else if((D|0)==1413564243){if(y){z=1;I=2484;break L3045}F=K>>>0<256?K:256;if((bK(E|0,1,F|0,b|0)|0)!=(F|0)){z=1;I=2485;break L3045}if(!(a[776]|0)){m=0;do{B=m<<25;X=(m&128|0)!=0?B^517762881:B;B=X<<1;W=(X|0)<0?B^517762881:B;B=W<<1;X=(W|0)<0?B^517762881:B;B=X<<1;W=(X|0)<0?B^517762881:B;B=W<<1;X=(W|0)<0?B^517762881:B;B=X<<1;W=(X|0)<0?B^517762881:B;B=W<<1;X=(W|0)<0?B^517762881:B;B=X<<1;c[41880+(m<<2)>>2]=(X|0)<0?B^517762881:B;m=m+1|0;}while(m>>>0<256);a[776]=1}if((F|0)==0){aa=J}else{m=F;B=J;X=E;while(1){W=c[41880+((d[X]^B>>>24)<<2)>>2]^B<<8;H=m-1|0;if((H|0)==0){aa=W;break}else{m=H;B=W;X=X+1|0}}}uU(l,E,F)|0;if((F|0)==(K|0)){ab=aa}else{X=aa;B=K-F|0;while(1){m=B>>>0<256?B:256;if((bK(h|0,1,m|0,b|0)|0)!=(m|0)){z=1;I=2492;break L3045}if(!(a[776]|0)){W=0;do{H=W<<25;Z=(W&128|0)!=0?H^517762881:H;H=Z<<1;$=(Z|0)<0?H^517762881:H;H=$<<1;Z=($|0)<0?H^517762881:H;H=Z<<1;$=(Z|0)<0?H^517762881:H;H=$<<1;Z=($|0)<0?H^517762881:H;H=Z<<1;$=(Z|0)<0?H^517762881:H;H=$<<1;Z=($|0)<0?H^517762881:H;H=Z<<1;c[41880+(W<<2)>>2]=(Z|0)<0?H^517762881:H;W=W+1|0;}while(W>>>0<256);a[776]=1}if((m|0)==0){ac=X}else{W=m;C=X;H=h;while(1){Z=c[41880+((d[H]^C>>>24)<<2)>>2]^C<<8;$=W-1|0;if(($|0)==0){ac=Z;break}else{W=$;C=Z;H=H+1|0}}}if((B|0)==(m|0)){ab=ac;break}else{X=ac;B=B-m|0}}}if((bK(h|0,1,4,b|0)|0)!=4){z=1;I=2495;break L3045}if((vQ(h,0)|0)!=(ab|0)){I=2440;break L3045}}else if((D|0)==1162757152){I=2352;break L3045}else if((D|0)==1397048148){break L3048}else{if((K|0)==0){ad=J}else{B=J;X=K;while(1){F=X>>>0<256?X:256;if((bK(h|0,1,F|0,b|0)|0)!=(F|0)){z=1;I=2491;break L3045}if(!(a[776]|0)){H=0;do{C=H<<25;W=(H&128|0)!=0?C^517762881:C;C=W<<1;Z=(W|0)<0?C^517762881:C;C=Z<<1;W=(Z|0)<0?C^517762881:C;C=W<<1;Z=(W|0)<0?C^517762881:C;C=Z<<1;W=(Z|0)<0?C^517762881:C;C=W<<1;Z=(W|0)<0?C^517762881:C;C=Z<<1;W=(Z|0)<0?C^517762881:C;C=W<<1;c[41880+(H<<2)>>2]=(W|0)<0?C^517762881:C;H=H+1|0;}while(H>>>0<256);a[776]=1}if((F|0)==0){ae=B}else{H=F;m=B;C=h;while(1){W=c[41880+((d[C]^m>>>24)<<2)>>2]^m<<8;Z=H-1|0;if((Z|0)==0){ae=W;break}else{H=Z;m=W;C=C+1|0}}}if((X|0)==(F|0)){ad=ae;break}else{B=ae;X=X-F|0}}}if((bK(h|0,1,4,b|0)|0)!=4){z=1;I=2476;break L3045}if((vQ(h,0)|0)!=(ad|0)){I=2469;break L3045}}}while(0);if((bK(p|0,1,8,b|0)|0)!=8){z=1;I=2490;break L3045}}if(K>>>0<18){z=1;I=2494;break}if((bK(k|0,1,18,b|0)|0)!=18){z=1;I=2477;break}if(a[776]|0){af=18;ag=J;ah=k}else{n=0;do{o=n<<25;D=(n&128|0)!=0?o^517762881:o;o=D<<1;X=(D|0)<0?o^517762881:o;o=X<<1;D=(X|0)<0?o^517762881:o;o=D<<1;X=(D|0)<0?o^517762881:o;o=X<<1;D=(X|0)<0?o^517762881:o;o=D<<1;X=(D|0)<0?o^517762881:o;o=X<<1;D=(X|0)<0?o^517762881:o;o=D<<1;c[41880+(n<<2)>>2]=(D|0)<0?o^517762881:o;n=n+1|0;}while(n>>>0<256);a[776]=1;af=18;ag=J;ah=k}while(1){ai=c[41880+((d[ah]^ag>>>24)<<2)>>2]^ag<<8;n=af-1|0;if((n|0)==0){break}else{af=n;ag=ai;ah=ah+1|0}}n=vP(k,0)|0;o=vP(k,2)|0;D=vP(k,4)|0;X=vP(k,6)|0;B=vP(k,8)|0;C=vP(k,10)|0;m=a[G]|0;H=vP(k,14)|0;W=vP(k,16)|0;aj=uW(D,X,B,C)|0;if((aj|0)==0){z=1;I=2488;break}if((H&1|0)!=0){C=aj+12|0;c[C>>2]=c[C>>2]|1}if((H&2|0)!=0){C=aj+12|0;c[C>>2]=c[C>>2]|2}if((H&4|0)!=0){C=aj+12|0;c[C>>2]=c[C>>2]|4}if((H&8|0)!=0){C=aj+12|0;c[C>>2]=c[C>>2]|8}uP(aj,W);C=W&4095;if((C|0)==1|(C|0)==2){uQ(aj,m)}else if((C|0)==3){uS(aj,m)}if((H&16384|0)==0){if((u3(f,aj,n,o)|0)!=0){I=2387;break}}else{if(y){I=2384;break}uK(l,aj)}o=K-18|0;if((H&32768|0)!=0){uM(aj,d[A]|0)}if((o|0)==0){ak=ai}else{H=ai;n=o;while(1){o=n>>>0<256?n:256;if((bK(h|0,1,o|0,b|0)|0)!=(o|0)){z=1;I=2506;break L3045}if(!(a[776]|0)){m=0;do{C=m<<25;W=(m&128|0)!=0?C^517762881:C;C=W<<1;B=(W|0)<0?C^517762881:C;C=B<<1;W=(B|0)<0?C^517762881:C;C=W<<1;B=(W|0)<0?C^517762881:C;C=B<<1;W=(B|0)<0?C^517762881:C;C=W<<1;B=(W|0)<0?C^517762881:C;C=B<<1;W=(B|0)<0?C^517762881:C;C=W<<1;c[41880+(m<<2)>>2]=(W|0)<0?C^517762881:C;m=m+1|0;}while(m>>>0<256);a[776]=1}if((o|0)==0){al=H}else{m=o;C=H;W=h;while(1){B=c[41880+((d[W]^C>>>24)<<2)>>2]^C<<8;X=m-1|0;if((X|0)==0){al=B;break}else{m=X;C=B;W=W+1|0}}}if((n|0)==(o|0)){ak=al;break}else{H=al;n=n-o|0}}}if((bK(h|0,1,4,b|0)|0)!=4){z=1;I=2505;break}if((vQ(h,0)|0)==(ak|0)){l=aj}else{I=2402;break}}if((I|0)==2444){l=c[q>>2]|0;aB(35272,16,1,l|0)|0;z=1;i=j;return z|0}else if((I|0)==2451){zI(L);z=1;i=j;return z|0}else if((I|0)==2421){aB(35272,16,1,c[q>>2]|0)|0;z=1;i=j;return z|0}else if((I|0)==2469){aB(35272,16,1,c[q>>2]|0)|0;z=1;i=j;return z|0}else if((I|0)==2352){L3210:do{if((K|0)==0){am=J}else{L=J;l=K;while(1){ak=l>>>0<256?l:256;if((bK(h|0,1,ak|0,b|0)|0)!=(ak|0)){z=1;break}if(!(a[776]|0)){al=0;do{ai=al<<25;A=(al&128|0)!=0?ai^517762881:ai;ai=A<<1;k=(A|0)<0?ai^517762881:ai;ai=k<<1;A=(k|0)<0?ai^517762881:ai;ai=A<<1;k=(A|0)<0?ai^517762881:ai;ai=k<<1;A=(k|0)<0?ai^517762881:ai;ai=A<<1;k=(A|0)<0?ai^517762881:ai;ai=k<<1;A=(k|0)<0?ai^517762881:ai;ai=A<<1;c[41880+(al<<2)>>2]=(A|0)<0?ai^517762881:ai;al=al+1|0;}while(al>>>0<256);a[776]=1}if((ak|0)==0){an=L}else{al=ak;o=L;ai=h;while(1){A=c[41880+((d[ai]^o>>>24)<<2)>>2]^o<<8;k=al-1|0;if((k|0)==0){an=A;break}else{al=k;o=A;ai=ai+1|0}}}if((l|0)==(ak|0)){am=an;break L3210}else{L=an;l=l-ak|0}}i=j;return z|0}}while(0);if((bK(h|0,1,4,b|0)|0)!=4){z=1;i=j;return z|0}if((vQ(h,0)|0)==(am|0)){vb(f);z=0;i=j;return z|0}else{f=c[q>>2]|0;aB(35272,16,1,f|0)|0;z=1;i=j;return z|0}}else if((I|0)==2440){aB(35272,16,1,c[q>>2]|0)|0;z=1;i=j;return z|0}else if((I|0)==2387){uX(aj);z=1;i=j;return z|0}else if((I|0)==2384){aB(39840,32,1,c[q>>2]|0)|0;uX(aj);z=1;i=j;return z|0}else if((I|0)==2402){aB(35272,16,1,c[q>>2]|0)|0;z=1;i=j;return z|0}else if((I|0)==2472){i=j;return z|0}else if((I|0)==2476){i=j;return z|0}else if((I|0)==2477){i=j;return z|0}else if((I|0)==2479){i=j;return z|0}else if((I|0)==2480){i=j;return z|0}else if((I|0)==2481){i=j;return z|0}else if((I|0)==2484){i=j;return z|0}else if((I|0)==2485){i=j;return z|0}else if((I|0)==2488){i=j;return z|0}else if((I|0)==2490){i=j;return z|0}else if((I|0)==2491){i=j;return z|0}else if((I|0)==2492){i=j;return z|0}else if((I|0)==2494){i=j;return z|0}else if((I|0)==2495){i=j;return z|0}else if((I|0)==2500){i=j;return z|0}else if((I|0)==2502){i=j;return z|0}else if((I|0)==2503){i=j;return z|0}else if((I|0)==2505){i=j;return z|0}else if((I|0)==2506){i=j;return z|0}else if((I|0)==2507){i=j;return z|0}return 0}function vB(d,f){d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;i=i+48|0;h=g|0;j=g+8|0;k=g+16|0;l=g+24|0;m=g+40|0;vR(m,0,4);vR(m,2,0);if((vC(d,1346782275,4,m)|0)!=0){n=1;i=g;return n|0}m=l|0;o=f+8|0;do{if((c[o>>2]|0)!=0){vS(m,0,1413830740);vS(m,4,(c[o>>2]|0)+2|0);p=l+8|0;a[p]=10;c[k>>2]=0;q=vD(d,m,9,k)|0;r=vD(d,c[f+12>>2]|0,c[o>>2]|0,k)|0|q;q=r|(vD(d,p,1,k)|0);vS(m,0,c[k>>2]|0);if((q|(aB(m|0,1,4,d|0)|0)!=4|0)==0){break}else{n=1}i=g;return n|0}}while(0);m=f|0;k=b[m>>1]|0;L3269:do{if(k<<16>>16!=0){o=f+4|0;l=0;q=k;L3271:while(1){p=c[(c[o>>2]|0)+(l<<2)>>2]|0;r=p+2|0;s=b[r>>1]|0;if(s<<16>>16==0){t=q}else{u=p+4|0;p=0;v=s;while(1){s=c[(c[u>>2]|0)+(p<<2)>>2]|0;w=s+2|0;if((b[w>>1]|0)==0){x=v}else{y=s+4|0;s=0;do{z=c[(c[y>>2]|0)+(s<<2)>>2]|0;if((vE(d,z,l,p,0)|0)==0){A=z}else{n=1;B=2534;break L3271}while(1){z=c[A>>2]|0;if((z|0)==0){break}if((vE(d,z,l,p,1)|0)==0){A=z}else{n=1;B=2532;break L3271}}s=s+1|0;}while(s>>>0<(e[w>>1]|0)>>>0);x=b[r>>1]|0}w=p+1|0;if(w>>>0<(x&65535)>>>0){p=w;v=x}else{break}}t=b[m>>1]|0}v=l+1|0;if(v>>>0<(t&65535)>>>0){l=v;q=t}else{break L3269}}if((B|0)==2534){i=g;return n|0}else if((B|0)==2532){i=g;return n|0}}}while(0);B=j|0;vS(B,0,1162757152);vS(B,4,0);c[h>>2]=0;if((vD(d,B,8,h)|0)!=0){n=1;i=g;return n|0}vS(B,0,c[h>>2]|0);if((aB(B|0,1,4,d|0)|0)!=4){n=1;i=g;return n|0}ax(d|0)|0;n=0;i=g;return n|0}function vC(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+16|0;g=f|0;h=f+8|0;vS(h,0,b);vS(h,4,d);c[g>>2]=0;if((vD(a,h,8,g)|0)!=0){j=1;i=f;return j|0}do{if((d|0)!=0){if((vD(a,e,d,g)|0)==0){break}else{j=1}i=f;return j|0}}while(0);vS(h,0,c[g>>2]|0);j=(aB(h|0,1,4,a|0)|0)!=4|0;i=f;return j|0}function vD(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((g|0)==0){h=aB(e|0,1,f|0,b|0)|0;i=(h|0)!=(f|0);j=i&1;return j|0}k=c[g>>2]|0;if(!(a[776]|0)){l=0;do{m=l<<25;n=(l&128|0)!=0?m^517762881:m;m=n<<1;o=(n|0)<0?m^517762881:m;m=o<<1;n=(o|0)<0?m^517762881:m;m=n<<1;o=(n|0)<0?m^517762881:m;m=o<<1;n=(o|0)<0?m^517762881:m;m=n<<1;o=(n|0)<0?m^517762881:m;m=o<<1;n=(o|0)<0?m^517762881:m;m=n<<1;c[41880+(l<<2)>>2]=(n|0)<0?m^517762881:m;l=l+1|0;}while(l>>>0<256);a[776]=1}if((f|0)==0){p=k}else{l=f;m=k;k=e;while(1){n=c[41880+(((d[k]|0)^m>>>24)<<2)>>2]^m<<8;o=l-1|0;if((o|0)==0){p=n;break}else{l=o;m=n;k=k+1|0}}}c[g>>2]=p;h=aB(e|0,1,f|0,b|0)|0;i=(h|0)!=(f|0);j=i&1;return j|0}function vE(d,f,g,h,j){d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=i;i=i+256|0;l=k|0;m=c[f+12>>2]|0;n=m&1;o=(m&2|0)==0?n:n|2;n=(m&4|0)==0?o:o|4;o=(m&8|0)==0?n:n|8;n=f+10|0;if((uN(f)|0)==0){p=o}else{p=(b[n>>1]|0)==0?o:o|32768}o=(j|0)==0?p:p|16384;p=l|0;vR(p,0,g);vR(p,2,h);vR(p,4,e[f+4>>1]|0);vR(p,6,e[f+6>>1]|0);vR(p,8,e[f+8>>1]|0);vR(p,10,e[n>>1]|0);vR(p,12,0);vR(p,14,o);h=f+16|0;vR(p,16,e[h>>1]|0);if((o&32768|0)!=0){a[l+13|0]=a[c[f+24>>2]|0]|0}g=b[h>>1]&4095;if((g|0)==1|(g|0)==2){a[l+12|0]=(uR(f)|0)&255}else if((g|0)==3){a[l+12|0]=(uT(f)|0)&255}if((vC(d,1397048148,18,p)|0)!=0){q=1;i=k;return q|0}g=uY(f,p,256)|0;L3337:do{if((g|0)!=0){h=0;while(1){if(h>>>0>=g>>>0){break L3337}if((a[l+h|0]|0)==0){h=h+1|0}else{break}}if((vC(d,1413564243,g,p)|0)==0){break}else{q=1}i=k;return q|0}}while(0);do{if((o&32776|0)==0){p=b[n>>1]|0;if(p<<16>>16==0){break}if((vC(d,1145132097,p&65535,c[f+24>>2]|0)|0)==0){break}else{q=1}i=k;return q|0}}while(0);q=0;i=k;return q|0}function vF(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=u1()|0;if((b|0)==0){d=0;return d|0}e=a$(a|0)|0;L3354:do{if((bS(a|0,0,2)|0)==0){f=a$(a|0)|0;if((bS(a|0,e|0,0)|0)==0){g=0}else{break}while(1){h=c[15552+(g*24|0)>>2]|0;if((h|0)==0){break L3354}if((h|0)==(f|0)){break}else{g=g+1|0}}f=15556+(g*24|0)|0;h=c[f>>2]|0;if((h|0)==0){d=b;return d|0}i=15560+(g*24|0)|0;j=15564+(g*24|0)|0;k=15568+(g*24|0)|0;l=15572+(g*24|0)|0;m=0;n=c[i>>2]|0;o=h;L3363:while(1){if((n|0)==0){p=0;q=o}else{h=0;do{r=u4(b,m,h,1)|0;if((r|0)==0){break L3354}else{s=0}while(1){if(s>>>0>=(c[j>>2]|0)>>>0){break}s=s+1|0;t=uW(m,h,s,c[k>>2]|0)|0;if((t|0)==0){break L3354}uP(t,c[l>>2]|0);if((u_(r,t)|0)!=0){u=2588;break L3363}v=bK(c[t+24>>2]|0,1,c[k>>2]|0,a|0)|0;if((v|0)!=(c[k>>2]|0)){break L3354}}h=h+1|0;w=c[i>>2]|0;}while(h>>>0<w>>>0);p=w;q=c[f>>2]|0}h=m+1|0;if(h>>>0<q>>>0){m=h;n=p;o=q}else{d=b;u=2598;break}}if((u|0)==2588){uX(t);break}else if((u|0)==2598){return d|0}}}while(0);u2(b);d=0;return d|0}function vG(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=d|0;g=b[f>>1]|0;L3382:do{if(g<<16>>16!=0){h=d+4|0;i=0;j=g;L3384:while(1){k=c[(c[h>>2]|0)+(i<<2)>>2]|0;l=k+2|0;if((b[l>>1]|0)==0){m=j}else{n=k+4|0;k=0;do{o=c[(c[n>>2]|0)+(k<<2)>>2]|0;p=o+2|0;q=b[p>>1]|0;L3390:do{if(q<<16>>16!=0){r=c[o+4>>2]|0;s=q&65535;t=0;u=65535;v=0;while(1){w=c[r+(t<<2)>>2]|0;x=e[w+8>>1]|0;y=x>>>0<u>>>0;z=y?w:v;w=t+1|0;if(w>>>0<s>>>0){t=w;u=y?x:u;v=z}else{break}}if((z|0)==0){break}v=o+4|0;u=z;t=z;while(1){s=(e[u+8>>1]|0)+1|0;r=t+10|0;x=aB(c[t+24>>2]|0,1,e[r>>1]|0,a|0)|0;if((x|0)!=(e[r>>1]|0)){A=1;break L3384}r=b[p>>1]|0;if(r<<16>>16==0){break L3390}x=c[v>>2]|0;y=r&65535;r=0;w=65535;B=0;while(1){C=c[x+(r<<2)>>2]|0;D=e[C+8>>1]|0;E=D>>>0>=s>>>0&D>>>0<w>>>0;F=E?C:B;C=r+1|0;if(C>>>0<y>>>0){r=C;w=E?D:w;B=F}else{break}}if((F|0)==0){break L3390}u=F;t=F}}}while(0);k=k+1|0;}while(k>>>0<(e[l>>1]|0)>>>0);m=b[f>>1]|0}l=i+1|0;if(l>>>0<(m&65535)>>>0){i=l;j=m}else{break L3382}}return A|0}}while(0);ax(a|0)|0;A=0;return A|0}function vH(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;if((bS(a|0,0,2)|0)!=0){b=0;return b|0}d=a$(a|0)|0;a=0;while(1){e=15552+(a*24|0)|0;f=c[e>>2]|0;if((f|0)==0){g=0;break}if((f|0)==(d|0)){g=e;break}else{a=a+1|0}}b=(g|0)!=0|0;return b|0}function vI(b){b=b|0;var e=0,f=0,g=0,h=0;e=b+65544|0;f=c[e>>2]|0;g=(d[(f>>>3)+(b+4)|0]&128>>>((f&7)>>>0)|0)!=0|0;h=f+1|0;c[e>>2]=h;if(h>>>0>=(c[b+65540>>2]|0)>>>0){c[e>>2]=0;e=b+65548|0;c[e>>2]=(c[e>>2]|0)+1}e=b+65555|0;a[e]=(a[e]|0)==0|0;return g|0}function vJ(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0;g=i;i=i+65616|0;h=g+8|0;j=g+16|0;k=g+24|0;l=g+32|0;m=g+40|0;n=g+48|0;o=g+56|0;p=u1()|0;if((p|0)==0){r=0;i=g;return r|0}s=o|0;c[s>>2]=f;f=o+65540|0;zP(f|0,0,16);t=g|0;u=o+65544|0;v=o+65554|0;w=o+65548|0;y=j|0;z=j+1|0;A=j+2|0;B=j+3|0;C=j+4|0;D=j+5|0;j=o+65552|0;E=h|0;F=h+1|0;h=o+4|0;G=0;L3427:while(1){H=G<<1;I=0;do{c[u>>2]=0;c[f>>2]=0;a[v]=0;J=c[s>>2]|0;K=I+H<<1;if((bS(J|0,K+773|0,0)|0)!=0){break L3427}if((bK(t|0,1,2,J|0)|0)!=2){break L3427}L=(vP(t,0)|0)<<8;L3433:do{if((L|0)!=0){if((bS(J|0,K+1285|0,0)|0)!=0){break L3427}if((bK(t|0,1,2,J|0)|0)!=2){break L3427}M=vT(t,0)|0;if((bS(J|0,L|0,0)|0)!=0){break L3427}if((bK(h|0,1,M|0,J|0)|0)!=(M|0)){break L3427}c[u>>2]=0;N=M<<3;c[f>>2]=N;if((N|0)==0){break}else{O=0}while(1){if(O>>>0>=2){break L3433}c[w>>2]=0;c[u>>2]=0;L3442:do{do{if((vK(o,n,m)|0)==0){if((O|0)==1){if((c[m>>2]|0)==0){break}}else if((O|0)==0){if((c[m>>2]|0)!=0){break}}if((c[w>>2]|0)!=0){break L3442}N=d[n]|0;M=c[m>>2]|0;P=c[u>>2]|0;do{if((N|0)==254){vL(o,y);vL(o,z);vL(o,A);vL(o,B);vL(o,C);vL(o,D);Q=vP(y,4)|0;R=e[j>>1]|0;S=4;T=y;while(1){U=d[T]<<8^R;V=U<<1;W=(U&32768|0)==0?V:V^4129;V=W<<1;U=(W&32768|0)==0?V:V^4129;V=U<<1;W=(U&32768|0)==0?V:V^4129;V=W<<1;U=(W&32768|0)==0?V:V^4129;V=U<<1;W=(U&32768|0)==0?V:V^4129;V=W<<1;U=(W&32768|0)==0?V:V^4129;V=U<<1;W=(U&32768|0)==0?V:V^4129;V=W<<1;X=(W&32768|0)==0?V:V^4129;V=S-1|0;if((V|0)==0){break}else{R=X;S=V;T=T+1|0}}b[j>>1]=X&65535;T=a[B]|0;S=uW(d[y]|0,d[z]|0,d[A]|0,(T&255)<6?128<<(T&255):8192)|0;if((S|0)==0){break L3427}uQ(S,a[B]|0);uO(S,8,1);if((X&65535|0)!=(Q|0)){uO(S,1,1)}uM(S,0);if((M|0)==0){uP(S,2)}else{uP(S,1)}u3(p,S,G,I)|0;if((vK(o,l,k)|0)!=0){break}T=a[l]|0;if(!((T<<24>>24|0)==(-8|0)|(T<<24>>24|0)==(-5|0))){break}R=S+24|0;V=c[R>>2]|0;W=S+10|0;U=b[W>>1]|0;Y=U&65535;if(U<<16>>16!=0){Z=0;do{vL(o,V+Z|0);Z=Z+1|0;}while(Z>>>0<Y>>>0);if(U<<16>>16!=(b[W>>1]|0)){break L3427}}vL(o,E);vL(o,F);uO(S,8,0);uO(S,4,T<<24>>24==-8|0);Y=vP(E,0)|0;Z=e[j>>1]|0;V=b[W>>1]|0;if(V<<16>>16==0){_=Z}else{Q=Z;Z=V&65535;V=c[R>>2]|0;while(1){$=d[V]<<8^Q;aa=$<<1;ab=($&32768|0)==0?aa:aa^4129;aa=ab<<1;$=(ab&32768|0)==0?aa:aa^4129;aa=$<<1;ab=($&32768|0)==0?aa:aa^4129;aa=ab<<1;$=(ab&32768|0)==0?aa:aa^4129;aa=$<<1;ab=($&32768|0)==0?aa:aa^4129;aa=ab<<1;$=(ab&32768|0)==0?aa:aa^4129;aa=$<<1;ab=($&32768|0)==0?aa:aa^4129;aa=ab<<1;$=(ab&32768|0)==0?aa:aa^4129;aa=Z-1|0;if((aa|0)==0){_=$;break}else{Q=$;Z=aa;V=V+1|0}}}b[j>>1]=_&65535;if((_&65535|0)==(Y|0)){break}uO(S,2,1)}else if(!((N|0)==248|(N|0)==251)){V=c[f>>2]|0;bN(c[q>>2]|0,35160,(x=i,i=i+48|0,c[x>>2]=N,c[x+8>>2]=(M|0)!=0?39816:32824,c[x+16>>2]=G,c[x+24>>2]=I,c[x+32>>2]=P,c[x+40>>2]=V,x)|0)|0}}while(0);c[w>>2]=0;c[u>>2]=P}}while(0);}while((c[w>>2]|0)==0);if((u6(p,G,I,0,1)|0)==0){O=O+1|0}else{break}}}}while(0);I=I+1|0;}while(I>>>0<2);I=G+1|0;if(I>>>0<80){G=I}else{r=p;ac=2678;break}}if((ac|0)==2678){i=g;return r|0}u2(p);r=0;i=g;return r|0}function vK(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;c[h>>2]=0;a[g]=0;i=f+65554|0;a[i]=0;j=f+65548|0;k=c[j>>2]|0;l=k+2|0;m=f+65544|0;n=f+65555|0;o=c[f+65540>>2]|0;p=0;q=c[m>>2]|0;r=k;while(1){k=(d[(q>>>3)+(f+4)|0]&128>>>((q&7)>>>0)|0)!=0|0;s=q+1|0;c[m>>2]=s;if(s>>>0<o>>>0){t=s;u=r}else{c[m>>2]=0;s=r+1|0;c[j>>2]=s;t=0;u=s}a[n]=(a[n]|0)==0|0;s=k|p<<1;k=s&65535;if((k|0)==62831){v=2687;break}else if((k|0)==17545){v=2684;break}else if((k|0)==62846){v=2686;break}else if((k|0)==63338){v=2685;break}else if((k|0)==62826){v=2688;break}if((a[g]|0)!=0){break}if(u>>>0<l>>>0){p=s;q=t;r=u}else{w=1;v=2697;break}}if((v|0)==2687){a[g]=-5}else if((v|0)==2697){return w|0}else if((v|0)==2684){a[g]=-95}else if((v|0)==2686){a[g]=-2}else if((v|0)==2685){a[g]=-4}else if((v|0)==2688){a[g]=-8}a[i]=1;a[n]=1;n=d[g]<<8^65535;i=n<<1;u=(n&32768|0)==0?i:i^4129;i=u<<1;n=(u&32768|0)==0?i:i^4129;i=n<<1;u=(n&32768|0)==0?i:i^4129;i=u<<1;n=(u&32768|0)==0?i:i^4129;i=n<<1;u=(n&32768|0)==0?i:i^4129;i=u<<1;n=(u&32768|0)==0?i:i^4129;i=n<<1;u=(n&32768|0)==0?i:i^4129;i=u<<1;n=f+65552|0;b[n>>1]=((u&32768|0)==0?i:i^4129)&65535;if((a[g]|0)==-95){x=0}else{c[h>>2]=1;w=0;return w|0}while(1){vL(f,g);h=d[g]<<8^e[n>>1];i=h<<1;u=(h&32768|0)==0?i:i^4129;i=u<<1;h=(u&32768|0)==0?i:i^4129;i=h<<1;u=(h&32768|0)==0?i:i^4129;i=u<<1;h=(u&32768|0)==0?i:i^4129;i=h<<1;u=(h&32768|0)==0?i:i^4129;i=u<<1;h=(u&32768|0)==0?i:i^4129;i=h<<1;u=(h&32768|0)==0?i:i^4129;i=u<<1;b[n>>1]=((u&32768|0)==0?i:i^4129)&65535;if(x>>>0>=2){w=0;v=2699;break}if((a[g]|0)==-95){x=x+1|0}else{w=0;v=2698;break}}if((v|0)==2699){return w|0}else if((v|0)==2698){return w|0}return 0}function vL(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;a[d]=0;e=b+65555|0;if((a[e]|0)==0){f=0}else{g=b+65544|0;h=(c[g>>2]|0)+1|0;c[g>>2]=h;if(h>>>0>=(c[b+65540>>2]|0)>>>0){c[g>>2]=0;g=b+65548|0;c[g>>2]=(c[g>>2]|0)+1}a[e]=0;f=a[d]<<1}a[d]=f;if((vI(b)|0)!=0){a[d]=a[d]|1}vI(b)|0;a[d]=a[d]<<1;if((vI(b)|0)!=0){a[d]=a[d]|1}vI(b)|0;a[d]=a[d]<<1;if((vI(b)|0)!=0){a[d]=a[d]|1}vI(b)|0;a[d]=a[d]<<1;if((vI(b)|0)!=0){a[d]=a[d]|1}vI(b)|0;a[d]=a[d]<<1;if((vI(b)|0)!=0){a[d]=a[d]|1}vI(b)|0;a[d]=a[d]<<1;if((vI(b)|0)!=0){a[d]=a[d]|1}vI(b)|0;a[d]=a[d]<<1;if((vI(b)|0)!=0){a[d]=a[d]|1}vI(b)|0;a[d]=a[d]<<1;if((vI(b)|0)==0){i=vI(b)|0;return}a[d]=a[d]|1;i=vI(b)|0;return}function vM(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0;g=i;i=i+48|0;h=g|0;j=g+8|0;k=g+16|0;l=g+32|0;m=u1()|0;if((m|0)==0){n=0;i=g;return n|0}o=l|0;L3548:do{if((vZ(f,o,12)|0)==0){p=a[o]|0;if((p<<24>>24|0)==116){if((a[l+1|0]|0)!=100){break}r=c[q>>2]|0;aB(39768,40,1,r|0)|0;break}else if((p<<24>>24|0)!=84){break}if((a[l+1|0]|0)!=68){break}if((a[l+2|0]|0)!=0){break}if((d[l+4|0]|0)>21){break}p=a[l+5|0]|0;r=a[l+7|0]|0;s=vT(o,10)|0;t=0;u=10;v=o;while(1){w=d[v]<<8^t;y=w<<1;z=(w&32768|0)==0?y:y^41111;y=z<<1;w=(z&32768|0)==0?y:y^41111;y=w<<1;z=(w&32768|0)==0?y:y^41111;y=z<<1;w=(z&32768|0)==0?y:y^41111;y=w<<1;z=(w&32768|0)==0?y:y^41111;y=z<<1;w=(z&32768|0)==0?y:y^41111;y=w<<1;z=(w&32768|0)==0?y:y^41111;y=z<<1;A=(z&32768|0)==0?y:y^41111;y=u-1|0;if((y|0)==0){break}else{t=A;u=y;v=v+1|0}}v=p&255;u=A&65535;if((s|0)!=(u|0)){t=c[q>>2]|0;bN(t|0,32784,(x=i,i=i+16|0,c[x>>2]=s,c[x+8>>2]=u,x)|0)|0;break}u=k|0;do{if(r<<24>>24<0){if((vZ(f,u,10)|0)!=0){break L3548}t=vT(u,0)|0;y=0;z=8;w=k+2|0;while(1){B=d[w]<<8^y;C=B<<1;D=(B&32768|0)==0?C:C^41111;C=D<<1;B=(D&32768|0)==0?C:C^41111;C=B<<1;D=(B&32768|0)==0?C:C^41111;C=D<<1;B=(D&32768|0)==0?C:C^41111;C=B<<1;D=(B&32768|0)==0?C:C^41111;C=D<<1;B=(D&32768|0)==0?C:C^41111;C=B<<1;D=(B&32768|0)==0?C:C^41111;C=D<<1;E=(D&32768|0)==0?C:C^41111;C=z-1|0;if((C|0)==0){break}else{y=E;z=C;w=w+1|0}}w=E&65535;z=vT(u,2)|0;if((z|0)==0){F=w}else{y=zH(z)|0;if((y|0)==0){break L3548}if((vZ(f,y,z)|0)==0){G=w;H=z;I=y}else{zI(y);break L3548}while(1){w=d[I]<<8^G;C=w<<1;D=(w&32768|0)==0?C:C^41111;C=D<<1;w=(D&32768|0)==0?C:C^41111;C=w<<1;D=(w&32768|0)==0?C:C^41111;C=D<<1;w=(D&32768|0)==0?C:C^41111;C=w<<1;D=(w&32768|0)==0?C:C^41111;C=D<<1;w=(D&32768|0)==0?C:C^41111;C=w<<1;D=(w&32768|0)==0?C:C^41111;C=D<<1;J=(D&32768|0)==0?C:C^41111;C=H-1|0;if((C|0)==0){break}else{G=J;H=C;I=I+1|0}}C=J&65535;D=0;while(1){if(D>>>0>=z>>>0){K=z;break}if((a[y+D|0]|0)==0){D=D+1|0}else{K=z;break}}while(1){if(D>>>0>=K>>>0){break}z=K-1|0;if((a[y+z|0]|0)==0){K=z}else{L=D;M=2749;break}}if((M|0)==2749){while(1){M=0;z=y+L|0;if((a[z]|0)==0){a[z]=10}z=L+1|0;if(z>>>0<K>>>0){L=z;M=2749}else{break}}}va(m,y+D|0,K-D|0)|0;zI(y);vb(m);F=C}if((t|0)==(F|0)){break}bN(c[q>>2]|0,40568,(x=i,i=i+16|0,c[x>>2]=t,c[x+8>>2]=F,x)|0)|0;break L3548}}while(0);if((vZ(f,u,1)|0)!=0){break}r=k+1|0;s=k+3|0;p=v|128;z=j|0;w=j+2|0;B=j+3|0;N=j+4|0;O=j+1|0;P=j+5|0;Q=h|0;R=h+2|0;S=h+3|0;T=h+1|0;U=k+2|0;L3594:while(1){if((a[u]|0)==-1){n=m;M=2826;break}if((vZ(f,r,3)|0)!=0){break L3548}V=a[u]|0;W=V&255;X=W<<9;Y=(W&128|0)==0?X:X^41111;X=Y<<1;Z=(Y&32768|0)==0?X:X^41111;X=Z<<1;Y=(Z&32768|0)==0?X:X^41111;X=Y<<1;Z=(Y&32768|0)==0?X:X^41111;X=Z<<1;Y=(Z&32768|0)==0?X:X^41111;X=Y<<1;Z=(Y&32768|0)==0?X:X^41111;X=Z<<1;Y=(Z&32768|0)==0?X:X^41111;X=Y<<1;_=d[r]|0;Z=((Y&32768|0)==0?X:X^41111)^_<<8;X=Z<<1;Y=(Z&32768|0)==0?X:X^41111;X=Y<<1;Z=(Y&32768|0)==0?X:X^41111;X=Z<<1;Y=(Z&32768|0)==0?X:X^41111;X=Y<<1;Z=(Y&32768|0)==0?X:X^41111;X=Z<<1;Y=(Z&32768|0)==0?X:X^41111;X=Y<<1;Z=(Y&32768|0)==0?X:X^41111;X=Z<<1;Y=(Z&32768|0)==0?X:X^41111;X=Y<<1;Z=d[U]|0;$=((Y&32768|0)==0?X:X^41111)^Z<<8;X=$<<1;Y=($&32768|0)==0?X:X^41111;X=Y<<1;$=(Y&32768|0)==0?X:X^41111;X=$<<1;Y=($&32768|0)==0?X:X^41111;X=Y<<1;$=(Y&32768|0)==0?X:X^41111;X=$<<1;Y=($&32768|0)==0?X:X^41111;X=Y<<1;$=(Y&32768|0)==0?X:X^41111;X=$<<1;Y=($&32768|0)==0?X:X^41111;X=Y<<1;aa=(Y&32768|0)==0?X:X^41111;ab=d[s]|0;if((ab|0)!=(aa&255|0)){M=2761;break}ac=Z&127;X=(Z&128|0)==0?v:p;if(V<<24>>24!=0){V=2-(X>>>7)|0;Z=(X&127|0)==2?V|32768:V;V=0;do{if((vZ(f,z,6)|0)!=0){break L3548}ad=d[w]|0;X=a[B]|0;Y=d[N]|0;$=(X&255)<7;if($){ae=128<<(X&255)}else{ae=0}af=uW(d[z]|0,d[O]|0,ad,ae)|0;if((af|0)==0){break L3548}uQ(af,a[B]|0);if((u3(m,af,_,ac)|0)!=0){M=2769;break L3594}uP(af,Z);if((Y&2|0)!=0){uO(af,2,1)}if((Y&4|0)!=0){uO(af,4,1)}X=a[P]|0;ag=0;ah=5;ai=z;while(1){aj=d[ai]<<8^ag;ak=aj<<1;al=(aj&32768|0)==0?ak:ak^41111;ak=al<<1;aj=(al&32768|0)==0?ak:ak^41111;ak=aj<<1;al=(aj&32768|0)==0?ak:ak^41111;ak=al<<1;aj=(al&32768|0)==0?ak:ak^41111;ak=aj<<1;al=(aj&32768|0)==0?ak:ak^41111;ak=al<<1;aj=(al&32768|0)==0?ak:ak^41111;ak=aj<<1;al=(aj&32768|0)==0?ak:ak^41111;ak=al<<1;am=(al&32768|0)==0?ak:ak^41111;ak=ah-1|0;if((ak|0)==0){break}else{ag=am;ah=ak;ai=ai+1|0}}an=X&255;ai=am&65535;do{if((Y&48|0)==0){do{if($){if((vZ(f,z,3)|0)!=0){break L3548}ah=vT(z,0)|0;if((ah|0)==0){M=2784;break L3594}ag=ah-1|0;ao=a[w]|0;if((ao<<24>>24|0)==1){if((ag|0)!=4){break L3548}if((vZ(f,Q,4)|0)!=0){break L3548}ah=vT(Q,0)|0;ak=af+10|0;if((ah<<1|0)!=(e[ak>>1]|0)){break L3548}if((ah|0)==0){ap=ak;break}al=af+24|0;aj=0;while(1){aq=aj<<1;a[(c[al>>2]|0)+aq|0]=a[R]|0;a[(c[al>>2]|0)+(aq|1)|0]=a[S]|0;aq=aj+1|0;if(aq>>>0<ah>>>0){aj=aq}else{ap=ak;break}}}else if((ao<<24>>24|0)==0){ak=af+10|0;if((e[ak>>1]|0)!=(ag|0)){break L3548}if((vZ(f,c[af+24>>2]|0,ag)|0)==0){ap=ak;break}else{M=2788;break L3594}}else if((ao<<24>>24|0)==2){ak=af+10|0;if((ag|0)==0){ar=0}else{aj=af+24|0;ah=ag;al=0;while(1){if(ah>>>0<2){break L3548}if((vZ(f,Q,2)|0)!=0){break L3548}aq=ah-2|0;as=a[Q]|0;do{if((as<<24>>24|0)==1){at=a[T]|0;au=at&255;if(aq>>>0<2){break L3548}av=(au<<1)+al|0;if(av>>>0>(e[ak>>1]|0)>>>0){break L3548}if((vZ(f,R,2)|0)!=0){break L3548}aw=ah-4|0;if(at<<24>>24==0){ax=al;ay=aw;break}else{az=al;aA=au}while(1){a[(c[aj>>2]|0)+az|0]=a[R]|0;a[(c[aj>>2]|0)+(az+1)|0]=a[S]|0;au=aA-1|0;if((au|0)==0){ax=av;ay=aw;break}else{az=az+2|0;aA=au}}}else if((as<<24>>24|0)==0){aw=d[T]|0;if(aw>>>0>aq>>>0){break L3548}av=aw+al|0;if(av>>>0>(e[ak>>1]|0)>>>0){break L3548}if((vZ(f,(c[aj>>2]|0)+al|0,aw)|0)!=0){break L3548}ax=av;ay=aq-aw|0}else{break L3548}}while(0);if((ay|0)==0){ar=ax;break}else{ah=ay;al=ax}}}if(ar>>>0<(e[ak>>1]|0)>>>0){break L3548}else{ap=ak;break}}else{M=2811;break L3594}}else{ap=af+10|0}}while(0);al=b[ap>>1]|0;if(al<<16>>16==0){aC=0;aD=ai;aE=ai}else{ah=al&65535;al=c[af+24>>2]|0;aj=ai;ag=ah;aq=al;while(1){as=d[aq]<<8^aj;aw=as<<1;av=(as&32768|0)==0?aw:aw^41111;aw=av<<1;as=(av&32768|0)==0?aw:aw^41111;aw=as<<1;av=(as&32768|0)==0?aw:aw^41111;aw=av<<1;as=(av&32768|0)==0?aw:aw^41111;aw=as<<1;av=(as&32768|0)==0?aw:aw^41111;aw=av<<1;as=(av&32768|0)==0?aw:aw^41111;aw=as<<1;av=(as&32768|0)==0?aw:aw^41111;aw=av<<1;aF=(av&32768|0)==0?aw:aw^41111;aw=ag-1|0;if((aw|0)==0){aG=0;aH=ah;aI=al;break}else{aj=aF;ag=aw;aq=aq+1|0}}while(1){aq=d[aI]<<8^aG;ag=aq<<1;aj=(aq&32768|0)==0?ag:ag^41111;ag=aj<<1;aq=(aj&32768|0)==0?ag:ag^41111;ag=aq<<1;aj=(aq&32768|0)==0?ag:ag^41111;ag=aj<<1;aq=(aj&32768|0)==0?ag:ag^41111;ag=aq<<1;aj=(aq&32768|0)==0?ag:ag^41111;ag=aj<<1;aq=(aj&32768|0)==0?ag:ag^41111;ag=aq<<1;aj=(aq&32768|0)==0?ag:ag^41111;ag=aj<<1;aJ=(aj&32768|0)==0?ag:ag^41111;ag=aH-1|0;if((ag|0)==0){break}else{aG=aJ;aH=ag;aI=aI+1|0}}aC=aJ;aD=aF;aE=aF&65535}if((an|0)!=(aC&255|0)){ag=c[q>>2]|0;aB(24288,33,1,ag|0)|0;if((an|0)!=(aD&255|0)){M=2819;break L3594}}if((Y&64|0)==0){break}ag=c[q>>2]|0;aj=e[af+8>>1]|0;bN(ag|0,21552,(x=i,i=i+24|0,c[x>>2]=_,c[x+8>>2]=ac,c[x+16>>2]=aj,x)|0)|0;u5(m,af);uX(af)}else{if((an|0)!=(am&255|0)){M=2778;break L3594}uM(af,(Y&16|0)!=0?246:0)}}while(0);V=V+1|0;}while(V>>>0<W>>>0)}if((vZ(f,u,1)|0)!=0){break L3548}}if((M|0)==2769){uX(af);break}else if((M|0)==2784){bN(c[q>>2]|0,27080,(x=i,i=i+24|0,c[x>>2]=_,c[x+8>>2]=ac,c[x+16>>2]=ad,x)|0)|0;break}else if((M|0)==2811){bN(c[q>>2]|0,25504,(x=i,i=i+32|0,c[x>>2]=_,c[x+8>>2]=ac,c[x+16>>2]=ad,c[x+24>>2]=ao&255,x)|0)|0;break}else if((M|0)==2778){u=e[af+8>>1]|0;bN(c[q>>2]|0,28776,(x=i,i=i+24|0,c[x>>2]=_,c[x+8>>2]=ac,c[x+16>>2]=u,x)|0)|0;break}else if((M|0)==2761){bN(c[q>>2]|0,30832,(x=i,i=i+16|0,c[x>>2]=ab,c[x+8>>2]=aa&65535,x)|0)|0;break}else if((M|0)==2788){aB(41632,16,1,c[q>>2]|0)|0;break}else if((M|0)==2826){i=g;return n|0}else if((M|0)==2819){u=e[af+8>>1]|0;bN(c[q>>2]|0,22696,(x=i,i=i+48|0,c[x>>2]=_,c[x+8>>2]=ac,c[x+16>>2]=u,c[x+24>>2]=an,c[x+32>>2]=aC&65535,c[x+40>>2]=aE,x)|0)|0;break}}}while(0);u2(m);n=0;i=g;return n|0}function vN(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0;h=i;i=i+40|0;j=h|0;k=h+8|0;l=h+16|0;m=h+32|0;n=l|0;o=g|0;p=b[o>>1]|0;do{if(p<<16>>16==0){q=0;r=0;s=2843}else{t=c[g+4>>2]|0;u=p&65535;v=0;w=0;x=0;y=0;while(1){z=c[t+(y<<2)>>2]|0;A=b[z+2>>1]|0;B=A&65535;C=B>>>0>v>>>0?B:v;if(A<<16>>16==0){D=w;E=x}else{A=c[z+4>>2]|0;z=w;F=x;G=0;while(1){H=c[A+(G<<2)>>2]|0;I=b[H+2>>1]|0;J=I&65535;K=J>>>0>z>>>0?J:z;if(I<<16>>16==0){L=F}else{I=H+4|0;H=F;M=0;while(1){if((H|0)==0){N=e[(c[(c[I>>2]|0)+(M<<2)>>2]|0)+16>>1]|0}else{N=H}O=M+1|0;if(O>>>0<J>>>0){H=N;M=O}else{L=N;break}}}M=G+1|0;if(M>>>0<B>>>0){z=K;F=L;G=M}else{D=K;E=L;break}}}G=y+1|0;if(G>>>0<u>>>0){v=C;w=D;x=E;y=G}else{break}}y=C&255;if((E|0)==32770){P=2;Q=D;R=y;break}else if((E|0)==32769){P=-126;Q=D;R=y;break}else if((E|0)==2){P=0;Q=D;R=y;break}else if((E|0)==1){P=-128;Q=D;R=y;break}else{q=D;r=y;s=2843;break}}}while(0);if((s|0)==2843){P=0;Q=q;R=r}do{if((p&65535)<45){S=1}else{if(Q>>>0<12){S=3;break}S=Q>>>0<17?2:4}}while(0);a[n]=84;Q=l+1|0;a[Q]=68;p=l+2|0;a[p]=0;r=l+3|0;a[r]=0;q=l+4|0;a[q]=21;D=l+5|0;a[D]=P;P=l+6|0;a[P]=S;S=l+7|0;a[S]=0;E=l+8|0;a[E]=0;C=l+9|0;a[C]=R;R=g+8|0;if((c[R>>2]|0)==0){T=0;U=9;V=n;W=21504}else{a[S]=-128;T=0;U=9;V=n;W=21504}while(1){l=T^W;L=l<<1;N=(l&32768|0)==0?L:L^41111;L=N<<1;l=(N&32768|0)==0?L:L^41111;L=l<<1;N=(l&32768|0)==0?L:L^41111;L=N<<1;l=(N&32768|0)==0?L:L^41111;L=l<<1;N=(l&32768|0)==0?L:L^41111;L=N<<1;l=(N&32768|0)==0?L:L^41111;L=l<<1;N=(l&32768|0)==0?L:L^41111;L=N<<1;X=(N&32768|0)==0?L:L^41111;L=V+1|0;if((U|0)==0){break}T=X;U=U-1|0;V=L;W=d[L]<<8}vU(n,10,X&65535);if((v$(f,n,12)|0)!=0){Y=1;i=h;return Y|0}X=c[R>>2]|0;do{if((X|0)!=0){R=X>>>0>65535?65535:X;vU(n,2,R);c[k>>2]=b0(0)|0;W=a4(k|0)|0;a[q]=c[W+20>>2]&255;a[D]=c[W+16>>2]&255;a[P]=c[W+12>>2]&255;a[S]=c[W+8>>2]&255;a[E]=c[W+4>>2]&255;a[C]=c[W>>2]&255;W=zH(R)|0;if((W|0)==0){Y=1;i=h;return Y|0}V=(R|0)==0;if(V){Z=0;_=8;$=p}else{U=c[g+12>>2]|0;T=0;while(1){L=a[U+T|0]|0;a[W+T|0]=L<<24>>24==10?0:L;L=T+1|0;if(L>>>0<R>>>0){T=L}else{Z=0;_=8;$=p;break}}}while(1){T=d[$]<<8^Z;U=T<<1;L=(T&32768|0)==0?U:U^41111;U=L<<1;T=(L&32768|0)==0?U:U^41111;U=T<<1;L=(T&32768|0)==0?U:U^41111;U=L<<1;T=(L&32768|0)==0?U:U^41111;U=T<<1;L=(T&32768|0)==0?U:U^41111;U=L<<1;T=(L&32768|0)==0?U:U^41111;U=T<<1;L=(T&32768|0)==0?U:U^41111;U=L<<1;aa=(L&32768|0)==0?U:U^41111;U=_-1|0;if((U|0)==0){break}else{Z=aa;_=U;$=$+1|0}}U=aa&65535;L3734:do{if(V){ab=U}else{L=U;T=R;N=W;while(1){l=d[N]<<8^L;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=T-1|0;if((y|0)==0){ab=l;break L3734}L=l;T=y;N=N+1|0}}}while(0);vU(n,0,ab&65535);if((v$(f,n,10)|0)==0){U=v$(f,W,R)|0;zI(W);if((U|0)==0){break}else{Y=1}i=h;return Y|0}else{zI(W);Y=1;i=h;return Y|0}}}while(0);ab=b[o>>1]|0;L3745:do{if(ab<<16>>16!=0){aa=g+4|0;$=j|0;_=j+1|0;Z=j+2|0;C=j+3|0;E=0;S=ab;L3747:while(1){k=c[(c[aa>>2]|0)+(E<<2)>>2]|0;X=k+2|0;if((b[X>>1]|0)==0){ac=S}else{U=k+4|0;k=E&255;V=E<<8&65280;N=0;do{T=c[(c[U>>2]|0)+(N<<2)>>2]|0;L=T+2|0;y=b[L>>1]|0;a[$]=y&255;a[_]=k;a[Z]=N&255;l=y&255;y=l<<9;x=(l&128|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=((x&32768|0)==0?y:y^41111)^V;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=((x&32768|0)==0?y:y^41111)^N<<8&65280;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;a[C]=((x&32768|0)==0?y:y^151)&255;if((v$(f,$,4)|0)!=0){Y=1;s=2896;break L3747}y=T+4|0;if((b[L>>1]|0)!=0){T=0;do{x=c[(c[y>>2]|0)+(T<<2)>>2]|0;l=x+10|0;w=e[l>>1]|0;if((w+65535&w|0)!=0){Y=1;s=2897;break L3747}a[n]=b[x+4>>1]&255;a[Q]=b[x+6>>1]&255;a[p]=b[x+8>>1]&255;a[r]=(uR(x)|0)&255;a[q]=0;w=c[x+12>>2]|0;if((w&2|0)==0){ad=4}else{a[q]=2;ad=6}if((w&4|0)!=0){a[q]=ad}w=x+24|0;x=b[l>>1]|0;if(x<<16>>16==0){ae=0}else{v=0;u=x&65535;x=c[w>>2]|0;while(1){t=d[x]<<8^v;G=t<<1;F=(t&32768|0)==0?G:G^41111;G=F<<1;t=(F&32768|0)==0?G:G^41111;G=t<<1;F=(t&32768|0)==0?G:G^41111;G=F<<1;t=(F&32768|0)==0?G:G^41111;G=t<<1;F=(t&32768|0)==0?G:G^41111;G=F<<1;t=(F&32768|0)==0?G:G^41111;G=t<<1;F=(t&32768|0)==0?G:G^41111;G=F<<1;af=(F&32768|0)==0?G:G^41111;G=u-1|0;if((G|0)==0){break}else{v=af;u=G;x=x+1|0}}ae=af&255}a[D]=ae;if((v$(f,n,6)|0)!=0){Y=1;s=2903;break L3747}L3771:do{if((d[r]|0)<=6){x=b[l>>1]|0;u=x&65535;L3773:do{if(!((x&1)!=0|(x&65535)<2)){v=2;while(1){if(v>>>0>=u>>>0){break}G=c[w>>2]|0;if((a[G+v|0]|0)==(a[G+(v&1)|0]|0)){v=v+1|0}else{break L3773}}vU(n,0,5);a[p]=1;vU(n,3,(e[l>>1]|0)>>>1);v=c[w>>2]|0;a[D]=a[v]|0;a[P]=a[v+1|0]|0;if((v$(f,n,7)|0)==0){break L3771}else{Y=1;s=2902;break L3747}}}while(0);vU(n,0,u+1|0);a[p]=0;if((v$(f,n,3)|0)!=0){Y=1;s=2900;break L3747}if((v$(f,c[w>>2]|0,e[l>>1]|0)|0)!=0){Y=1;s=2901;break L3747}}}while(0);T=T+1|0;}while(T>>>0<(e[L>>1]|0)>>>0)}N=N+1|0;}while(N>>>0<(e[X>>1]|0)>>>0);ac=b[o>>1]|0}X=E+1|0;if(X>>>0<(ac&65535)>>>0){E=X;S=ac}else{break L3745}}if((s|0)==2900){i=h;return Y|0}else if((s|0)==2901){i=h;return Y|0}else if((s|0)==2902){i=h;return Y|0}else if((s|0)==2903){i=h;return Y|0}else if((s|0)==2896){i=h;return Y|0}else if((s|0)==2897){i=h;return Y|0}}}while(0);s=m|0;a[s]=-1;a[m+1|0]=0;a[m+2|0]=0;a[m+3|0]=53;if((v$(f,s,4)|0)!=0){Y=1;i=h;return Y|0}ax(f|0)|0;Y=0;i=h;return Y|0}function vO(b){b=b|0;var c=0,d=0,e=0,f=0,g=0;c=i;i=i+16|0;d=c|0;do{if((bS(b|0,0,0)|0)==0){e=d|0;if((vZ(b,e,16)|0)!=0){f=0;break}g=a[e]|0;if((g<<24>>24|0)==116){if((a[d+1|0]|0)!=100){f=0;break}}else if((g<<24>>24|0)==84){if((a[d+1|0]|0)!=68){f=0;break}}else{f=0;break}f=(a[d+2|0]|0)==0|0}else{f=0}}while(0);i=c;return f|0}function vP(a,b){a=a|0;b=b|0;return(d[a+b|0]|0)<<8|(d[a+(b+1)|0]|0)|0}function vQ(a,b){a=a|0;b=b|0;return(((d[a+b|0]|0)<<8|(d[a+(b+1)|0]|0))<<8|(d[a+(b+2)|0]|0))<<8|(d[a+(b+3)|0]|0)|0}function vR(b,c,d){b=b|0;c=c|0;d=d|0;a[b+c|0]=d>>>8&255;a[b+(c+1)|0]=d&255;return}function vS(b,c,d){b=b|0;c=c|0;d=d|0;a[b+c|0]=d>>>24&255;a[b+(c+1)|0]=d>>>16&255;a[b+(c+2)|0]=d>>>8&255;a[b+(c+3)|0]=d&255;return}function vT(a,b){a=a|0;b=b|0;return(d[a+(b+1)|0]|0)<<8|(d[a+b|0]|0)|0}function vU(b,c,d){b=b|0;c=c|0;d=d|0;a[b+c|0]=d&255;a[b+(c+1)|0]=d>>>8&255;return}function vV(a,d,f,g,h,i){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((g|0)==0){return}j=(i|0)!=0?32768:0;i=a+28|0;k=a+32|0;l=a+24|0;m=a+40|0;n=a+44|0;o=a+36|0;p=a|0;q=a+4|0;r=a+8|0;s=a+16|0;t=a+20|0;a=g;g=f;f=d;while(1){d=((e[g>>1]|0)^j)-32768|0;u=c[i>>2]|0;c[k>>2]=u;v=c[l>>2]|0;c[i>>2]=v;c[l>>2]=d;w=c[m>>2]|0;c[n>>2]=w;x=c[o>>2]|0;c[m>>2]=x;y=ac(d,c[p>>2]|0)|0;d=ac(v,c[q>>2]|0)|0;v=d+y+(ac(u,c[r>>2]|0)|0)|0;u=ac(x,c[s>>2]|0)|0;x=(v-u-(ac(w,c[t>>2]|0)|0)|0)/8192|0;c[o>>2]=x;w=x+32768|0;if((w|0)<0){z=0}else{z=(w|0)>65535?65535:w&65535}b[f>>1]=(z^j)&65535;w=a-1|0;if((w|0)==0){break}else{a=w;g=g+(h<<1)|0;f=f+(h<<1)|0}}return}function vW(c,d,e,f,g){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=(f|0)!=0?-32768:0;f=(e|0)==0;if((g|0)==0){if(f){return}else{i=d;j=0;k=c}while(1){g=b[i>>1]^h;a[k]=g&255;a[k+1|0]=(g&65535)>>>8&255;g=j+1|0;if(g>>>0<e>>>0){i=i+2|0;j=g;k=k+2|0}else{break}}return}else{if(f){return}else{l=d;m=0;n=c}while(1){c=b[l>>1]^h;a[n]=(c&65535)>>>8&255;a[n+1|0]=c&255;c=m+1|0;if(c>>>0<e>>>0){l=l+2|0;m=c;n=n+2|0}else{break}}return}}function vX(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=u1()|0;if((b|0)==0){e=0;return e|0}else{f=0}while(1){if(f>>>0>=(c[96]|0)>>>0){g=2942;break}h=c[97]|0;i=128<<(d[h+(f<<3)+2|0]|0);j=h+(f<<3)|0;k=uW(0,d[j]|0,d[h+(f<<3)+1|0]|0,i)|0;if((k|0)==0){break}uP(k,32770);if((u3(b,k,0,d[j]|0)|0)!=0){break}if((v_(a,c[h+(f<<3)+4>>2]|0,c[k+24>>2]|0,i)|0)==0){f=f+1|0}else{break}}L3843:do{if((g|0)==2942){if((c[94]|0)>>>0<=1){e=b;return e|0}f=1;i=c[95]|0;while(1){k=0;while(1){if(k>>>0>=(c[98]|0)>>>0){break}h=c[99]|0;j=128<<(d[h+(k<<3)+2|0]|0);l=h+(k<<3)|0;m=uW(f,d[l]|0,d[h+(k<<3)+1|0]|0,j)|0;if((m|0)==0){break L3843}uP(m,32770);if((u3(b,m,f,d[l]|0)|0)!=0){break L3843}if((v_(a,(c[h+(k<<3)+4>>2]|0)+i|0,c[m+24>>2]|0,j)|0)!=0){break L3843}k=k+1|0}k=f+1|0;if(k>>>0<(c[94]|0)>>>0){f=k;i=(c[95]|0)+i|0}else{e=b;break}}return e|0}}while(0);u2(b);e=0;return e|0}function vY(a,b){a=a|0;b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=0;while(1){if(f>>>0>=(c[96]|0)>>>0){g=2962;break}h=c[97]|0;i=128<<(d[h+(f<<3)+2|0]|0);j=u6(b,0,d[h+(f<<3)|0]|0,d[h+(f<<3)+1|0]|0,0)|0;if((j|0)==0){k=1;g=2979;break}if((e[j+10>>1]|0|0)!=(i|0)){k=1;g=2972;break}if((v0(a,c[h+(f<<3)+4>>2]|0,c[j+24>>2]|0,i)|0)==0){f=f+1|0}else{k=1;g=2977;break}}if((g|0)==2962){if((c[94]|0)>>>0<=1){k=0;return k|0}f=1;i=c[95]|0;L3871:while(1){j=0;while(1){if(j>>>0>=(c[98]|0)>>>0){break}h=c[99]|0;l=128<<(d[h+(j<<3)+2|0]|0);m=u6(b,f,d[h+(j<<3)|0]|0,d[h+(j<<3)+1|0]|0,0)|0;if((m|0)==0){k=1;g=2975;break L3871}if((e[m+10>>1]|0|0)!=(l|0)){k=1;g=2978;break L3871}if((v0(a,(c[h+(j<<3)+4>>2]|0)+i|0,c[m+24>>2]|0,l)|0)!=0){k=1;g=2976;break L3871}j=j+1|0}j=f+1|0;if(j>>>0<(c[94]|0)>>>0){f=j;i=(c[95]|0)+i|0}else{k=0;g=2973;break}}if((g|0)==2973){return k|0}else if((g|0)==2975){return k|0}else if((g|0)==2978){return k|0}else if((g|0)==2976){return k|0}}else if((g|0)==2972){return k|0}else if((g|0)==2977){return k|0}else if((g|0)==2979){return k|0}return 0}function vZ(a,b,c){a=a|0;b=b|0;c=c|0;return(bK(b|0,1,c|0,a|0)|0)!=(c|0)|0}function v_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if((bS(a|0,b|0,0)|0)!=0){e=1;return e|0}e=(bK(c|0,1,d|0,a|0)|0)!=(d|0)|0;return e|0}function v$(a,b,c){a=a|0;b=b|0;c=c|0;return(aB(b|0,1,c|0,a|0)|0)!=(c|0)|0}function v0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if((bS(a|0,b|0,0)|0)!=0){e=1;return e|0}e=(aB(c|0,1,d|0,a|0)|0)!=(d|0)|0;return e|0}function v1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=i;i=i+256|0;d=c|0;e=b;while(1){if((e|0)==0){f=0;g=2996;break}b=e>>>0<256?e:256;if((bK(d|0,1,b|0,a|0)|0)==(b|0)){e=e-b|0}else{f=1;g=2997;break}}if((g|0)==2996){i=c;return f|0}else if((g|0)==2997){i=c;return f|0}return 0}function v2(a){a=a|0;zP(a|0,0,48);c[a>>2]=8192;return}function v3(a){a=a|0;zP(a+24|0,0,24);return}function v4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0.0,h=0.0;e=a|0;zP(a|0,0,48);c[e>>2]=8192;if((b|0)==0|(d|0)==0){return}if(b<<1>>>0<d>>>0){f=b}else{f=(d>>>1)-1|0}g=1.0/+W(+(+(f>>>0>>>0)*3.141592653589793/+(d>>>0>>>0)));h=g*(g+1.4142135623730951)+1.0;d=~~(8192.0/h);c[e>>2]=d;c[a+4>>2]=~~(16384.0/h);c[a+8>>2]=d;c[a+12>>2]=8192;c[a+16>>2]=~~((1.0-g*g)*16384.0/h);c[a+20>>2]=~~((g*(g-1.4142135623730951)+1.0)*8192.0/h);return}function v5(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a+788|0;e=a+792|0;a=c[e>>2]|0;if((c[d>>2]|0)>>>0>=b>>>0){f=a;return f|0}g=zJ(a,b)|0;if((g|0)==0){f=0;return f|0}c[e>>2]=g;c[d>>2]=b;f=g;return f|0}function v6(b,d){b=b|0;d=d|0;c[b>>2]=d;zP(b+4|0,0,16);zP(b+788|0,0,24);a[b+812|0]=1;c[b+816>>2]=0;c[b+820>>2]=0;c[b+824>>2]=0;return}function v7(a){a=a|0;var b=0;if((a|0)==0){return}wk(a);b=c[a+816>>2]|0;if((b|0)!=0){b2[b&255](a)}b=c[a+800>>2]|0;if((b|0)!=0){zI(b)}b=c[a+792>>2]|0;if((b|0)==0){return}zI(b);return}function v8(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((b|0)==0){f=1;return f|0}g=b+820|0;if((c[g>>2]|0)==0){f=1;return f|0}do{if((c[b+16>>2]|0)==0){h=d}else{i=b+4|0;j=ac(c[i>>2]|0,e)|0;k=b+796|0;l=b+800|0;m=c[l>>2]|0;if((c[k>>2]|0)>>>0<j>>>0){n=zJ(m,j<<1)|0;if((n|0)==0){h=0;break}o=n;c[l>>2]=o;c[k>>2]=j;p=o}else{p=m}if((p|0)==0){h=0;break}m=c[i>>2]|0;if((m|0)==0){h=p;break}o=b+12|0;j=0;k=m;while(1){vV(b+20+(j*48|0)|0,p+(j<<1)|0,d+(j<<1)|0,e,k,c[o>>2]|0);m=j+1|0;l=c[i>>2]|0;if(m>>>0<l>>>0){j=m;k=l}else{h=p;break}}}}while(0);p=b4[c[g>>2]&127](b,h,e)|0;wm(b,(a[b+812|0]|0)!=0?h:d,e)|0;f=p;return f|0}function v9(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;if((a|0)==0){f=1;return f|0}g=c[a+824>>2]|0;if((g|0)==0){f=1;return f|0}h=(e|0)!=0|0;if(b>>>0>16){f=1;return f|0}e=a+4|0;do{if((c[e>>2]|0)==(b|0)){if((c[a+8>>2]|0)!=(d|0)){break}if((c[a+12>>2]|0)==(h|0)){f=0}else{break}return f|0}}while(0);if((b7[g&63](a,b,d,h)|0)!=0){f=1;return f|0}c[e>>2]=b;g=a+8|0;c[g>>2]=d;c[a+12>>2]=h;if((wn(a,b,d,h)|0)!=0){f=1;return f|0}if((c[e>>2]|0)==0){f=0;return f|0}h=a+16|0;d=0;while(1){b=a+20+(d*48|0)|0;v4(b,c[h>>2]|0,c[g>>2]|0);v3(b);b=d+1|0;if(b>>>0<(c[e>>2]|0)>>>0){d=b}else{f=0;break}}return f|0}function wa(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b;e=32760;f=110;while(1){if(f<<24>>24!=(a[d]|0)){g=3064;break}h=e+1|0;i=d+1|0;j=a[h]|0;if(j<<24>>24==0){k=i;g=3065;break}else{d=i;e=h;f=j}}if((g|0)==3064){if((a[e]|0)==0){k=d;g=3065}else{l=b;m=30784;n=119;g=3078}}if((g|0)==3065){d=a[k]|0;if((d<<24>>24|0)==58|(d<<24>>24|0)==0){o=0}else{l=b;m=30784;n=119;g=3078}}do{if((g|0)==3078){while(1){g=0;if(n<<24>>24!=(a[l]|0)){g=3079;break}d=m+1|0;k=l+1|0;e=a[d]|0;if(e<<24>>24==0){p=k;g=3081;break}else{l=k;m=d;n=e;g=3078}}if((g|0)==3079){if((a[m]|0)==0){p=l;g=3081}else{q=b;r=28744;s=115}}if((g|0)==3081){e=a[p]|0;if((e<<24>>24|0)==58|(e<<24>>24|0)==0){o=1;break}else{q=b;r=28744;s=115}}while(1){if(s<<24>>24!=(a[q]|0)){g=3083;break}e=r+1|0;d=q+1|0;k=a[e]|0;if(k<<24>>24==0){t=d;break}else{q=d;r=e;s=k}}do{if((g|0)==3083){if((a[r]|0)==0){t=q;break}else{u=0}return u|0}}while(0);k=a[t]|0;if((k<<24>>24|0)==58|(k<<24>>24|0)==0){o=2;break}else{u=0}return u|0}}while(0);t=b1[c[14380+(o<<3)>>2]&1023](b)|0;if((t|0)==0){u=0;return u|0}if((wo(t,b)|0)==0){a[t+812|0]=(wq(b,34920,1)|0)&255;o=wv(b,39728,0)|0;b=t+16|0;c[b>>2]=o;q=t+4|0;if((c[q>>2]|0)==0){u=t;return u|0}r=t+8|0;g=t+20|0;v4(g,o,c[r>>2]|0);v3(g);if((c[q>>2]|0)>>>0>1){v=1}else{u=t;return u|0}while(1){g=t+20+(v*48|0)|0;v4(g,c[b>>2]|0,c[r>>2]|0);v3(g);g=v+1|0;if(g>>>0<(c[q>>2]|0)>>>0){v=g}else{u=t;break}}return u|0}wk(t);v=c[t+816>>2]|0;if((v|0)!=0){b2[v&255](t)}v=c[t+800>>2]|0;if((v|0)!=0){zI(v)}v=c[t+792>>2]|0;if((v|0)==0){u=0;return u|0}zI(v);u=0;return u|0}function wb(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function wc(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 0}function wd(a){a=a|0;var b=0,d=0;a=zH(828)|0;if((a|0)==0){b=0;return b|0}d=a;v6(d,a);c[a+816>>2]=90;c[a+820>>2]=8;c[a+824>>2]=24;b=d;return b|0}function we(a){a=a|0;zI(c[a>>2]|0);return}function wf(b){b=b|0;var d=0,e=0;b=zH(856)|0;if((b|0)==0){d=0;return d|0}e=b;v6(e,b);c[b+816>>2]=178;c[b+820>>2]=104;c[b+824>>2]=4;a[b+828|0]=0;a[b+829|0]=1;zP(b+840|0,0,16);d=e;return d|0}function wg(b){b=b|0;var d=0,e=0,f=0;d=c[b>>2]|0;if((a[d+828|0]|0)!=0){bC()}b=c[d+844>>2]|0;if((b|0)!=0){e=b;while(1){b=c[e>>2]|0;zI(c[e+16>>2]|0);zI(e);if((b|0)==0){break}else{e=b}}}e=c[d+852>>2]|0;if((e|0)==0){zI(d);return}else{f=e}while(1){e=c[f>>2]|0;zI(c[f+16>>2]|0);zI(f);if((e|0)==0){break}else{f=e}}zI(d);return}function wh(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[b>>2]|0;g=ac(c[b+4>>2]|0,e)|0;e=g<<1;h=f+852|0;i=c[h>>2]|0;do{if((i|0)==0){j=f+840|0;k=c[j>>2]|0;if(k>>>0>32){break}l=zH(20)|0;if((l|0)==0){break}c[l+12>>2]=0;c[l+16>>2]=0;c[j>>2]=k+1;m=l;n=3121}else{c[h>>2]=c[i>>2];m=i;n=3121}}while(0);L4067:do{if((n|0)==3121){c[m>>2]=0;i=m+4|0;c[i>>2]=0;h=m+8|0;c[h>>2]=0;l=m+12|0;do{if((c[l>>2]|0)>>>0<e>>>0){k=m+16|0;j=zJ(c[k>>2]|0,e)|0;if((j|0)==0){zI(c[k>>2]|0);zI(m);o=f+840|0;c[o>>2]=(c[o>>2]|0)-1;break L4067}else{c[l>>2]=e;c[k>>2]=j;break}}}while(0);if((m|0)==0){p=1;return p|0}vW(c[m+16>>2]|0,d,g,(c[b+12>>2]|0)!=(c[f+832>>2]|0)|0,c[f+836>>2]|0);c[i>>2]=0;c[h>>2]=e;l=f+848|0;j=c[l>>2]|0;if((j|0)==0){c[f+844>>2]=m}else{c[j>>2]=m}c[l>>2]=m;l=f+829|0;if((a[l]|0)==0){p=0;return p|0}aN(0);a[l]=0;p=0;return p|0}}while(0);p=1;return p|0}function wi(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;g=i;i=i+24|0;h=g|0;j=c[d>>2]|0;do{if((aI(16)|0)==0){if((bt(16)|0)>=0){break}d=c[q>>2]|0;k=bv()|0;bN(d|0,34864,(x=i,i=i+8|0,c[x>>2]=k,x)|0)|0;l=1;i=g;return l|0}}while(0);k=j+828|0;if((a[k]|0)!=0){bC();a[k]=0}c[h>>2]=f;b[h+4>>1]=-32752;a[h+6|0]=e&255;b[h+8>>1]=1024;c[h+16>>2]=72;c[h+20>>2]=j;if((bG(h|0,0)|0)<0){h=c[q>>2]|0;e=bv()|0;bN(h|0,39688,(x=i,i=i+8|0,c[x>>2]=e,x)|0)|0;l=1;i=g;return l|0}else{aN(1);a[k]=1;a[j+829|0]=1;c[j+832>>2]=1;c[j+836>>2]=0;l=0;i=g;return l|0}return 0}function wj(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=b+844|0;g=c[f>>2]|0;if((g|0)==0){aN(1);a[b+829|0]=1;return}if((e|0)<=0){return}h=b+848|0;i=b+852|0;b=e;e=d;d=g;while(1){if((d|0)==0){j=3153;break}k=d+4|0;g=c[k>>2]|0;l=(c[d+8>>2]|0)-g|0;m=(c[d+16>>2]|0)+g|0;if((l|0)>(b|0)){j=3160;break}zO(e|0,m|0,l)|0;g=b-l|0;n=d|0;o=c[n>>2]|0;c[f>>2]=o;if((o|0)==0){c[h>>2]=0}c[n>>2]=c[i>>2];c[i>>2]=d;if((g|0)<=0){j=3164;break}b=g;e=e+l|0;d=c[f>>2]|0}if((j|0)==3160){zO(e|0,m|0,b)|0;c[k>>2]=(c[k>>2]|0)+b;return}else if((j|0)==3153){zP(e|0,0,b|0);return}else if((j|0)==3164){return}}function wk(a){a=a|0;if((c[a+804>>2]|0)==0){return}wl(a)|0;return}function wl(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+64|0;e=d|0;f=b+804|0;if((bS(c[f>>2]|0,0,0)|0)!=0){g=1;i=d;return g|0}h=e|0;a[h]=82;a[e+1|0]=73;a[e+2|0]=70;a[e+3|0]=70;j=b+808|0;k=c[j>>2]|0;l=k+36|0;a[e+4|0]=l&255;a[e+5|0]=l>>>8&255;a[e+6|0]=l>>>16&255;a[e+7|0]=l>>>24&255;a[e+8|0]=87;a[e+9|0]=65;a[e+10|0]=86;a[e+11|0]=69;a[e+12|0]=102;a[e+13|0]=109;a[e+14|0]=116;a[e+15|0]=32;a[e+16|0]=16;a[e+17|0]=0;a[e+18|0]=0;a[e+19|0]=0;a[e+20|0]=1;a[e+21|0]=0;l=c[b+4>>2]|0;a[e+22|0]=l&255;a[e+23|0]=l>>>8&255;m=c[b+8>>2]|0;a[e+24|0]=m&255;a[e+25|0]=m>>>8&255;a[e+26|0]=m>>>16&255;a[e+27|0]=m>>>24&255;b=l<<1;n=ac(b,m)|0;a[e+28|0]=n&255;a[e+29|0]=n>>>8&255;a[e+30|0]=n>>>16&255;a[e+31|0]=n>>>24&255;a[e+32|0]=b&255;a[e+33|0]=l>>>7&255;a[e+34|0]=16;a[e+35|0]=0;a[e+36|0]=100;a[e+37|0]=97;a[e+38|0]=116;a[e+39|0]=97;a[e+40|0]=k&255;a[e+41|0]=k>>>8&255;a[e+42|0]=k>>>16&255;a[e+43|0]=k>>>24&255;if((aB(h|0,1,44,c[f>>2]|0)|0)!=44){g=1;i=d;return g|0}g=(bS(c[f>>2]|0,(c[j>>2]|0)+44|0,0)|0)!=0|0;i=d;return g|0}function wm(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=a+804|0;if((c[e>>2]|0)==0){f=0;return f|0}g=ac(c[a+4>>2]|0,d)|0;d=g<<1;h=v5(a,d)|0;if((b|0)==0){f=1;return f|0}vW(h,b,g,(c[a+12>>2]|0)==0|0,0);if((aB(h|0,1,d|0,c[e>>2]|0)|0)!=(d|0)){f=1;return f|0}e=a+808|0;c[e>>2]=(c[e>>2]|0)+d;f=0;return f|0}function wn(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;if((c[a+804>>2]|0)==0){f=0;return f|0}f=(wl(a)|0)!=0|0;return f|0}function wo(b,d){b=b|0;d=d|0;var e=0,f=0;e=b+804|0;c[e>>2]=0;c[b+808>>2]=0;b=wp(d,34848)|0;if((b|0)==0){f=0;return f|0}if((a[b]|0)==0){f=0;return f|0}c[e>>2]=bl(b|0,39680)|0;zI(b);f=(c[e>>2]|0)==0|0;return f|0}function wp(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;if((b|0)==0){d=0;return d|0}e=a[c]|0;L4165:do{if(e<<24>>24==0){f=b;L4194:while(1){g=f;while(1){h=a[g]|0;if(!((h<<24>>24|0)==32|(h<<24>>24|0)==9)){i=g;j=h;break}g=g+1|0}while(1){if((j<<24>>24|0)==61){k=i;l=3206;break}else if(!((j<<24>>24|0)==32|(j<<24>>24|0)==9)){break}g=i+1|0;i=g;j=a[g]|0}if((l|0)==3206){while(1){l=0;m=k+1|0;n=a[m]|0;if((n<<24>>24|0)==32|(n<<24>>24|0)==9){k=m;l=3206}else{break}}if((m|0)!=0){o=k;p=n;break L4165}}g=a[f]|0;if(g<<24>>24==0){d=0;l=3252;break}else{q=f;r=g}while(1){s=q+1|0;if(r<<24>>24==58){if((a[s]|0)!=58){break}t=q+2|0}else{t=s}g=a[t]|0;if(g<<24>>24==0){d=0;l=3248;break L4194}else{q=t;r=g}}if((s|0)==0){d=0;l=3251;break}else{f=s}}if((l|0)==3251){return d|0}else if((l|0)==3252){return d|0}else if((l|0)==3248){return d|0}}else{f=b;L4166:while(1){g=f;while(1){u=a[g]|0;if(!((u<<24>>24|0)==32|(u<<24>>24|0)==9)){break}g=g+1|0}L4172:do{if(u<<24>>24==e<<24>>24){h=c;v=g;while(1){v=v+1|0;h=h+1|0;w=a[h]|0;if(w<<24>>24==0){x=v;break}if((a[v]|0)!=w<<24>>24){break L4172}}while(1){v=a[x]|0;if((v<<24>>24|0)==61){y=x;break}else if(!((v<<24>>24|0)==32|(v<<24>>24|0)==9)){break L4172}x=x+1|0}while(1){z=y+1|0;A=a[z]|0;if((A<<24>>24|0)==32|(A<<24>>24|0)==9){y=z}else{break}}if((z|0)!=0){o=y;p=A;break L4165}}}while(0);g=a[f]|0;if(g<<24>>24==0){d=0;l=3250;break}else{B=f;C=g}while(1){D=B+1|0;if(C<<24>>24==58){if((a[D]|0)!=58){break}E=B+2|0}else{E=D}g=a[E]|0;if(g<<24>>24==0){d=0;l=3255;break L4166}else{B=E;C=g}}if((D|0)==0){d=0;l=3256;break}else{f=D}}if((l|0)==3250){return d|0}else if((l|0)==3255){return d|0}else if((l|0)==3256){return d|0}}}while(0);L4219:do{if(p<<24>>24==0){F=0}else{D=0;C=p;while(1){E=D+1|0;if(C<<24>>24==58){B=D+2|0;if((a[o+B|0]|0)==58){G=B}else{H=D;break}}else{G=E}E=a[o+(G+1)|0]|0;if(E<<24>>24==0){H=G;break}else{D=G;C=E}}if((H|0)==0){F=0;break}else{I=H}while(1){C=I-1|0;D=a[o+I|0]|0;if(!((D<<24>>24|0)==32|(D<<24>>24|0)==9)){F=I;break L4219}if((C|0)==0){F=0;break}else{I=C}}}}while(0);I=zH(F+1|0)|0;if((I|0)==0){d=0;return d|0}L4233:do{if((F|0)==0){J=0}else{H=0;G=0;C=p;while(1){D=H+1|0;do{if(C<<24>>24==58){E=H+2|0;if((a[o+E|0]|0)!=58){l=3237;break}a[I+G|0]=58;K=E}else{l=3237}}while(0);if((l|0)==3237){l=0;a[I+G|0]=C;K=D}E=G+1|0;if(K>>>0>=F>>>0){J=E;break L4233}H=K;G=E;C=a[o+(K+1)|0]|0}}}while(0);a[I+J|0]=0;d=I;return d|0}function wq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=wp(a,b)|0;if((d|0)==0){e=c;return e|0}do{if((aP(d|0,34752)|0)==0){f=1}else{if((aP(d|0,39664)|0)==0){f=1;break}if((aP(d|0,32752)|0)==0){f=1;break}if((aP(d|0,30776)|0)==0){f=0;break}if((aP(d|0,28736)|0)==0){f=0;break}f=(aP(d|0,27056)|0)==0?0:c}}while(0);zI(d);e=f;return e|0}function wr(a,b,d){a=a|0;b=b|0;d=d|0;return(c[a+28>>2]|0)==((b<<4)+d|0)|0}function ws(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;do{if((c[a+24>>2]|0)==(b|0)){if((c[a+28>>2]|0)==(d|0)){e=1}else{break}return e|0}}while(0);e=0;return e|0}function wt(a){a=a|0;c[a>>2]=0;c[a+4>>2]=0;return}function wu(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;c[b>>2]=0;e=0;while(1){if(e>>>0>=256){break}f=d+e|0;a[b+4+e|0]=a[f]|0;if((a[f]|0)==0){g=3282;break}else{e=e+1|0}}if((g|0)==3282){return}a[b+259|0]=0;return}function wv(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;h=wp(b,d)|0;L4274:do{if((h|0)==0){j=e}else{d=aw(h|0,g|0,0)|0;b=c[g>>2]|0;do{if((b|0)!=0){if((a[b]|0)==0){break}zI(h);j=e;break L4274}}while(0);zI(h);j=d}}while(0);i=f;return j|0}function ww(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;h=wp(b,d)|0;L4282:do{if((h|0)==0){j=e}else{d=az(h|0,g|0,0)|0;b=c[g>>2]|0;do{if((b|0)!=0){if((a[b]|0)==0){break}zI(h);j=e;break L4282}}while(0);zI(h);j=d}}while(0);i=f;return j|0}function wx(a){a=a|0;var b=0,d=0,e=0;b=zH(36)|0;if((b|0)==0){d=0;return d|0}c[b>>2]=1;e=b+4|0;zP(e|0,0,20);c[e>>2]=60;c[b+8>>2]=108;c[b+12>>2]=264;c[b+24>>2]=0;c[b+28>>2]=a;d=b;return d|0}function wy(a){a=a|0;zI(a);return}function wz(a,b){a=a|0;b=b|0;var d=0,e=0;b=i;d=c[a+16>>2]|0;e=c[a+20>>2]|0;bh(38976,(x=i,i=i+24|0,c[x>>2]=c[a+28>>2],c[x+8>>2]=d,c[x+16>>2]=e,x)|0)|0;i=b;return}function wA(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=zH(36)|0;if((d|0)==0){e=0;return e|0}c[d>>2]=2;f=d+4|0;zP(f|0,0,20);c[f>>2]=38;c[d+8>>2]=50;c[d+12>>2]=456;c[d+24>>2]=a&65535;c[d+28>>2]=b&65535;e=d;return e|0}function wB(a){a=a|0;zI(a);return}function wC(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;b=i;d=c[a+28>>2]|0;e=c[a+16>>2]|0;f=c[a+20>>2]|0;bh(40520,(x=i,i=i+32|0,c[x>>2]=c[a+24>>2],c[x+8>>2]=d,c[x+16>>2]=e,c[x+24>>2]=f,x)|0)|0;i=b;return}function wD(a){a=a|0;zI(c[a+32>>2]|0);zI(a);return}function wE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;d=i;i=i+272|0;b=d|0;e=d+8|0;wu(e,c[a+32>>2]|0);a=(wT(e,b)|0)!=0;i=d;return a&(c[b>>2]|0)!=0&1|0}function wF(a,b){a=a|0;b=b|0;b=i;bh(41600,(x=i,i=i+8|0,c[x>>2]=c[a+32>>2],x)|0)|0;i=b;return}function wG(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a+4|0;e=a|0;a=zJ(c[d>>2]|0,(c[e>>2]<<2)+4|0)|0;f=a;if((a|0)==0){g=1;return g|0}c[d>>2]=f;d=c[e>>2]|0;c[f+(d<<2)>>2]=b;c[e>>2]=d+1;g=0;return g|0}function wH(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=a|0;if((c[f>>2]|0)==0){g=0;return g|0}h=a+4|0;a=0;L4315:while(1){i=c[(c[h>>2]|0)+(a<<2)>>2]|0;j=c[i+8>>2]|0;do{if((j|0)!=0){if((b4[j&127](i,b,d)|0)==0){break}k=i+16|0;l=c[k>>2]|0;if((l|0)==0){break L4315}m=l-1|0;c[k>>2]=m;if((m|0)==0){break L4315}}}while(0);j=a+1|0;if(j>>>0<(c[f>>2]|0)>>>0){a=j}else{g=0;n=3340;break}}if((n|0)==3340){return g|0}d=c[i+20>>2]|0;if((d|0)!=0){c[k>>2]=d}d=c[(c[h>>2]|0)+(a<<2)>>2]|0;if((d|0)==0){g=0;return g|0}a=c[d+12>>2]|0;if((a|0)!=0){b3[a&511](d,e)}if((c[d+16>>2]|0)!=0){g=1;return g|0}e=c[f>>2]|0;a=0;while(1){if(a>>>0>=e>>>0){g=1;n=3345;break}o=a+1|0;if((c[(c[h>>2]|0)+(a<<2)>>2]|0)==(d|0)){break}else{a=o}}if((n|0)==3345){return g|0}n=c[d+4>>2]|0;if((n|0)==0){zI(d)}else{b2[n&255](d)}d=c[f>>2]|0;if(o>>>0<d>>>0){n=a;a=o;while(1){o=c[h>>2]|0;c[o+(n<<2)>>2]=c[o+(a<<2)>>2];o=a+1|0;e=c[f>>2]|0;if(o>>>0<e>>>0){n=a;a=o}else{p=e;break}}}else{p=d}c[f>>2]=p-1;g=1;return g|0}function wI(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0;f=i;i=i+304|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=f+32|0;m=f+40|0;n=f+48|0;if((wM(a,39656)|0)!=0){if((wP(a)|0)==0){i=f;return}p=c[o>>2]|0;q=d|0;if((c[q>>2]|0)!=0){r=d+4|0;s=0;do{bN(p|0,34728,(x=i,i=i+8|0,c[x>>2]=s,x)|0)|0;t=c[(c[r>>2]|0)+(s<<2)>>2]|0;u=c[t+12>>2]|0;if((u|0)!=0){b3[u&511](t,p)}s=s+1|0;}while(s>>>0<(c[q>>2]|0)>>>0)}ax(p|0)|0;i=f;return}if((wM(a,32744)|0)==0){if((wM(a,30768)|0)==0){wK(a,28712);i=f;return}if((wL(a)|0)!=0){p=d|0;q=d+4|0;s=c[q>>2]|0;if((c[p>>2]|0)==0){v=s}else{r=0;t=s;while(1){s=c[t+(r<<2)>>2]|0;u=c[s+4>>2]|0;if((u|0)==0){zI(s)}else{b2[u&255](s)}s=r+1|0;u=c[q>>2]|0;if(s>>>0<(c[p>>2]|0)>>>0){r=s;t=u}else{v=u;break}}}zI(v);c[p>>2]=0;c[q>>2]=0;i=f;return}if((wS(a,g)|0)!=0){q=d|0;p=d+4|0;do{v=e[g>>1]|0;if((c[q>>2]|0)>>>0>v>>>0){t=c[(c[p>>2]|0)+(v<<2)>>2]|0;r=c[t+4>>2]|0;if((r|0)==0){zI(t)}else{b2[r&255](t)}t=v+1|0;r=c[q>>2]|0;if(t>>>0<r>>>0){u=v;v=t;while(1){t=c[p>>2]|0;c[t+(u<<2)>>2]=c[t+(v<<2)>>2];t=v+1|0;s=c[q>>2]|0;if(t>>>0<s>>>0){u=v;v=t}else{w=s;break}}}else{w=r}c[q>>2]=w-1}}while((wS(a,g)|0)!=0)}wP(a)|0;i=f;return}if((wM(a,27048)|0)!=0){g=n|0;b[l>>1]=1;b[m>>1]=0;if((wO(a,g,256)|0)==0){wK(a,21512);i=f;return}wS(a,l)|0;wS(a,m)|0;if((wP(a)|0)==0){i=f;return}n=b[l>>1]|0;if(n<<16>>16==0){i=f;return}w=zH(36)|0;if((w|0)==0){y=0;z=n}else{c[w>>2]=3;n=w+4|0;zP(n|0,0,20);c[n>>2]=114;c[w+8>>2]=62;c[w+12>>2]=260;c[w+32>>2]=bu(g|0)|0;y=w;z=b[l>>1]|0}l=e[m>>1]|0;c[y+16>>2]=z&65535;c[y+20>>2]=l;l=c[y+12>>2]|0;if((l|0)!=0){b3[l&511](y,c[o>>2]|0)}l=d+4|0;z=d|0;m=zJ(c[l>>2]|0,(c[z>>2]<<2)+4|0)|0;w=m;if((m|0)==0){i=f;return}c[l>>2]=w;l=c[z>>2]|0;c[w+(l<<2)>>2]=y;c[z>>2]=l+1;i=f;return}b[j>>1]=1;b[k>>1]=0;c[h>>2]=0;if((wT(a,h)|0)==0){wK(a,25464);i=f;return}do{if((wM(a,24264)|0)==0){A=0;B=0}else{l=c[h>>2]|0;if((wT(a,h)|0)!=0){A=l&65535;B=1;break}wK(a,22664);i=f;return}}while(0);wS(a,j)|0;wS(a,k)|0;if((wP(a)|0)==0){i=f;return}a=b[j>>1]|0;if(a<<16>>16==0){i=f;return}j=c[h>>2]|0;h=zH(36)|0;l=(h|0)==0;do{if((B|0)==0){if(l){C=0;break}c[h>>2]=1;z=h+4|0;zP(z|0,0,20);c[z>>2]=60;c[h+8>>2]=108;c[h+12>>2]=264;c[h+24>>2]=0;c[h+28>>2]=j;C=h}else{if(l){C=0;break}c[h>>2]=2;z=h+4|0;zP(z|0,0,20);c[z>>2]=38;c[h+8>>2]=50;c[h+12>>2]=456;c[h+24>>2]=A;c[h+28>>2]=j&65535;C=h}}while(0);h=e[k>>1]|0;c[C+16>>2]=a&65535;c[C+20>>2]=h;h=c[C+12>>2]|0;if((h|0)!=0){b3[h&511](C,c[o>>2]|0)}h=d+4|0;a=d|0;d=zJ(c[h>>2]|0,(c[a>>2]<<2)+4|0)|0;k=d;if((d|0)==0){i=f;return}c[h>>2]=k;h=c[a>>2]|0;c[k+(h<<2)>>2]=C;c[a>>2]=h+1;i=f;return}function wJ(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=a[d]|0;f=(b-36&255)<2?d+1|0:d;do{if(b<<24>>24!=36){g=c[11100]|0;do{if((g|0)==0){h=b}else{if((b4[g&127](c[11102]|0,f,e)|0)==0){i=0;return i|0}else{h=a[d]|0;break}}}while(0);if(h<<24>>24==37){i=1}else{break}return i|0}}while(0);h=c[11096]|0;d=c[11098]|0;b=0;while(1){if(b>>>0>=h>>>0){break}if((aP(c[d+(b<<3)>>2]|0,f|0)|0)==0){j=3428;break}else{b=b+1|0}}if((j|0)==3428){c[d+(b<<3)+4>>2]=e;i=0;return i|0}b=zJ(d,(h<<3)+8|0)|0;h=b;if((b|0)==0){i=1;return i|0}b=c[11096]|0;L4478:do{if((b|0)==0){k=0}else{d=b;while(1){j=d-1|0;g=h+(j<<3)|0;if((aP(c[g>>2]|0,f|0)|0)<0){k=d;break L4478}l=g;g=h+(d<<3)|0;m=c[l+4>>2]|0;c[g>>2]=c[l>>2];c[g+4>>2]=m;if((j|0)==0){k=0;break}else{d=j}}}}while(0);c[h+(k<<3)>>2]=bu(f|0)|0;c[h+(k<<3)+4>>2]=e;c[11098]=h;c[11096]=(c[11096]|0)+1;i=0;return i|0}function wK(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=(c[a>>2]|0)+(a+4)|0;w2(28696,(x=i,i=i+16|0,c[x>>2]=b,c[x+8>>2]=e,x)|0);i=d;return}function wL(b){b=b|0;var d=0,e=0,f=0,g=0;d=b|0;e=c[d>>2]|0;while(1){f=b+4+e|0;g=a[f]|0;if(!((g<<24>>24|0)==13|(g<<24>>24|0)==32|(g<<24>>24|0)==9|(g<<24>>24|0)==10)){break}e=e+1|0}c[d>>2]=e;return(a[f]|0)==0|0}function wM(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=b|0;f=c[e>>2]|0;while(1){g=a[b+4+f|0]|0;if(!((g<<24>>24|0)==13|(g<<24>>24|0)==32|(g<<24>>24|0)==9|(g<<24>>24|0)==10)){break}f=f+1|0}c[e>>2]=f;g=a[d]|0;L4495:do{if(g<<24>>24==0){h=f}else{i=d;j=f;k=g;while(1){if((a[b+4+j|0]|0)!=k<<24>>24){l=0;break}m=j+1|0;n=i+1|0;o=a[n]|0;if(o<<24>>24==0){h=m;break L4495}else{i=n;j=m;k=o}}return l|0}}while(0);c[e>>2]=h;l=1;return l|0}function wN(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;g=b|0;h=c[g>>2]|0;while(1){j=b+4+h|0;k=a[j]|0;if(!((k<<24>>24|0)==13|(k<<24>>24|0)==32|(k<<24>>24|0)==9|(k<<24>>24|0)==10)){break}h=h+1|0}c[g>>2]=h;k=a[j]|0;if(((k<<24>>24)-36|0)>>>0<2){a[d]=k;l=1;m=h+1|0;n=d+1|0}else{l=0;m=h;n=d}while(1){d=a[b+4+m|0]|0;if(d<<24>>24==0){o=3464;break}if(!((d-48&255)<10|(d-97&255)<26|(d-65&255)<26|d<<24>>24==95)){o=3464;break}a[n]=d;d=l+1|0;if(d>>>0<e>>>0){l=d;m=m+1|0;n=n+1|0}else{o=3463;break}}if((o|0)==3464){a[n]=0;c[g>>2]=m;p=(l|0)!=0|0;i=f;return p|0}else if((o|0)==3463){o=(c[g>>2]|0)+(b+4)|0;w2(28696,(x=i,i=i+16|0,c[x>>2]=27024,c[x+8>>2]=o,x)|0);p=0;i=f;return p|0}return 0}function wO(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;g=b|0;h=c[g>>2]|0;while(1){j=b+4+h|0;k=a[j]|0;if(!((k<<24>>24|0)==13|(k<<24>>24|0)==32|(k<<24>>24|0)==9|(k<<24>>24|0)==10)){break}h=h+1|0}c[g>>2]=h;k=(a[j]|0)==34;j=(k&1)+h|0;L4523:do{if(k){h=0;l=j;m=d;while(1){n=a[b+4+l|0]|0;if((n<<24>>24|0)==0){o=l;p=m;q=h;r=3478;break L4523}else if((n<<24>>24|0)==34){break}a[m]=n;n=h+1|0;if(n>>>0<e>>>0){h=n;l=l+1|0;m=m+1|0}else{r=3477;break L4523}}o=l+1|0;p=m;q=h;r=3478}else{n=0;s=j;t=d;while(1){u=a[b+4+s|0]|0;if((u<<24>>24|0)==0|(u<<24>>24|0)==32|(u<<24>>24|0)==9|(u<<24>>24|0)==10|(u<<24>>24|0)==13){o=s;p=t;q=n;r=3478;break L4523}a[t]=u;u=n+1|0;if(u>>>0<e>>>0){n=u;s=s+1|0;t=t+1|0}else{r=3477;break}}}}while(0);if((r|0)==3477){e=(c[g>>2]|0)+(b+4)|0;w2(28696,(x=i,i=i+16|0,c[x>>2]=25448,c[x+8>>2]=e,x)|0);v=0;i=f;return v|0}else if((r|0)==3478){a[p]=0;c[g>>2]=o;v=(q|0)!=0|0;i=f;return v|0}return 0}function wP(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;e=b|0;f=c[e>>2]|0;while(1){g=b+4+f|0;h=a[g]|0;if(!((h<<24>>24|0)==13|(h<<24>>24|0)==32|(h<<24>>24|0)==9|(h<<24>>24|0)==10)){break}f=f+1|0}c[e>>2]=f;if((a[g]|0)==0){j=1;i=d;return j|0}w2(28696,(x=i,i=i+16|0,c[x>>2]=24248,c[x+8>>2]=g,x)|0);j=0;i=d;return j|0}function wQ(a,b,d){a=a|0;b=b|0;d=d|0;c[11106]=a;c[11104]=b;c[11102]=a;c[11100]=d;return}function wR(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ad=0,ae=0,af=0;f=i;i=i+264|0;g=f|0;h=f+256|0;j=g|0;k=b|0;l=g+1|0;m=c[k>>2]|0;while(1){n=a[b+4+m|0]|0;if((n<<24>>24|0)==13|(n<<24>>24|0)==32|(n<<24>>24|0)==9|(n<<24>>24|0)==10){m=m+1|0;continue}c[k>>2]=m;n=m;while(1){o=b+4+n|0;p=a[o]|0;if(!((p<<24>>24|0)==13|(p<<24>>24|0)==32|(p<<24>>24|0)==9|(p<<24>>24|0)==10)){break}n=n+1|0}c[k>>2]=n;p=a[o]|0;if(((p<<24>>24)-36|0)>>>0<2){a[j]=p;q=1;r=n+1|0;s=l}else{q=0;r=n;s=j}while(1){p=a[b+4+r|0]|0;if(p<<24>>24==0){t=3503;break}if(!((p-48&255)<10|(p-97&255)<26|(p-65&255)<26|p<<24>>24==95)){t=3503;break}a[s]=p;p=q+1|0;if(p>>>0<256){q=p;r=r+1|0;s=s+1|0}else{t=3502;break}}L4562:do{if((t|0)==3503){t=0;a[s]=0;c[k>>2]=r;if((q|0)==0){t=3583;break}else{u=0}while(1){v=g+u|0;w=a[v]|0;y=u+1|0;if(w<<24>>24==37){u=y}else{z=r;break}}while(1){A=b+4+z|0;n=a[A]|0;if(!((n<<24>>24|0)==13|(n<<24>>24|0)==32|(n<<24>>24|0)==9|(n<<24>>24|0)==10)){break}z=z+1|0}c[k>>2]=z;n=a[A]|0;L4570:do{if(n<<24>>24==61){p=z+1|0;c[k>>2]=p;B=1;C=p}else{p=z;D=n;while(1){if(!((D<<24>>24|0)==13|(D<<24>>24|0)==32|(D<<24>>24|0)==9|(D<<24>>24|0)==10)){break}E=p+1|0;p=E;D=a[b+4+E|0]|0}c[k>>2]=p;D=a[b+4+p|0]|0;do{if(D<<24>>24==43){if((a[p+1+(b+4)|0]|0)!=61){F=p;G=43;break}E=p+2|0;c[k>>2]=E;B=2;C=E;break L4570}else{F=p;G=D}}while(0);while(1){if(!((G<<24>>24|0)==13|(G<<24>>24|0)==32|(G<<24>>24|0)==9|(G<<24>>24|0)==10)){break}D=F+1|0;F=D;G=a[b+4+D|0]|0}c[k>>2]=F;D=a[b+4+F|0]|0;do{if(D<<24>>24==45){if((a[F+1+(b+4)|0]|0)!=61){H=F;I=45;break}p=F+2|0;c[k>>2]=p;B=3;C=p;break L4570}else{H=F;I=D}}while(0);while(1){if(!((I<<24>>24|0)==13|(I<<24>>24|0)==32|(I<<24>>24|0)==9|(I<<24>>24|0)==10)){break}D=H+1|0;H=D;I=a[b+4+D|0]|0}c[k>>2]=H;D=a[b+4+H|0]|0;do{if(D<<24>>24==42){if((a[H+1+(b+4)|0]|0)!=61){J=H;K=42;break}p=H+2|0;c[k>>2]=p;B=4;C=p;break L4570}else{J=H;K=D}}while(0);while(1){if(!((K<<24>>24|0)==13|(K<<24>>24|0)==32|(K<<24>>24|0)==9|(K<<24>>24|0)==10)){break}D=J+1|0;J=D;K=a[b+4+D|0]|0}c[k>>2]=J;D=a[b+4+J|0]|0;do{if(D<<24>>24==47){if((a[J+1+(b+4)|0]|0)!=61){L=J;M=47;break}p=J+2|0;c[k>>2]=p;B=5;C=p;break L4570}else{L=J;M=D}}while(0);while(1){if(!((M<<24>>24|0)==13|(M<<24>>24|0)==32|(M<<24>>24|0)==9|(M<<24>>24|0)==10)){break}D=L+1|0;L=D;M=a[b+4+D|0]|0}c[k>>2]=L;D=a[b+4+L|0]|0;do{if(D<<24>>24==60){if((a[L+1+(b+4)|0]|0)!=60){N=L;O=60;break}if((a[L+2+(b+4)|0]|0)!=61){N=L;O=D;break}p=L+3|0;c[k>>2]=p;B=6;C=p;break L4570}else{N=L;O=D}}while(0);while(1){if(!((O<<24>>24|0)==13|(O<<24>>24|0)==32|(O<<24>>24|0)==9|(O<<24>>24|0)==10)){break}D=N+1|0;N=D;O=a[b+4+D|0]|0}c[k>>2]=N;D=a[b+4+N|0]|0;do{if(D<<24>>24==62){if((a[N+1+(b+4)|0]|0)!=62){P=N;Q=62;break}if((a[N+2+(b+4)|0]|0)!=61){P=N;Q=D;break}p=N+3|0;c[k>>2]=p;B=7;C=p;break L4570}else{P=N;Q=D}}while(0);while(1){if(!((Q<<24>>24|0)==13|(Q<<24>>24|0)==32|(Q<<24>>24|0)==9|(Q<<24>>24|0)==10)){break}D=P+1|0;P=D;Q=a[b+4+D|0]|0}c[k>>2]=P;D=a[b+4+P|0]|0;do{if(D<<24>>24==124){if((a[P+1+(b+4)|0]|0)!=61){R=P;S=124;break}p=P+2|0;c[k>>2]=p;B=8;C=p;break L4570}else{R=P;S=D}}while(0);while(1){if(!((S<<24>>24|0)==13|(S<<24>>24|0)==32|(S<<24>>24|0)==9|(S<<24>>24|0)==10)){break}D=R+1|0;R=D;S=a[b+4+D|0]|0}c[k>>2]=R;D=a[b+4+R|0]|0;do{if(D<<24>>24==38){if((a[R+1+(b+4)|0]|0)!=61){T=R;U=38;break}p=R+2|0;c[k>>2]=p;B=9;C=p;break L4570}else{T=R;U=D}}while(0);while(1){if(!((U<<24>>24|0)==13|(U<<24>>24|0)==32|(U<<24>>24|0)==9|(U<<24>>24|0)==10)){break}D=T+1|0;T=D;U=a[b+4+D|0]|0}c[k>>2]=T;if((a[b+4+T|0]|0)!=94){t=3583;break L4562}if((a[T+1+(b+4)|0]|0)!=61){t=3583;break L4562}D=T+2|0;c[k>>2]=D;B=10;C=D}}while(0);n=C;while(1){V=b+4+n|0;D=a[V]|0;if(!((D<<24>>24|0)==13|(D<<24>>24|0)==32|(D<<24>>24|0)==9|(D<<24>>24|0)==10)){break}n=n+1|0}c[k>>2]=n;if((a[V]|0)==59){c[k>>2]=n+1;if((w<<24>>24|0)==37){break}else if((w<<24>>24|0)==36){W=g+y|0}else{W=v}c[d>>2]=0;D=c[11096]|0;if((D|0)==0){X=0}else{p=0;E=0;Y=D;while(1){D=c[11098]|0;if((aP(c[D+(p<<3)>>2]|0,W|0)|0)==0){c[d>>2]=c[D+(p<<3)+4>>2];zI(c[(c[11098]|0)+(p<<3)>>2]|0);Z=E;_=c[11096]|0}else{$=D+(p<<3)|0;aa=D+(E<<3)|0;D=c[$+4>>2]|0;c[aa>>2]=c[$>>2];c[aa+4>>2]=D;Z=E+1|0;_=Y}D=p+1|0;if(D>>>0<_>>>0){p=D;E=Z;Y=_}else{X=Z;break}}}c[11096]=X;break}Y=(w-36&255)<2?g+y|0:v;do{if(w<<24>>24==36){t=3562}else{E=c[11104]|0;if((E|0)==0){ab=w}else{if((b4[E&127](c[11106]|0,Y,d)|0)==0){break}ab=a[v]|0}if(ab<<24>>24==37){t=3566}else{t=3562}}}while(0);L4661:do{if((t|0)==3562){t=0;E=c[11096]|0;p=c[11098]|0;n=0;while(1){if(n>>>0>=E>>>0){t=3566;break L4661}if((aP(c[p+(n<<3)>>2]|0,Y|0)|0)==0){break}else{n=n+1|0}}c[d>>2]=c[p+(n<<3)+4>>2]}}while(0);if((t|0)==3566){t=0;c[d>>2]=0}if((wV(b,h,e)|0)==0){t=3583;break}do{if((B|0)==4){Y=ac(c[d>>2]|0,c[h>>2]|0)|0;c[d>>2]=Y;ad=Y}else if((B|0)==5){Y=c[h>>2]|0;if((Y|0)==0){c[d>>2]=-1;ad=-1;break}else{E=((c[d>>2]|0)>>>0)/(Y>>>0)|0;c[d>>2]=E;ad=E;break}}else if((B|0)==1){E=c[h>>2]|0;c[d>>2]=E;ad=E}else if((B|0)==2){E=(c[d>>2]|0)+(c[h>>2]|0)|0;c[d>>2]=E;ad=E}else if((B|0)==3){E=(c[d>>2]|0)-(c[h>>2]|0)|0;c[d>>2]=E;ad=E}else if((B|0)==10){E=c[d>>2]^c[h>>2];c[d>>2]=E;ad=E}else if((B|0)==8){E=c[d>>2]|c[h>>2];c[d>>2]=E;ad=E}else if((B|0)==9){E=c[d>>2]&c[h>>2];c[d>>2]=E;ad=E}else if((B|0)==6){E=c[d>>2]<<c[h>>2];c[d>>2]=E;ad=E}else if((B|0)==7){E=(c[d>>2]|0)>>>((c[h>>2]|0)>>>0);c[d>>2]=E;ad=E}else{E=c[h>>2]|0;c[d>>2]=E;ad=E}}while(0);wJ(0,v,ad)|0}else if((t|0)==3502){t=0;E=(c[k>>2]|0)+(b+4)|0;w2(28696,(x=i,i=i+16|0,c[x>>2]=27024,c[x+8>>2]=E,x)|0);t=3583}}while(0);if((t|0)==3583){t=0;c[k>>2]=m;if((wV(b,d,e)|0)==0){ae=0;t=3602;break}}E=c[k>>2]|0;while(1){af=b+4+E|0;Y=a[af]|0;if(!((Y<<24>>24|0)==13|(Y<<24>>24|0)==32|(Y<<24>>24|0)==9|(Y<<24>>24|0)==10)){break}E=E+1|0}c[k>>2]=E;if((a[af]|0)!=44){ae=1;t=3601;break}Y=E+1|0;c[k>>2]=Y;m=Y}if((t|0)==3601){i=f;return ae|0}else if((t|0)==3602){i=f;return ae|0}return 0}function wS(a,d){a=a|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+8|0;f=e|0;if((wR(a,f,16)|0)==0){g=0;i=e;return g|0}b[d>>1]=c[f>>2]&65535;g=1;i=e;return g|0}function wT(a,b){a=a|0;b=b|0;return wR(a,b,16)|0}function wU(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+16|0;h=g|0;j=g+8|0;if((wR(d,j,16)|0)==0){k=0;i=g;return k|0}l=c[j>>2]|0;j=d|0;m=c[j>>2]|0;while(1){n=d+4+m|0;o=a[n]|0;if(!((o<<24>>24|0)==13|(o<<24>>24|0)==32|(o<<24>>24|0)==9|(o<<24>>24|0)==10)){break}m=m+1|0}o=l&65535;c[j>>2]=m;if((a[n]|0)!=58){b[f>>1]=o;k=1;i=g;return k|0}c[j>>2]=m+1;b[e>>1]=o;if((wR(d,h,16)|0)==0){k=1;i=g;return k|0}b[f>>1]=c[h>>2]&65535;k=1;i=g;return k|0}
function wV(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0,fn=0,fo=0,fp=0,fq=0,fr=0,fs=0,ft=0,fu=0,fv=0,fw=0,fx=0,fy=0,fz=0,fA=0,fB=0,fC=0,fD=0,fE=0,fF=0,fG=0,fH=0,fI=0,fJ=0,fK=0,fL=0,fM=0,fN=0,fO=0,fP=0,fQ=0,fR=0,fS=0,fT=0,fU=0,fV=0,fW=0,fX=0,fY=0,fZ=0,f_=0,f$=0,f0=0,f1=0,f2=0,f3=0,f4=0,f5=0,f6=0,f7=0,f8=0,f9=0,ga=0,gb=0,gc=0,gd=0,ge=0,gf=0,gg=0,gh=0,gi=0,gj=0,gk=0,gl=0,gm=0,gn=0,go=0,gp=0,gq=0,gr=0,gs=0,gt=0,gu=0,gv=0,gw=0,gx=0,gy=0,gz=0,gA=0,gB=0,gC=0,gD=0,gE=0,gF=0,gG=0,gH=0,gI=0,gJ=0,gK=0,gL=0,gM=0,gN=0,gO=0,gP=0,gQ=0,gR=0,gS=0,gT=0,gU=0,gV=0,gW=0,gX=0,gY=0,gZ=0,g_=0,g$=0,g0=0,g1=0,g2=0,g3=0,g4=0,g5=0,g6=0,g7=0,g8=0,g9=0,ha=0,hb=0,hc=0,hd=0,he=0,hf=0,hg=0,hh=0,hi=0,hj=0,hk=0,hl=0,hm=0,hn=0,ho=0,hp=0,hq=0,hr=0,hs=0,ht=0,hu=0,hv=0,hw=0,hx=0,hy=0,hz=0,hA=0,hB=0,hC=0,hD=0,hE=0,hF=0,hG=0,hH=0,hI=0,hJ=0,hK=0,hL=0,hM=0,hN=0,hO=0,hP=0,hQ=0,hR=0,hS=0,hT=0,hU=0,hV=0,hW=0,hX=0,hY=0,hZ=0,h_=0,h$=0,h0=0,h1=0,h2=0,h3=0,h4=0,h5=0,h6=0,h7=0,h8=0,h9=0,ia=0,ib=0,ic=0,id=0,ie=0,ig=0,ih=0,ii=0,ij=0,ik=0,il=0,im=0,io=0,ip=0,iq=0,ir=0,is=0,it=0,iu=0,iv=0,iw=0,ix=0,iy=0,iz=0,iA=0,iB=0,iC=0,iD=0,iE=0,iF=0,iG=0,iH=0,iI=0,iJ=0,iK=0,iL=0,iM=0,iN=0,iO=0,iP=0,iQ=0,iR=0,iS=0,iT=0,iU=0,iV=0,iW=0,iX=0,iY=0,iZ=0,i_=0,i$=0,i0=0,i1=0,i2=0,i3=0,i4=0,i5=0,i6=0,i7=0,i8=0,i9=0,ja=0,jb=0,jc=0,jd=0,je=0,jf=0,jg=0,jh=0,ji=0,jj=0,jk=0,jl=0,jm=0,jn=0,jo=0,jp=0,jq=0,jr=0,js=0,jt=0,ju=0,jv=0,jw=0,jx=0,jy=0,jz=0,jA=0,jB=0,jC=0,jD=0,jE=0,jF=0,jG=0,jH=0,jI=0,jJ=0,jK=0,jL=0,jM=0,jN=0,jO=0,jP=0,jQ=0,jR=0,jS=0,jT=0,jU=0,jV=0,jW=0,jX=0,jY=0,jZ=0,j_=0,j$=0,j0=0,j1=0,j2=0,j3=0,j4=0,j5=0,j6=0,j7=0,j8=0,j9=0,ka=0,kb=0,kc=0,kd=0,ke=0,kf=0,kg=0,kh=0,ki=0,kj=0,kk=0,kl=0,km=0,kn=0,ko=0,kp=0,kq=0,kr=0,ks=0,kt=0,ku=0,kv=0,kw=0,kx=0,ky=0,kz=0,kA=0,kB=0,kC=0,kD=0,kE=0,kF=0,kG=0,kH=0,kI=0,kJ=0,kK=0,kL=0,kM=0,kN=0,kO=0,kP=0,kQ=0,kR=0,kS=0,kT=0,kU=0,kV=0,kW=0,kX=0,kY=0,kZ=0,k_=0,k$=0,k0=0,k1=0,k2=0,k3=0,k4=0,k5=0,k6=0,k7=0,k8=0,k9=0,la=0,lb=0,lc=0,ld=0,le=0,lf=0,lg=0,lh=0,li=0,lj=0,lk=0,ll=0,lm=0,ln=0,lo=0,lp=0,lq=0,lr=0,ls=0,lt=0,lu=0,lv=0,lw=0,lx=0,ly=0,lz=0,lA=0,lB=0,lC=0,lD=0,lE=0,lF=0,lG=0,lH=0,lI=0,lJ=0,lK=0,lL=0,lM=0,lN=0,lO=0,lP=0,lQ=0,lR=0,lS=0,lT=0,lU=0,lV=0,lW=0,lX=0,lY=0,lZ=0,l_=0,l$=0,l0=0,l1=0,l2=0,l3=0,l4=0,l5=0,l6=0,l7=0,l8=0,l9=0,ma=0,mb=0,mc=0,md=0,me=0,mf=0,mg=0,mh=0,mi=0,mj=0,mk=0,ml=0,mm=0,mn=0,mo=0,mp=0,mq=0,mr=0,ms=0,mt=0,mu=0,mv=0,mw=0,mx=0,my=0,mz=0,mA=0,mB=0,mC=0,mD=0,mE=0,mF=0,mG=0,mH=0,mI=0,mJ=0,mK=0,mL=0,mM=0,mN=0,mO=0,mP=0,mQ=0,mR=0,mS=0,mT=0,mU=0,mV=0,mW=0,mX=0,mY=0,mZ=0,m_=0,m$=0,m0=0,m1=0,m2=0,m3=0,m4=0,m5=0,m6=0,m7=0,m8=0,m9=0,na=0,nb=0,nc=0,nd=0,ne=0,nf=0,ng=0,nh=0,ni=0,nj=0,nk=0,nl=0,nm=0,nn=0,no=0,np=0,nq=0,nr=0,ns=0,nt=0,nu=0,nv=0,nw=0,nx=0,ny=0,nz=0,nA=0,nB=0,nC=0,nD=0,nE=0,nF=0,nG=0,nH=0,nI=0,nJ=0,nK=0,nL=0,nM=0,nN=0,nO=0,nP=0,nQ=0,nR=0,nS=0,nT=0,nU=0,nV=0,nW=0,nX=0,nY=0,nZ=0,n_=0,n$=0,n0=0,n1=0,n2=0,n3=0,n4=0,n5=0,n6=0,n7=0,n8=0,n9=0,oa=0,ob=0,oc=0,od=0,oe=0,of=0,og=0,oh=0,oi=0,oj=0,ok=0,ol=0,om=0,on=0,oo=0,op=0,oq=0,or=0,os=0,ot=0,ou=0,ov=0,ow=0,ox=0,oy=0,oz=0,oA=0,oB=0,oC=0,oD=0,oE=0,oF=0,oG=0,oH=0,oI=0,oJ=0,oK=0,oL=0,oM=0,oN=0,oO=0,oP=0,oQ=0,oR=0,oS=0,oT=0,oU=0,oV=0,oW=0,oX=0,oY=0,oZ=0,o_=0,o$=0,o0=0,o1=0,o2=0,o3=0,o4=0,o5=0,o6=0,o7=0,o8=0,o9=0,pa=0,pb=0,pc=0,pd=0,pe=0,pf=0,pg=0,ph=0,pi=0,pj=0,pk=0,pl=0,pm=0,pn=0,po=0,pp=0,pq=0,pr=0,ps=0,pt=0,pu=0,pv=0,pw=0,px=0,py=0,pz=0,pA=0,pB=0,pC=0,pD=0,pE=0,pF=0,pG=0,pH=0,pI=0,pJ=0,pK=0,pL=0,pM=0,pN=0,pO=0,pP=0,pQ=0,pR=0,pS=0,pT=0,pU=0,pV=0,pW=0,pX=0,pY=0,pZ=0,p_=0,p$=0,p0=0,p1=0,p2=0,p3=0,p4=0,p5=0,p6=0,p7=0,p8=0,p9=0,qa=0,qb=0,qc=0,qd=0,qe=0,qf=0,qg=0;f=i;i=i+1528|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=f+32|0;m=f+40|0;n=f+48|0;o=f+56|0;p=f+64|0;q=f+72|0;r=f+80|0;s=f+88|0;t=f+96|0;u=f+104|0;v=f+112|0;w=f+120|0;x=f+128|0;y=f+136|0;z=f+144|0;A=f+152|0;B=f+160|0;C=f+168|0;D=f+176|0;E=f+184|0;F=f+192|0;G=f+200|0;H=f+208|0;I=f+216|0;J=f+224|0;K=f+232|0;L=f+240|0;M=f+248|0;N=f+256|0;O=f+264|0;P=f+272|0;Q=f+280|0;R=f+288|0;S=f+296|0;T=f+304|0;U=f+312|0;V=f+320|0;W=f+328|0;X=f+336|0;Y=f+344|0;Z=f+352|0;_=f+360|0;$=f+368|0;aa=f+376|0;ab=f+384|0;ac=f+392|0;ad=f+400|0;ae=f+408|0;af=f+416|0;ag=f+424|0;ah=f+432|0;ai=f+440|0;aj=f+448|0;ak=f+456|0;al=f+464|0;am=f+472|0;an=f+480|0;ao=f+488|0;ap=f+496|0;aq=f+504|0;ar=f+512|0;as=f+520|0;at=f+528|0;au=f+536|0;av=f+544|0;aw=f+552|0;ax=f+560|0;ay=f+568|0;az=f+576|0;aA=f+584|0;aB=f+592|0;aC=f+600|0;aD=f+608|0;aE=f+616|0;aF=f+624|0;aG=f+632|0;aH=f+640|0;aI=f+648|0;aJ=f+656|0;aK=f+664|0;aL=f+672|0;aM=f+680|0;aN=f+688|0;aO=f+696|0;aP=f+704|0;aQ=f+712|0;aR=f+720|0;aS=f+728|0;aT=f+736|0;aU=f+744|0;aV=f+752|0;aW=f+760|0;aX=f+768|0;aY=f+776|0;aZ=f+784|0;a_=f+792|0;a$=f+800|0;a0=f+808|0;a1=f+816|0;a2=f+824|0;a3=f+832|0;a4=f+840|0;a5=f+848|0;a6=f+856|0;a7=f+864|0;a8=f+872|0;a9=f+880|0;ba=f+888|0;bb=f+896|0;bc=f+904|0;bd=f+912|0;be=f+920|0;bf=f+928|0;bg=f+936|0;bh=f+944|0;bi=f+952|0;bj=f+960|0;bk=f+968|0;bl=f+976|0;bm=f+984|0;bn=f+992|0;bo=f+1e3|0;bp=f+1008|0;bq=f+1016|0;br=f+1024|0;bs=f+1032|0;bt=f+1040|0;bu=f+1048|0;bv=f+1056|0;bw=f+1064|0;bx=f+1072|0;by=f+1080|0;bz=f+1088|0;bA=f+1096|0;bB=f+1104|0;bC=f+1112|0;bD=f+1120|0;bE=f+1128|0;bF=f+1136|0;bG=f+1144|0;bH=f+1152|0;bI=f+1160|0;bJ=f+1168|0;bK=f+1176|0;bL=f+1184|0;bM=f+1192|0;bN=f+1200|0;bO=f+1208|0;bP=f+1216|0;bQ=f+1224|0;bR=f+1232|0;bS=f+1240|0;bT=f+1248|0;bU=f+1256|0;bV=f+1264|0;bW=f+1272|0;bX=f+1280|0;bY=f+1288|0;bZ=f+1296|0;b_=f+1304|0;b$=f+1312|0;b0=f+1320|0;b1=f+1328|0;b2=f+1336|0;b3=f+1344|0;b4=f+1352|0;b5=f+1360|0;b6=f+1368|0;b7=f+1376|0;b8=f+1384|0;b9=f+1392|0;ca=f+1400|0;cb=f+1408|0;cc=f+1416|0;cd=f+1424|0;ce=f+1432|0;cf=f+1440|0;cg=f+1448|0;ch=f+1456|0;ci=f+1464|0;cj=f+1472|0;ck=f+1480|0;cl=f+1488|0;cm=f+1496|0;cn=f+1504|0;co=f+1512|0;cp=f+1520|0;cq=b|0;cr=c[cq>>2]|0;if((wW(b,d,e)|0)==0){cs=0;i=f;return cs|0}while(1){ct=c[cq>>2]|0;while(1){cu=b+4+ct|0;cv=a[cu]|0;if(!((cv<<24>>24|0)==13|(cv<<24>>24|0)==32|(cv<<24>>24|0)==9|(cv<<24>>24|0)==10)){break}ct=ct+1|0}c[cq>>2]=ct;cv=a[cu]|0;if(cv<<24>>24==61){if((a[ct+1+(b+4)|0]|0)==61){cw=1;cx=ct}else{cy=ct;cz=61;cA=7}}else{cy=ct;cz=cv;cA=7}if((cA|0)==7){while(1){cA=0;if(!((cz<<24>>24|0)==13|(cz<<24>>24|0)==32|(cz<<24>>24|0)==9|(cz<<24>>24|0)==10)){break}cv=cy+1|0;cy=cv;cz=a[b+4+cv|0]|0;cA=7}c[cq>>2]=cy;if((a[b+4+cy|0]|0)!=33){break}if((a[cy+1+(b+4)|0]|0)==61){cw=2;cx=cy}else{break}}c[cq>>2]=cx+2;if((wW(b,aW,e)|0)==0){cA=13;break}if((cw|0)==1){c[d>>2]=(c[d>>2]|0)==(c[aW>>2]|0);continue}else if((cw|0)==2){c[d>>2]=(c[d>>2]|0)!=(c[aW>>2]|0);continue}else{continue}}if((cA|0)==13){c[cq>>2]=cr;cs=0;i=f;return cs|0}aW=cy;L26:while(1){cy=aW;while(1){cB=b+4+cy|0;cw=a[cB]|0;if(!((cw<<24>>24|0)==13|(cw<<24>>24|0)==32|(cw<<24>>24|0)==9|(cw<<24>>24|0)==10)){break}cy=cy+1|0}c[cq>>2]=cy;cw=a[cB]|0;if(cw<<24>>24==38){if((a[cy+1+(b+4)|0]|0)==38){cA=2318;break}else{cC=cy;cD=38}}else{cC=cy;cD=cw}while(1){if(!((cD<<24>>24|0)==13|(cD<<24>>24|0)==32|(cD<<24>>24|0)==9|(cD<<24>>24|0)==10)){break}cw=cC+1|0;cC=cw;cD=a[b+4+cw|0]|0}c[cq>>2]=cC;if((a[b+4+cC|0]|0)!=38){cE=cC;break}cF=cC+1|0;c[cq>>2]=cF;if((wW(b,bG,e)|0)==0){cA=41;break}while(1){cy=c[cq>>2]|0;while(1){cG=b+4+cy|0;cw=a[cG]|0;if(!((cw<<24>>24|0)==13|(cw<<24>>24|0)==32|(cw<<24>>24|0)==9|(cw<<24>>24|0)==10)){break}cy=cy+1|0}c[cq>>2]=cy;cw=a[cG]|0;if(cw<<24>>24==61){if((a[cy+1+(b+4)|0]|0)==61){cH=1;cI=cy}else{cJ=cy;cK=61;cA=32}}else{cJ=cy;cK=cw;cA=32}if((cA|0)==32){while(1){cA=0;if(!((cK<<24>>24|0)==13|(cK<<24>>24|0)==32|(cK<<24>>24|0)==9|(cK<<24>>24|0)==10)){break}cw=cJ+1|0;cJ=cw;cK=a[b+4+cw|0]|0;cA=32}c[cq>>2]=cJ;if((a[b+4+cJ|0]|0)!=33){break}if((a[cJ+1+(b+4)|0]|0)==61){cH=2;cI=cJ}else{break}}c[cq>>2]=cI+2;if((wW(b,aV,e)|0)==0){cA=37;break L26}if((cH|0)==1){c[bG>>2]=(c[bG>>2]|0)==(c[aV>>2]|0);continue}else if((cH|0)==2){c[bG>>2]=(c[bG>>2]|0)!=(c[aV>>2]|0);continue}else{continue}}c[d>>2]=c[bG>>2]&c[d>>2];aW=c[cq>>2]|0}if((cA|0)==37){c[cq>>2]=cF;cA=41}else if((cA|0)==2318){c[cq>>2]=aW;cE=aW}if((cA|0)==41){c[cq>>2]=cr;cs=0;i=f;return cs|0}aW=cE;L66:while(1){cE=b+4+aW|0;cF=a[cE]|0;if((cF<<24>>24|0)==13|(cF<<24>>24|0)==32|(cF<<24>>24|0)==9|(cF<<24>>24|0)==10){aW=aW+1|0;continue}c[cq>>2]=aW;if((a[cE]|0)!=94){cA=46;break}cL=aW+1|0;c[cq>>2]=cL;if((wW(b,b2,e)|0)==0){break}while(1){cE=c[cq>>2]|0;while(1){cM=b+4+cE|0;cF=a[cM]|0;if(!((cF<<24>>24|0)==13|(cF<<24>>24|0)==32|(cF<<24>>24|0)==9|(cF<<24>>24|0)==10)){break}cE=cE+1|0}c[cq>>2]=cE;cF=a[cM]|0;if(cF<<24>>24==61){if((a[cE+1+(b+4)|0]|0)==61){cN=1;cO=cE}else{cP=cE;cQ=61;cA=53}}else{cP=cE;cQ=cF;cA=53}if((cA|0)==53){while(1){cA=0;if(!((cQ<<24>>24|0)==13|(cQ<<24>>24|0)==32|(cQ<<24>>24|0)==9|(cQ<<24>>24|0)==10)){break}cF=cP+1|0;cP=cF;cQ=a[b+4+cF|0]|0;cA=53}c[cq>>2]=cP;if((a[b+4+cP|0]|0)!=33){cR=cP;break}if((a[cP+1+(b+4)|0]|0)==61){cN=2;cO=cP}else{cR=cP;break}}c[cq>>2]=cO+2;if((wW(b,aU,e)|0)==0){cA=58;break L66}if((cN|0)==1){c[b2>>2]=(c[b2>>2]|0)==(c[aU>>2]|0);continue}else if((cN|0)==2){c[b2>>2]=(c[b2>>2]|0)!=(c[aU>>2]|0);continue}else{continue}}while(1){cE=cR;while(1){cS=b+4+cE|0;cF=a[cS]|0;if(!((cF<<24>>24|0)==13|(cF<<24>>24|0)==32|(cF<<24>>24|0)==9|(cF<<24>>24|0)==10)){break}cE=cE+1|0}c[cq>>2]=cE;cF=a[cS]|0;if(cF<<24>>24==38){if((a[cE+1+(b+4)|0]|0)==38){cA=2317;break}else{cT=cE;cU=38}}else{cT=cE;cU=cF}while(1){if(!((cU<<24>>24|0)==13|(cU<<24>>24|0)==32|(cU<<24>>24|0)==9|(cU<<24>>24|0)==10)){break}cF=cT+1|0;cT=cF;cU=a[b+4+cF|0]|0}c[cq>>2]=cT;if((a[b+4+cT|0]|0)!=38){break}cV=cT+1|0;c[cq>>2]=cV;if((wW(b,bF,e)|0)==0){cA=85;break L66}while(1){cE=c[cq>>2]|0;while(1){cW=b+4+cE|0;cF=a[cW]|0;if(!((cF<<24>>24|0)==13|(cF<<24>>24|0)==32|(cF<<24>>24|0)==9|(cF<<24>>24|0)==10)){break}cE=cE+1|0}c[cq>>2]=cE;cF=a[cW]|0;if(cF<<24>>24==61){if((a[cE+1+(b+4)|0]|0)==61){cX=1;cY=cE}else{cZ=cE;c_=61;cA=76}}else{cZ=cE;c_=cF;cA=76}if((cA|0)==76){while(1){cA=0;if(!((c_<<24>>24|0)==13|(c_<<24>>24|0)==32|(c_<<24>>24|0)==9|(c_<<24>>24|0)==10)){break}cF=cZ+1|0;cZ=cF;c_=a[b+4+cF|0]|0;cA=76}c[cq>>2]=cZ;if((a[b+4+cZ|0]|0)!=33){break}if((a[cZ+1+(b+4)|0]|0)==61){cX=2;cY=cZ}else{break}}c[cq>>2]=cY+2;if((wW(b,aT,e)|0)==0){cA=81;break L66}if((cX|0)==1){c[bF>>2]=(c[bF>>2]|0)==(c[aT>>2]|0);continue}else if((cX|0)==2){c[bF>>2]=(c[bF>>2]|0)!=(c[aT>>2]|0);continue}else{continue}}c[b2>>2]=c[bF>>2]&c[b2>>2];cR=cZ}if((cA|0)==2317){cA=0;c[cq>>2]=cR}c[d>>2]=c[b2>>2]^c[d>>2];aW=c[cq>>2]|0}if((cA|0)==46){b2=aW;L129:while(1){aW=b2;while(1){c$=b+4+aW|0;cR=a[c$]|0;if(!((cR<<24>>24|0)==13|(cR<<24>>24|0)==32|(cR<<24>>24|0)==9|(cR<<24>>24|0)==10)){break}aW=aW+1|0}c[cq>>2]=aW;cR=a[c$]|0;if(cR<<24>>24==124){if((a[aW+1+(b+4)|0]|0)==124){cA=2314;break}else{c0=aW;c1=124}}else{c0=aW;c1=cR}while(1){if(!((c1<<24>>24|0)==13|(c1<<24>>24|0)==32|(c1<<24>>24|0)==9|(c1<<24>>24|0)==10)){break}cR=c0+1|0;c0=cR;c1=a[b+4+cR|0]|0}c[cq>>2]=c0;if((a[b+4+c0|0]|0)!=124){c2=c0;cA=97;break}c3=c0+1|0;c[cq>>2]=c3;if((wW(b,ce,e)|0)==0){break}while(1){aW=c[cq>>2]|0;while(1){c4=b+4+aW|0;cR=a[c4]|0;if(!((cR<<24>>24|0)==13|(cR<<24>>24|0)==32|(cR<<24>>24|0)==9|(cR<<24>>24|0)==10)){break}aW=aW+1|0}c[cq>>2]=aW;cR=a[c4]|0;if(cR<<24>>24==61){if((a[aW+1+(b+4)|0]|0)==61){c5=1;c6=aW}else{c7=aW;c8=61;cA=104}}else{c7=aW;c8=cR;cA=104}if((cA|0)==104){while(1){cA=0;if(!((c8<<24>>24|0)==13|(c8<<24>>24|0)==32|(c8<<24>>24|0)==9|(c8<<24>>24|0)==10)){break}cR=c7+1|0;c7=cR;c8=a[b+4+cR|0]|0;cA=104}c[cq>>2]=c7;if((a[b+4+c7|0]|0)!=33){c9=c7;break}if((a[c7+1+(b+4)|0]|0)==61){c5=2;c6=c7}else{c9=c7;break}}c[cq>>2]=c6+2;if((wW(b,aS,e)|0)==0){cA=109;break L129}if((c5|0)==1){c[ce>>2]=(c[ce>>2]|0)==(c[aS>>2]|0);continue}else if((c5|0)==2){c[ce>>2]=(c[ce>>2]|0)!=(c[aS>>2]|0);continue}else{continue}}while(1){aW=c9;while(1){da=b+4+aW|0;cR=a[da]|0;if(!((cR<<24>>24|0)==13|(cR<<24>>24|0)==32|(cR<<24>>24|0)==9|(cR<<24>>24|0)==10)){break}aW=aW+1|0}c[cq>>2]=aW;cR=a[da]|0;if(cR<<24>>24==38){if((a[aW+1+(b+4)|0]|0)==38){cA=2315;break}else{db=aW;dc=38}}else{db=aW;dc=cR}while(1){if(!((dc<<24>>24|0)==13|(dc<<24>>24|0)==32|(dc<<24>>24|0)==9|(dc<<24>>24|0)==10)){break}cR=db+1|0;db=cR;dc=a[b+4+cR|0]|0}c[cq>>2]=db;if((a[b+4+db|0]|0)!=38){dd=db;break}de=db+1|0;c[cq>>2]=de;if((wW(b,bE,e)|0)==0){cA=136;break L129}while(1){aW=c[cq>>2]|0;while(1){df=b+4+aW|0;cR=a[df]|0;if(!((cR<<24>>24|0)==13|(cR<<24>>24|0)==32|(cR<<24>>24|0)==9|(cR<<24>>24|0)==10)){break}aW=aW+1|0}c[cq>>2]=aW;cR=a[df]|0;if(cR<<24>>24==61){if((a[aW+1+(b+4)|0]|0)==61){dg=1;dh=aW}else{di=aW;dj=61;cA=127}}else{di=aW;dj=cR;cA=127}if((cA|0)==127){while(1){cA=0;if(!((dj<<24>>24|0)==13|(dj<<24>>24|0)==32|(dj<<24>>24|0)==9|(dj<<24>>24|0)==10)){break}cR=di+1|0;di=cR;dj=a[b+4+cR|0]|0;cA=127}c[cq>>2]=di;if((a[b+4+di|0]|0)!=33){break}if((a[di+1+(b+4)|0]|0)==61){dg=2;dh=di}else{break}}c[cq>>2]=dh+2;if((wW(b,aR,e)|0)==0){cA=132;break L129}if((dg|0)==1){c[bE>>2]=(c[bE>>2]|0)==(c[aR>>2]|0);continue}else if((dg|0)==2){c[bE>>2]=(c[bE>>2]|0)!=(c[aR>>2]|0);continue}else{continue}}c[ce>>2]=c[bE>>2]&c[ce>>2];c9=di}if((cA|0)==2315){cA=0;c[cq>>2]=c9;dd=c9}while(1){aW=b+4+dd|0;cR=a[aW]|0;if((cR<<24>>24|0)==13|(cR<<24>>24|0)==32|(cR<<24>>24|0)==9|(cR<<24>>24|0)==10){dd=dd+1|0;continue}c[cq>>2]=dd;if((a[aW]|0)!=94){break}dk=dd+1|0;c[cq>>2]=dk;if((wW(b,b1,e)|0)==0){cA=181;break L129}while(1){aW=c[cq>>2]|0;while(1){dl=b+4+aW|0;cR=a[dl]|0;if(!((cR<<24>>24|0)==13|(cR<<24>>24|0)==32|(cR<<24>>24|0)==9|(cR<<24>>24|0)==10)){break}aW=aW+1|0}c[cq>>2]=aW;cR=a[dl]|0;if(cR<<24>>24==61){if((a[aW+1+(b+4)|0]|0)==61){dm=1;dn=aW}else{dp=aW;dq=61;cA=147}}else{dp=aW;dq=cR;cA=147}if((cA|0)==147){while(1){cA=0;if(!((dq<<24>>24|0)==13|(dq<<24>>24|0)==32|(dq<<24>>24|0)==9|(dq<<24>>24|0)==10)){break}cR=dp+1|0;dp=cR;dq=a[b+4+cR|0]|0;cA=147}c[cq>>2]=dp;if((a[b+4+dp|0]|0)!=33){dr=dp;break}if((a[dp+1+(b+4)|0]|0)==61){dm=2;dn=dp}else{dr=dp;break}}c[cq>>2]=dn+2;if((wW(b,aQ,e)|0)==0){cA=152;break L129}if((dm|0)==1){c[b1>>2]=(c[b1>>2]|0)==(c[aQ>>2]|0);continue}else if((dm|0)==2){c[b1>>2]=(c[b1>>2]|0)!=(c[aQ>>2]|0);continue}else{continue}}while(1){aW=dr;while(1){ds=b+4+aW|0;cR=a[ds]|0;if(!((cR<<24>>24|0)==13|(cR<<24>>24|0)==32|(cR<<24>>24|0)==9|(cR<<24>>24|0)==10)){break}aW=aW+1|0}c[cq>>2]=aW;cR=a[ds]|0;if(cR<<24>>24==38){if((a[aW+1+(b+4)|0]|0)==38){cA=2316;break}else{dt=aW;du=38}}else{dt=aW;du=cR}while(1){if(!((du<<24>>24|0)==13|(du<<24>>24|0)==32|(du<<24>>24|0)==9|(du<<24>>24|0)==10)){break}cR=dt+1|0;dt=cR;du=a[b+4+cR|0]|0}c[cq>>2]=dt;if((a[b+4+dt|0]|0)!=38){dv=dt;break}dw=dt+1|0;c[cq>>2]=dw;if((wW(b,bD,e)|0)==0){cA=179;break L129}while(1){aW=c[cq>>2]|0;while(1){dx=b+4+aW|0;cR=a[dx]|0;if(!((cR<<24>>24|0)==13|(cR<<24>>24|0)==32|(cR<<24>>24|0)==9|(cR<<24>>24|0)==10)){break}aW=aW+1|0}c[cq>>2]=aW;cR=a[dx]|0;if(cR<<24>>24==61){if((a[aW+1+(b+4)|0]|0)==61){dy=1;dz=aW}else{dA=aW;dB=61;cA=170}}else{dA=aW;dB=cR;cA=170}if((cA|0)==170){while(1){cA=0;if(!((dB<<24>>24|0)==13|(dB<<24>>24|0)==32|(dB<<24>>24|0)==9|(dB<<24>>24|0)==10)){break}cR=dA+1|0;dA=cR;dB=a[b+4+cR|0]|0;cA=170}c[cq>>2]=dA;if((a[b+4+dA|0]|0)!=33){break}if((a[dA+1+(b+4)|0]|0)==61){dy=2;dz=dA}else{break}}c[cq>>2]=dz+2;if((wW(b,aP,e)|0)==0){cA=175;break L129}if((dy|0)==1){c[bD>>2]=(c[bD>>2]|0)==(c[aP>>2]|0);continue}else if((dy|0)==2){c[bD>>2]=(c[bD>>2]|0)!=(c[aP>>2]|0);continue}else{continue}}c[b1>>2]=c[bD>>2]&c[b1>>2];dr=dA}if((cA|0)==2316){cA=0;c[cq>>2]=dr;dv=dr}c[ce>>2]=c[b1>>2]^c[ce>>2];dd=dv}c[d>>2]=c[ce>>2]|c[d>>2];b2=c[cq>>2]|0}if((cA|0)==109){c[cq>>2]=c3}else if((cA|0)==132){c[cq>>2]=de;cA=136}else if((cA|0)==152){c[cq>>2]=dk;cA=181}else if((cA|0)==175){c[cq>>2]=dw;cA=179}else if((cA|0)==2314){c[cq>>2]=b2;c2=b2;cA=97}if((cA|0)==97){b2=c2;L266:while(1){c2=b+4+b2|0;dw=a[c2]|0;if((dw<<24>>24|0)==13|(dw<<24>>24|0)==32|(dw<<24>>24|0)==9|(dw<<24>>24|0)==10){b2=b2+1|0;continue}c[cq>>2]=b2;if((a[c2]|0)!=38){cA=188;break}if((a[b2+1+(b+4)|0]|0)!=38){cA=188;break}dC=b2+2|0;c[cq>>2]=dC;if((wW(b,ck,e)|0)==0){break}while(1){c2=c[cq>>2]|0;while(1){dD=b+4+c2|0;dw=a[dD]|0;if(!((dw<<24>>24|0)==13|(dw<<24>>24|0)==32|(dw<<24>>24|0)==9|(dw<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;dw=a[dD]|0;if(dw<<24>>24==61){if((a[c2+1+(b+4)|0]|0)==61){dE=1;dF=c2}else{dG=c2;dH=61;cA=195}}else{dG=c2;dH=dw;cA=195}if((cA|0)==195){while(1){cA=0;if(!((dH<<24>>24|0)==13|(dH<<24>>24|0)==32|(dH<<24>>24|0)==9|(dH<<24>>24|0)==10)){break}dw=dG+1|0;dG=dw;dH=a[b+4+dw|0]|0;cA=195}c[cq>>2]=dG;if((a[b+4+dG|0]|0)!=33){dI=dG;break}if((a[dG+1+(b+4)|0]|0)==61){dE=2;dF=dG}else{dI=dG;break}}c[cq>>2]=dF+2;if((wW(b,aO,e)|0)==0){cA=200;break L266}if((dE|0)==1){c[ck>>2]=(c[ck>>2]|0)==(c[aO>>2]|0);continue}else if((dE|0)==2){c[ck>>2]=(c[ck>>2]|0)!=(c[aO>>2]|0);continue}else{continue}}while(1){c2=dI;while(1){dJ=b+4+c2|0;dw=a[dJ]|0;if(!((dw<<24>>24|0)==13|(dw<<24>>24|0)==32|(dw<<24>>24|0)==9|(dw<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;dw=a[dJ]|0;if(dw<<24>>24==38){if((a[c2+1+(b+4)|0]|0)==38){cA=2309;break}else{dK=c2;dL=38}}else{dK=c2;dL=dw}while(1){if(!((dL<<24>>24|0)==13|(dL<<24>>24|0)==32|(dL<<24>>24|0)==9|(dL<<24>>24|0)==10)){break}dw=dK+1|0;dK=dw;dL=a[b+4+dw|0]|0}c[cq>>2]=dK;if((a[b+4+dK|0]|0)!=38){dM=dK;break}dN=dK+1|0;c[cq>>2]=dN;if((wW(b,bC,e)|0)==0){cA=227;break L266}while(1){c2=c[cq>>2]|0;while(1){dO=b+4+c2|0;dw=a[dO]|0;if(!((dw<<24>>24|0)==13|(dw<<24>>24|0)==32|(dw<<24>>24|0)==9|(dw<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;dw=a[dO]|0;if(dw<<24>>24==61){if((a[c2+1+(b+4)|0]|0)==61){dP=1;dQ=c2}else{dR=c2;dS=61;cA=218}}else{dR=c2;dS=dw;cA=218}if((cA|0)==218){while(1){cA=0;if(!((dS<<24>>24|0)==13|(dS<<24>>24|0)==32|(dS<<24>>24|0)==9|(dS<<24>>24|0)==10)){break}dw=dR+1|0;dR=dw;dS=a[b+4+dw|0]|0;cA=218}c[cq>>2]=dR;if((a[b+4+dR|0]|0)!=33){break}if((a[dR+1+(b+4)|0]|0)==61){dP=2;dQ=dR}else{break}}c[cq>>2]=dQ+2;if((wW(b,aN,e)|0)==0){cA=223;break L266}if((dP|0)==1){c[bC>>2]=(c[bC>>2]|0)==(c[aN>>2]|0);continue}else if((dP|0)==2){c[bC>>2]=(c[bC>>2]|0)!=(c[aN>>2]|0);continue}else{continue}}c[ck>>2]=c[bC>>2]&c[ck>>2];dI=dR}if((cA|0)==2309){cA=0;c[cq>>2]=dI;dM=dI}while(1){c2=b+4+dM|0;dw=a[c2]|0;if((dw<<24>>24|0)==13|(dw<<24>>24|0)==32|(dw<<24>>24|0)==9|(dw<<24>>24|0)==10){dM=dM+1|0;continue}c[cq>>2]=dM;if((a[c2]|0)!=94){dT=dM;break}dU=dM+1|0;c[cq>>2]=dU;if((wW(b,b0,e)|0)==0){cA=272;break L266}while(1){c2=c[cq>>2]|0;while(1){dV=b+4+c2|0;dw=a[dV]|0;if(!((dw<<24>>24|0)==13|(dw<<24>>24|0)==32|(dw<<24>>24|0)==9|(dw<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;dw=a[dV]|0;if(dw<<24>>24==61){if((a[c2+1+(b+4)|0]|0)==61){dW=1;dX=c2}else{dY=c2;dZ=61;cA=238}}else{dY=c2;dZ=dw;cA=238}if((cA|0)==238){while(1){cA=0;if(!((dZ<<24>>24|0)==13|(dZ<<24>>24|0)==32|(dZ<<24>>24|0)==9|(dZ<<24>>24|0)==10)){break}dw=dY+1|0;dY=dw;dZ=a[b+4+dw|0]|0;cA=238}c[cq>>2]=dY;if((a[b+4+dY|0]|0)!=33){d_=dY;break}if((a[dY+1+(b+4)|0]|0)==61){dW=2;dX=dY}else{d_=dY;break}}c[cq>>2]=dX+2;if((wW(b,aM,e)|0)==0){cA=243;break L266}if((dW|0)==1){c[b0>>2]=(c[b0>>2]|0)==(c[aM>>2]|0);continue}else if((dW|0)==2){c[b0>>2]=(c[b0>>2]|0)!=(c[aM>>2]|0);continue}else{continue}}while(1){c2=d_;while(1){d$=b+4+c2|0;dw=a[d$]|0;if(!((dw<<24>>24|0)==13|(dw<<24>>24|0)==32|(dw<<24>>24|0)==9|(dw<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;dw=a[d$]|0;if(dw<<24>>24==38){if((a[c2+1+(b+4)|0]|0)==38){cA=2310;break}else{d0=c2;d1=38}}else{d0=c2;d1=dw}while(1){if(!((d1<<24>>24|0)==13|(d1<<24>>24|0)==32|(d1<<24>>24|0)==9|(d1<<24>>24|0)==10)){break}dw=d0+1|0;d0=dw;d1=a[b+4+dw|0]|0}c[cq>>2]=d0;if((a[b+4+d0|0]|0)!=38){d2=d0;break}d3=d0+1|0;c[cq>>2]=d3;if((wW(b,bB,e)|0)==0){cA=270;break L266}while(1){c2=c[cq>>2]|0;while(1){d4=b+4+c2|0;dw=a[d4]|0;if(!((dw<<24>>24|0)==13|(dw<<24>>24|0)==32|(dw<<24>>24|0)==9|(dw<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;dw=a[d4]|0;if(dw<<24>>24==61){if((a[c2+1+(b+4)|0]|0)==61){d5=1;d6=c2}else{d7=c2;d8=61;cA=261}}else{d7=c2;d8=dw;cA=261}if((cA|0)==261){while(1){cA=0;if(!((d8<<24>>24|0)==13|(d8<<24>>24|0)==32|(d8<<24>>24|0)==9|(d8<<24>>24|0)==10)){break}dw=d7+1|0;d7=dw;d8=a[b+4+dw|0]|0;cA=261}c[cq>>2]=d7;if((a[b+4+d7|0]|0)!=33){break}if((a[d7+1+(b+4)|0]|0)==61){d5=2;d6=d7}else{break}}c[cq>>2]=d6+2;if((wW(b,aL,e)|0)==0){cA=266;break L266}if((d5|0)==1){c[bB>>2]=(c[bB>>2]|0)==(c[aL>>2]|0);continue}else if((d5|0)==2){c[bB>>2]=(c[bB>>2]|0)!=(c[aL>>2]|0);continue}else{continue}}c[b0>>2]=c[bB>>2]&c[b0>>2];d_=d7}if((cA|0)==2310){cA=0;c[cq>>2]=d_;d2=d_}c[ck>>2]=c[b0>>2]^c[ck>>2];dM=d2}while(1){c2=dT;while(1){d9=b+4+c2|0;dw=a[d9]|0;if(!((dw<<24>>24|0)==13|(dw<<24>>24|0)==32|(dw<<24>>24|0)==9|(dw<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;dw=a[d9]|0;if(dw<<24>>24==124){if((a[c2+1+(b+4)|0]|0)==124){cA=2311;break}else{ea=c2;eb=124}}else{ea=c2;eb=dw}while(1){if(!((eb<<24>>24|0)==13|(eb<<24>>24|0)==32|(eb<<24>>24|0)==9|(eb<<24>>24|0)==10)){break}dw=ea+1|0;ea=dw;eb=a[b+4+dw|0]|0}c[cq>>2]=ea;if((a[b+4+ea|0]|0)!=124){break}ec=ea+1|0;c[cq>>2]=ec;if((wW(b,cd,e)|0)==0){cA=367;break L266}while(1){c2=c[cq>>2]|0;while(1){ed=b+4+c2|0;dw=a[ed]|0;if(!((dw<<24>>24|0)==13|(dw<<24>>24|0)==32|(dw<<24>>24|0)==9|(dw<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;dw=a[ed]|0;if(dw<<24>>24==61){if((a[c2+1+(b+4)|0]|0)==61){ee=1;ef=c2}else{eg=c2;eh=61;cA=288}}else{eg=c2;eh=dw;cA=288}if((cA|0)==288){while(1){cA=0;if(!((eh<<24>>24|0)==13|(eh<<24>>24|0)==32|(eh<<24>>24|0)==9|(eh<<24>>24|0)==10)){break}dw=eg+1|0;eg=dw;eh=a[b+4+dw|0]|0;cA=288}c[cq>>2]=eg;if((a[b+4+eg|0]|0)!=33){ei=eg;break}if((a[eg+1+(b+4)|0]|0)==61){ee=2;ef=eg}else{ei=eg;break}}c[cq>>2]=ef+2;if((wW(b,aK,e)|0)==0){cA=293;break L266}if((ee|0)==1){c[cd>>2]=(c[cd>>2]|0)==(c[aK>>2]|0);continue}else if((ee|0)==2){c[cd>>2]=(c[cd>>2]|0)!=(c[aK>>2]|0);continue}else{continue}}while(1){c2=ei;while(1){ej=b+4+c2|0;dw=a[ej]|0;if(!((dw<<24>>24|0)==13|(dw<<24>>24|0)==32|(dw<<24>>24|0)==9|(dw<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;dw=a[ej]|0;if(dw<<24>>24==38){if((a[c2+1+(b+4)|0]|0)==38){cA=2312;break}else{ek=c2;el=38}}else{ek=c2;el=dw}while(1){if(!((el<<24>>24|0)==13|(el<<24>>24|0)==32|(el<<24>>24|0)==9|(el<<24>>24|0)==10)){break}dw=ek+1|0;ek=dw;el=a[b+4+dw|0]|0}c[cq>>2]=ek;if((a[b+4+ek|0]|0)!=38){em=ek;break}en=ek+1|0;c[cq>>2]=en;if((wW(b,bA,e)|0)==0){cA=320;break L266}while(1){c2=c[cq>>2]|0;while(1){eo=b+4+c2|0;dw=a[eo]|0;if(!((dw<<24>>24|0)==13|(dw<<24>>24|0)==32|(dw<<24>>24|0)==9|(dw<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;dw=a[eo]|0;if(dw<<24>>24==61){if((a[c2+1+(b+4)|0]|0)==61){ep=1;eq=c2}else{er=c2;es=61;cA=311}}else{er=c2;es=dw;cA=311}if((cA|0)==311){while(1){cA=0;if(!((es<<24>>24|0)==13|(es<<24>>24|0)==32|(es<<24>>24|0)==9|(es<<24>>24|0)==10)){break}dw=er+1|0;er=dw;es=a[b+4+dw|0]|0;cA=311}c[cq>>2]=er;if((a[b+4+er|0]|0)!=33){break}if((a[er+1+(b+4)|0]|0)==61){ep=2;eq=er}else{break}}c[cq>>2]=eq+2;if((wW(b,aJ,e)|0)==0){cA=316;break L266}if((ep|0)==1){c[bA>>2]=(c[bA>>2]|0)==(c[aJ>>2]|0);continue}else if((ep|0)==2){c[bA>>2]=(c[bA>>2]|0)!=(c[aJ>>2]|0);continue}else{continue}}c[cd>>2]=c[bA>>2]&c[cd>>2];ei=er}if((cA|0)==2312){cA=0;c[cq>>2]=ei;em=ei}while(1){c2=b+4+em|0;dw=a[c2]|0;if((dw<<24>>24|0)==13|(dw<<24>>24|0)==32|(dw<<24>>24|0)==9|(dw<<24>>24|0)==10){em=em+1|0;continue}c[cq>>2]=em;if((a[c2]|0)!=94){break}et=em+1|0;c[cq>>2]=et;if((wW(b,b$,e)|0)==0){cA=365;break L266}while(1){c2=c[cq>>2]|0;while(1){eu=b+4+c2|0;dw=a[eu]|0;if(!((dw<<24>>24|0)==13|(dw<<24>>24|0)==32|(dw<<24>>24|0)==9|(dw<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;dw=a[eu]|0;if(dw<<24>>24==61){if((a[c2+1+(b+4)|0]|0)==61){ev=1;ew=c2}else{ex=c2;ey=61;cA=331}}else{ex=c2;ey=dw;cA=331}if((cA|0)==331){while(1){cA=0;if(!((ey<<24>>24|0)==13|(ey<<24>>24|0)==32|(ey<<24>>24|0)==9|(ey<<24>>24|0)==10)){break}dw=ex+1|0;ex=dw;ey=a[b+4+dw|0]|0;cA=331}c[cq>>2]=ex;if((a[b+4+ex|0]|0)!=33){ez=ex;break}if((a[ex+1+(b+4)|0]|0)==61){ev=2;ew=ex}else{ez=ex;break}}c[cq>>2]=ew+2;if((wW(b,aI,e)|0)==0){cA=336;break L266}if((ev|0)==1){c[b$>>2]=(c[b$>>2]|0)==(c[aI>>2]|0);continue}else if((ev|0)==2){c[b$>>2]=(c[b$>>2]|0)!=(c[aI>>2]|0);continue}else{continue}}while(1){c2=ez;while(1){eA=b+4+c2|0;dw=a[eA]|0;if(!((dw<<24>>24|0)==13|(dw<<24>>24|0)==32|(dw<<24>>24|0)==9|(dw<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;dw=a[eA]|0;if(dw<<24>>24==38){if((a[c2+1+(b+4)|0]|0)==38){cA=2313;break}else{eB=c2;eC=38}}else{eB=c2;eC=dw}while(1){if(!((eC<<24>>24|0)==13|(eC<<24>>24|0)==32|(eC<<24>>24|0)==9|(eC<<24>>24|0)==10)){break}dw=eB+1|0;eB=dw;eC=a[b+4+dw|0]|0}c[cq>>2]=eB;if((a[b+4+eB|0]|0)!=38){eD=eB;break}eE=eB+1|0;c[cq>>2]=eE;if((wW(b,bz,e)|0)==0){cA=363;break L266}while(1){c2=c[cq>>2]|0;while(1){eF=b+4+c2|0;dw=a[eF]|0;if(!((dw<<24>>24|0)==13|(dw<<24>>24|0)==32|(dw<<24>>24|0)==9|(dw<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;dw=a[eF]|0;if(dw<<24>>24==61){if((a[c2+1+(b+4)|0]|0)==61){eG=1;eH=c2}else{eI=c2;eJ=61;cA=354}}else{eI=c2;eJ=dw;cA=354}if((cA|0)==354){while(1){cA=0;if(!((eJ<<24>>24|0)==13|(eJ<<24>>24|0)==32|(eJ<<24>>24|0)==9|(eJ<<24>>24|0)==10)){break}dw=eI+1|0;eI=dw;eJ=a[b+4+dw|0]|0;cA=354}c[cq>>2]=eI;if((a[b+4+eI|0]|0)!=33){break}if((a[eI+1+(b+4)|0]|0)==61){eG=2;eH=eI}else{break}}c[cq>>2]=eH+2;if((wW(b,aH,e)|0)==0){cA=359;break L266}if((eG|0)==1){c[bz>>2]=(c[bz>>2]|0)==(c[aH>>2]|0);continue}else if((eG|0)==2){c[bz>>2]=(c[bz>>2]|0)!=(c[aH>>2]|0);continue}else{continue}}c[b$>>2]=c[bz>>2]&c[b$>>2];ez=eI}if((cA|0)==2313){cA=0;c[cq>>2]=ez;eD=ez}c[cd>>2]=c[b$>>2]^c[cd>>2];em=eD}c[ck>>2]=c[cd>>2]|c[ck>>2];dT=em}if((cA|0)==2311){cA=0;c[cq>>2]=dT}if((c[d>>2]|0)==0){eK=0}else{eK=(c[ck>>2]|0)!=0|0}c[d>>2]=eK;b2=c[cq>>2]|0}if((cA|0)==188){eK=b2;L525:while(1){b2=b+4+eK|0;ck=a[b2]|0;if((ck<<24>>24|0)==13|(ck<<24>>24|0)==32|(ck<<24>>24|0)==9|(ck<<24>>24|0)==10){eK=eK+1|0;continue}c[cq>>2]=eK;ck=a[b2]|0;if(ck<<24>>24!=124){eL=eK;eM=ck;cA=747;break}if((a[eK+1+(b+4)|0]|0)!=124){eL=eK;eM=ck;cA=747;break}eN=eK+2|0;c[cq>>2]=eN;if((wW(b,cn,e)|0)==0){break}while(1){ck=c[cq>>2]|0;while(1){eO=b+4+ck|0;b2=a[eO]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[eO]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){eP=1;eQ=ck}else{eR=ck;eS=61;cA=382}}else{eR=ck;eS=b2;cA=382}if((cA|0)==382){while(1){cA=0;if(!((eS<<24>>24|0)==13|(eS<<24>>24|0)==32|(eS<<24>>24|0)==9|(eS<<24>>24|0)==10)){break}b2=eR+1|0;eR=b2;eS=a[b+4+b2|0]|0;cA=382}c[cq>>2]=eR;if((a[b+4+eR|0]|0)!=33){eT=eR;break}if((a[eR+1+(b+4)|0]|0)==61){eP=2;eQ=eR}else{eT=eR;break}}c[cq>>2]=eQ+2;if((wW(b,aG,e)|0)==0){cA=387;break L525}if((eP|0)==1){c[cn>>2]=(c[cn>>2]|0)==(c[aG>>2]|0);continue}else if((eP|0)==2){c[cn>>2]=(c[cn>>2]|0)!=(c[aG>>2]|0);continue}else{continue}}while(1){ck=eT;while(1){eU=b+4+ck|0;b2=a[eU]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[eU]|0;if(b2<<24>>24==38){if((a[ck+1+(b+4)|0]|0)==38){cA=2297;break}else{eV=ck;eW=38}}else{eV=ck;eW=b2}while(1){if(!((eW<<24>>24|0)==13|(eW<<24>>24|0)==32|(eW<<24>>24|0)==9|(eW<<24>>24|0)==10)){break}b2=eV+1|0;eV=b2;eW=a[b+4+b2|0]|0}c[cq>>2]=eV;if((a[b+4+eV|0]|0)!=38){eX=eV;break}eY=eV+1|0;c[cq>>2]=eY;if((wW(b,by,e)|0)==0){cA=414;break L525}while(1){ck=c[cq>>2]|0;while(1){eZ=b+4+ck|0;b2=a[eZ]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[eZ]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){e_=1;e$=ck}else{e0=ck;e1=61;cA=405}}else{e0=ck;e1=b2;cA=405}if((cA|0)==405){while(1){cA=0;if(!((e1<<24>>24|0)==13|(e1<<24>>24|0)==32|(e1<<24>>24|0)==9|(e1<<24>>24|0)==10)){break}b2=e0+1|0;e0=b2;e1=a[b+4+b2|0]|0;cA=405}c[cq>>2]=e0;if((a[b+4+e0|0]|0)!=33){break}if((a[e0+1+(b+4)|0]|0)==61){e_=2;e$=e0}else{break}}c[cq>>2]=e$+2;if((wW(b,aF,e)|0)==0){cA=410;break L525}if((e_|0)==1){c[by>>2]=(c[by>>2]|0)==(c[aF>>2]|0);continue}else if((e_|0)==2){c[by>>2]=(c[by>>2]|0)!=(c[aF>>2]|0);continue}else{continue}}c[cn>>2]=c[by>>2]&c[cn>>2];eT=e0}if((cA|0)==2297){cA=0;c[cq>>2]=eT;eX=eT}while(1){ck=b+4+eX|0;b2=a[ck]|0;if((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10){eX=eX+1|0;continue}c[cq>>2]=eX;if((a[ck]|0)!=94){e2=eX;break}e3=eX+1|0;c[cq>>2]=e3;if((wW(b,b_,e)|0)==0){cA=459;break L525}while(1){ck=c[cq>>2]|0;while(1){e4=b+4+ck|0;b2=a[e4]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[e4]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){e5=1;e6=ck}else{e7=ck;e8=61;cA=425}}else{e7=ck;e8=b2;cA=425}if((cA|0)==425){while(1){cA=0;if(!((e8<<24>>24|0)==13|(e8<<24>>24|0)==32|(e8<<24>>24|0)==9|(e8<<24>>24|0)==10)){break}b2=e7+1|0;e7=b2;e8=a[b+4+b2|0]|0;cA=425}c[cq>>2]=e7;if((a[b+4+e7|0]|0)!=33){e9=e7;break}if((a[e7+1+(b+4)|0]|0)==61){e5=2;e6=e7}else{e9=e7;break}}c[cq>>2]=e6+2;if((wW(b,aE,e)|0)==0){cA=430;break L525}if((e5|0)==1){c[b_>>2]=(c[b_>>2]|0)==(c[aE>>2]|0);continue}else if((e5|0)==2){c[b_>>2]=(c[b_>>2]|0)!=(c[aE>>2]|0);continue}else{continue}}while(1){ck=e9;while(1){fa=b+4+ck|0;b2=a[fa]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[fa]|0;if(b2<<24>>24==38){if((a[ck+1+(b+4)|0]|0)==38){cA=2298;break}else{fb=ck;fc=38}}else{fb=ck;fc=b2}while(1){if(!((fc<<24>>24|0)==13|(fc<<24>>24|0)==32|(fc<<24>>24|0)==9|(fc<<24>>24|0)==10)){break}b2=fb+1|0;fb=b2;fc=a[b+4+b2|0]|0}c[cq>>2]=fb;if((a[b+4+fb|0]|0)!=38){fd=fb;break}fe=fb+1|0;c[cq>>2]=fe;if((wW(b,bx,e)|0)==0){cA=457;break L525}while(1){ck=c[cq>>2]|0;while(1){ff=b+4+ck|0;b2=a[ff]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[ff]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){fg=1;fh=ck}else{fi=ck;fj=61;cA=448}}else{fi=ck;fj=b2;cA=448}if((cA|0)==448){while(1){cA=0;if(!((fj<<24>>24|0)==13|(fj<<24>>24|0)==32|(fj<<24>>24|0)==9|(fj<<24>>24|0)==10)){break}b2=fi+1|0;fi=b2;fj=a[b+4+b2|0]|0;cA=448}c[cq>>2]=fi;if((a[b+4+fi|0]|0)!=33){break}if((a[fi+1+(b+4)|0]|0)==61){fg=2;fh=fi}else{break}}c[cq>>2]=fh+2;if((wW(b,aD,e)|0)==0){cA=453;break L525}if((fg|0)==1){c[bx>>2]=(c[bx>>2]|0)==(c[aD>>2]|0);continue}else if((fg|0)==2){c[bx>>2]=(c[bx>>2]|0)!=(c[aD>>2]|0);continue}else{continue}}c[b_>>2]=c[bx>>2]&c[b_>>2];e9=fi}if((cA|0)==2298){cA=0;c[cq>>2]=e9;fd=e9}c[cn>>2]=c[b_>>2]^c[cn>>2];eX=fd}while(1){ck=e2;while(1){fk=b+4+ck|0;b2=a[fk]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[fk]|0;if(b2<<24>>24==124){if((a[ck+1+(b+4)|0]|0)==124){cA=2299;break}else{fl=ck;fm=124}}else{fl=ck;fm=b2}while(1){if(!((fm<<24>>24|0)==13|(fm<<24>>24|0)==32|(fm<<24>>24|0)==9|(fm<<24>>24|0)==10)){break}b2=fl+1|0;fl=b2;fm=a[b+4+b2|0]|0}c[cq>>2]=fl;if((a[b+4+fl|0]|0)!=124){fn=fl;break}fo=fl+1|0;c[cq>>2]=fo;if((wW(b,cc,e)|0)==0){cA=554;break L525}while(1){ck=c[cq>>2]|0;while(1){fp=b+4+ck|0;b2=a[fp]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[fp]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){fq=1;fr=ck}else{fs=ck;ft=61;cA=475}}else{fs=ck;ft=b2;cA=475}if((cA|0)==475){while(1){cA=0;if(!((ft<<24>>24|0)==13|(ft<<24>>24|0)==32|(ft<<24>>24|0)==9|(ft<<24>>24|0)==10)){break}b2=fs+1|0;fs=b2;ft=a[b+4+b2|0]|0;cA=475}c[cq>>2]=fs;if((a[b+4+fs|0]|0)!=33){fu=fs;break}if((a[fs+1+(b+4)|0]|0)==61){fq=2;fr=fs}else{fu=fs;break}}c[cq>>2]=fr+2;if((wW(b,aC,e)|0)==0){cA=480;break L525}if((fq|0)==1){c[cc>>2]=(c[cc>>2]|0)==(c[aC>>2]|0);continue}else if((fq|0)==2){c[cc>>2]=(c[cc>>2]|0)!=(c[aC>>2]|0);continue}else{continue}}while(1){ck=fu;while(1){fv=b+4+ck|0;b2=a[fv]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[fv]|0;if(b2<<24>>24==38){if((a[ck+1+(b+4)|0]|0)==38){cA=2300;break}else{fw=ck;fx=38}}else{fw=ck;fx=b2}while(1){if(!((fx<<24>>24|0)==13|(fx<<24>>24|0)==32|(fx<<24>>24|0)==9|(fx<<24>>24|0)==10)){break}b2=fw+1|0;fw=b2;fx=a[b+4+b2|0]|0}c[cq>>2]=fw;if((a[b+4+fw|0]|0)!=38){fy=fw;break}fz=fw+1|0;c[cq>>2]=fz;if((wW(b,bw,e)|0)==0){cA=507;break L525}while(1){ck=c[cq>>2]|0;while(1){fA=b+4+ck|0;b2=a[fA]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[fA]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){fB=1;fC=ck}else{fD=ck;fE=61;cA=498}}else{fD=ck;fE=b2;cA=498}if((cA|0)==498){while(1){cA=0;if(!((fE<<24>>24|0)==13|(fE<<24>>24|0)==32|(fE<<24>>24|0)==9|(fE<<24>>24|0)==10)){break}b2=fD+1|0;fD=b2;fE=a[b+4+b2|0]|0;cA=498}c[cq>>2]=fD;if((a[b+4+fD|0]|0)!=33){break}if((a[fD+1+(b+4)|0]|0)==61){fB=2;fC=fD}else{break}}c[cq>>2]=fC+2;if((wW(b,aB,e)|0)==0){cA=503;break L525}if((fB|0)==1){c[bw>>2]=(c[bw>>2]|0)==(c[aB>>2]|0);continue}else if((fB|0)==2){c[bw>>2]=(c[bw>>2]|0)!=(c[aB>>2]|0);continue}else{continue}}c[cc>>2]=c[bw>>2]&c[cc>>2];fu=fD}if((cA|0)==2300){cA=0;c[cq>>2]=fu;fy=fu}while(1){ck=b+4+fy|0;b2=a[ck]|0;if((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10){fy=fy+1|0;continue}c[cq>>2]=fy;if((a[ck]|0)!=94){break}fF=fy+1|0;c[cq>>2]=fF;if((wW(b,bZ,e)|0)==0){cA=552;break L525}while(1){ck=c[cq>>2]|0;while(1){fG=b+4+ck|0;b2=a[fG]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[fG]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){fH=1;fI=ck}else{fJ=ck;fK=61;cA=518}}else{fJ=ck;fK=b2;cA=518}if((cA|0)==518){while(1){cA=0;if(!((fK<<24>>24|0)==13|(fK<<24>>24|0)==32|(fK<<24>>24|0)==9|(fK<<24>>24|0)==10)){break}b2=fJ+1|0;fJ=b2;fK=a[b+4+b2|0]|0;cA=518}c[cq>>2]=fJ;if((a[b+4+fJ|0]|0)!=33){fL=fJ;break}if((a[fJ+1+(b+4)|0]|0)==61){fH=2;fI=fJ}else{fL=fJ;break}}c[cq>>2]=fI+2;if((wW(b,aA,e)|0)==0){cA=523;break L525}if((fH|0)==1){c[bZ>>2]=(c[bZ>>2]|0)==(c[aA>>2]|0);continue}else if((fH|0)==2){c[bZ>>2]=(c[bZ>>2]|0)!=(c[aA>>2]|0);continue}else{continue}}while(1){ck=fL;while(1){fM=b+4+ck|0;b2=a[fM]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[fM]|0;if(b2<<24>>24==38){if((a[ck+1+(b+4)|0]|0)==38){cA=2301;break}else{fN=ck;fO=38}}else{fN=ck;fO=b2}while(1){if(!((fO<<24>>24|0)==13|(fO<<24>>24|0)==32|(fO<<24>>24|0)==9|(fO<<24>>24|0)==10)){break}b2=fN+1|0;fN=b2;fO=a[b+4+b2|0]|0}c[cq>>2]=fN;if((a[b+4+fN|0]|0)!=38){fP=fN;break}fQ=fN+1|0;c[cq>>2]=fQ;if((wW(b,bv,e)|0)==0){cA=550;break L525}while(1){ck=c[cq>>2]|0;while(1){fR=b+4+ck|0;b2=a[fR]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[fR]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){fS=1;fT=ck}else{fU=ck;fV=61;cA=541}}else{fU=ck;fV=b2;cA=541}if((cA|0)==541){while(1){cA=0;if(!((fV<<24>>24|0)==13|(fV<<24>>24|0)==32|(fV<<24>>24|0)==9|(fV<<24>>24|0)==10)){break}b2=fU+1|0;fU=b2;fV=a[b+4+b2|0]|0;cA=541}c[cq>>2]=fU;if((a[b+4+fU|0]|0)!=33){break}if((a[fU+1+(b+4)|0]|0)==61){fS=2;fT=fU}else{break}}c[cq>>2]=fT+2;if((wW(b,az,e)|0)==0){cA=546;break L525}if((fS|0)==1){c[bv>>2]=(c[bv>>2]|0)==(c[az>>2]|0);continue}else if((fS|0)==2){c[bv>>2]=(c[bv>>2]|0)!=(c[az>>2]|0);continue}else{continue}}c[bZ>>2]=c[bv>>2]&c[bZ>>2];fL=fU}if((cA|0)==2301){cA=0;c[cq>>2]=fL;fP=fL}c[cc>>2]=c[bZ>>2]^c[cc>>2];fy=fP}c[cn>>2]=c[cc>>2]|c[cn>>2];e2=fy}if((cA|0)==2299){cA=0;c[cq>>2]=e2;fn=e2}while(1){ck=b+4+fn|0;b2=a[ck]|0;if((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10){fn=fn+1|0;continue}c[cq>>2]=fn;if((a[ck]|0)!=38){break}if((a[fn+1+(b+4)|0]|0)!=38){break}fW=fn+2|0;c[cq>>2]=fW;if((wW(b,cj,e)|0)==0){cA=739;break L525}while(1){ck=c[cq>>2]|0;while(1){fX=b+4+ck|0;b2=a[fX]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[fX]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){fY=1;fZ=ck}else{f_=ck;f$=61;cA=565}}else{f_=ck;f$=b2;cA=565}if((cA|0)==565){while(1){cA=0;if(!((f$<<24>>24|0)==13|(f$<<24>>24|0)==32|(f$<<24>>24|0)==9|(f$<<24>>24|0)==10)){break}b2=f_+1|0;f_=b2;f$=a[b+4+b2|0]|0;cA=565}c[cq>>2]=f_;if((a[b+4+f_|0]|0)!=33){f0=f_;break}if((a[f_+1+(b+4)|0]|0)==61){fY=2;fZ=f_}else{f0=f_;break}}c[cq>>2]=fZ+2;if((wW(b,ay,e)|0)==0){cA=570;break L525}if((fY|0)==1){c[cj>>2]=(c[cj>>2]|0)==(c[ay>>2]|0);continue}else if((fY|0)==2){c[cj>>2]=(c[cj>>2]|0)!=(c[ay>>2]|0);continue}else{continue}}while(1){ck=f0;while(1){f1=b+4+ck|0;b2=a[f1]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[f1]|0;if(b2<<24>>24==38){if((a[ck+1+(b+4)|0]|0)==38){cA=2303;break}else{f2=ck;f3=38}}else{f2=ck;f3=b2}while(1){if(!((f3<<24>>24|0)==13|(f3<<24>>24|0)==32|(f3<<24>>24|0)==9|(f3<<24>>24|0)==10)){break}b2=f2+1|0;f2=b2;f3=a[b+4+b2|0]|0}c[cq>>2]=f2;if((a[b+4+f2|0]|0)!=38){f4=f2;break}f5=f2+1|0;c[cq>>2]=f5;if((wW(b,bu,e)|0)==0){cA=597;break L525}while(1){ck=c[cq>>2]|0;while(1){f6=b+4+ck|0;b2=a[f6]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[f6]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){f7=1;f8=ck}else{f9=ck;ga=61;cA=588}}else{f9=ck;ga=b2;cA=588}if((cA|0)==588){while(1){cA=0;if(!((ga<<24>>24|0)==13|(ga<<24>>24|0)==32|(ga<<24>>24|0)==9|(ga<<24>>24|0)==10)){break}b2=f9+1|0;f9=b2;ga=a[b+4+b2|0]|0;cA=588}c[cq>>2]=f9;if((a[b+4+f9|0]|0)!=33){break}if((a[f9+1+(b+4)|0]|0)==61){f7=2;f8=f9}else{break}}c[cq>>2]=f8+2;if((wW(b,ax,e)|0)==0){cA=593;break L525}if((f7|0)==1){c[bu>>2]=(c[bu>>2]|0)==(c[ax>>2]|0);continue}else if((f7|0)==2){c[bu>>2]=(c[bu>>2]|0)!=(c[ax>>2]|0);continue}else{continue}}c[cj>>2]=c[bu>>2]&c[cj>>2];f0=f9}if((cA|0)==2303){cA=0;c[cq>>2]=f0;f4=f0}while(1){ck=b+4+f4|0;b2=a[ck]|0;if((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10){f4=f4+1|0;continue}c[cq>>2]=f4;if((a[ck]|0)!=94){gb=f4;break}gc=f4+1|0;c[cq>>2]=gc;if((wW(b,bY,e)|0)==0){cA=642;break L525}while(1){ck=c[cq>>2]|0;while(1){gd=b+4+ck|0;b2=a[gd]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[gd]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){ge=1;gf=ck}else{gg=ck;gh=61;cA=608}}else{gg=ck;gh=b2;cA=608}if((cA|0)==608){while(1){cA=0;if(!((gh<<24>>24|0)==13|(gh<<24>>24|0)==32|(gh<<24>>24|0)==9|(gh<<24>>24|0)==10)){break}b2=gg+1|0;gg=b2;gh=a[b+4+b2|0]|0;cA=608}c[cq>>2]=gg;if((a[b+4+gg|0]|0)!=33){gi=gg;break}if((a[gg+1+(b+4)|0]|0)==61){ge=2;gf=gg}else{gi=gg;break}}c[cq>>2]=gf+2;if((wW(b,aw,e)|0)==0){cA=613;break L525}if((ge|0)==1){c[bY>>2]=(c[bY>>2]|0)==(c[aw>>2]|0);continue}else if((ge|0)==2){c[bY>>2]=(c[bY>>2]|0)!=(c[aw>>2]|0);continue}else{continue}}while(1){ck=gi;while(1){gj=b+4+ck|0;b2=a[gj]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[gj]|0;if(b2<<24>>24==38){if((a[ck+1+(b+4)|0]|0)==38){cA=2304;break}else{gk=ck;gl=38}}else{gk=ck;gl=b2}while(1){if(!((gl<<24>>24|0)==13|(gl<<24>>24|0)==32|(gl<<24>>24|0)==9|(gl<<24>>24|0)==10)){break}b2=gk+1|0;gk=b2;gl=a[b+4+b2|0]|0}c[cq>>2]=gk;if((a[b+4+gk|0]|0)!=38){gm=gk;break}gn=gk+1|0;c[cq>>2]=gn;if((wW(b,bt,e)|0)==0){cA=640;break L525}while(1){ck=c[cq>>2]|0;while(1){go=b+4+ck|0;b2=a[go]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[go]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){gp=1;gq=ck}else{gr=ck;gs=61;cA=631}}else{gr=ck;gs=b2;cA=631}if((cA|0)==631){while(1){cA=0;if(!((gs<<24>>24|0)==13|(gs<<24>>24|0)==32|(gs<<24>>24|0)==9|(gs<<24>>24|0)==10)){break}b2=gr+1|0;gr=b2;gs=a[b+4+b2|0]|0;cA=631}c[cq>>2]=gr;if((a[b+4+gr|0]|0)!=33){break}if((a[gr+1+(b+4)|0]|0)==61){gp=2;gq=gr}else{break}}c[cq>>2]=gq+2;if((wW(b,av,e)|0)==0){cA=636;break L525}if((gp|0)==1){c[bt>>2]=(c[bt>>2]|0)==(c[av>>2]|0);continue}else if((gp|0)==2){c[bt>>2]=(c[bt>>2]|0)!=(c[av>>2]|0);continue}else{continue}}c[bY>>2]=c[bt>>2]&c[bY>>2];gi=gr}if((cA|0)==2304){cA=0;c[cq>>2]=gi;gm=gi}c[cj>>2]=c[bY>>2]^c[cj>>2];f4=gm}while(1){ck=gb;while(1){gt=b+4+ck|0;b2=a[gt]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[gt]|0;if(b2<<24>>24==124){if((a[ck+1+(b+4)|0]|0)==124){cA=2305;break}else{gu=ck;gv=124}}else{gu=ck;gv=b2}while(1){if(!((gv<<24>>24|0)==13|(gv<<24>>24|0)==32|(gv<<24>>24|0)==9|(gv<<24>>24|0)==10)){break}b2=gu+1|0;gu=b2;gv=a[b+4+b2|0]|0}c[cq>>2]=gu;if((a[b+4+gu|0]|0)!=124){gw=gu;break}gx=gu+1|0;c[cq>>2]=gx;if((wW(b,cb,e)|0)==0){cA=737;break L525}while(1){ck=c[cq>>2]|0;while(1){gy=b+4+ck|0;b2=a[gy]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[gy]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){gz=1;gA=ck}else{gB=ck;gC=61;cA=658}}else{gB=ck;gC=b2;cA=658}if((cA|0)==658){while(1){cA=0;if(!((gC<<24>>24|0)==13|(gC<<24>>24|0)==32|(gC<<24>>24|0)==9|(gC<<24>>24|0)==10)){break}b2=gB+1|0;gB=b2;gC=a[b+4+b2|0]|0;cA=658}c[cq>>2]=gB;if((a[b+4+gB|0]|0)!=33){gD=gB;break}if((a[gB+1+(b+4)|0]|0)==61){gz=2;gA=gB}else{gD=gB;break}}c[cq>>2]=gA+2;if((wW(b,au,e)|0)==0){cA=663;break L525}if((gz|0)==1){c[cb>>2]=(c[cb>>2]|0)==(c[au>>2]|0);continue}else if((gz|0)==2){c[cb>>2]=(c[cb>>2]|0)!=(c[au>>2]|0);continue}else{continue}}while(1){ck=gD;while(1){gE=b+4+ck|0;b2=a[gE]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[gE]|0;if(b2<<24>>24==38){if((a[ck+1+(b+4)|0]|0)==38){cA=2306;break}else{gF=ck;gG=38}}else{gF=ck;gG=b2}while(1){if(!((gG<<24>>24|0)==13|(gG<<24>>24|0)==32|(gG<<24>>24|0)==9|(gG<<24>>24|0)==10)){break}b2=gF+1|0;gF=b2;gG=a[b+4+b2|0]|0}c[cq>>2]=gF;if((a[b+4+gF|0]|0)!=38){gH=gF;break}gI=gF+1|0;c[cq>>2]=gI;if((wW(b,bs,e)|0)==0){cA=690;break L525}while(1){ck=c[cq>>2]|0;while(1){gJ=b+4+ck|0;b2=a[gJ]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[gJ]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){gK=1;gL=ck}else{gM=ck;gN=61;cA=681}}else{gM=ck;gN=b2;cA=681}if((cA|0)==681){while(1){cA=0;if(!((gN<<24>>24|0)==13|(gN<<24>>24|0)==32|(gN<<24>>24|0)==9|(gN<<24>>24|0)==10)){break}b2=gM+1|0;gM=b2;gN=a[b+4+b2|0]|0;cA=681}c[cq>>2]=gM;if((a[b+4+gM|0]|0)!=33){break}if((a[gM+1+(b+4)|0]|0)==61){gK=2;gL=gM}else{break}}c[cq>>2]=gL+2;if((wW(b,at,e)|0)==0){cA=686;break L525}if((gK|0)==1){c[bs>>2]=(c[bs>>2]|0)==(c[at>>2]|0);continue}else if((gK|0)==2){c[bs>>2]=(c[bs>>2]|0)!=(c[at>>2]|0);continue}else{continue}}c[cb>>2]=c[bs>>2]&c[cb>>2];gD=gM}if((cA|0)==2306){cA=0;c[cq>>2]=gD;gH=gD}while(1){ck=b+4+gH|0;b2=a[ck]|0;if((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10){gH=gH+1|0;continue}c[cq>>2]=gH;if((a[ck]|0)!=94){break}gO=gH+1|0;c[cq>>2]=gO;if((wW(b,bX,e)|0)==0){cA=735;break L525}while(1){ck=c[cq>>2]|0;while(1){gP=b+4+ck|0;b2=a[gP]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[gP]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){gQ=1;gR=ck}else{gS=ck;gT=61;cA=701}}else{gS=ck;gT=b2;cA=701}if((cA|0)==701){while(1){cA=0;if(!((gT<<24>>24|0)==13|(gT<<24>>24|0)==32|(gT<<24>>24|0)==9|(gT<<24>>24|0)==10)){break}b2=gS+1|0;gS=b2;gT=a[b+4+b2|0]|0;cA=701}c[cq>>2]=gS;if((a[b+4+gS|0]|0)!=33){gU=gS;break}if((a[gS+1+(b+4)|0]|0)==61){gQ=2;gR=gS}else{gU=gS;break}}c[cq>>2]=gR+2;if((wW(b,as,e)|0)==0){cA=706;break L525}if((gQ|0)==1){c[bX>>2]=(c[bX>>2]|0)==(c[as>>2]|0);continue}else if((gQ|0)==2){c[bX>>2]=(c[bX>>2]|0)!=(c[as>>2]|0);continue}else{continue}}while(1){ck=gU;while(1){gV=b+4+ck|0;b2=a[gV]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[gV]|0;if(b2<<24>>24==38){if((a[ck+1+(b+4)|0]|0)==38){cA=2307;break}else{gW=ck;gX=38}}else{gW=ck;gX=b2}while(1){if(!((gX<<24>>24|0)==13|(gX<<24>>24|0)==32|(gX<<24>>24|0)==9|(gX<<24>>24|0)==10)){break}b2=gW+1|0;gW=b2;gX=a[b+4+b2|0]|0}c[cq>>2]=gW;if((a[b+4+gW|0]|0)!=38){gY=gW;break}gZ=gW+1|0;c[cq>>2]=gZ;if((wW(b,br,e)|0)==0){cA=733;break L525}while(1){ck=c[cq>>2]|0;while(1){g_=b+4+ck|0;b2=a[g_]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[g_]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){g$=1;g0=ck}else{g1=ck;g2=61;cA=724}}else{g1=ck;g2=b2;cA=724}if((cA|0)==724){while(1){cA=0;if(!((g2<<24>>24|0)==13|(g2<<24>>24|0)==32|(g2<<24>>24|0)==9|(g2<<24>>24|0)==10)){break}b2=g1+1|0;g1=b2;g2=a[b+4+b2|0]|0;cA=724}c[cq>>2]=g1;if((a[b+4+g1|0]|0)!=33){break}if((a[g1+1+(b+4)|0]|0)==61){g$=2;g0=g1}else{break}}c[cq>>2]=g0+2;if((wW(b,ar,e)|0)==0){cA=729;break L525}if((g$|0)==1){c[br>>2]=(c[br>>2]|0)==(c[ar>>2]|0);continue}else if((g$|0)==2){c[br>>2]=(c[br>>2]|0)!=(c[ar>>2]|0);continue}else{continue}}c[bX>>2]=c[br>>2]&c[bX>>2];gU=g1}if((cA|0)==2307){cA=0;c[cq>>2]=gU;gY=gU}c[cb>>2]=c[bX>>2]^c[cb>>2];gH=gY}c[cj>>2]=c[cb>>2]|c[cj>>2];gb=gH}if((cA|0)==2305){cA=0;c[cq>>2]=gb;gw=gb}if((c[cn>>2]|0)==0){g3=0}else{g3=(c[cj>>2]|0)!=0|0}c[cn>>2]=g3;fn=gw}if((c[d>>2]|0)==0){g4=(c[cn>>2]|0)!=0|0}else{g4=1}c[d>>2]=g4;eK=c[cq>>2]|0}if((cA|0)==387){c[cq>>2]=eN}else if((cA|0)==410){c[cq>>2]=eY;cA=414}else if((cA|0)==430){c[cq>>2]=e3;cA=459}else if((cA|0)==453){c[cq>>2]=fe;cA=457}else if((cA|0)==480){c[cq>>2]=fo;cA=554}else if((cA|0)==503){c[cq>>2]=fz;cA=507}else if((cA|0)==523){c[cq>>2]=fF;cA=552}else if((cA|0)==546){c[cq>>2]=fQ;cA=550}else if((cA|0)==570){c[cq>>2]=fW;cA=739}else if((cA|0)==593){c[cq>>2]=f5;cA=597}else if((cA|0)==613){c[cq>>2]=gc;cA=642}else if((cA|0)==636){c[cq>>2]=gn;cA=640}else if((cA|0)==663){c[cq>>2]=gx;cA=737}else if((cA|0)==686){c[cq>>2]=gI;cA=690}else if((cA|0)==706){c[cq>>2]=gO;cA=735}else if((cA|0)==729){c[cq>>2]=gZ;cA=733}else if((cA|0)==747){while(1){cA=0;if(!((eM<<24>>24|0)==13|(eM<<24>>24|0)==32|(eM<<24>>24|0)==9|(eM<<24>>24|0)==10)){break}gZ=eL+1|0;eL=gZ;eM=a[b+4+gZ|0]|0;cA=747}c[cq>>2]=eL;if((a[b+4+eL|0]|0)!=63){cs=1;i=f;return cs|0}eM=eL+1|0;c[cq>>2]=eM;do{if((wW(b,co,e)|0)!=0){while(1){eL=c[cq>>2]|0;while(1){g5=b+4+eL|0;gZ=a[g5]|0;if(!((gZ<<24>>24|0)==13|(gZ<<24>>24|0)==32|(gZ<<24>>24|0)==9|(gZ<<24>>24|0)==10)){break}eL=eL+1|0}c[cq>>2]=eL;gZ=a[g5]|0;if(gZ<<24>>24==61){if((a[eL+1+(b+4)|0]|0)==61){g6=1;g7=eL}else{g8=eL;g9=61;cA=756}}else{g8=eL;g9=gZ;cA=756}if((cA|0)==756){while(1){cA=0;if(!((g9<<24>>24|0)==13|(g9<<24>>24|0)==32|(g9<<24>>24|0)==9|(g9<<24>>24|0)==10)){break}gZ=g8+1|0;g8=gZ;g9=a[b+4+gZ|0]|0;cA=756}c[cq>>2]=g8;if((a[b+4+g8|0]|0)!=33){break}if((a[g8+1+(b+4)|0]|0)==61){g6=2;g7=g8}else{break}}c[cq>>2]=g7+2;if((wW(b,aq,e)|0)==0){cA=762;break}if((g6|0)==1){c[co>>2]=(c[co>>2]|0)==(c[aq>>2]|0);continue}else if((g6|0)==2){c[co>>2]=(c[co>>2]|0)!=(c[aq>>2]|0);continue}else{continue}}if((cA|0)==762){c[cq>>2]=eM;break}eL=g8;L1086:while(1){gZ=eL;while(1){ha=b+4+gZ|0;gI=a[ha]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gZ=gZ+1|0}c[cq>>2]=gZ;gI=a[ha]|0;if(gI<<24>>24==38){if((a[gZ+1+(b+4)|0]|0)==38){cA=2295;break}else{hb=gZ;hc=38}}else{hb=gZ;hc=gI}while(1){if(!((hc<<24>>24|0)==13|(hc<<24>>24|0)==32|(hc<<24>>24|0)==9|(hc<<24>>24|0)==10)){break}gI=hb+1|0;hb=gI;hc=a[b+4+gI|0]|0}c[cq>>2]=hb;if((a[b+4+hb|0]|0)!=38){hd=hb;break}he=hb+1|0;c[cq>>2]=he;if((wW(b,bq,e)|0)==0){cA=790;break}while(1){gZ=c[cq>>2]|0;while(1){hf=b+4+gZ|0;gI=a[hf]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gZ=gZ+1|0}c[cq>>2]=gZ;gI=a[hf]|0;if(gI<<24>>24==61){if((a[gZ+1+(b+4)|0]|0)==61){hg=1;hh=gZ}else{hi=gZ;hj=61;cA=781}}else{hi=gZ;hj=gI;cA=781}if((cA|0)==781){while(1){cA=0;if(!((hj<<24>>24|0)==13|(hj<<24>>24|0)==32|(hj<<24>>24|0)==9|(hj<<24>>24|0)==10)){break}gI=hi+1|0;hi=gI;hj=a[b+4+gI|0]|0;cA=781}c[cq>>2]=hi;if((a[b+4+hi|0]|0)!=33){break}if((a[hi+1+(b+4)|0]|0)==61){hg=2;hh=hi}else{break}}c[cq>>2]=hh+2;if((wW(b,ap,e)|0)==0){cA=786;break L1086}if((hg|0)==1){c[bq>>2]=(c[bq>>2]|0)==(c[ap>>2]|0);continue}else if((hg|0)==2){c[bq>>2]=(c[bq>>2]|0)!=(c[ap>>2]|0);continue}else{continue}}c[co>>2]=c[bq>>2]&c[co>>2];eL=hi}if((cA|0)==786){c[cq>>2]=he;cA=790}else if((cA|0)==2295){c[cq>>2]=eL;hd=eL}if((cA|0)==790){c[cq>>2]=eM;break}gZ=hd;L1125:while(1){gI=b+4+gZ|0;gn=a[gI]|0;if((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10){gZ=gZ+1|0;continue}c[cq>>2]=gZ;if((a[gI]|0)!=94){cA=795;break}hk=gZ+1|0;c[cq>>2]=hk;if((wW(b,bW,e)|0)==0){break}while(1){gI=c[cq>>2]|0;while(1){hl=b+4+gI|0;gn=a[hl]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[hl]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){hm=1;hn=gI}else{ho=gI;hp=61;cA=802}}else{ho=gI;hp=gn;cA=802}if((cA|0)==802){while(1){cA=0;if(!((hp<<24>>24|0)==13|(hp<<24>>24|0)==32|(hp<<24>>24|0)==9|(hp<<24>>24|0)==10)){break}gn=ho+1|0;ho=gn;hp=a[b+4+gn|0]|0;cA=802}c[cq>>2]=ho;if((a[b+4+ho|0]|0)!=33){hq=ho;break}if((a[ho+1+(b+4)|0]|0)==61){hm=2;hn=ho}else{hq=ho;break}}c[cq>>2]=hn+2;if((wW(b,ao,e)|0)==0){cA=807;break L1125}if((hm|0)==1){c[bW>>2]=(c[bW>>2]|0)==(c[ao>>2]|0);continue}else if((hm|0)==2){c[bW>>2]=(c[bW>>2]|0)!=(c[ao>>2]|0);continue}else{continue}}while(1){gI=hq;while(1){hr=b+4+gI|0;gn=a[hr]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[hr]|0;if(gn<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=2294;break}else{hs=gI;ht=38}}else{hs=gI;ht=gn}while(1){if(!((ht<<24>>24|0)==13|(ht<<24>>24|0)==32|(ht<<24>>24|0)==9|(ht<<24>>24|0)==10)){break}gn=hs+1|0;hs=gn;ht=a[b+4+gn|0]|0}c[cq>>2]=hs;if((a[b+4+hs|0]|0)!=38){hu=hs;break}hv=hs+1|0;c[cq>>2]=hv;if((wW(b,bp,e)|0)==0){cA=834;break L1125}while(1){gI=c[cq>>2]|0;while(1){hw=b+4+gI|0;gn=a[hw]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[hw]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){hx=1;hy=gI}else{hz=gI;hA=61;cA=825}}else{hz=gI;hA=gn;cA=825}if((cA|0)==825){while(1){cA=0;if(!((hA<<24>>24|0)==13|(hA<<24>>24|0)==32|(hA<<24>>24|0)==9|(hA<<24>>24|0)==10)){break}gn=hz+1|0;hz=gn;hA=a[b+4+gn|0]|0;cA=825}c[cq>>2]=hz;if((a[b+4+hz|0]|0)!=33){break}if((a[hz+1+(b+4)|0]|0)==61){hx=2;hy=hz}else{break}}c[cq>>2]=hy+2;if((wW(b,an,e)|0)==0){cA=830;break L1125}if((hx|0)==1){c[bp>>2]=(c[bp>>2]|0)==(c[an>>2]|0);continue}else if((hx|0)==2){c[bp>>2]=(c[bp>>2]|0)!=(c[an>>2]|0);continue}else{continue}}c[bW>>2]=c[bp>>2]&c[bW>>2];hq=hz}if((cA|0)==2294){cA=0;c[cq>>2]=hq;hu=hq}c[co>>2]=c[bW>>2]^c[co>>2];gZ=hu}if((cA|0)==795){eL=gZ;L1188:while(1){gI=eL;while(1){hB=b+4+gI|0;gn=a[hB]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[hB]|0;if(gn<<24>>24==124){if((a[gI+1+(b+4)|0]|0)==124){cA=2291;break}else{hC=gI;hD=124}}else{hC=gI;hD=gn}while(1){if(!((hD<<24>>24|0)==13|(hD<<24>>24|0)==32|(hD<<24>>24|0)==9|(hD<<24>>24|0)==10)){break}gn=hC+1|0;hC=gn;hD=a[b+4+gn|0]|0}c[cq>>2]=hC;if((a[b+4+hC|0]|0)!=124){hE=hC;cA=846;break}hF=hC+1|0;c[cq>>2]=hF;if((wW(b,ca,e)|0)==0){break}while(1){gI=c[cq>>2]|0;while(1){hG=b+4+gI|0;gn=a[hG]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[hG]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){hH=1;hI=gI}else{hJ=gI;hK=61;cA=853}}else{hJ=gI;hK=gn;cA=853}if((cA|0)==853){while(1){cA=0;if(!((hK<<24>>24|0)==13|(hK<<24>>24|0)==32|(hK<<24>>24|0)==9|(hK<<24>>24|0)==10)){break}gn=hJ+1|0;hJ=gn;hK=a[b+4+gn|0]|0;cA=853}c[cq>>2]=hJ;if((a[b+4+hJ|0]|0)!=33){hL=hJ;break}if((a[hJ+1+(b+4)|0]|0)==61){hH=2;hI=hJ}else{hL=hJ;break}}c[cq>>2]=hI+2;if((wW(b,am,e)|0)==0){cA=858;break L1188}if((hH|0)==1){c[ca>>2]=(c[ca>>2]|0)==(c[am>>2]|0);continue}else if((hH|0)==2){c[ca>>2]=(c[ca>>2]|0)!=(c[am>>2]|0);continue}else{continue}}while(1){gI=hL;while(1){hM=b+4+gI|0;gn=a[hM]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[hM]|0;if(gn<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=2292;break}else{hN=gI;hO=38}}else{hN=gI;hO=gn}while(1){if(!((hO<<24>>24|0)==13|(hO<<24>>24|0)==32|(hO<<24>>24|0)==9|(hO<<24>>24|0)==10)){break}gn=hN+1|0;hN=gn;hO=a[b+4+gn|0]|0}c[cq>>2]=hN;if((a[b+4+hN|0]|0)!=38){hP=hN;break}hQ=hN+1|0;c[cq>>2]=hQ;if((wW(b,bo,e)|0)==0){cA=885;break L1188}while(1){gI=c[cq>>2]|0;while(1){hR=b+4+gI|0;gn=a[hR]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[hR]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){hS=1;hT=gI}else{hU=gI;hV=61;cA=876}}else{hU=gI;hV=gn;cA=876}if((cA|0)==876){while(1){cA=0;if(!((hV<<24>>24|0)==13|(hV<<24>>24|0)==32|(hV<<24>>24|0)==9|(hV<<24>>24|0)==10)){break}gn=hU+1|0;hU=gn;hV=a[b+4+gn|0]|0;cA=876}c[cq>>2]=hU;if((a[b+4+hU|0]|0)!=33){break}if((a[hU+1+(b+4)|0]|0)==61){hS=2;hT=hU}else{break}}c[cq>>2]=hT+2;if((wW(b,al,e)|0)==0){cA=881;break L1188}if((hS|0)==1){c[bo>>2]=(c[bo>>2]|0)==(c[al>>2]|0);continue}else if((hS|0)==2){c[bo>>2]=(c[bo>>2]|0)!=(c[al>>2]|0);continue}else{continue}}c[ca>>2]=c[bo>>2]&c[ca>>2];hL=hU}if((cA|0)==2292){cA=0;c[cq>>2]=hL;hP=hL}while(1){gI=b+4+hP|0;gn=a[gI]|0;if((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10){hP=hP+1|0;continue}c[cq>>2]=hP;if((a[gI]|0)!=94){break}hW=hP+1|0;c[cq>>2]=hW;if((wW(b,bV,e)|0)==0){cA=930;break L1188}while(1){gI=c[cq>>2]|0;while(1){hX=b+4+gI|0;gn=a[hX]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[hX]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){hY=1;hZ=gI}else{h_=gI;h$=61;cA=896}}else{h_=gI;h$=gn;cA=896}if((cA|0)==896){while(1){cA=0;if(!((h$<<24>>24|0)==13|(h$<<24>>24|0)==32|(h$<<24>>24|0)==9|(h$<<24>>24|0)==10)){break}gn=h_+1|0;h_=gn;h$=a[b+4+gn|0]|0;cA=896}c[cq>>2]=h_;if((a[b+4+h_|0]|0)!=33){h0=h_;break}if((a[h_+1+(b+4)|0]|0)==61){hY=2;hZ=h_}else{h0=h_;break}}c[cq>>2]=hZ+2;if((wW(b,ak,e)|0)==0){cA=901;break L1188}if((hY|0)==1){c[bV>>2]=(c[bV>>2]|0)==(c[ak>>2]|0);continue}else if((hY|0)==2){c[bV>>2]=(c[bV>>2]|0)!=(c[ak>>2]|0);continue}else{continue}}while(1){gI=h0;while(1){h1=b+4+gI|0;gn=a[h1]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[h1]|0;if(gn<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=2293;break}else{h2=gI;h3=38}}else{h2=gI;h3=gn}while(1){if(!((h3<<24>>24|0)==13|(h3<<24>>24|0)==32|(h3<<24>>24|0)==9|(h3<<24>>24|0)==10)){break}gn=h2+1|0;h2=gn;h3=a[b+4+gn|0]|0}c[cq>>2]=h2;if((a[b+4+h2|0]|0)!=38){h4=h2;break}h5=h2+1|0;c[cq>>2]=h5;if((wW(b,bn,e)|0)==0){cA=928;break L1188}while(1){gI=c[cq>>2]|0;while(1){h6=b+4+gI|0;gn=a[h6]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[h6]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){h7=1;h8=gI}else{h9=gI;ia=61;cA=919}}else{h9=gI;ia=gn;cA=919}if((cA|0)==919){while(1){cA=0;if(!((ia<<24>>24|0)==13|(ia<<24>>24|0)==32|(ia<<24>>24|0)==9|(ia<<24>>24|0)==10)){break}gn=h9+1|0;h9=gn;ia=a[b+4+gn|0]|0;cA=919}c[cq>>2]=h9;if((a[b+4+h9|0]|0)!=33){break}if((a[h9+1+(b+4)|0]|0)==61){h7=2;h8=h9}else{break}}c[cq>>2]=h8+2;if((wW(b,aj,e)|0)==0){cA=924;break L1188}if((h7|0)==1){c[bn>>2]=(c[bn>>2]|0)==(c[aj>>2]|0);continue}else if((h7|0)==2){c[bn>>2]=(c[bn>>2]|0)!=(c[aj>>2]|0);continue}else{continue}}c[bV>>2]=c[bn>>2]&c[bV>>2];h0=h9}if((cA|0)==2293){cA=0;c[cq>>2]=h0;h4=h0}c[ca>>2]=c[bV>>2]^c[ca>>2];hP=h4}c[co>>2]=c[ca>>2]|c[co>>2];eL=hP}if((cA|0)==858){c[cq>>2]=hF}else if((cA|0)==881){c[cq>>2]=hQ;cA=885}else if((cA|0)==901){c[cq>>2]=hW;cA=930}else if((cA|0)==924){c[cq>>2]=h5;cA=928}else if((cA|0)==2291){c[cq>>2]=eL;hE=eL;cA=846}if((cA|0)==846){gZ=hE;L1325:while(1){gI=b+4+gZ|0;gn=a[gI]|0;if((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10){gZ=gZ+1|0;continue}c[cq>>2]=gZ;if((a[gI]|0)!=38){cA=937;break}if((a[gZ+1+(b+4)|0]|0)!=38){cA=937;break}ib=gZ+2|0;c[cq>>2]=ib;if((wW(b,ci,e)|0)==0){break}while(1){gI=c[cq>>2]|0;while(1){ic=b+4+gI|0;gn=a[ic]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[ic]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){id=1;ie=gI}else{ig=gI;ih=61;cA=944}}else{ig=gI;ih=gn;cA=944}if((cA|0)==944){while(1){cA=0;if(!((ih<<24>>24|0)==13|(ih<<24>>24|0)==32|(ih<<24>>24|0)==9|(ih<<24>>24|0)==10)){break}gn=ig+1|0;ig=gn;ih=a[b+4+gn|0]|0;cA=944}c[cq>>2]=ig;if((a[b+4+ig|0]|0)!=33){ii=ig;break}if((a[ig+1+(b+4)|0]|0)==61){id=2;ie=ig}else{ii=ig;break}}c[cq>>2]=ie+2;if((wW(b,ai,e)|0)==0){cA=949;break L1325}if((id|0)==1){c[ci>>2]=(c[ci>>2]|0)==(c[ai>>2]|0);continue}else if((id|0)==2){c[ci>>2]=(c[ci>>2]|0)!=(c[ai>>2]|0);continue}else{continue}}while(1){gI=ii;while(1){ij=b+4+gI|0;gn=a[ij]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[ij]|0;if(gn<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=2286;break}else{ik=gI;il=38}}else{ik=gI;il=gn}while(1){if(!((il<<24>>24|0)==13|(il<<24>>24|0)==32|(il<<24>>24|0)==9|(il<<24>>24|0)==10)){break}gn=ik+1|0;ik=gn;il=a[b+4+gn|0]|0}c[cq>>2]=ik;if((a[b+4+ik|0]|0)!=38){im=ik;break}io=ik+1|0;c[cq>>2]=io;if((wW(b,bm,e)|0)==0){cA=976;break L1325}while(1){gI=c[cq>>2]|0;while(1){ip=b+4+gI|0;gn=a[ip]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[ip]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){iq=1;ir=gI}else{is=gI;it=61;cA=967}}else{is=gI;it=gn;cA=967}if((cA|0)==967){while(1){cA=0;if(!((it<<24>>24|0)==13|(it<<24>>24|0)==32|(it<<24>>24|0)==9|(it<<24>>24|0)==10)){break}gn=is+1|0;is=gn;it=a[b+4+gn|0]|0;cA=967}c[cq>>2]=is;if((a[b+4+is|0]|0)!=33){break}if((a[is+1+(b+4)|0]|0)==61){iq=2;ir=is}else{break}}c[cq>>2]=ir+2;if((wW(b,ah,e)|0)==0){cA=972;break L1325}if((iq|0)==1){c[bm>>2]=(c[bm>>2]|0)==(c[ah>>2]|0);continue}else if((iq|0)==2){c[bm>>2]=(c[bm>>2]|0)!=(c[ah>>2]|0);continue}else{continue}}c[ci>>2]=c[bm>>2]&c[ci>>2];ii=is}if((cA|0)==2286){cA=0;c[cq>>2]=ii;im=ii}while(1){gI=b+4+im|0;gn=a[gI]|0;if((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10){im=im+1|0;continue}c[cq>>2]=im;if((a[gI]|0)!=94){iu=im;break}iv=im+1|0;c[cq>>2]=iv;if((wW(b,bU,e)|0)==0){cA=1021;break L1325}while(1){gI=c[cq>>2]|0;while(1){iw=b+4+gI|0;gn=a[iw]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[iw]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){ix=1;iy=gI}else{iz=gI;iA=61;cA=987}}else{iz=gI;iA=gn;cA=987}if((cA|0)==987){while(1){cA=0;if(!((iA<<24>>24|0)==13|(iA<<24>>24|0)==32|(iA<<24>>24|0)==9|(iA<<24>>24|0)==10)){break}gn=iz+1|0;iz=gn;iA=a[b+4+gn|0]|0;cA=987}c[cq>>2]=iz;if((a[b+4+iz|0]|0)!=33){iB=iz;break}if((a[iz+1+(b+4)|0]|0)==61){ix=2;iy=iz}else{iB=iz;break}}c[cq>>2]=iy+2;if((wW(b,ag,e)|0)==0){cA=992;break L1325}if((ix|0)==1){c[bU>>2]=(c[bU>>2]|0)==(c[ag>>2]|0);continue}else if((ix|0)==2){c[bU>>2]=(c[bU>>2]|0)!=(c[ag>>2]|0);continue}else{continue}}while(1){gI=iB;while(1){iC=b+4+gI|0;gn=a[iC]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[iC]|0;if(gn<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=2287;break}else{iD=gI;iE=38}}else{iD=gI;iE=gn}while(1){if(!((iE<<24>>24|0)==13|(iE<<24>>24|0)==32|(iE<<24>>24|0)==9|(iE<<24>>24|0)==10)){break}gn=iD+1|0;iD=gn;iE=a[b+4+gn|0]|0}c[cq>>2]=iD;if((a[b+4+iD|0]|0)!=38){iF=iD;break}iG=iD+1|0;c[cq>>2]=iG;if((wW(b,bl,e)|0)==0){cA=1019;break L1325}while(1){gI=c[cq>>2]|0;while(1){iH=b+4+gI|0;gn=a[iH]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[iH]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){iI=1;iJ=gI}else{iK=gI;iL=61;cA=1010}}else{iK=gI;iL=gn;cA=1010}if((cA|0)==1010){while(1){cA=0;if(!((iL<<24>>24|0)==13|(iL<<24>>24|0)==32|(iL<<24>>24|0)==9|(iL<<24>>24|0)==10)){break}gn=iK+1|0;iK=gn;iL=a[b+4+gn|0]|0;cA=1010}c[cq>>2]=iK;if((a[b+4+iK|0]|0)!=33){break}if((a[iK+1+(b+4)|0]|0)==61){iI=2;iJ=iK}else{break}}c[cq>>2]=iJ+2;if((wW(b,af,e)|0)==0){cA=1015;break L1325}if((iI|0)==1){c[bl>>2]=(c[bl>>2]|0)==(c[af>>2]|0);continue}else if((iI|0)==2){c[bl>>2]=(c[bl>>2]|0)!=(c[af>>2]|0);continue}else{continue}}c[bU>>2]=c[bl>>2]&c[bU>>2];iB=iK}if((cA|0)==2287){cA=0;c[cq>>2]=iB;iF=iB}c[ci>>2]=c[bU>>2]^c[ci>>2];im=iF}while(1){gI=iu;while(1){iM=b+4+gI|0;gn=a[iM]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[iM]|0;if(gn<<24>>24==124){if((a[gI+1+(b+4)|0]|0)==124){cA=2288;break}else{iN=gI;iO=124}}else{iN=gI;iO=gn}while(1){if(!((iO<<24>>24|0)==13|(iO<<24>>24|0)==32|(iO<<24>>24|0)==9|(iO<<24>>24|0)==10)){break}gn=iN+1|0;iN=gn;iO=a[b+4+gn|0]|0}c[cq>>2]=iN;if((a[b+4+iN|0]|0)!=124){iP=iN;break}iQ=iN+1|0;c[cq>>2]=iQ;if((wW(b,b9,e)|0)==0){cA=1116;break L1325}while(1){gI=c[cq>>2]|0;while(1){iR=b+4+gI|0;gn=a[iR]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[iR]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){iS=1;iT=gI}else{iU=gI;iV=61;cA=1037}}else{iU=gI;iV=gn;cA=1037}if((cA|0)==1037){while(1){cA=0;if(!((iV<<24>>24|0)==13|(iV<<24>>24|0)==32|(iV<<24>>24|0)==9|(iV<<24>>24|0)==10)){break}gn=iU+1|0;iU=gn;iV=a[b+4+gn|0]|0;cA=1037}c[cq>>2]=iU;if((a[b+4+iU|0]|0)!=33){iW=iU;break}if((a[iU+1+(b+4)|0]|0)==61){iS=2;iT=iU}else{iW=iU;break}}c[cq>>2]=iT+2;if((wW(b,ae,e)|0)==0){cA=1042;break L1325}if((iS|0)==1){c[b9>>2]=(c[b9>>2]|0)==(c[ae>>2]|0);continue}else if((iS|0)==2){c[b9>>2]=(c[b9>>2]|0)!=(c[ae>>2]|0);continue}else{continue}}while(1){gI=iW;while(1){iX=b+4+gI|0;gn=a[iX]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[iX]|0;if(gn<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=2289;break}else{iY=gI;iZ=38}}else{iY=gI;iZ=gn}while(1){if(!((iZ<<24>>24|0)==13|(iZ<<24>>24|0)==32|(iZ<<24>>24|0)==9|(iZ<<24>>24|0)==10)){break}gn=iY+1|0;iY=gn;iZ=a[b+4+gn|0]|0}c[cq>>2]=iY;if((a[b+4+iY|0]|0)!=38){i_=iY;break}i$=iY+1|0;c[cq>>2]=i$;if((wW(b,bk,e)|0)==0){cA=1069;break L1325}while(1){gI=c[cq>>2]|0;while(1){i0=b+4+gI|0;gn=a[i0]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[i0]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){i1=1;i2=gI}else{i3=gI;i4=61;cA=1060}}else{i3=gI;i4=gn;cA=1060}if((cA|0)==1060){while(1){cA=0;if(!((i4<<24>>24|0)==13|(i4<<24>>24|0)==32|(i4<<24>>24|0)==9|(i4<<24>>24|0)==10)){break}gn=i3+1|0;i3=gn;i4=a[b+4+gn|0]|0;cA=1060}c[cq>>2]=i3;if((a[b+4+i3|0]|0)!=33){break}if((a[i3+1+(b+4)|0]|0)==61){i1=2;i2=i3}else{break}}c[cq>>2]=i2+2;if((wW(b,ad,e)|0)==0){cA=1065;break L1325}if((i1|0)==1){c[bk>>2]=(c[bk>>2]|0)==(c[ad>>2]|0);continue}else if((i1|0)==2){c[bk>>2]=(c[bk>>2]|0)!=(c[ad>>2]|0);continue}else{continue}}c[b9>>2]=c[bk>>2]&c[b9>>2];iW=i3}if((cA|0)==2289){cA=0;c[cq>>2]=iW;i_=iW}while(1){gI=b+4+i_|0;gn=a[gI]|0;if((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10){i_=i_+1|0;continue}c[cq>>2]=i_;if((a[gI]|0)!=94){break}i5=i_+1|0;c[cq>>2]=i5;if((wW(b,bT,e)|0)==0){cA=1114;break L1325}while(1){gI=c[cq>>2]|0;while(1){i6=b+4+gI|0;gn=a[i6]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[i6]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){i7=1;i8=gI}else{i9=gI;ja=61;cA=1080}}else{i9=gI;ja=gn;cA=1080}if((cA|0)==1080){while(1){cA=0;if(!((ja<<24>>24|0)==13|(ja<<24>>24|0)==32|(ja<<24>>24|0)==9|(ja<<24>>24|0)==10)){break}gn=i9+1|0;i9=gn;ja=a[b+4+gn|0]|0;cA=1080}c[cq>>2]=i9;if((a[b+4+i9|0]|0)!=33){jb=i9;break}if((a[i9+1+(b+4)|0]|0)==61){i7=2;i8=i9}else{jb=i9;break}}c[cq>>2]=i8+2;if((wW(b,ac,e)|0)==0){cA=1085;break L1325}if((i7|0)==1){c[bT>>2]=(c[bT>>2]|0)==(c[ac>>2]|0);continue}else if((i7|0)==2){c[bT>>2]=(c[bT>>2]|0)!=(c[ac>>2]|0);continue}else{continue}}while(1){gI=jb;while(1){jc=b+4+gI|0;gn=a[jc]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[jc]|0;if(gn<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=2290;break}else{jd=gI;je=38}}else{jd=gI;je=gn}while(1){if(!((je<<24>>24|0)==13|(je<<24>>24|0)==32|(je<<24>>24|0)==9|(je<<24>>24|0)==10)){break}gn=jd+1|0;jd=gn;je=a[b+4+gn|0]|0}c[cq>>2]=jd;if((a[b+4+jd|0]|0)!=38){jf=jd;break}jg=jd+1|0;c[cq>>2]=jg;if((wW(b,bj,e)|0)==0){cA=1112;break L1325}while(1){gI=c[cq>>2]|0;while(1){jh=b+4+gI|0;gn=a[jh]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[jh]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){ji=1;jj=gI}else{jk=gI;jl=61;cA=1103}}else{jk=gI;jl=gn;cA=1103}if((cA|0)==1103){while(1){cA=0;if(!((jl<<24>>24|0)==13|(jl<<24>>24|0)==32|(jl<<24>>24|0)==9|(jl<<24>>24|0)==10)){break}gn=jk+1|0;jk=gn;jl=a[b+4+gn|0]|0;cA=1103}c[cq>>2]=jk;if((a[b+4+jk|0]|0)!=33){break}if((a[jk+1+(b+4)|0]|0)==61){ji=2;jj=jk}else{break}}c[cq>>2]=jj+2;if((wW(b,ab,e)|0)==0){cA=1108;break L1325}if((ji|0)==1){c[bj>>2]=(c[bj>>2]|0)==(c[ab>>2]|0);continue}else if((ji|0)==2){c[bj>>2]=(c[bj>>2]|0)!=(c[ab>>2]|0);continue}else{continue}}c[bT>>2]=c[bj>>2]&c[bT>>2];jb=jk}if((cA|0)==2290){cA=0;c[cq>>2]=jb;jf=jb}c[b9>>2]=c[bT>>2]^c[b9>>2];i_=jf}c[ci>>2]=c[b9>>2]|c[ci>>2];iu=i_}if((cA|0)==2288){cA=0;c[cq>>2]=iu;iP=iu}if((c[co>>2]|0)==0){jm=0}else{jm=(c[ci>>2]|0)!=0|0}c[co>>2]=jm;gZ=iP}if((cA|0)==937){eL=gZ;L1584:while(1){gI=b+4+eL|0;gn=a[gI]|0;if((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10){eL=eL+1|0;continue}c[cq>>2]=eL;gn=a[gI]|0;if(gn<<24>>24!=124){jn=eL;jo=gn;cA=1497;break}if((a[eL+1+(b+4)|0]|0)!=124){jn=eL;jo=gn;cA=1497;break}jp=eL+2|0;c[cq>>2]=jp;if((wW(b,cm,e)|0)==0){break}while(1){gn=c[cq>>2]|0;while(1){jq=b+4+gn|0;gI=a[jq]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[jq]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){jr=1;js=gn}else{jt=gn;ju=61;cA=1131}}else{jt=gn;ju=gI;cA=1131}if((cA|0)==1131){while(1){cA=0;if(!((ju<<24>>24|0)==13|(ju<<24>>24|0)==32|(ju<<24>>24|0)==9|(ju<<24>>24|0)==10)){break}gI=jt+1|0;jt=gI;ju=a[b+4+gI|0]|0;cA=1131}c[cq>>2]=jt;if((a[b+4+jt|0]|0)!=33){jv=jt;break}if((a[jt+1+(b+4)|0]|0)==61){jr=2;js=jt}else{jv=jt;break}}c[cq>>2]=js+2;if((wW(b,aa,e)|0)==0){cA=1136;break L1584}if((jr|0)==1){c[cm>>2]=(c[cm>>2]|0)==(c[aa>>2]|0);continue}else if((jr|0)==2){c[cm>>2]=(c[cm>>2]|0)!=(c[aa>>2]|0);continue}else{continue}}while(1){gn=jv;while(1){jw=b+4+gn|0;gI=a[jw]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[jw]|0;if(gI<<24>>24==38){if((a[gn+1+(b+4)|0]|0)==38){cA=2274;break}else{jx=gn;jy=38}}else{jx=gn;jy=gI}while(1){if(!((jy<<24>>24|0)==13|(jy<<24>>24|0)==32|(jy<<24>>24|0)==9|(jy<<24>>24|0)==10)){break}gI=jx+1|0;jx=gI;jy=a[b+4+gI|0]|0}c[cq>>2]=jx;if((a[b+4+jx|0]|0)!=38){jz=jx;break}jA=jx+1|0;c[cq>>2]=jA;if((wW(b,bi,e)|0)==0){cA=1163;break L1584}while(1){gn=c[cq>>2]|0;while(1){jB=b+4+gn|0;gI=a[jB]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[jB]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){jC=1;jD=gn}else{jE=gn;jF=61;cA=1154}}else{jE=gn;jF=gI;cA=1154}if((cA|0)==1154){while(1){cA=0;if(!((jF<<24>>24|0)==13|(jF<<24>>24|0)==32|(jF<<24>>24|0)==9|(jF<<24>>24|0)==10)){break}gI=jE+1|0;jE=gI;jF=a[b+4+gI|0]|0;cA=1154}c[cq>>2]=jE;if((a[b+4+jE|0]|0)!=33){break}if((a[jE+1+(b+4)|0]|0)==61){jC=2;jD=jE}else{break}}c[cq>>2]=jD+2;if((wW(b,$,e)|0)==0){cA=1159;break L1584}if((jC|0)==1){c[bi>>2]=(c[bi>>2]|0)==(c[$>>2]|0);continue}else if((jC|0)==2){c[bi>>2]=(c[bi>>2]|0)!=(c[$>>2]|0);continue}else{continue}}c[cm>>2]=c[bi>>2]&c[cm>>2];jv=jE}if((cA|0)==2274){cA=0;c[cq>>2]=jv;jz=jv}while(1){gn=b+4+jz|0;gI=a[gn]|0;if((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10){jz=jz+1|0;continue}c[cq>>2]=jz;if((a[gn]|0)!=94){jG=jz;break}jH=jz+1|0;c[cq>>2]=jH;if((wW(b,bS,e)|0)==0){cA=1208;break L1584}while(1){gn=c[cq>>2]|0;while(1){jI=b+4+gn|0;gI=a[jI]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[jI]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){jJ=1;jK=gn}else{jL=gn;jM=61;cA=1174}}else{jL=gn;jM=gI;cA=1174}if((cA|0)==1174){while(1){cA=0;if(!((jM<<24>>24|0)==13|(jM<<24>>24|0)==32|(jM<<24>>24|0)==9|(jM<<24>>24|0)==10)){break}gI=jL+1|0;jL=gI;jM=a[b+4+gI|0]|0;cA=1174}c[cq>>2]=jL;if((a[b+4+jL|0]|0)!=33){jN=jL;break}if((a[jL+1+(b+4)|0]|0)==61){jJ=2;jK=jL}else{jN=jL;break}}c[cq>>2]=jK+2;if((wW(b,_,e)|0)==0){cA=1179;break L1584}if((jJ|0)==1){c[bS>>2]=(c[bS>>2]|0)==(c[_>>2]|0);continue}else if((jJ|0)==2){c[bS>>2]=(c[bS>>2]|0)!=(c[_>>2]|0);continue}else{continue}}while(1){gn=jN;while(1){jO=b+4+gn|0;gI=a[jO]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[jO]|0;if(gI<<24>>24==38){if((a[gn+1+(b+4)|0]|0)==38){cA=2275;break}else{jP=gn;jQ=38}}else{jP=gn;jQ=gI}while(1){if(!((jQ<<24>>24|0)==13|(jQ<<24>>24|0)==32|(jQ<<24>>24|0)==9|(jQ<<24>>24|0)==10)){break}gI=jP+1|0;jP=gI;jQ=a[b+4+gI|0]|0}c[cq>>2]=jP;if((a[b+4+jP|0]|0)!=38){jR=jP;break}jS=jP+1|0;c[cq>>2]=jS;if((wW(b,bh,e)|0)==0){cA=1206;break L1584}while(1){gn=c[cq>>2]|0;while(1){jT=b+4+gn|0;gI=a[jT]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[jT]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){jU=1;jV=gn}else{jW=gn;jX=61;cA=1197}}else{jW=gn;jX=gI;cA=1197}if((cA|0)==1197){while(1){cA=0;if(!((jX<<24>>24|0)==13|(jX<<24>>24|0)==32|(jX<<24>>24|0)==9|(jX<<24>>24|0)==10)){break}gI=jW+1|0;jW=gI;jX=a[b+4+gI|0]|0;cA=1197}c[cq>>2]=jW;if((a[b+4+jW|0]|0)!=33){break}if((a[jW+1+(b+4)|0]|0)==61){jU=2;jV=jW}else{break}}c[cq>>2]=jV+2;if((wW(b,Z,e)|0)==0){cA=1202;break L1584}if((jU|0)==1){c[bh>>2]=(c[bh>>2]|0)==(c[Z>>2]|0);continue}else if((jU|0)==2){c[bh>>2]=(c[bh>>2]|0)!=(c[Z>>2]|0);continue}else{continue}}c[bS>>2]=c[bh>>2]&c[bS>>2];jN=jW}if((cA|0)==2275){cA=0;c[cq>>2]=jN;jR=jN}c[cm>>2]=c[bS>>2]^c[cm>>2];jz=jR}while(1){gn=jG;while(1){jY=b+4+gn|0;gI=a[jY]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[jY]|0;if(gI<<24>>24==124){if((a[gn+1+(b+4)|0]|0)==124){cA=2276;break}else{jZ=gn;j_=124}}else{jZ=gn;j_=gI}while(1){if(!((j_<<24>>24|0)==13|(j_<<24>>24|0)==32|(j_<<24>>24|0)==9|(j_<<24>>24|0)==10)){break}gI=jZ+1|0;jZ=gI;j_=a[b+4+gI|0]|0}c[cq>>2]=jZ;if((a[b+4+jZ|0]|0)!=124){j$=jZ;break}j0=jZ+1|0;c[cq>>2]=j0;if((wW(b,b8,e)|0)==0){cA=1303;break L1584}while(1){gn=c[cq>>2]|0;while(1){j1=b+4+gn|0;gI=a[j1]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[j1]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){j2=1;j3=gn}else{j4=gn;j5=61;cA=1224}}else{j4=gn;j5=gI;cA=1224}if((cA|0)==1224){while(1){cA=0;if(!((j5<<24>>24|0)==13|(j5<<24>>24|0)==32|(j5<<24>>24|0)==9|(j5<<24>>24|0)==10)){break}gI=j4+1|0;j4=gI;j5=a[b+4+gI|0]|0;cA=1224}c[cq>>2]=j4;if((a[b+4+j4|0]|0)!=33){j6=j4;break}if((a[j4+1+(b+4)|0]|0)==61){j2=2;j3=j4}else{j6=j4;break}}c[cq>>2]=j3+2;if((wW(b,Y,e)|0)==0){cA=1229;break L1584}if((j2|0)==1){c[b8>>2]=(c[b8>>2]|0)==(c[Y>>2]|0);continue}else if((j2|0)==2){c[b8>>2]=(c[b8>>2]|0)!=(c[Y>>2]|0);continue}else{continue}}while(1){gn=j6;while(1){j7=b+4+gn|0;gI=a[j7]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[j7]|0;if(gI<<24>>24==38){if((a[gn+1+(b+4)|0]|0)==38){cA=2277;break}else{j8=gn;j9=38}}else{j8=gn;j9=gI}while(1){if(!((j9<<24>>24|0)==13|(j9<<24>>24|0)==32|(j9<<24>>24|0)==9|(j9<<24>>24|0)==10)){break}gI=j8+1|0;j8=gI;j9=a[b+4+gI|0]|0}c[cq>>2]=j8;if((a[b+4+j8|0]|0)!=38){ka=j8;break}kb=j8+1|0;c[cq>>2]=kb;if((wW(b,bg,e)|0)==0){cA=1256;break L1584}while(1){gn=c[cq>>2]|0;while(1){kc=b+4+gn|0;gI=a[kc]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[kc]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){kd=1;ke=gn}else{kf=gn;kg=61;cA=1247}}else{kf=gn;kg=gI;cA=1247}if((cA|0)==1247){while(1){cA=0;if(!((kg<<24>>24|0)==13|(kg<<24>>24|0)==32|(kg<<24>>24|0)==9|(kg<<24>>24|0)==10)){break}gI=kf+1|0;kf=gI;kg=a[b+4+gI|0]|0;cA=1247}c[cq>>2]=kf;if((a[b+4+kf|0]|0)!=33){break}if((a[kf+1+(b+4)|0]|0)==61){kd=2;ke=kf}else{break}}c[cq>>2]=ke+2;if((wW(b,X,e)|0)==0){cA=1252;break L1584}if((kd|0)==1){c[bg>>2]=(c[bg>>2]|0)==(c[X>>2]|0);continue}else if((kd|0)==2){c[bg>>2]=(c[bg>>2]|0)!=(c[X>>2]|0);continue}else{continue}}c[b8>>2]=c[bg>>2]&c[b8>>2];j6=kf}if((cA|0)==2277){cA=0;c[cq>>2]=j6;ka=j6}while(1){gn=b+4+ka|0;gI=a[gn]|0;if((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10){ka=ka+1|0;continue}c[cq>>2]=ka;if((a[gn]|0)!=94){break}kh=ka+1|0;c[cq>>2]=kh;if((wW(b,bR,e)|0)==0){cA=1301;break L1584}while(1){gn=c[cq>>2]|0;while(1){ki=b+4+gn|0;gI=a[ki]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[ki]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){kj=1;kk=gn}else{kl=gn;km=61;cA=1267}}else{kl=gn;km=gI;cA=1267}if((cA|0)==1267){while(1){cA=0;if(!((km<<24>>24|0)==13|(km<<24>>24|0)==32|(km<<24>>24|0)==9|(km<<24>>24|0)==10)){break}gI=kl+1|0;kl=gI;km=a[b+4+gI|0]|0;cA=1267}c[cq>>2]=kl;if((a[b+4+kl|0]|0)!=33){kn=kl;break}if((a[kl+1+(b+4)|0]|0)==61){kj=2;kk=kl}else{kn=kl;break}}c[cq>>2]=kk+2;if((wW(b,W,e)|0)==0){cA=1272;break L1584}if((kj|0)==1){c[bR>>2]=(c[bR>>2]|0)==(c[W>>2]|0);continue}else if((kj|0)==2){c[bR>>2]=(c[bR>>2]|0)!=(c[W>>2]|0);continue}else{continue}}while(1){gn=kn;while(1){ko=b+4+gn|0;gI=a[ko]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[ko]|0;if(gI<<24>>24==38){if((a[gn+1+(b+4)|0]|0)==38){cA=2278;break}else{kp=gn;kq=38}}else{kp=gn;kq=gI}while(1){if(!((kq<<24>>24|0)==13|(kq<<24>>24|0)==32|(kq<<24>>24|0)==9|(kq<<24>>24|0)==10)){break}gI=kp+1|0;kp=gI;kq=a[b+4+gI|0]|0}c[cq>>2]=kp;if((a[b+4+kp|0]|0)!=38){kr=kp;break}ks=kp+1|0;c[cq>>2]=ks;if((wW(b,bf,e)|0)==0){cA=1299;break L1584}while(1){gn=c[cq>>2]|0;while(1){kt=b+4+gn|0;gI=a[kt]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[kt]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){ku=1;kv=gn}else{kw=gn;kx=61;cA=1290}}else{kw=gn;kx=gI;cA=1290}if((cA|0)==1290){while(1){cA=0;if(!((kx<<24>>24|0)==13|(kx<<24>>24|0)==32|(kx<<24>>24|0)==9|(kx<<24>>24|0)==10)){break}gI=kw+1|0;kw=gI;kx=a[b+4+gI|0]|0;cA=1290}c[cq>>2]=kw;if((a[b+4+kw|0]|0)!=33){break}if((a[kw+1+(b+4)|0]|0)==61){ku=2;kv=kw}else{break}}c[cq>>2]=kv+2;if((wW(b,V,e)|0)==0){cA=1295;break L1584}if((ku|0)==1){c[bf>>2]=(c[bf>>2]|0)==(c[V>>2]|0);continue}else if((ku|0)==2){c[bf>>2]=(c[bf>>2]|0)!=(c[V>>2]|0);continue}else{continue}}c[bR>>2]=c[bf>>2]&c[bR>>2];kn=kw}if((cA|0)==2278){cA=0;c[cq>>2]=kn;kr=kn}c[b8>>2]=c[bR>>2]^c[b8>>2];ka=kr}c[cm>>2]=c[b8>>2]|c[cm>>2];jG=ka}if((cA|0)==2276){cA=0;c[cq>>2]=jG;j$=jG}while(1){gn=b+4+j$|0;gI=a[gn]|0;if((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10){j$=j$+1|0;continue}c[cq>>2]=j$;if((a[gn]|0)!=38){break}if((a[j$+1+(b+4)|0]|0)!=38){break}ky=j$+2|0;c[cq>>2]=ky;if((wW(b,ch,e)|0)==0){cA=1488;break L1584}while(1){gn=c[cq>>2]|0;while(1){kz=b+4+gn|0;gI=a[kz]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[kz]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){kA=1;kB=gn}else{kC=gn;kD=61;cA=1314}}else{kC=gn;kD=gI;cA=1314}if((cA|0)==1314){while(1){cA=0;if(!((kD<<24>>24|0)==13|(kD<<24>>24|0)==32|(kD<<24>>24|0)==9|(kD<<24>>24|0)==10)){break}gI=kC+1|0;kC=gI;kD=a[b+4+gI|0]|0;cA=1314}c[cq>>2]=kC;if((a[b+4+kC|0]|0)!=33){kE=kC;break}if((a[kC+1+(b+4)|0]|0)==61){kA=2;kB=kC}else{kE=kC;break}}c[cq>>2]=kB+2;if((wW(b,U,e)|0)==0){cA=1319;break L1584}if((kA|0)==1){c[ch>>2]=(c[ch>>2]|0)==(c[U>>2]|0);continue}else if((kA|0)==2){c[ch>>2]=(c[ch>>2]|0)!=(c[U>>2]|0);continue}else{continue}}while(1){gn=kE;while(1){kF=b+4+gn|0;gI=a[kF]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[kF]|0;if(gI<<24>>24==38){if((a[gn+1+(b+4)|0]|0)==38){cA=2280;break}else{kG=gn;kH=38}}else{kG=gn;kH=gI}while(1){if(!((kH<<24>>24|0)==13|(kH<<24>>24|0)==32|(kH<<24>>24|0)==9|(kH<<24>>24|0)==10)){break}gI=kG+1|0;kG=gI;kH=a[b+4+gI|0]|0}c[cq>>2]=kG;if((a[b+4+kG|0]|0)!=38){kI=kG;break}kJ=kG+1|0;c[cq>>2]=kJ;if((wW(b,be,e)|0)==0){cA=1346;break L1584}while(1){gn=c[cq>>2]|0;while(1){kK=b+4+gn|0;gI=a[kK]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[kK]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){kL=1;kM=gn}else{kN=gn;kO=61;cA=1337}}else{kN=gn;kO=gI;cA=1337}if((cA|0)==1337){while(1){cA=0;if(!((kO<<24>>24|0)==13|(kO<<24>>24|0)==32|(kO<<24>>24|0)==9|(kO<<24>>24|0)==10)){break}gI=kN+1|0;kN=gI;kO=a[b+4+gI|0]|0;cA=1337}c[cq>>2]=kN;if((a[b+4+kN|0]|0)!=33){break}if((a[kN+1+(b+4)|0]|0)==61){kL=2;kM=kN}else{break}}c[cq>>2]=kM+2;if((wW(b,T,e)|0)==0){cA=1342;break L1584}if((kL|0)==1){c[be>>2]=(c[be>>2]|0)==(c[T>>2]|0);continue}else if((kL|0)==2){c[be>>2]=(c[be>>2]|0)!=(c[T>>2]|0);continue}else{continue}}c[ch>>2]=c[be>>2]&c[ch>>2];kE=kN}if((cA|0)==2280){cA=0;c[cq>>2]=kE;kI=kE}while(1){gn=b+4+kI|0;gI=a[gn]|0;if((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10){kI=kI+1|0;continue}c[cq>>2]=kI;if((a[gn]|0)!=94){kP=kI;break}kQ=kI+1|0;c[cq>>2]=kQ;if((wW(b,bQ,e)|0)==0){cA=1391;break L1584}while(1){gn=c[cq>>2]|0;while(1){kR=b+4+gn|0;gI=a[kR]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[kR]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){kS=1;kT=gn}else{kU=gn;kV=61;cA=1357}}else{kU=gn;kV=gI;cA=1357}if((cA|0)==1357){while(1){cA=0;if(!((kV<<24>>24|0)==13|(kV<<24>>24|0)==32|(kV<<24>>24|0)==9|(kV<<24>>24|0)==10)){break}gI=kU+1|0;kU=gI;kV=a[b+4+gI|0]|0;cA=1357}c[cq>>2]=kU;if((a[b+4+kU|0]|0)!=33){kW=kU;break}if((a[kU+1+(b+4)|0]|0)==61){kS=2;kT=kU}else{kW=kU;break}}c[cq>>2]=kT+2;if((wW(b,S,e)|0)==0){cA=1362;break L1584}if((kS|0)==1){c[bQ>>2]=(c[bQ>>2]|0)==(c[S>>2]|0);continue}else if((kS|0)==2){c[bQ>>2]=(c[bQ>>2]|0)!=(c[S>>2]|0);continue}else{continue}}while(1){gn=kW;while(1){kX=b+4+gn|0;gI=a[kX]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[kX]|0;if(gI<<24>>24==38){if((a[gn+1+(b+4)|0]|0)==38){cA=2281;break}else{kY=gn;kZ=38}}else{kY=gn;kZ=gI}while(1){if(!((kZ<<24>>24|0)==13|(kZ<<24>>24|0)==32|(kZ<<24>>24|0)==9|(kZ<<24>>24|0)==10)){break}gI=kY+1|0;kY=gI;kZ=a[b+4+gI|0]|0}c[cq>>2]=kY;if((a[b+4+kY|0]|0)!=38){k_=kY;break}k$=kY+1|0;c[cq>>2]=k$;if((wW(b,bd,e)|0)==0){cA=1389;break L1584}while(1){gn=c[cq>>2]|0;while(1){k0=b+4+gn|0;gI=a[k0]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[k0]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){k1=1;k2=gn}else{k3=gn;k4=61;cA=1380}}else{k3=gn;k4=gI;cA=1380}if((cA|0)==1380){while(1){cA=0;if(!((k4<<24>>24|0)==13|(k4<<24>>24|0)==32|(k4<<24>>24|0)==9|(k4<<24>>24|0)==10)){break}gI=k3+1|0;k3=gI;k4=a[b+4+gI|0]|0;cA=1380}c[cq>>2]=k3;if((a[b+4+k3|0]|0)!=33){break}if((a[k3+1+(b+4)|0]|0)==61){k1=2;k2=k3}else{break}}c[cq>>2]=k2+2;if((wW(b,R,e)|0)==0){cA=1385;break L1584}if((k1|0)==1){c[bd>>2]=(c[bd>>2]|0)==(c[R>>2]|0);continue}else if((k1|0)==2){c[bd>>2]=(c[bd>>2]|0)!=(c[R>>2]|0);continue}else{continue}}c[bQ>>2]=c[bd>>2]&c[bQ>>2];kW=k3}if((cA|0)==2281){cA=0;c[cq>>2]=kW;k_=kW}c[ch>>2]=c[bQ>>2]^c[ch>>2];kI=k_}while(1){gn=kP;while(1){k5=b+4+gn|0;gI=a[k5]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[k5]|0;if(gI<<24>>24==124){if((a[gn+1+(b+4)|0]|0)==124){cA=2282;break}else{k6=gn;k7=124}}else{k6=gn;k7=gI}while(1){if(!((k7<<24>>24|0)==13|(k7<<24>>24|0)==32|(k7<<24>>24|0)==9|(k7<<24>>24|0)==10)){break}gI=k6+1|0;k6=gI;k7=a[b+4+gI|0]|0}c[cq>>2]=k6;if((a[b+4+k6|0]|0)!=124){k8=k6;break}k9=k6+1|0;c[cq>>2]=k9;if((wW(b,b7,e)|0)==0){cA=1486;break L1584}while(1){gn=c[cq>>2]|0;while(1){la=b+4+gn|0;gI=a[la]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[la]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){lb=1;lc=gn}else{ld=gn;le=61;cA=1407}}else{ld=gn;le=gI;cA=1407}if((cA|0)==1407){while(1){cA=0;if(!((le<<24>>24|0)==13|(le<<24>>24|0)==32|(le<<24>>24|0)==9|(le<<24>>24|0)==10)){break}gI=ld+1|0;ld=gI;le=a[b+4+gI|0]|0;cA=1407}c[cq>>2]=ld;if((a[b+4+ld|0]|0)!=33){lf=ld;break}if((a[ld+1+(b+4)|0]|0)==61){lb=2;lc=ld}else{lf=ld;break}}c[cq>>2]=lc+2;if((wW(b,Q,e)|0)==0){cA=1412;break L1584}if((lb|0)==1){c[b7>>2]=(c[b7>>2]|0)==(c[Q>>2]|0);continue}else if((lb|0)==2){c[b7>>2]=(c[b7>>2]|0)!=(c[Q>>2]|0);continue}else{continue}}while(1){gn=lf;while(1){lg=b+4+gn|0;gI=a[lg]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[lg]|0;if(gI<<24>>24==38){if((a[gn+1+(b+4)|0]|0)==38){cA=2283;break}else{lh=gn;li=38}}else{lh=gn;li=gI}while(1){if(!((li<<24>>24|0)==13|(li<<24>>24|0)==32|(li<<24>>24|0)==9|(li<<24>>24|0)==10)){break}gI=lh+1|0;lh=gI;li=a[b+4+gI|0]|0}c[cq>>2]=lh;if((a[b+4+lh|0]|0)!=38){lj=lh;break}lk=lh+1|0;c[cq>>2]=lk;if((wW(b,bc,e)|0)==0){cA=1439;break L1584}while(1){gn=c[cq>>2]|0;while(1){ll=b+4+gn|0;gI=a[ll]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[ll]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){lm=1;ln=gn}else{lo=gn;lp=61;cA=1430}}else{lo=gn;lp=gI;cA=1430}if((cA|0)==1430){while(1){cA=0;if(!((lp<<24>>24|0)==13|(lp<<24>>24|0)==32|(lp<<24>>24|0)==9|(lp<<24>>24|0)==10)){break}gI=lo+1|0;lo=gI;lp=a[b+4+gI|0]|0;cA=1430}c[cq>>2]=lo;if((a[b+4+lo|0]|0)!=33){break}if((a[lo+1+(b+4)|0]|0)==61){lm=2;ln=lo}else{break}}c[cq>>2]=ln+2;if((wW(b,P,e)|0)==0){cA=1435;break L1584}if((lm|0)==1){c[bc>>2]=(c[bc>>2]|0)==(c[P>>2]|0);continue}else if((lm|0)==2){c[bc>>2]=(c[bc>>2]|0)!=(c[P>>2]|0);continue}else{continue}}c[b7>>2]=c[bc>>2]&c[b7>>2];lf=lo}if((cA|0)==2283){cA=0;c[cq>>2]=lf;lj=lf}while(1){gn=b+4+lj|0;gI=a[gn]|0;if((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10){lj=lj+1|0;continue}c[cq>>2]=lj;if((a[gn]|0)!=94){break}lq=lj+1|0;c[cq>>2]=lq;if((wW(b,bP,e)|0)==0){cA=1484;break L1584}while(1){gn=c[cq>>2]|0;while(1){lr=b+4+gn|0;gI=a[lr]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[lr]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){ls=1;lt=gn}else{lu=gn;lv=61;cA=1450}}else{lu=gn;lv=gI;cA=1450}if((cA|0)==1450){while(1){cA=0;if(!((lv<<24>>24|0)==13|(lv<<24>>24|0)==32|(lv<<24>>24|0)==9|(lv<<24>>24|0)==10)){break}gI=lu+1|0;lu=gI;lv=a[b+4+gI|0]|0;cA=1450}c[cq>>2]=lu;if((a[b+4+lu|0]|0)!=33){lw=lu;break}if((a[lu+1+(b+4)|0]|0)==61){ls=2;lt=lu}else{lw=lu;break}}c[cq>>2]=lt+2;if((wW(b,O,e)|0)==0){cA=1455;break L1584}if((ls|0)==1){c[bP>>2]=(c[bP>>2]|0)==(c[O>>2]|0);continue}else if((ls|0)==2){c[bP>>2]=(c[bP>>2]|0)!=(c[O>>2]|0);continue}else{continue}}while(1){gn=lw;while(1){lx=b+4+gn|0;gI=a[lx]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[lx]|0;if(gI<<24>>24==38){if((a[gn+1+(b+4)|0]|0)==38){cA=2284;break}else{ly=gn;lz=38}}else{ly=gn;lz=gI}while(1){if(!((lz<<24>>24|0)==13|(lz<<24>>24|0)==32|(lz<<24>>24|0)==9|(lz<<24>>24|0)==10)){break}gI=ly+1|0;ly=gI;lz=a[b+4+gI|0]|0}c[cq>>2]=ly;if((a[b+4+ly|0]|0)!=38){lA=ly;break}lB=ly+1|0;c[cq>>2]=lB;if((wW(b,bb,e)|0)==0){cA=1482;break L1584}while(1){gn=c[cq>>2]|0;while(1){lC=b+4+gn|0;gI=a[lC]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[lC]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){lD=1;lE=gn}else{lF=gn;lG=61;cA=1473}}else{lF=gn;lG=gI;cA=1473}if((cA|0)==1473){while(1){cA=0;if(!((lG<<24>>24|0)==13|(lG<<24>>24|0)==32|(lG<<24>>24|0)==9|(lG<<24>>24|0)==10)){break}gI=lF+1|0;lF=gI;lG=a[b+4+gI|0]|0;cA=1473}c[cq>>2]=lF;if((a[b+4+lF|0]|0)!=33){break}if((a[lF+1+(b+4)|0]|0)==61){lD=2;lE=lF}else{break}}c[cq>>2]=lE+2;if((wW(b,N,e)|0)==0){cA=1478;break L1584}if((lD|0)==1){c[bb>>2]=(c[bb>>2]|0)==(c[N>>2]|0);continue}else if((lD|0)==2){c[bb>>2]=(c[bb>>2]|0)!=(c[N>>2]|0);continue}else{continue}}c[bP>>2]=c[bb>>2]&c[bP>>2];lw=lF}if((cA|0)==2284){cA=0;c[cq>>2]=lw;lA=lw}c[b7>>2]=c[bP>>2]^c[b7>>2];lj=lA}c[ch>>2]=c[b7>>2]|c[ch>>2];kP=lj}if((cA|0)==2282){cA=0;c[cq>>2]=kP;k8=kP}if((c[cm>>2]|0)==0){lH=0}else{lH=(c[ch>>2]|0)!=0|0}c[cm>>2]=lH;j$=k8}if((c[co>>2]|0)==0){lI=(c[cm>>2]|0)!=0|0}else{lI=1}c[co>>2]=lI;eL=j$}if((cA|0)==1136){c[cq>>2]=jp}else if((cA|0)==1159){c[cq>>2]=jA;cA=1163}else if((cA|0)==1179){c[cq>>2]=jH;cA=1208}else if((cA|0)==1202){c[cq>>2]=jS;cA=1206}else if((cA|0)==1229){c[cq>>2]=j0;cA=1303}else if((cA|0)==1252){c[cq>>2]=kb;cA=1256}else if((cA|0)==1272){c[cq>>2]=kh;cA=1301}else if((cA|0)==1295){c[cq>>2]=ks;cA=1299}else if((cA|0)==1319){c[cq>>2]=ky;cA=1488}else if((cA|0)==1342){c[cq>>2]=kJ;cA=1346}else if((cA|0)==1362){c[cq>>2]=kQ;cA=1391}else if((cA|0)==1385){c[cq>>2]=k$;cA=1389}else if((cA|0)==1412){c[cq>>2]=k9;cA=1486}else if((cA|0)==1435){c[cq>>2]=lk;cA=1439}else if((cA|0)==1455){c[cq>>2]=lq;cA=1484}else if((cA|0)==1478){c[cq>>2]=lB;cA=1482}else if((cA|0)==1497){while(1){cA=0;if(!((jo<<24>>24|0)==13|(jo<<24>>24|0)==32|(jo<<24>>24|0)==9|(jo<<24>>24|0)==10)){break}eL=jn+1|0;jn=eL;jo=a[b+4+eL|0]|0;cA=1497}c[cq>>2]=jn;if((a[b+4+jn|0]|0)!=58){c[cq>>2]=cr;cs=0;i=f;return cs|0}eL=jn+1|0;c[cq>>2]=eL;do{if((wW(b,cp,e)|0)!=0){while(1){gZ=c[cq>>2]|0;while(1){lJ=b+4+gZ|0;gn=a[lJ]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gZ=gZ+1|0}c[cq>>2]=gZ;gn=a[lJ]|0;if(gn<<24>>24==61){if((a[gZ+1+(b+4)|0]|0)==61){lK=1;lL=gZ}else{lM=gZ;lN=61;cA=1507}}else{lM=gZ;lN=gn;cA=1507}if((cA|0)==1507){while(1){cA=0;if(!((lN<<24>>24|0)==13|(lN<<24>>24|0)==32|(lN<<24>>24|0)==9|(lN<<24>>24|0)==10)){break}gn=lM+1|0;lM=gn;lN=a[b+4+gn|0]|0;cA=1507}c[cq>>2]=lM;if((a[b+4+lM|0]|0)!=33){break}if((a[lM+1+(b+4)|0]|0)==61){lK=2;lL=lM}else{break}}c[cq>>2]=lL+2;if((wW(b,M,e)|0)==0){cA=1513;break}if((lK|0)==1){c[cp>>2]=(c[cp>>2]|0)==(c[M>>2]|0);continue}else if((lK|0)==2){c[cp>>2]=(c[cp>>2]|0)!=(c[M>>2]|0);continue}else{continue}}if((cA|0)==1513){c[cq>>2]=eL;break}gZ=lM;L2146:while(1){gn=gZ;while(1){lO=b+4+gn|0;gI=a[lO]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[lO]|0;if(gI<<24>>24==38){if((a[gn+1+(b+4)|0]|0)==38){cA=2272;break}else{lP=gn;lQ=38}}else{lP=gn;lQ=gI}while(1){if(!((lQ<<24>>24|0)==13|(lQ<<24>>24|0)==32|(lQ<<24>>24|0)==9|(lQ<<24>>24|0)==10)){break}gI=lP+1|0;lP=gI;lQ=a[b+4+gI|0]|0}c[cq>>2]=lP;if((a[b+4+lP|0]|0)!=38){lR=lP;break}lS=lP+1|0;c[cq>>2]=lS;if((wW(b,ba,e)|0)==0){cA=1541;break}while(1){gn=c[cq>>2]|0;while(1){lT=b+4+gn|0;gI=a[lT]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[lT]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){lU=1;lV=gn}else{lW=gn;lX=61;cA=1532}}else{lW=gn;lX=gI;cA=1532}if((cA|0)==1532){while(1){cA=0;if(!((lX<<24>>24|0)==13|(lX<<24>>24|0)==32|(lX<<24>>24|0)==9|(lX<<24>>24|0)==10)){break}gI=lW+1|0;lW=gI;lX=a[b+4+gI|0]|0;cA=1532}c[cq>>2]=lW;if((a[b+4+lW|0]|0)!=33){break}if((a[lW+1+(b+4)|0]|0)==61){lU=2;lV=lW}else{break}}c[cq>>2]=lV+2;if((wW(b,L,e)|0)==0){cA=1537;break L2146}if((lU|0)==1){c[ba>>2]=(c[ba>>2]|0)==(c[L>>2]|0);continue}else if((lU|0)==2){c[ba>>2]=(c[ba>>2]|0)!=(c[L>>2]|0);continue}else{continue}}c[cp>>2]=c[ba>>2]&c[cp>>2];gZ=lW}if((cA|0)==1537){c[cq>>2]=lS;cA=1541}else if((cA|0)==2272){c[cq>>2]=gZ;lR=gZ}if((cA|0)==1541){c[cq>>2]=eL;break}gn=lR;L2185:while(1){gI=b+4+gn|0;f5=a[gI]|0;if((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10){gn=gn+1|0;continue}c[cq>>2]=gn;if((a[gI]|0)!=94){cA=1546;break}lY=gn+1|0;c[cq>>2]=lY;if((wW(b,bO,e)|0)==0){break}while(1){gI=c[cq>>2]|0;while(1){lZ=b+4+gI|0;f5=a[lZ]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[lZ]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){l_=1;l$=gI}else{l0=gI;l1=61;cA=1553}}else{l0=gI;l1=f5;cA=1553}if((cA|0)==1553){while(1){cA=0;if(!((l1<<24>>24|0)==13|(l1<<24>>24|0)==32|(l1<<24>>24|0)==9|(l1<<24>>24|0)==10)){break}f5=l0+1|0;l0=f5;l1=a[b+4+f5|0]|0;cA=1553}c[cq>>2]=l0;if((a[b+4+l0|0]|0)!=33){l2=l0;break}if((a[l0+1+(b+4)|0]|0)==61){l_=2;l$=l0}else{l2=l0;break}}c[cq>>2]=l$+2;if((wW(b,K,e)|0)==0){cA=1558;break L2185}if((l_|0)==1){c[bO>>2]=(c[bO>>2]|0)==(c[K>>2]|0);continue}else if((l_|0)==2){c[bO>>2]=(c[bO>>2]|0)!=(c[K>>2]|0);continue}else{continue}}while(1){gI=l2;while(1){l3=b+4+gI|0;f5=a[l3]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[l3]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=2271;break}else{l4=gI;l5=38}}else{l4=gI;l5=f5}while(1){if(!((l5<<24>>24|0)==13|(l5<<24>>24|0)==32|(l5<<24>>24|0)==9|(l5<<24>>24|0)==10)){break}f5=l4+1|0;l4=f5;l5=a[b+4+f5|0]|0}c[cq>>2]=l4;if((a[b+4+l4|0]|0)!=38){l6=l4;break}l7=l4+1|0;c[cq>>2]=l7;if((wW(b,a9,e)|0)==0){cA=1585;break L2185}while(1){gI=c[cq>>2]|0;while(1){l8=b+4+gI|0;f5=a[l8]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[l8]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){l9=1;ma=gI}else{mb=gI;mc=61;cA=1576}}else{mb=gI;mc=f5;cA=1576}if((cA|0)==1576){while(1){cA=0;if(!((mc<<24>>24|0)==13|(mc<<24>>24|0)==32|(mc<<24>>24|0)==9|(mc<<24>>24|0)==10)){break}f5=mb+1|0;mb=f5;mc=a[b+4+f5|0]|0;cA=1576}c[cq>>2]=mb;if((a[b+4+mb|0]|0)!=33){break}if((a[mb+1+(b+4)|0]|0)==61){l9=2;ma=mb}else{break}}c[cq>>2]=ma+2;if((wW(b,J,e)|0)==0){cA=1581;break L2185}if((l9|0)==1){c[a9>>2]=(c[a9>>2]|0)==(c[J>>2]|0);continue}else if((l9|0)==2){c[a9>>2]=(c[a9>>2]|0)!=(c[J>>2]|0);continue}else{continue}}c[bO>>2]=c[a9>>2]&c[bO>>2];l2=mb}if((cA|0)==2271){cA=0;c[cq>>2]=l2;l6=l2}c[cp>>2]=c[bO>>2]^c[cp>>2];gn=l6}if((cA|0)==1546){gZ=gn;L2248:while(1){gI=gZ;while(1){md=b+4+gI|0;f5=a[md]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[md]|0;if(f5<<24>>24==124){if((a[gI+1+(b+4)|0]|0)==124){cA=2268;break}else{me=gI;mf=124}}else{me=gI;mf=f5}while(1){if(!((mf<<24>>24|0)==13|(mf<<24>>24|0)==32|(mf<<24>>24|0)==9|(mf<<24>>24|0)==10)){break}f5=me+1|0;me=f5;mf=a[b+4+f5|0]|0}c[cq>>2]=me;if((a[b+4+me|0]|0)!=124){mg=me;cA=1597;break}mh=me+1|0;c[cq>>2]=mh;if((wW(b,b6,e)|0)==0){break}while(1){gI=c[cq>>2]|0;while(1){mi=b+4+gI|0;f5=a[mi]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[mi]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){mj=1;mk=gI}else{ml=gI;mm=61;cA=1604}}else{ml=gI;mm=f5;cA=1604}if((cA|0)==1604){while(1){cA=0;if(!((mm<<24>>24|0)==13|(mm<<24>>24|0)==32|(mm<<24>>24|0)==9|(mm<<24>>24|0)==10)){break}f5=ml+1|0;ml=f5;mm=a[b+4+f5|0]|0;cA=1604}c[cq>>2]=ml;if((a[b+4+ml|0]|0)!=33){mn=ml;break}if((a[ml+1+(b+4)|0]|0)==61){mj=2;mk=ml}else{mn=ml;break}}c[cq>>2]=mk+2;if((wW(b,I,e)|0)==0){cA=1609;break L2248}if((mj|0)==1){c[b6>>2]=(c[b6>>2]|0)==(c[I>>2]|0);continue}else if((mj|0)==2){c[b6>>2]=(c[b6>>2]|0)!=(c[I>>2]|0);continue}else{continue}}while(1){gI=mn;while(1){mo=b+4+gI|0;f5=a[mo]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[mo]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=2269;break}else{mp=gI;mq=38}}else{mp=gI;mq=f5}while(1){if(!((mq<<24>>24|0)==13|(mq<<24>>24|0)==32|(mq<<24>>24|0)==9|(mq<<24>>24|0)==10)){break}f5=mp+1|0;mp=f5;mq=a[b+4+f5|0]|0}c[cq>>2]=mp;if((a[b+4+mp|0]|0)!=38){mr=mp;break}ms=mp+1|0;c[cq>>2]=ms;if((wW(b,a8,e)|0)==0){cA=1636;break L2248}while(1){gI=c[cq>>2]|0;while(1){mt=b+4+gI|0;f5=a[mt]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[mt]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){mu=1;mv=gI}else{mw=gI;mx=61;cA=1627}}else{mw=gI;mx=f5;cA=1627}if((cA|0)==1627){while(1){cA=0;if(!((mx<<24>>24|0)==13|(mx<<24>>24|0)==32|(mx<<24>>24|0)==9|(mx<<24>>24|0)==10)){break}f5=mw+1|0;mw=f5;mx=a[b+4+f5|0]|0;cA=1627}c[cq>>2]=mw;if((a[b+4+mw|0]|0)!=33){break}if((a[mw+1+(b+4)|0]|0)==61){mu=2;mv=mw}else{break}}c[cq>>2]=mv+2;if((wW(b,H,e)|0)==0){cA=1632;break L2248}if((mu|0)==1){c[a8>>2]=(c[a8>>2]|0)==(c[H>>2]|0);continue}else if((mu|0)==2){c[a8>>2]=(c[a8>>2]|0)!=(c[H>>2]|0);continue}else{continue}}c[b6>>2]=c[a8>>2]&c[b6>>2];mn=mw}if((cA|0)==2269){cA=0;c[cq>>2]=mn;mr=mn}while(1){gI=b+4+mr|0;f5=a[gI]|0;if((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10){mr=mr+1|0;continue}c[cq>>2]=mr;if((a[gI]|0)!=94){break}my=mr+1|0;c[cq>>2]=my;if((wW(b,bN,e)|0)==0){cA=1681;break L2248}while(1){gI=c[cq>>2]|0;while(1){mz=b+4+gI|0;f5=a[mz]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[mz]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){mA=1;mB=gI}else{mC=gI;mD=61;cA=1647}}else{mC=gI;mD=f5;cA=1647}if((cA|0)==1647){while(1){cA=0;if(!((mD<<24>>24|0)==13|(mD<<24>>24|0)==32|(mD<<24>>24|0)==9|(mD<<24>>24|0)==10)){break}f5=mC+1|0;mC=f5;mD=a[b+4+f5|0]|0;cA=1647}c[cq>>2]=mC;if((a[b+4+mC|0]|0)!=33){mE=mC;break}if((a[mC+1+(b+4)|0]|0)==61){mA=2;mB=mC}else{mE=mC;break}}c[cq>>2]=mB+2;if((wW(b,G,e)|0)==0){cA=1652;break L2248}if((mA|0)==1){c[bN>>2]=(c[bN>>2]|0)==(c[G>>2]|0);continue}else if((mA|0)==2){c[bN>>2]=(c[bN>>2]|0)!=(c[G>>2]|0);continue}else{continue}}while(1){gI=mE;while(1){mF=b+4+gI|0;f5=a[mF]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[mF]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=2270;break}else{mG=gI;mH=38}}else{mG=gI;mH=f5}while(1){if(!((mH<<24>>24|0)==13|(mH<<24>>24|0)==32|(mH<<24>>24|0)==9|(mH<<24>>24|0)==10)){break}f5=mG+1|0;mG=f5;mH=a[b+4+f5|0]|0}c[cq>>2]=mG;if((a[b+4+mG|0]|0)!=38){mI=mG;break}mJ=mG+1|0;c[cq>>2]=mJ;if((wW(b,a7,e)|0)==0){cA=1679;break L2248}while(1){gI=c[cq>>2]|0;while(1){mK=b+4+gI|0;f5=a[mK]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[mK]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){mL=1;mM=gI}else{mN=gI;mO=61;cA=1670}}else{mN=gI;mO=f5;cA=1670}if((cA|0)==1670){while(1){cA=0;if(!((mO<<24>>24|0)==13|(mO<<24>>24|0)==32|(mO<<24>>24|0)==9|(mO<<24>>24|0)==10)){break}f5=mN+1|0;mN=f5;mO=a[b+4+f5|0]|0;cA=1670}c[cq>>2]=mN;if((a[b+4+mN|0]|0)!=33){break}if((a[mN+1+(b+4)|0]|0)==61){mL=2;mM=mN}else{break}}c[cq>>2]=mM+2;if((wW(b,F,e)|0)==0){cA=1675;break L2248}if((mL|0)==1){c[a7>>2]=(c[a7>>2]|0)==(c[F>>2]|0);continue}else if((mL|0)==2){c[a7>>2]=(c[a7>>2]|0)!=(c[F>>2]|0);continue}else{continue}}c[bN>>2]=c[a7>>2]&c[bN>>2];mE=mN}if((cA|0)==2270){cA=0;c[cq>>2]=mE;mI=mE}c[b6>>2]=c[bN>>2]^c[b6>>2];mr=mI}c[cp>>2]=c[b6>>2]|c[cp>>2];gZ=mr}if((cA|0)==1609){c[cq>>2]=mh}else if((cA|0)==1632){c[cq>>2]=ms;cA=1636}else if((cA|0)==1652){c[cq>>2]=my;cA=1681}else if((cA|0)==1675){c[cq>>2]=mJ;cA=1679}else if((cA|0)==2268){c[cq>>2]=gZ;mg=gZ;cA=1597}if((cA|0)==1597){gn=mg;L2385:while(1){gI=b+4+gn|0;f5=a[gI]|0;if((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10){gn=gn+1|0;continue}c[cq>>2]=gn;if((a[gI]|0)!=38){cA=1688;break}if((a[gn+1+(b+4)|0]|0)!=38){cA=1688;break}mP=gn+2|0;c[cq>>2]=mP;if((wW(b,cg,e)|0)==0){break}while(1){gI=c[cq>>2]|0;while(1){mQ=b+4+gI|0;f5=a[mQ]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[mQ]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){mR=1;mS=gI}else{mT=gI;mU=61;cA=1695}}else{mT=gI;mU=f5;cA=1695}if((cA|0)==1695){while(1){cA=0;if(!((mU<<24>>24|0)==13|(mU<<24>>24|0)==32|(mU<<24>>24|0)==9|(mU<<24>>24|0)==10)){break}f5=mT+1|0;mT=f5;mU=a[b+4+f5|0]|0;cA=1695}c[cq>>2]=mT;if((a[b+4+mT|0]|0)!=33){mV=mT;break}if((a[mT+1+(b+4)|0]|0)==61){mR=2;mS=mT}else{mV=mT;break}}c[cq>>2]=mS+2;if((wW(b,E,e)|0)==0){cA=1700;break L2385}if((mR|0)==1){c[cg>>2]=(c[cg>>2]|0)==(c[E>>2]|0);continue}else if((mR|0)==2){c[cg>>2]=(c[cg>>2]|0)!=(c[E>>2]|0);continue}else{continue}}while(1){gI=mV;while(1){mW=b+4+gI|0;f5=a[mW]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[mW]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=2263;break}else{mX=gI;mY=38}}else{mX=gI;mY=f5}while(1){if(!((mY<<24>>24|0)==13|(mY<<24>>24|0)==32|(mY<<24>>24|0)==9|(mY<<24>>24|0)==10)){break}f5=mX+1|0;mX=f5;mY=a[b+4+f5|0]|0}c[cq>>2]=mX;if((a[b+4+mX|0]|0)!=38){mZ=mX;break}m_=mX+1|0;c[cq>>2]=m_;if((wW(b,a6,e)|0)==0){cA=1727;break L2385}while(1){gI=c[cq>>2]|0;while(1){m$=b+4+gI|0;f5=a[m$]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[m$]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){m0=1;m1=gI}else{m2=gI;m3=61;cA=1718}}else{m2=gI;m3=f5;cA=1718}if((cA|0)==1718){while(1){cA=0;if(!((m3<<24>>24|0)==13|(m3<<24>>24|0)==32|(m3<<24>>24|0)==9|(m3<<24>>24|0)==10)){break}f5=m2+1|0;m2=f5;m3=a[b+4+f5|0]|0;cA=1718}c[cq>>2]=m2;if((a[b+4+m2|0]|0)!=33){break}if((a[m2+1+(b+4)|0]|0)==61){m0=2;m1=m2}else{break}}c[cq>>2]=m1+2;if((wW(b,D,e)|0)==0){cA=1723;break L2385}if((m0|0)==1){c[a6>>2]=(c[a6>>2]|0)==(c[D>>2]|0);continue}else if((m0|0)==2){c[a6>>2]=(c[a6>>2]|0)!=(c[D>>2]|0);continue}else{continue}}c[cg>>2]=c[a6>>2]&c[cg>>2];mV=m2}if((cA|0)==2263){cA=0;c[cq>>2]=mV;mZ=mV}while(1){gI=b+4+mZ|0;f5=a[gI]|0;if((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10){mZ=mZ+1|0;continue}c[cq>>2]=mZ;if((a[gI]|0)!=94){m4=mZ;break}m5=mZ+1|0;c[cq>>2]=m5;if((wW(b,bM,e)|0)==0){cA=1772;break L2385}while(1){gI=c[cq>>2]|0;while(1){m6=b+4+gI|0;f5=a[m6]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[m6]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){m7=1;m8=gI}else{m9=gI;na=61;cA=1738}}else{m9=gI;na=f5;cA=1738}if((cA|0)==1738){while(1){cA=0;if(!((na<<24>>24|0)==13|(na<<24>>24|0)==32|(na<<24>>24|0)==9|(na<<24>>24|0)==10)){break}f5=m9+1|0;m9=f5;na=a[b+4+f5|0]|0;cA=1738}c[cq>>2]=m9;if((a[b+4+m9|0]|0)!=33){nb=m9;break}if((a[m9+1+(b+4)|0]|0)==61){m7=2;m8=m9}else{nb=m9;break}}c[cq>>2]=m8+2;if((wW(b,C,e)|0)==0){cA=1743;break L2385}if((m7|0)==1){c[bM>>2]=(c[bM>>2]|0)==(c[C>>2]|0);continue}else if((m7|0)==2){c[bM>>2]=(c[bM>>2]|0)!=(c[C>>2]|0);continue}else{continue}}while(1){gI=nb;while(1){nc=b+4+gI|0;f5=a[nc]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[nc]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=2264;break}else{nd=gI;ne=38}}else{nd=gI;ne=f5}while(1){if(!((ne<<24>>24|0)==13|(ne<<24>>24|0)==32|(ne<<24>>24|0)==9|(ne<<24>>24|0)==10)){break}f5=nd+1|0;nd=f5;ne=a[b+4+f5|0]|0}c[cq>>2]=nd;if((a[b+4+nd|0]|0)!=38){nf=nd;break}ng=nd+1|0;c[cq>>2]=ng;if((wW(b,a5,e)|0)==0){cA=1770;break L2385}while(1){gI=c[cq>>2]|0;while(1){nh=b+4+gI|0;f5=a[nh]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[nh]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){ni=1;nj=gI}else{nk=gI;nl=61;cA=1761}}else{nk=gI;nl=f5;cA=1761}if((cA|0)==1761){while(1){cA=0;if(!((nl<<24>>24|0)==13|(nl<<24>>24|0)==32|(nl<<24>>24|0)==9|(nl<<24>>24|0)==10)){break}f5=nk+1|0;nk=f5;nl=a[b+4+f5|0]|0;cA=1761}c[cq>>2]=nk;if((a[b+4+nk|0]|0)!=33){break}if((a[nk+1+(b+4)|0]|0)==61){ni=2;nj=nk}else{break}}c[cq>>2]=nj+2;if((wW(b,B,e)|0)==0){cA=1766;break L2385}if((ni|0)==1){c[a5>>2]=(c[a5>>2]|0)==(c[B>>2]|0);continue}else if((ni|0)==2){c[a5>>2]=(c[a5>>2]|0)!=(c[B>>2]|0);continue}else{continue}}c[bM>>2]=c[a5>>2]&c[bM>>2];nb=nk}if((cA|0)==2264){cA=0;c[cq>>2]=nb;nf=nb}c[cg>>2]=c[bM>>2]^c[cg>>2];mZ=nf}while(1){gI=m4;while(1){nm=b+4+gI|0;f5=a[nm]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[nm]|0;if(f5<<24>>24==124){if((a[gI+1+(b+4)|0]|0)==124){cA=2265;break}else{nn=gI;no=124}}else{nn=gI;no=f5}while(1){if(!((no<<24>>24|0)==13|(no<<24>>24|0)==32|(no<<24>>24|0)==9|(no<<24>>24|0)==10)){break}f5=nn+1|0;nn=f5;no=a[b+4+f5|0]|0}c[cq>>2]=nn;if((a[b+4+nn|0]|0)!=124){np=nn;break}nq=nn+1|0;c[cq>>2]=nq;if((wW(b,b5,e)|0)==0){cA=1867;break L2385}while(1){gI=c[cq>>2]|0;while(1){nr=b+4+gI|0;f5=a[nr]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[nr]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){ns=1;nt=gI}else{nu=gI;nv=61;cA=1788}}else{nu=gI;nv=f5;cA=1788}if((cA|0)==1788){while(1){cA=0;if(!((nv<<24>>24|0)==13|(nv<<24>>24|0)==32|(nv<<24>>24|0)==9|(nv<<24>>24|0)==10)){break}f5=nu+1|0;nu=f5;nv=a[b+4+f5|0]|0;cA=1788}c[cq>>2]=nu;if((a[b+4+nu|0]|0)!=33){nw=nu;break}if((a[nu+1+(b+4)|0]|0)==61){ns=2;nt=nu}else{nw=nu;break}}c[cq>>2]=nt+2;if((wW(b,A,e)|0)==0){cA=1793;break L2385}if((ns|0)==1){c[b5>>2]=(c[b5>>2]|0)==(c[A>>2]|0);continue}else if((ns|0)==2){c[b5>>2]=(c[b5>>2]|0)!=(c[A>>2]|0);continue}else{continue}}while(1){gI=nw;while(1){nx=b+4+gI|0;f5=a[nx]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[nx]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=2266;break}else{ny=gI;nz=38}}else{ny=gI;nz=f5}while(1){if(!((nz<<24>>24|0)==13|(nz<<24>>24|0)==32|(nz<<24>>24|0)==9|(nz<<24>>24|0)==10)){break}f5=ny+1|0;ny=f5;nz=a[b+4+f5|0]|0}c[cq>>2]=ny;if((a[b+4+ny|0]|0)!=38){nA=ny;break}nB=ny+1|0;c[cq>>2]=nB;if((wW(b,a4,e)|0)==0){cA=1820;break L2385}while(1){gI=c[cq>>2]|0;while(1){nC=b+4+gI|0;f5=a[nC]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[nC]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){nD=1;nE=gI}else{nF=gI;nG=61;cA=1811}}else{nF=gI;nG=f5;cA=1811}if((cA|0)==1811){while(1){cA=0;if(!((nG<<24>>24|0)==13|(nG<<24>>24|0)==32|(nG<<24>>24|0)==9|(nG<<24>>24|0)==10)){break}f5=nF+1|0;nF=f5;nG=a[b+4+f5|0]|0;cA=1811}c[cq>>2]=nF;if((a[b+4+nF|0]|0)!=33){break}if((a[nF+1+(b+4)|0]|0)==61){nD=2;nE=nF}else{break}}c[cq>>2]=nE+2;if((wW(b,z,e)|0)==0){cA=1816;break L2385}if((nD|0)==1){c[a4>>2]=(c[a4>>2]|0)==(c[z>>2]|0);continue}else if((nD|0)==2){c[a4>>2]=(c[a4>>2]|0)!=(c[z>>2]|0);continue}else{continue}}c[b5>>2]=c[a4>>2]&c[b5>>2];nw=nF}if((cA|0)==2266){cA=0;c[cq>>2]=nw;nA=nw}while(1){gI=b+4+nA|0;f5=a[gI]|0;if((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10){nA=nA+1|0;continue}c[cq>>2]=nA;if((a[gI]|0)!=94){break}nH=nA+1|0;c[cq>>2]=nH;if((wW(b,bL,e)|0)==0){cA=1865;break L2385}while(1){gI=c[cq>>2]|0;while(1){nI=b+4+gI|0;f5=a[nI]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[nI]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){nJ=1;nK=gI}else{nL=gI;nM=61;cA=1831}}else{nL=gI;nM=f5;cA=1831}if((cA|0)==1831){while(1){cA=0;if(!((nM<<24>>24|0)==13|(nM<<24>>24|0)==32|(nM<<24>>24|0)==9|(nM<<24>>24|0)==10)){break}f5=nL+1|0;nL=f5;nM=a[b+4+f5|0]|0;cA=1831}c[cq>>2]=nL;if((a[b+4+nL|0]|0)!=33){nN=nL;break}if((a[nL+1+(b+4)|0]|0)==61){nJ=2;nK=nL}else{nN=nL;break}}c[cq>>2]=nK+2;if((wW(b,y,e)|0)==0){cA=1836;break L2385}if((nJ|0)==1){c[bL>>2]=(c[bL>>2]|0)==(c[y>>2]|0);continue}else if((nJ|0)==2){c[bL>>2]=(c[bL>>2]|0)!=(c[y>>2]|0);continue}else{continue}}while(1){gI=nN;while(1){nO=b+4+gI|0;f5=a[nO]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[nO]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=2267;break}else{nP=gI;nQ=38}}else{nP=gI;nQ=f5}while(1){if(!((nQ<<24>>24|0)==13|(nQ<<24>>24|0)==32|(nQ<<24>>24|0)==9|(nQ<<24>>24|0)==10)){break}f5=nP+1|0;nP=f5;nQ=a[b+4+f5|0]|0}c[cq>>2]=nP;if((a[b+4+nP|0]|0)!=38){nR=nP;break}nS=nP+1|0;c[cq>>2]=nS;if((wW(b,a3,e)|0)==0){cA=1863;break L2385}while(1){gI=c[cq>>2]|0;while(1){nT=b+4+gI|0;f5=a[nT]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[nT]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){nU=1;nV=gI}else{nW=gI;nX=61;cA=1854}}else{nW=gI;nX=f5;cA=1854}if((cA|0)==1854){while(1){cA=0;if(!((nX<<24>>24|0)==13|(nX<<24>>24|0)==32|(nX<<24>>24|0)==9|(nX<<24>>24|0)==10)){break}f5=nW+1|0;nW=f5;nX=a[b+4+f5|0]|0;cA=1854}c[cq>>2]=nW;if((a[b+4+nW|0]|0)!=33){break}if((a[nW+1+(b+4)|0]|0)==61){nU=2;nV=nW}else{break}}c[cq>>2]=nV+2;if((wW(b,x,e)|0)==0){cA=1859;break L2385}if((nU|0)==1){c[a3>>2]=(c[a3>>2]|0)==(c[x>>2]|0);continue}else if((nU|0)==2){c[a3>>2]=(c[a3>>2]|0)!=(c[x>>2]|0);continue}else{continue}}c[bL>>2]=c[a3>>2]&c[bL>>2];nN=nW}if((cA|0)==2267){cA=0;c[cq>>2]=nN;nR=nN}c[b5>>2]=c[bL>>2]^c[b5>>2];nA=nR}c[cg>>2]=c[b5>>2]|c[cg>>2];m4=nA}if((cA|0)==2265){cA=0;c[cq>>2]=m4;np=m4}if((c[cp>>2]|0)==0){nY=0}else{nY=(c[cg>>2]|0)!=0|0}c[cp>>2]=nY;gn=np}if((cA|0)==1688){gZ=gn;L2644:while(1){gI=b+4+gZ|0;f5=a[gI]|0;if((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10){gZ=gZ+1|0;continue}c[cq>>2]=gZ;if((a[gI]|0)!=124){cA=2248;break}if((a[gZ+1+(b+4)|0]|0)!=124){cA=2248;break}nZ=gZ+2|0;c[cq>>2]=nZ;if((wW(b,cl,e)|0)==0){break}while(1){gI=c[cq>>2]|0;while(1){n_=b+4+gI|0;f5=a[n_]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[n_]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){n$=1;n0=gI}else{n1=gI;n2=61;cA=1882}}else{n1=gI;n2=f5;cA=1882}if((cA|0)==1882){while(1){cA=0;if(!((n2<<24>>24|0)==13|(n2<<24>>24|0)==32|(n2<<24>>24|0)==9|(n2<<24>>24|0)==10)){break}f5=n1+1|0;n1=f5;n2=a[b+4+f5|0]|0;cA=1882}c[cq>>2]=n1;if((a[b+4+n1|0]|0)!=33){n3=n1;break}if((a[n1+1+(b+4)|0]|0)==61){n$=2;n0=n1}else{n3=n1;break}}c[cq>>2]=n0+2;if((wW(b,w,e)|0)==0){cA=1887;break L2644}if((n$|0)==1){c[cl>>2]=(c[cl>>2]|0)==(c[w>>2]|0);continue}else if((n$|0)==2){c[cl>>2]=(c[cl>>2]|0)!=(c[w>>2]|0);continue}else{continue}}while(1){gI=n3;while(1){n4=b+4+gI|0;f5=a[n4]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[n4]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=2251;break}else{n5=gI;n6=38}}else{n5=gI;n6=f5}while(1){if(!((n6<<24>>24|0)==13|(n6<<24>>24|0)==32|(n6<<24>>24|0)==9|(n6<<24>>24|0)==10)){break}f5=n5+1|0;n5=f5;n6=a[b+4+f5|0]|0}c[cq>>2]=n5;if((a[b+4+n5|0]|0)!=38){n7=n5;break}n8=n5+1|0;c[cq>>2]=n8;if((wW(b,a2,e)|0)==0){cA=1914;break L2644}while(1){gI=c[cq>>2]|0;while(1){n9=b+4+gI|0;f5=a[n9]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[n9]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){oa=1;ob=gI}else{oc=gI;od=61;cA=1905}}else{oc=gI;od=f5;cA=1905}if((cA|0)==1905){while(1){cA=0;if(!((od<<24>>24|0)==13|(od<<24>>24|0)==32|(od<<24>>24|0)==9|(od<<24>>24|0)==10)){break}f5=oc+1|0;oc=f5;od=a[b+4+f5|0]|0;cA=1905}c[cq>>2]=oc;if((a[b+4+oc|0]|0)!=33){break}if((a[oc+1+(b+4)|0]|0)==61){oa=2;ob=oc}else{break}}c[cq>>2]=ob+2;if((wW(b,v,e)|0)==0){cA=1910;break L2644}if((oa|0)==1){c[a2>>2]=(c[a2>>2]|0)==(c[v>>2]|0);continue}else if((oa|0)==2){c[a2>>2]=(c[a2>>2]|0)!=(c[v>>2]|0);continue}else{continue}}c[cl>>2]=c[a2>>2]&c[cl>>2];n3=oc}if((cA|0)==2251){cA=0;c[cq>>2]=n3;n7=n3}while(1){gI=b+4+n7|0;f5=a[gI]|0;if((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10){n7=n7+1|0;continue}c[cq>>2]=n7;if((a[gI]|0)!=94){oe=n7;break}of=n7+1|0;c[cq>>2]=of;if((wW(b,bK,e)|0)==0){cA=1959;break L2644}while(1){gI=c[cq>>2]|0;while(1){og=b+4+gI|0;f5=a[og]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[og]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){oh=1;oi=gI}else{oj=gI;ok=61;cA=1925}}else{oj=gI;ok=f5;cA=1925}if((cA|0)==1925){while(1){cA=0;if(!((ok<<24>>24|0)==13|(ok<<24>>24|0)==32|(ok<<24>>24|0)==9|(ok<<24>>24|0)==10)){break}f5=oj+1|0;oj=f5;ok=a[b+4+f5|0]|0;cA=1925}c[cq>>2]=oj;if((a[b+4+oj|0]|0)!=33){ol=oj;break}if((a[oj+1+(b+4)|0]|0)==61){oh=2;oi=oj}else{ol=oj;break}}c[cq>>2]=oi+2;if((wW(b,u,e)|0)==0){cA=1930;break L2644}if((oh|0)==1){c[bK>>2]=(c[bK>>2]|0)==(c[u>>2]|0);continue}else if((oh|0)==2){c[bK>>2]=(c[bK>>2]|0)!=(c[u>>2]|0);continue}else{continue}}while(1){gI=ol;while(1){om=b+4+gI|0;f5=a[om]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[om]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=2252;break}else{on=gI;oo=38}}else{on=gI;oo=f5}while(1){if(!((oo<<24>>24|0)==13|(oo<<24>>24|0)==32|(oo<<24>>24|0)==9|(oo<<24>>24|0)==10)){break}f5=on+1|0;on=f5;oo=a[b+4+f5|0]|0}c[cq>>2]=on;if((a[b+4+on|0]|0)!=38){op=on;break}oq=on+1|0;c[cq>>2]=oq;if((wW(b,a1,e)|0)==0){cA=1957;break L2644}while(1){gI=c[cq>>2]|0;while(1){or=b+4+gI|0;f5=a[or]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[or]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){os=1;ot=gI}else{ou=gI;ov=61;cA=1948}}else{ou=gI;ov=f5;cA=1948}if((cA|0)==1948){while(1){cA=0;if(!((ov<<24>>24|0)==13|(ov<<24>>24|0)==32|(ov<<24>>24|0)==9|(ov<<24>>24|0)==10)){break}f5=ou+1|0;ou=f5;ov=a[b+4+f5|0]|0;cA=1948}c[cq>>2]=ou;if((a[b+4+ou|0]|0)!=33){break}if((a[ou+1+(b+4)|0]|0)==61){os=2;ot=ou}else{break}}c[cq>>2]=ot+2;if((wW(b,t,e)|0)==0){cA=1953;break L2644}if((os|0)==1){c[a1>>2]=(c[a1>>2]|0)==(c[t>>2]|0);continue}else if((os|0)==2){c[a1>>2]=(c[a1>>2]|0)!=(c[t>>2]|0);continue}else{continue}}c[bK>>2]=c[a1>>2]&c[bK>>2];ol=ou}if((cA|0)==2252){cA=0;c[cq>>2]=ol;op=ol}c[cl>>2]=c[bK>>2]^c[cl>>2];n7=op}while(1){gI=oe;while(1){ow=b+4+gI|0;f5=a[ow]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[ow]|0;if(f5<<24>>24==124){if((a[gI+1+(b+4)|0]|0)==124){cA=2253;break}else{ox=gI;oy=124}}else{ox=gI;oy=f5}while(1){if(!((oy<<24>>24|0)==13|(oy<<24>>24|0)==32|(oy<<24>>24|0)==9|(oy<<24>>24|0)==10)){break}f5=ox+1|0;ox=f5;oy=a[b+4+f5|0]|0}c[cq>>2]=ox;if((a[b+4+ox|0]|0)!=124){oz=ox;break}oA=ox+1|0;c[cq>>2]=oA;if((wW(b,b4,e)|0)==0){cA=2054;break L2644}while(1){gI=c[cq>>2]|0;while(1){oB=b+4+gI|0;f5=a[oB]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[oB]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){oC=1;oD=gI}else{oE=gI;oF=61;cA=1975}}else{oE=gI;oF=f5;cA=1975}if((cA|0)==1975){while(1){cA=0;if(!((oF<<24>>24|0)==13|(oF<<24>>24|0)==32|(oF<<24>>24|0)==9|(oF<<24>>24|0)==10)){break}f5=oE+1|0;oE=f5;oF=a[b+4+f5|0]|0;cA=1975}c[cq>>2]=oE;if((a[b+4+oE|0]|0)!=33){oG=oE;break}if((a[oE+1+(b+4)|0]|0)==61){oC=2;oD=oE}else{oG=oE;break}}c[cq>>2]=oD+2;if((wW(b,s,e)|0)==0){cA=1980;break L2644}if((oC|0)==1){c[b4>>2]=(c[b4>>2]|0)==(c[s>>2]|0);continue}else if((oC|0)==2){c[b4>>2]=(c[b4>>2]|0)!=(c[s>>2]|0);continue}else{continue}}while(1){gI=oG;while(1){oH=b+4+gI|0;f5=a[oH]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[oH]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=2254;break}else{oI=gI;oJ=38}}else{oI=gI;oJ=f5}while(1){if(!((oJ<<24>>24|0)==13|(oJ<<24>>24|0)==32|(oJ<<24>>24|0)==9|(oJ<<24>>24|0)==10)){break}f5=oI+1|0;oI=f5;oJ=a[b+4+f5|0]|0}c[cq>>2]=oI;if((a[b+4+oI|0]|0)!=38){oK=oI;break}oL=oI+1|0;c[cq>>2]=oL;if((wW(b,a0,e)|0)==0){cA=2007;break L2644}while(1){gI=c[cq>>2]|0;while(1){oM=b+4+gI|0;f5=a[oM]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[oM]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){oN=1;oO=gI}else{oP=gI;oQ=61;cA=1998}}else{oP=gI;oQ=f5;cA=1998}if((cA|0)==1998){while(1){cA=0;if(!((oQ<<24>>24|0)==13|(oQ<<24>>24|0)==32|(oQ<<24>>24|0)==9|(oQ<<24>>24|0)==10)){break}f5=oP+1|0;oP=f5;oQ=a[b+4+f5|0]|0;cA=1998}c[cq>>2]=oP;if((a[b+4+oP|0]|0)!=33){break}if((a[oP+1+(b+4)|0]|0)==61){oN=2;oO=oP}else{break}}c[cq>>2]=oO+2;if((wW(b,r,e)|0)==0){cA=2003;break L2644}if((oN|0)==1){c[a0>>2]=(c[a0>>2]|0)==(c[r>>2]|0);continue}else if((oN|0)==2){c[a0>>2]=(c[a0>>2]|0)!=(c[r>>2]|0);continue}else{continue}}c[b4>>2]=c[a0>>2]&c[b4>>2];oG=oP}if((cA|0)==2254){cA=0;c[cq>>2]=oG;oK=oG}while(1){gI=b+4+oK|0;f5=a[gI]|0;if((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10){oK=oK+1|0;continue}c[cq>>2]=oK;if((a[gI]|0)!=94){break}oR=oK+1|0;c[cq>>2]=oR;if((wW(b,bJ,e)|0)==0){cA=2052;break L2644}while(1){gI=c[cq>>2]|0;while(1){oS=b+4+gI|0;f5=a[oS]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[oS]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){oT=1;oU=gI}else{oV=gI;oW=61;cA=2018}}else{oV=gI;oW=f5;cA=2018}if((cA|0)==2018){while(1){cA=0;if(!((oW<<24>>24|0)==13|(oW<<24>>24|0)==32|(oW<<24>>24|0)==9|(oW<<24>>24|0)==10)){break}f5=oV+1|0;oV=f5;oW=a[b+4+f5|0]|0;cA=2018}c[cq>>2]=oV;if((a[b+4+oV|0]|0)!=33){oX=oV;break}if((a[oV+1+(b+4)|0]|0)==61){oT=2;oU=oV}else{oX=oV;break}}c[cq>>2]=oU+2;if((wW(b,q,e)|0)==0){cA=2023;break L2644}if((oT|0)==1){c[bJ>>2]=(c[bJ>>2]|0)==(c[q>>2]|0);continue}else if((oT|0)==2){c[bJ>>2]=(c[bJ>>2]|0)!=(c[q>>2]|0);continue}else{continue}}while(1){gI=oX;while(1){oY=b+4+gI|0;f5=a[oY]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[oY]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=2255;break}else{oZ=gI;o_=38}}else{oZ=gI;o_=f5}while(1){if(!((o_<<24>>24|0)==13|(o_<<24>>24|0)==32|(o_<<24>>24|0)==9|(o_<<24>>24|0)==10)){break}f5=oZ+1|0;oZ=f5;o_=a[b+4+f5|0]|0}c[cq>>2]=oZ;if((a[b+4+oZ|0]|0)!=38){o$=oZ;break}o0=oZ+1|0;c[cq>>2]=o0;if((wW(b,a$,e)|0)==0){cA=2050;break L2644}while(1){gI=c[cq>>2]|0;while(1){o1=b+4+gI|0;f5=a[o1]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[o1]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){o2=1;o3=gI}else{o4=gI;o5=61;cA=2041}}else{o4=gI;o5=f5;cA=2041}if((cA|0)==2041){while(1){cA=0;if(!((o5<<24>>24|0)==13|(o5<<24>>24|0)==32|(o5<<24>>24|0)==9|(o5<<24>>24|0)==10)){break}f5=o4+1|0;o4=f5;o5=a[b+4+f5|0]|0;cA=2041}c[cq>>2]=o4;if((a[b+4+o4|0]|0)!=33){break}if((a[o4+1+(b+4)|0]|0)==61){o2=2;o3=o4}else{break}}c[cq>>2]=o3+2;if((wW(b,p,e)|0)==0){cA=2046;break L2644}if((o2|0)==1){c[a$>>2]=(c[a$>>2]|0)==(c[p>>2]|0);continue}else if((o2|0)==2){c[a$>>2]=(c[a$>>2]|0)!=(c[p>>2]|0);continue}else{continue}}c[bJ>>2]=c[a$>>2]&c[bJ>>2];oX=o4}if((cA|0)==2255){cA=0;c[cq>>2]=oX;o$=oX}c[b4>>2]=c[bJ>>2]^c[b4>>2];oK=o$}c[cl>>2]=c[b4>>2]|c[cl>>2];oe=oK}if((cA|0)==2253){cA=0;c[cq>>2]=oe;oz=oe}while(1){gI=b+4+oz|0;f5=a[gI]|0;if((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10){oz=oz+1|0;continue}c[cq>>2]=oz;if((a[gI]|0)!=38){break}if((a[oz+1+(b+4)|0]|0)!=38){break}o6=oz+2|0;c[cq>>2]=o6;if((wW(b,cf,e)|0)==0){cA=2239;break L2644}while(1){gI=c[cq>>2]|0;while(1){o7=b+4+gI|0;f5=a[o7]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[o7]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){o8=1;o9=gI}else{pa=gI;pb=61;cA=2065}}else{pa=gI;pb=f5;cA=2065}if((cA|0)==2065){while(1){cA=0;if(!((pb<<24>>24|0)==13|(pb<<24>>24|0)==32|(pb<<24>>24|0)==9|(pb<<24>>24|0)==10)){break}f5=pa+1|0;pa=f5;pb=a[b+4+f5|0]|0;cA=2065}c[cq>>2]=pa;if((a[b+4+pa|0]|0)!=33){pc=pa;break}if((a[pa+1+(b+4)|0]|0)==61){o8=2;o9=pa}else{pc=pa;break}}c[cq>>2]=o9+2;if((wW(b,o,e)|0)==0){cA=2070;break L2644}if((o8|0)==1){c[cf>>2]=(c[cf>>2]|0)==(c[o>>2]|0);continue}else if((o8|0)==2){c[cf>>2]=(c[cf>>2]|0)!=(c[o>>2]|0);continue}else{continue}}while(1){gI=pc;while(1){pd=b+4+gI|0;f5=a[pd]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[pd]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=2257;break}else{pe=gI;pf=38}}else{pe=gI;pf=f5}while(1){if(!((pf<<24>>24|0)==13|(pf<<24>>24|0)==32|(pf<<24>>24|0)==9|(pf<<24>>24|0)==10)){break}f5=pe+1|0;pe=f5;pf=a[b+4+f5|0]|0}c[cq>>2]=pe;if((a[b+4+pe|0]|0)!=38){pg=pe;break}ph=pe+1|0;c[cq>>2]=ph;if((wW(b,a_,e)|0)==0){cA=2097;break L2644}while(1){gI=c[cq>>2]|0;while(1){pi=b+4+gI|0;f5=a[pi]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[pi]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){pj=1;pk=gI}else{pl=gI;pm=61;cA=2088}}else{pl=gI;pm=f5;cA=2088}if((cA|0)==2088){while(1){cA=0;if(!((pm<<24>>24|0)==13|(pm<<24>>24|0)==32|(pm<<24>>24|0)==9|(pm<<24>>24|0)==10)){break}f5=pl+1|0;pl=f5;pm=a[b+4+f5|0]|0;cA=2088}c[cq>>2]=pl;if((a[b+4+pl|0]|0)!=33){break}if((a[pl+1+(b+4)|0]|0)==61){pj=2;pk=pl}else{break}}c[cq>>2]=pk+2;if((wW(b,n,e)|0)==0){cA=2093;break L2644}if((pj|0)==1){c[a_>>2]=(c[a_>>2]|0)==(c[n>>2]|0);continue}else if((pj|0)==2){c[a_>>2]=(c[a_>>2]|0)!=(c[n>>2]|0);continue}else{continue}}c[cf>>2]=c[a_>>2]&c[cf>>2];pc=pl}if((cA|0)==2257){cA=0;c[cq>>2]=pc;pg=pc}while(1){gI=b+4+pg|0;f5=a[gI]|0;if((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10){pg=pg+1|0;continue}c[cq>>2]=pg;if((a[gI]|0)!=94){pn=pg;break}po=pg+1|0;c[cq>>2]=po;if((wW(b,bI,e)|0)==0){cA=2142;break L2644}while(1){gI=c[cq>>2]|0;while(1){pp=b+4+gI|0;f5=a[pp]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[pp]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){pq=1;pr=gI}else{ps=gI;pt=61;cA=2108}}else{ps=gI;pt=f5;cA=2108}if((cA|0)==2108){while(1){cA=0;if(!((pt<<24>>24|0)==13|(pt<<24>>24|0)==32|(pt<<24>>24|0)==9|(pt<<24>>24|0)==10)){break}f5=ps+1|0;ps=f5;pt=a[b+4+f5|0]|0;cA=2108}c[cq>>2]=ps;if((a[b+4+ps|0]|0)!=33){pu=ps;break}if((a[ps+1+(b+4)|0]|0)==61){pq=2;pr=ps}else{pu=ps;break}}c[cq>>2]=pr+2;if((wW(b,m,e)|0)==0){cA=2113;break L2644}if((pq|0)==1){c[bI>>2]=(c[bI>>2]|0)==(c[m>>2]|0);continue}else if((pq|0)==2){c[bI>>2]=(c[bI>>2]|0)!=(c[m>>2]|0);continue}else{continue}}while(1){gI=pu;while(1){pv=b+4+gI|0;f5=a[pv]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[pv]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=2258;break}else{pw=gI;px=38}}else{pw=gI;px=f5}while(1){if(!((px<<24>>24|0)==13|(px<<24>>24|0)==32|(px<<24>>24|0)==9|(px<<24>>24|0)==10)){break}f5=pw+1|0;pw=f5;px=a[b+4+f5|0]|0}c[cq>>2]=pw;if((a[b+4+pw|0]|0)!=38){py=pw;break}pz=pw+1|0;c[cq>>2]=pz;if((wW(b,aZ,e)|0)==0){cA=2140;break L2644}while(1){gI=c[cq>>2]|0;while(1){pA=b+4+gI|0;f5=a[pA]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[pA]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){pB=1;pC=gI}else{pD=gI;pE=61;cA=2131}}else{pD=gI;pE=f5;cA=2131}if((cA|0)==2131){while(1){cA=0;if(!((pE<<24>>24|0)==13|(pE<<24>>24|0)==32|(pE<<24>>24|0)==9|(pE<<24>>24|0)==10)){break}f5=pD+1|0;pD=f5;pE=a[b+4+f5|0]|0;cA=2131}c[cq>>2]=pD;if((a[b+4+pD|0]|0)!=33){break}if((a[pD+1+(b+4)|0]|0)==61){pB=2;pC=pD}else{break}}c[cq>>2]=pC+2;if((wW(b,l,e)|0)==0){cA=2136;break L2644}if((pB|0)==1){c[aZ>>2]=(c[aZ>>2]|0)==(c[l>>2]|0);continue}else if((pB|0)==2){c[aZ>>2]=(c[aZ>>2]|0)!=(c[l>>2]|0);continue}else{continue}}c[bI>>2]=c[aZ>>2]&c[bI>>2];pu=pD}if((cA|0)==2258){cA=0;c[cq>>2]=pu;py=pu}c[cf>>2]=c[bI>>2]^c[cf>>2];pg=py}while(1){gI=pn;while(1){pF=b+4+gI|0;f5=a[pF]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[pF]|0;if(f5<<24>>24==124){if((a[gI+1+(b+4)|0]|0)==124){cA=2259;break}else{pG=gI;pH=124}}else{pG=gI;pH=f5}while(1){if(!((pH<<24>>24|0)==13|(pH<<24>>24|0)==32|(pH<<24>>24|0)==9|(pH<<24>>24|0)==10)){break}f5=pG+1|0;pG=f5;pH=a[b+4+f5|0]|0}c[cq>>2]=pG;if((a[b+4+pG|0]|0)!=124){pI=pG;break}pJ=pG+1|0;c[cq>>2]=pJ;if((wW(b,b3,e)|0)==0){cA=2237;break L2644}while(1){gI=c[cq>>2]|0;while(1){pK=b+4+gI|0;f5=a[pK]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[pK]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){pL=1;pM=gI}else{pN=gI;pO=61;cA=2158}}else{pN=gI;pO=f5;cA=2158}if((cA|0)==2158){while(1){cA=0;if(!((pO<<24>>24|0)==13|(pO<<24>>24|0)==32|(pO<<24>>24|0)==9|(pO<<24>>24|0)==10)){break}f5=pN+1|0;pN=f5;pO=a[b+4+f5|0]|0;cA=2158}c[cq>>2]=pN;if((a[b+4+pN|0]|0)!=33){pP=pN;break}if((a[pN+1+(b+4)|0]|0)==61){pL=2;pM=pN}else{pP=pN;break}}c[cq>>2]=pM+2;if((wW(b,k,e)|0)==0){cA=2163;break L2644}if((pL|0)==1){c[b3>>2]=(c[b3>>2]|0)==(c[k>>2]|0);continue}else if((pL|0)==2){c[b3>>2]=(c[b3>>2]|0)!=(c[k>>2]|0);continue}else{continue}}while(1){gI=pP;while(1){pQ=b+4+gI|0;f5=a[pQ]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[pQ]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=2260;break}else{pR=gI;pS=38}}else{pR=gI;pS=f5}while(1){if(!((pS<<24>>24|0)==13|(pS<<24>>24|0)==32|(pS<<24>>24|0)==9|(pS<<24>>24|0)==10)){break}f5=pR+1|0;pR=f5;pS=a[b+4+f5|0]|0}c[cq>>2]=pR;if((a[b+4+pR|0]|0)!=38){pT=pR;break}pU=pR+1|0;c[cq>>2]=pU;if((wW(b,aY,e)|0)==0){cA=2190;break L2644}while(1){gI=c[cq>>2]|0;while(1){pV=b+4+gI|0;f5=a[pV]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[pV]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){pW=1;pX=gI}else{pY=gI;pZ=61;cA=2181}}else{pY=gI;pZ=f5;cA=2181}if((cA|0)==2181){while(1){cA=0;if(!((pZ<<24>>24|0)==13|(pZ<<24>>24|0)==32|(pZ<<24>>24|0)==9|(pZ<<24>>24|0)==10)){break}f5=pY+1|0;pY=f5;pZ=a[b+4+f5|0]|0;cA=2181}c[cq>>2]=pY;if((a[b+4+pY|0]|0)!=33){break}if((a[pY+1+(b+4)|0]|0)==61){pW=2;pX=pY}else{break}}c[cq>>2]=pX+2;if((wW(b,j,e)|0)==0){cA=2186;break L2644}if((pW|0)==1){c[aY>>2]=(c[aY>>2]|0)==(c[j>>2]|0);continue}else if((pW|0)==2){c[aY>>2]=(c[aY>>2]|0)!=(c[j>>2]|0);continue}else{continue}}c[b3>>2]=c[aY>>2]&c[b3>>2];pP=pY}if((cA|0)==2260){cA=0;c[cq>>2]=pP;pT=pP}while(1){gI=b+4+pT|0;f5=a[gI]|0;if((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10){pT=pT+1|0;continue}c[cq>>2]=pT;if((a[gI]|0)!=94){break}p_=pT+1|0;c[cq>>2]=p_;if((wW(b,bH,e)|0)==0){cA=2235;break L2644}while(1){gI=c[cq>>2]|0;while(1){p$=b+4+gI|0;f5=a[p$]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[p$]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){p0=1;p1=gI}else{p2=gI;p3=61;cA=2201}}else{p2=gI;p3=f5;cA=2201}if((cA|0)==2201){while(1){cA=0;if(!((p3<<24>>24|0)==13|(p3<<24>>24|0)==32|(p3<<24>>24|0)==9|(p3<<24>>24|0)==10)){break}f5=p2+1|0;p2=f5;p3=a[b+4+f5|0]|0;cA=2201}c[cq>>2]=p2;if((a[b+4+p2|0]|0)!=33){p4=p2;break}if((a[p2+1+(b+4)|0]|0)==61){p0=2;p1=p2}else{p4=p2;break}}c[cq>>2]=p1+2;if((wW(b,h,e)|0)==0){cA=2206;break L2644}if((p0|0)==1){c[bH>>2]=(c[bH>>2]|0)==(c[h>>2]|0);continue}else if((p0|0)==2){c[bH>>2]=(c[bH>>2]|0)!=(c[h>>2]|0);continue}else{continue}}while(1){gI=p4;while(1){p5=b+4+gI|0;f5=a[p5]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[p5]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=2261;break}else{p6=gI;p7=38}}else{p6=gI;p7=f5}while(1){if(!((p7<<24>>24|0)==13|(p7<<24>>24|0)==32|(p7<<24>>24|0)==9|(p7<<24>>24|0)==10)){break}f5=p6+1|0;p6=f5;p7=a[b+4+f5|0]|0}c[cq>>2]=p6;if((a[b+4+p6|0]|0)!=38){p8=p6;break}p9=p6+1|0;c[cq>>2]=p9;if((wW(b,aX,e)|0)==0){cA=2233;break L2644}while(1){gI=c[cq>>2]|0;while(1){qa=b+4+gI|0;f5=a[qa]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[qa]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){qb=1;qc=gI}else{qd=gI;qe=61;cA=2224}}else{qd=gI;qe=f5;cA=2224}if((cA|0)==2224){while(1){cA=0;if(!((qe<<24>>24|0)==13|(qe<<24>>24|0)==32|(qe<<24>>24|0)==9|(qe<<24>>24|0)==10)){break}f5=qd+1|0;qd=f5;qe=a[b+4+f5|0]|0;cA=2224}c[cq>>2]=qd;if((a[b+4+qd|0]|0)!=33){break}if((a[qd+1+(b+4)|0]|0)==61){qb=2;qc=qd}else{break}}c[cq>>2]=qc+2;if((wW(b,g,e)|0)==0){cA=2229;break L2644}if((qb|0)==1){c[aX>>2]=(c[aX>>2]|0)==(c[g>>2]|0);continue}else if((qb|0)==2){c[aX>>2]=(c[aX>>2]|0)!=(c[g>>2]|0);continue}else{continue}}c[bH>>2]=c[aX>>2]&c[bH>>2];p4=qd}if((cA|0)==2261){cA=0;c[cq>>2]=p4;p8=p4}c[b3>>2]=c[bH>>2]^c[b3>>2];pT=p8}c[cf>>2]=c[b3>>2]|c[cf>>2];pn=pT}if((cA|0)==2259){cA=0;c[cq>>2]=pn;pI=pn}if((c[cl>>2]|0)==0){qf=0}else{qf=(c[cf>>2]|0)!=0|0}c[cl>>2]=qf;oz=pI}if((c[cp>>2]|0)==0){qg=(c[cl>>2]|0)!=0|0}else{qg=1}c[cp>>2]=qg;gZ=oz}if((cA|0)==1887){c[cq>>2]=nZ}else if((cA|0)==1910){c[cq>>2]=n8;cA=1914}else if((cA|0)==1930){c[cq>>2]=of;cA=1959}else if((cA|0)==1953){c[cq>>2]=oq;cA=1957}else if((cA|0)==1980){c[cq>>2]=oA;cA=2054}else if((cA|0)==2003){c[cq>>2]=oL;cA=2007}else if((cA|0)==2023){c[cq>>2]=oR;cA=2052}else if((cA|0)==2046){c[cq>>2]=o0;cA=2050}else if((cA|0)==2070){c[cq>>2]=o6;cA=2239}else if((cA|0)==2093){c[cq>>2]=ph;cA=2097}else if((cA|0)==2113){c[cq>>2]=po;cA=2142}else if((cA|0)==2136){c[cq>>2]=pz;cA=2140}else if((cA|0)==2163){c[cq>>2]=pJ;cA=2237}else if((cA|0)==2186){c[cq>>2]=pU;cA=2190}else if((cA|0)==2206){c[cq>>2]=p_;cA=2235}else if((cA|0)==2229){c[cq>>2]=p9;cA=2233}else if((cA|0)==2248){c[d>>2]=(c[d>>2]|0)!=0?c[co>>2]|0:c[cp>>2]|0;cs=1;i=f;return cs|0}if((cA|0)==1914){c[cq>>2]=nZ}else if((cA|0)==1957){c[cq>>2]=of;cA=1959}else if((cA|0)==2007){c[cq>>2]=oA;cA=2054}else if((cA|0)==2050){c[cq>>2]=oR;cA=2052}else if((cA|0)==2097){c[cq>>2]=o6;cA=2239}else if((cA|0)==2140){c[cq>>2]=po;cA=2142}else if((cA|0)==2190){c[cq>>2]=pJ;cA=2237}else if((cA|0)==2233){c[cq>>2]=p_;cA=2235}if((cA|0)==1959){c[cq>>2]=nZ}else if((cA|0)==2052){c[cq>>2]=oA;cA=2054}else if((cA|0)==2142){c[cq>>2]=o6;cA=2239}else if((cA|0)==2235){c[cq>>2]=pJ;cA=2237}if((cA|0)==2054){c[cq>>2]=nZ}else if((cA|0)==2237){c[cq>>2]=o6;cA=2239}if((cA|0)==2239){c[cq>>2]=nZ}c[cq>>2]=eL;break}else if((cA|0)==1700){c[cq>>2]=mP}else if((cA|0)==1723){c[cq>>2]=m_;cA=1727}else if((cA|0)==1743){c[cq>>2]=m5;cA=1772}else if((cA|0)==1766){c[cq>>2]=ng;cA=1770}else if((cA|0)==1793){c[cq>>2]=nq;cA=1867}else if((cA|0)==1816){c[cq>>2]=nB;cA=1820}else if((cA|0)==1836){c[cq>>2]=nH;cA=1865}else if((cA|0)==1859){c[cq>>2]=nS;cA=1863}if((cA|0)==1727){c[cq>>2]=mP}else if((cA|0)==1770){c[cq>>2]=m5;cA=1772}else if((cA|0)==1820){c[cq>>2]=nq;cA=1867}else if((cA|0)==1863){c[cq>>2]=nH;cA=1865}if((cA|0)==1772){c[cq>>2]=mP}else if((cA|0)==1865){c[cq>>2]=nq;cA=1867}if((cA|0)==1867){c[cq>>2]=mP}c[cq>>2]=eL;break}else if((cA|0)==1636){c[cq>>2]=mh}else if((cA|0)==1679){c[cq>>2]=my;cA=1681}if((cA|0)==1681){c[cq>>2]=mh}c[cq>>2]=eL;break}else if((cA|0)==1558){c[cq>>2]=lY}else if((cA|0)==1581){c[cq>>2]=l7;cA=1585}if((cA|0)==1585){c[cq>>2]=lY}c[cq>>2]=eL}}while(0);c[cq>>2]=cr;cs=0;i=f;return cs|0}if((cA|0)==1163){c[cq>>2]=jp}else if((cA|0)==1206){c[cq>>2]=jH;cA=1208}else if((cA|0)==1256){c[cq>>2]=j0;cA=1303}else if((cA|0)==1299){c[cq>>2]=kh;cA=1301}else if((cA|0)==1346){c[cq>>2]=ky;cA=1488}else if((cA|0)==1389){c[cq>>2]=kQ;cA=1391}else if((cA|0)==1439){c[cq>>2]=k9;cA=1486}else if((cA|0)==1482){c[cq>>2]=lq;cA=1484}if((cA|0)==1208){c[cq>>2]=jp}else if((cA|0)==1301){c[cq>>2]=j0;cA=1303}else if((cA|0)==1391){c[cq>>2]=ky;cA=1488}else if((cA|0)==1484){c[cq>>2]=k9;cA=1486}if((cA|0)==1303){c[cq>>2]=jp}else if((cA|0)==1486){c[cq>>2]=ky;cA=1488}if((cA|0)==1488){c[cq>>2]=jp}c[cq>>2]=eM;break}else if((cA|0)==949){c[cq>>2]=ib}else if((cA|0)==972){c[cq>>2]=io;cA=976}else if((cA|0)==992){c[cq>>2]=iv;cA=1021}else if((cA|0)==1015){c[cq>>2]=iG;cA=1019}else if((cA|0)==1042){c[cq>>2]=iQ;cA=1116}else if((cA|0)==1065){c[cq>>2]=i$;cA=1069}else if((cA|0)==1085){c[cq>>2]=i5;cA=1114}else if((cA|0)==1108){c[cq>>2]=jg;cA=1112}if((cA|0)==976){c[cq>>2]=ib}else if((cA|0)==1019){c[cq>>2]=iv;cA=1021}else if((cA|0)==1069){c[cq>>2]=iQ;cA=1116}else if((cA|0)==1112){c[cq>>2]=i5;cA=1114}if((cA|0)==1021){c[cq>>2]=ib}else if((cA|0)==1114){c[cq>>2]=iQ;cA=1116}if((cA|0)==1116){c[cq>>2]=ib}c[cq>>2]=eM;break}else if((cA|0)==885){c[cq>>2]=hF}else if((cA|0)==928){c[cq>>2]=hW;cA=930}if((cA|0)==930){c[cq>>2]=hF}c[cq>>2]=eM;break}else if((cA|0)==807){c[cq>>2]=hk}else if((cA|0)==830){c[cq>>2]=hv;cA=834}if((cA|0)==834){c[cq>>2]=hk}c[cq>>2]=eM}}while(0);c[cq>>2]=cr;cs=0;i=f;return cs|0}if((cA|0)==414){c[cq>>2]=eN}else if((cA|0)==457){c[cq>>2]=e3;cA=459}else if((cA|0)==507){c[cq>>2]=fo;cA=554}else if((cA|0)==550){c[cq>>2]=fF;cA=552}else if((cA|0)==597){c[cq>>2]=fW;cA=739}else if((cA|0)==640){c[cq>>2]=gc;cA=642}else if((cA|0)==690){c[cq>>2]=gx;cA=737}else if((cA|0)==733){c[cq>>2]=gO;cA=735}if((cA|0)==459){c[cq>>2]=eN}else if((cA|0)==552){c[cq>>2]=fo;cA=554}else if((cA|0)==642){c[cq>>2]=fW;cA=739}else if((cA|0)==735){c[cq>>2]=gx;cA=737}if((cA|0)==554){c[cq>>2]=eN}else if((cA|0)==737){c[cq>>2]=fW;cA=739}if((cA|0)==739){c[cq>>2]=eN}c[cq>>2]=cr;cs=0;i=f;return cs|0}else if((cA|0)==200){c[cq>>2]=dC}else if((cA|0)==223){c[cq>>2]=dN;cA=227}else if((cA|0)==243){c[cq>>2]=dU;cA=272}else if((cA|0)==266){c[cq>>2]=d3;cA=270}else if((cA|0)==293){c[cq>>2]=ec;cA=367}else if((cA|0)==316){c[cq>>2]=en;cA=320}else if((cA|0)==336){c[cq>>2]=et;cA=365}else if((cA|0)==359){c[cq>>2]=eE;cA=363}if((cA|0)==227){c[cq>>2]=dC}else if((cA|0)==270){c[cq>>2]=dU;cA=272}else if((cA|0)==320){c[cq>>2]=ec;cA=367}else if((cA|0)==363){c[cq>>2]=et;cA=365}if((cA|0)==272){c[cq>>2]=dC}else if((cA|0)==365){c[cq>>2]=ec;cA=367}if((cA|0)==367){c[cq>>2]=dC}c[cq>>2]=cr;cs=0;i=f;return cs|0}else if((cA|0)==136){c[cq>>2]=c3}else if((cA|0)==179){c[cq>>2]=dk;cA=181}if((cA|0)==181){c[cq>>2]=c3}c[cq>>2]=cr;cs=0;i=f;return cs|0}else if((cA|0)==58){c[cq>>2]=cL}else if((cA|0)==81){c[cq>>2]=cV;cA=85}if((cA|0)==85){c[cq>>2]=cL}c[cq>>2]=cr;cs=0;i=f;return cs|0}function wW(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+8|0;g=f|0;h=b|0;j=c[h>>2]|0;if((wX(b,d,e)|0)==0){k=0;i=f;return k|0}L3335:while(1){l=c[h>>2]|0;while(1){m=b+4+l|0;n=a[m]|0;if(!((n<<24>>24|0)==13|(n<<24>>24|0)==32|(n<<24>>24|0)==9|(n<<24>>24|0)==10)){break}l=l+1|0}c[h>>2]=l;n=a[m]|0;do{if(n<<24>>24==60){if((a[l+1+(b+4)|0]|0)!=61){o=l;p=60;q=2337;break}c[h>>2]=l+2;r=1}else{o=l;p=n;q=2337}}while(0);L3344:do{if((q|0)==2337){while(1){q=0;if(!((p<<24>>24|0)==13|(p<<24>>24|0)==32|(p<<24>>24|0)==9|(p<<24>>24|0)==10)){break}n=o+1|0;o=n;p=a[b+4+n|0]|0;q=2337}c[h>>2]=o;n=a[b+4+o|0]|0;if(n<<24>>24==60){c[h>>2]=o+1;r=2;break}else{s=o;t=n}while(1){if(!((t<<24>>24|0)==13|(t<<24>>24|0)==32|(t<<24>>24|0)==9|(t<<24>>24|0)==10)){break}n=s+1|0;s=n;t=a[b+4+n|0]|0}c[h>>2]=s;n=a[b+4+s|0]|0;do{if(n<<24>>24==62){if((a[s+1+(b+4)|0]|0)!=61){u=s;v=62;break}c[h>>2]=s+2;r=3;break L3344}else{u=s;v=n}}while(0);while(1){if(!((v<<24>>24|0)==13|(v<<24>>24|0)==32|(v<<24>>24|0)==9|(v<<24>>24|0)==10)){break}n=u+1|0;u=n;v=a[b+4+n|0]|0}c[h>>2]=u;if((a[b+4+u|0]|0)!=62){k=1;q=2359;break L3335}c[h>>2]=u+1;r=4}}while(0);if((wX(b,g,e)|0)==0){break}if((r|0)==1){c[d>>2]=(c[d>>2]|0)>>>0<=(c[g>>2]|0)>>>0;continue}else if((r|0)==2){c[d>>2]=(c[d>>2]|0)>>>0<(c[g>>2]|0)>>>0;continue}else if((r|0)==3){c[d>>2]=(c[d>>2]|0)>>>0>=(c[g>>2]|0)>>>0;continue}else if((r|0)==4){c[d>>2]=(c[d>>2]|0)>>>0>(c[g>>2]|0)>>>0;continue}else{continue}}if((q|0)==2359){i=f;return k|0}c[h>>2]=j;k=0;i=f;return k|0}function wX(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=i;i=i+24|0;g=f|0;h=f+8|0;j=f+16|0;k=b|0;l=c[k>>2]|0;if((wY(b,d,e)|0)==0){m=0;i=f;return m|0}while(1){n=c[k>>2]|0;while(1){o=b+4+n|0;p=a[o]|0;if(!((p<<24>>24|0)==13|(p<<24>>24|0)==32|(p<<24>>24|0)==9|(p<<24>>24|0)==10)){break}n=n+1|0}c[k>>2]=n;p=a[o]|0;if(p<<24>>24==43){q=1;r=n}else{s=n;t=p;while(1){if(!((t<<24>>24|0)==13|(t<<24>>24|0)==32|(t<<24>>24|0)==9|(t<<24>>24|0)==10)){break}p=s+1|0;s=p;t=a[b+4+p|0]|0}c[k>>2]=s;if((a[b+4+s|0]|0)==45){q=2;r=s}else{break}}c[k>>2]=r+1;if((wY(b,g,e)|0)==0){u=2372;break}t=c[g>>2]|0;c[d>>2]=(c[d>>2]|0)+((q|0)==1?t:-t|0)}if((u|0)==2372){c[k>>2]=l;m=0;i=f;return m|0}q=s;L3394:while(1){s=b+4+q|0;g=a[s]|0;if((g<<24>>24|0)==13|(g<<24>>24|0)==32|(g<<24>>24|0)==9|(g<<24>>24|0)==10){q=q+1|0;continue}c[k>>2]=q;g=a[s]|0;do{if(g<<24>>24==60){if((a[q+1+(b+4)|0]|0)!=60){v=q;w=60;u=2378;break}if((a[q+2+(b+4)|0]|0)!=60){v=q;w=g;u=2378;break}s=q+3|0;c[k>>2]=s;x=1;y=s}else{v=q;w=g;u=2378}}while(0);L3403:do{if((u|0)==2378){while(1){u=0;if(!((w<<24>>24|0)==13|(w<<24>>24|0)==32|(w<<24>>24|0)==9|(w<<24>>24|0)==10)){break}g=v+1|0;v=g;w=a[b+4+g|0]|0;u=2378}c[k>>2]=v;g=a[b+4+v|0]|0;do{if(g<<24>>24==62){if((a[v+1+(b+4)|0]|0)!=62){z=v;A=62;break}if((a[v+2+(b+4)|0]|0)!=62){z=v;A=g;break}s=v+3|0;c[k>>2]=s;x=2;y=s;break L3403}else{z=v;A=g}}while(0);while(1){if(!((A<<24>>24|0)==13|(A<<24>>24|0)==32|(A<<24>>24|0)==9|(A<<24>>24|0)==10)){break}g=z+1|0;z=g;A=a[b+4+g|0]|0}c[k>>2]=z;g=a[b+4+z|0]|0;do{if(g<<24>>24==60){if((a[z+1+(b+4)|0]|0)!=60){B=z;C=60;break}s=z+2|0;c[k>>2]=s;x=3;y=s;break L3403}else{B=z;C=g}}while(0);while(1){if(!((C<<24>>24|0)==13|(C<<24>>24|0)==32|(C<<24>>24|0)==9|(C<<24>>24|0)==10)){break}g=B+1|0;B=g;C=a[b+4+g|0]|0}c[k>>2]=B;if((a[b+4+B|0]|0)!=62){m=1;u=2417;break L3394}if((a[B+1+(b+4)|0]|0)!=62){m=1;u=2418;break L3394}g=B+2|0;c[k>>2]=g;x=4;y=g}}while(0);if((wY(b,j,e)|0)==0){break}while(1){g=c[k>>2]|0;while(1){D=b+4+g|0;s=a[D]|0;if(!((s<<24>>24|0)==13|(s<<24>>24|0)==32|(s<<24>>24|0)==9|(s<<24>>24|0)==10)){break}g=g+1|0}c[k>>2]=g;s=a[D]|0;if(s<<24>>24==43){E=1;F=g}else{r=g;o=s;while(1){if(!((o<<24>>24|0)==13|(o<<24>>24|0)==32|(o<<24>>24|0)==9|(o<<24>>24|0)==10)){break}s=r+1|0;r=s;o=a[b+4+s|0]|0}c[k>>2]=r;if((a[b+4+r|0]|0)==45){E=2;F=r}else{break}}c[k>>2]=F+1;if((wY(b,h,e)|0)==0){u=2399;break L3394}o=c[h>>2]|0;c[j>>2]=(c[j>>2]|0)+((E|0)==1?o:-o|0)}o=c[j>>2]&31;c[j>>2]=o;if((x|0)==1){g=c[d>>2]|0;c[d>>2]=g<<o|g>>>((32-o|0)>>>0)}else if((x|0)==2){g=c[d>>2]|0;c[d>>2]=g>>>(o>>>0)|g<<32-o}else if((x|0)==3){c[d>>2]=c[d>>2]<<o}else if((x|0)==4){c[d>>2]=(c[d>>2]|0)>>>(o>>>0)}q=c[k>>2]|0}if((u|0)==2417){i=f;return m|0}else if((u|0)==2418){i=f;return m|0}else if((u|0)==2399){c[k>>2]=y}c[k>>2]=l;m=0;i=f;return m|0}function wY(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+8|0;g=f|0;h=b|0;j=c[h>>2]|0;if((w0(b,d,e)|0)==0){k=0;i=f;return k|0}L3455:while(1){l=c[h>>2]|0;while(1){m=b+4+l|0;n=a[m]|0;if(!((n<<24>>24|0)==13|(n<<24>>24|0)==32|(n<<24>>24|0)==9|(n<<24>>24|0)==10)){break}l=l+1|0}c[h>>2]=l;n=a[m]|0;do{if(n<<24>>24==42){c[h>>2]=l+1;o=1}else{p=l;q=n;while(1){if(!((q<<24>>24|0)==13|(q<<24>>24|0)==32|(q<<24>>24|0)==9|(q<<24>>24|0)==10)){break}r=p+1|0;p=r;q=a[b+4+r|0]|0}c[h>>2]=p;q=a[b+4+p|0]|0;if(q<<24>>24==47){c[h>>2]=p+1;o=2;break}else{s=p;t=q}while(1){if(!((t<<24>>24|0)==13|(t<<24>>24|0)==32|(t<<24>>24|0)==9|(t<<24>>24|0)==10)){break}q=s+1|0;s=q;t=a[b+4+q|0]|0}c[h>>2]=s;if((a[b+4+s|0]|0)!=37){k=1;u=2447;break L3455}c[h>>2]=s+1;o=3}}while(0);if((w0(b,g,e)|0)==0){break}if((o|0)==1){c[d>>2]=ac(c[g>>2]|0,c[d>>2]|0)|0;continue}n=c[g>>2]|0;l=(n|0)!=0;if((o|0)==2){if(l){c[d>>2]=((c[d>>2]|0)>>>0)/(n>>>0)|0;continue}else{c[d>>2]=-1;continue}}else{if(l){c[d>>2]=((c[d>>2]|0)>>>0)%(n>>>0)|0;continue}else{c[d>>2]=0;continue}}}if((u|0)==2447){i=f;return k|0}c[h>>2]=j;k=0;i=f;return k|0}function wZ(a,b){a=a|0;b=b|0;c[10732]=a;c[10730]=b;return}function w_(){return c[10726]|0}function w$(){return c[10730]|0}function w0(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;f=i;i=i+256|0;g=f|0;h=b|0;j=c[h>>2]|0;k=j;while(1){l=b+4+k|0;m=a[l]|0;if(!((m<<24>>24|0)==13|(m<<24>>24|0)==32|(m<<24>>24|0)==9|(m<<24>>24|0)==10)){break}k=k+1|0}c[h>>2]=k;m=a[l]|0;do{if(m<<24>>24==33){l=k+1|0;c[h>>2]=l;n=1;o=l}else{l=k;p=m;while(1){if(!((p<<24>>24|0)==13|(p<<24>>24|0)==32|(p<<24>>24|0)==9|(p<<24>>24|0)==10)){break}q=l+1|0;l=q;p=a[b+4+q|0]|0}c[h>>2]=l;p=a[b+4+l|0]|0;if(p<<24>>24==126){q=l+1|0;c[h>>2]=q;n=2;o=q;break}else{r=l;s=p}while(1){if(!((s<<24>>24|0)==13|(s<<24>>24|0)==32|(s<<24>>24|0)==9|(s<<24>>24|0)==10)){break}p=r+1|0;r=p;s=a[b+4+p|0]|0}c[h>>2]=r;l=a[b+4+r|0]|0;if(l<<24>>24==43){p=r+1|0;c[h>>2]=p;n=3;o=p;break}else{t=r;u=l}while(1){if(!((u<<24>>24|0)==13|(u<<24>>24|0)==32|(u<<24>>24|0)==9|(u<<24>>24|0)==10)){break}l=t+1|0;t=l;u=a[b+4+l|0]|0}c[h>>2]=t;if((a[b+4+t|0]|0)!=45){n=0;o=t;break}l=t+1|0;c[h>>2]=l;n=4;o=l}}while(0);t=g|0;u=o;while(1){o=a[b+4+u|0]|0;if(!((o<<24>>24|0)==13|(o<<24>>24|0)==32|(o<<24>>24|0)==9|(o<<24>>24|0)==10)){break}u=u+1|0}c[h>>2]=u;o=u;while(1){v=b+4+o|0;r=a[v]|0;if(!((r<<24>>24|0)==13|(r<<24>>24|0)==32|(r<<24>>24|0)==9|(r<<24>>24|0)==10)){break}o=o+1|0}c[h>>2]=o;r=a[v]|0;if(((r<<24>>24)-36|0)>>>0<2){a[t]=r;w=1;y=o+1|0;z=g+1|0}else{w=0;y=o;z=t}while(1){o=a[b+4+y|0]|0;if(o<<24>>24==0){A=2481;break}if(!((o-48&255)<10|(o-97&255)<26|(o-65&255)<26|o<<24>>24==95)){A=2481;break}a[z]=o;o=w+1|0;if(o>>>0<256){w=o;y=y+1|0;z=z+1|0}else{A=2480;break}}L3534:do{if((A|0)==2480){o=(c[h>>2]|0)+(b+4)|0;w2(28696,(x=i,i=i+16|0,c[x>>2]=27024,c[x+8>>2]=o,x)|0);B=c[h>>2]|0;A=2508}else if((A|0)==2481){a[z]=0;c[h>>2]=y;if((w|0)==0){B=y;A=2508;break}o=a[t]|0;r=(o-36&255)<2;if(!r){c[h>>2]=u;v=u;while(1){C=b+4+v|0;s=a[C]|0;if(!((s<<24>>24|0)==13|(s<<24>>24|0)==32|(s<<24>>24|0)==9|(s<<24>>24|0)==10)){break}v=v+1|0}c[h>>2]=v;s=a[C]|0;do{if(s<<24>>24!=0){m=v;k=0;l=0;p=s;L3545:while(1){q=p<<24>>24;do{if((p-48&255)<10){D=q-48|0}else{if((p-97&255)<6){D=q-87|0;break}if((p-65&255)>=6){E=m;F=k;G=l;break L3545}D=q-55|0}}while(0);if(D>>>0>=e>>>0){E=m;F=k;G=l;break}q=D+(ac(l,e)|0)|0;H=k+1|0;I=m+1|0;J=a[b+4+I|0]|0;if(J<<24>>24==0){E=I;F=H;G=q;break}else{m=I;k=H;l=q;p=J}}if((F|0)==0){break}c[h>>2]=E;c[d>>2]=G;if((c[h>>2]|0)>>>0>=y>>>0){break L3534}}}while(0);c[h>>2]=y}s=r?g+1|0:t;if(o<<24>>24==36){A=2503}else{v=c[11104]|0;if((v|0)==0){K=o}else{if((b4[v&127](c[11106]|0,s,d)|0)==0){break}K=a[t]|0}if(K<<24>>24!=37){A=2503}}L3566:do{if((A|0)==2503){v=c[11096]|0;p=c[11098]|0;l=0;while(1){if(l>>>0>=v>>>0){break L3566}if((aP(c[p+(l<<3)>>2]|0,s|0)|0)==0){break}else{l=l+1|0}}c[d>>2]=c[p+(l<<3)+4>>2];break L3534}}while(0);c[h>>2]=u;B=u;A=2508}}while(0);L3573:do{if((A|0)==2508){while(1){A=0;L=b+4+B|0;K=a[L]|0;if(!((K<<24>>24|0)==13|(K<<24>>24|0)==32|(K<<24>>24|0)==9|(K<<24>>24|0)==10)){break}B=B+1|0;A=2508}c[h>>2]=B;K=a[L]|0;do{if(K<<24>>24==40){c[h>>2]=B+1;do{if((wR(b,d,e)|0)!=0){t=c[h>>2]|0;while(1){M=b+4+t|0;g=a[M]|0;if(!((g<<24>>24|0)==13|(g<<24>>24|0)==32|(g<<24>>24|0)==9|(g<<24>>24|0)==10)){break}t=t+1|0}c[h>>2]=t;if((a[M]|0)!=41){break}c[h>>2]=t+1;break L3573}}while(0);c[h>>2]=u}else{l=B;p=K;while(1){if(!((p<<24>>24|0)==13|(p<<24>>24|0)==32|(p<<24>>24|0)==9|(p<<24>>24|0)==10)){break}g=l+1|0;l=g;p=a[b+4+g|0]|0}c[h>>2]=l;p=a[b+4+l|0]|0;if(p<<24>>24==0){break}else{N=l;O=0;P=0;Q=p}L3592:while(1){p=Q<<24>>24;do{if((Q-48&255)<10){R=p-48|0}else{if((Q-97&255)<6){R=p-87|0;break}if((Q-65&255)>=6){S=N;T=O;U=P;break L3592}R=p-55|0}}while(0);if(R>>>0>=e>>>0){S=N;T=O;U=P;break}p=R+(ac(P,e)|0)|0;t=O+1|0;g=N+1|0;y=a[b+4+g|0]|0;if(y<<24>>24==0){S=g;T=t;U=p;break}else{N=g;O=t;P=p;Q=y}}if((T|0)==0){break}c[h>>2]=S;c[d>>2]=U;break L3573}}while(0);c[h>>2]=j;V=0;i=f;return V|0}}while(0);if((n|0)==1){c[d>>2]=(c[d>>2]|0)==0;V=1;i=f;return V|0}else if((n|0)==2){c[d>>2]=~c[d>>2];V=1;i=f;return V|0}else if((n|0)==4){c[d>>2]=-(c[d>>2]|0);V=1;i=f;return V|0}else{V=1;i=f;return V|0}return 0}function w1(a){a=a|0;var b=0,d=0,e=0;b=c[10730]|0;if((b|0)==0){d=c[o>>2]|0;c[10730]=d;e=d}else{e=b}aF(a|0,e|0)|0;ax(c[10730]|0)|0;e=c[10726]|0;if((e|0)==0){return}aF(a|0,e|0)|0;ax(c[10726]|0)|0;return}function w2(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+16|0;e=d|0;if((c[10730]|0)==0){c[10730]=c[o>>2]}f=e|0;g=e;c[g>>2]=b;c[g+4>>2]=0;by(c[10730]|0,a|0,f|0)|0;ax(c[10730]|0)|0;g=c[10726]|0;if((g|0)==0){i=d;return}by(g|0,a|0,f|0)|0;ax(c[10726]|0)|0;i=d;return}function w3(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=zN(a|0)|0;d=c[10730]|0;if((d|0)==0){e=c[o>>2]|0;c[10730]=e;f=e}else{f=d}aA(45,f|0)|0;ax(c[10730]|0)|0;f=c[10726]|0;if((f|0)!=0){aA(45,f|0)|0;f=c[10726]|0;ax(f|0)|0}f=c[10730]|0;if((f|0)==0){d=c[o>>2]|0;c[10730]=d;g=d}else{g=f}aF(a|0,g|0)|0;ax(c[10730]|0)|0;g=c[10726]|0;if((g|0)!=0){aF(a|0,g|0)|0;g=c[10726]|0;ax(g|0)|0}g=b+1|0;b=c[10730]|0;a=(b|0)==0;if(g>>>0<78){f=g;g=b;d=a;while(1){if(d){e=c[o>>2]|0;c[10730]=e;h=e}else{h=g}aA(45,h|0)|0;ax(c[10730]|0)|0;e=c[10726]|0;if((e|0)!=0){aA(45,e|0)|0;e=c[10726]|0;ax(e|0)|0}e=f+1|0;i=c[10730]|0;j=(i|0)==0;if(e>>>0<78){f=e;g=i;d=j}else{k=i;l=j;break}}}else{k=b;l=a}if(l){l=c[o>>2]|0;c[10730]=l;m=l}else{m=k}aA(10,m|0)|0;ax(c[10730]|0)|0;m=c[10726]|0;if((m|0)==0){return}aA(10,m|0)|0;ax(c[10726]|0)|0;return}function w4(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;f=i;i=i+16|0;g=f|0;h=e|0;j=b[h>>1]|0;do{if(j<<16>>16<0){k=2}else{l=e+16|0;m=b[l>>1]|0;if(m<<16>>16>-1){n=1;p=l;l=m;do{m=n-1|0;q=e+(m<<4)|0;r=l<<16>>16;if(l<<16>>16<256){s=zT(r|0)|0}else{s=r}r=q|0;t=b[r>>1]|0;u=t<<16>>16;if(t<<16>>16<256){v=zT(u|0)|0}else{v=u}do{if((s|0)<(v|0)){w=b[p>>1]|0;y=2588}else{if((s|0)>(v|0)){break}u=b[p>>1]|0;if(u<<16>>16>(b[r>>1]|0)){w=u;y=2588}}}while(0);if((y|0)==2588){y=0;r=p;u=e+(n<<4)+2|0;b[g>>1]=b[u>>1]|0;b[g+2>>1]=b[u+2>>1]|0;b[g+4>>1]=b[u+4>>1]|0;b[g+6>>1]=b[u+6>>1]|0;b[g+8>>1]=b[u+8>>1]|0;b[g+10>>1]=b[u+10>>1]|0;b[g+12>>1]=b[u+12>>1]|0;u=q;c[r>>2]=c[u>>2];c[r+4>>2]=c[u+4>>2];c[r+8>>2]=c[u+8>>2];c[r+12>>2]=c[u+12>>2];L3680:do{if((m|0)==0){z=e}else{u=w<<16>>16;L3682:do{if(w<<16>>16<256){r=m;while(1){t=r-1|0;A=zT(u|0)|0;B=e+(t<<4)|0;C=b[B>>1]|0;D=C<<16>>16;if(C<<16>>16<256){E=zT(D|0)|0}else{E=D}if((A|0)<(E|0)){F=e+(r<<4)|0}else{if((A|0)>(E|0)){G=r;break L3682}A=b[B>>1]|0;if(w<<16>>16<A<<16>>16){G=r;break L3682}B=e+(r<<4)|0;if(w<<16>>16>A<<16>>16){F=B}else{z=B;break L3680}}B=F;A=e+(t<<4)|0;c[B>>2]=c[A>>2];c[B+4>>2]=c[A+4>>2];c[B+8>>2]=c[A+8>>2];c[B+12>>2]=c[A+12>>2];if((t|0)==0){z=e;break L3680}else{r=t}}}else{r=m;while(1){t=r-1|0;A=e+(t<<4)|0;B=b[A>>1]|0;D=B<<16>>16;if(B<<16>>16<256){H=zT(D|0)|0}else{H=D}if((u|0)<(H|0)){I=e+(r<<4)|0}else{if((u|0)>(H|0)){G=r;break L3682}D=b[A>>1]|0;if(w<<16>>16<D<<16>>16){G=r;break L3682}A=e+(r<<4)|0;if(w<<16>>16>D<<16>>16){I=A}else{z=A;break L3680}}A=I;D=e+(t<<4)|0;c[A>>2]=c[D>>2];c[A+4>>2]=c[D+4>>2];c[A+8>>2]=c[D+8>>2];c[A+12>>2]=c[D+12>>2];if((t|0)==0){z=e;break L3680}else{r=t}}}}while(0);z=e+(G<<4)|0}}while(0);b[z>>1]=w;m=z+2|0;b[m>>1]=b[g>>1]|0;b[m+2>>1]=b[g+2>>1]|0;b[m+4>>1]=b[g+4>>1]|0;b[m+6>>1]=b[g+6>>1]|0;b[m+8>>1]=b[g+8>>1]|0;b[m+10>>1]=b[g+10>>1]|0;b[m+12>>1]=b[g+12>>1]|0}n=n+1|0;p=e+(n<<4)|0;l=b[p>>1]|0;}while(l<<16>>16>-1);l=b[h>>1]|0;if(l<<16>>16>-1){J=0;K=0;L=l}else{k=2;break}}else{J=0;K=0;L=j}do{do{if((c[e+(J<<4)+12>>2]|0)==0){M=0}else{l=c[e+(J<<4)+4>>2]|0;if(L<<16>>16<256){N=(l|0)==0?2:4}else{N=0}if((l|0)==0){O=N}else{O=N+2+(zN(l|0)|0)|0}l=c[e+(J<<4)+8>>2]|0;if((l|0)==0){M=O;break}M=O+1+(zN(l|0)|0)|0}}while(0);K=M>>>0>K>>>0?M:K;J=J+1|0;L=b[e+(J<<4)>>1]|0;}while(L<<16>>16>-1);k=K+2|0}}while(0);if((a|0)!=0){bh(34544,(x=i,i=i+8|0,c[x>>2]=a,x)|0)|0}if((d|0)!=0){bp(d|0)|0}d=b[h>>1]|0;if(d<<16>>16>-1){P=e;Q=d}else{i=f;return}do{do{if(Q<<16>>16<256){d=Q<<16>>16;bh(25440,(x=i,i=i+8|0,c[x>>2]=d,x)|0)|0;d=P+4|0;if((c[d>>2]|0)==0){R=2;S=d;break}bh(24240,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0)|0;R=4;S=d}else{bh(22656,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0)|0;R=0;S=P+4|0}}while(0);d=c[S>>2]|0;if((d|0)==0){T=R}else{bh(21504,(x=i,i=i+8|0,c[x>>2]=d,x)|0)|0;T=R+2+(zN(c[S>>2]|0)|0)|0}d=P+8|0;e=c[d>>2]|0;if((e|0)==0){U=T}else{bh(41592,(x=i,i=i+8|0,c[x>>2]=e,x)|0)|0;U=T+1+(zN(c[d>>2]|0)|0)|0}if(U>>>0<k>>>0){d=U;do{aA(32,c[o>>2]|0)|0;d=d+1|0;}while(d>>>0<k>>>0)}bp(c[P+12>>2]|0)|0;P=P+16|0;Q=b[P>>1]|0;}while(Q<<16>>16>-1);i=f;return}function w5(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0;j=i;if((d|0)==0&(f|0)==0){c[200]=-1;k=0;i=j;return k|0}if((c[200]|0)<0){a[808]=0;c[200]=0;c[198]=1;c[10728]=0;l=0}else{l=a[808]|0}if(l|(h|0)==0){l=c[198]|0;if((l|0)>=(d|0)){k=-1;i=j;return k|0}c[200]=l;c[198]=l+1;c[g>>2]=f+(l<<2);k=0;i=j;return k|0}l=c[10728]|0;if((l|0)==0){m=2647}else{n=a[l]|0;if(n<<24>>24==0){m=2647}else{o=n}}L3767:do{if((m|0)==2647){n=c[198]|0;if((n|0)>=(d|0)){k=-1;i=j;return k|0}c[200]=n;l=n+1|0;c[198]=l;p=f+(n<<2)|0;r=c[p>>2]|0;c[10728]=r;do{if((a[r]|0)==45){s=r+1|0;t=a[s]|0;if((t<<24>>24|0)==0){break}else if((t<<24>>24|0)!=45){c[10728]=s;o=a[s]|0;break L3767}s=r+2|0;if((a[s]|0)==0){a[808]=1;if((l|0)>=(d|0)){k=-1;i=j;return k|0}c[200]=l;c[198]=n+2;c[g>>2]=f+(l<<2);k=0;i=j;return k|0}else{u=h}while(1){v=u|0;if((b[v>>1]|0)<=-1){break}if((aP(c[u+4>>2]|0,s|0)|0)==0){m=2656;break}else{u=u+16|0}}do{if((m|0)==2656){if((u|0)==0){break}s=u+2|0;if(((e[s>>1]|0)+l|0)>(d|0)){t=c[q>>2]|0;w=c[f>>2]|0;bN(t|0,30728,(x=i,i=i+16|0,c[x>>2]=w,c[x+8>>2]=r,x)|0)|0;k=-3;i=j;return k|0}else{c[g>>2]=f+(l<<2);c[198]=(c[198]|0)+(e[s>>1]|0);c[10728]=0;k=b[v>>1]|0;i=j;return k|0}}}while(0);bN(c[q>>2]|0,32704,(x=i,i=i+16|0,c[x>>2]=c[f>>2],c[x+8>>2]=r,x)|0)|0;k=-2;i=j;return k|0}}while(0);c[g>>2]=p;c[10728]=0;k=0;i=j;return k|0}}while(0);v=o<<24>>24;o=h;while(1){y=o|0;h=b[y>>1]|0;if(h<<16>>16<=-1){break}if((h<<16>>16|0)==(v|0)){m=2665;break}else{o=o+16|0}}do{if((m|0)==2665){if((o|0)==0){break}h=c[198]|0;u=o+2|0;if(((e[u>>1]|0)+h|0)>(d|0)){r=c[q>>2]|0;l=c[f>>2]|0;bN(r|0,26984,(x=i,i=i+16|0,c[x>>2]=l,c[x+8>>2]=v,x)|0)|0;k=-3;i=j;return k|0}else{c[g>>2]=f+(h<<2);c[198]=(c[198]|0)+(e[u>>1]|0);c[10728]=(c[10728]|0)+1;k=b[y>>1]|0;i=j;return k|0}}}while(0);bN(c[q>>2]|0,28664,(x=i,i=i+16|0,c[x>>2]=c[f>>2],c[x+8>>2]=v,x)|0)|0;k=-2;i=j;return k|0}function w6(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+16|0;f=e|0;g=a[c]|0;if((g<<24>>24|0)==58){a[f|0]=0;h=1;i=e;return h|0}else if((g<<24>>24|0)==0){h=1;i=e;return h|0}else{a[f|0]=g;g=a[c+1|0]|0;do{if((g<<24>>24|0)==58){j=1;k=2687}else if((g<<24>>24|0)==0){l=1}else{a[f+1|0]=g;m=a[c+2|0]|0;if((m<<24>>24|0)==58){j=2;k=2687;break}else if((m<<24>>24|0)==0){l=2;break}a[f+2|0]=m;m=a[c+3|0]|0;if((m<<24>>24|0)==58){j=3;k=2687;break}else if((m<<24>>24|0)==0){l=3;break}a[f+3|0]=m;m=a[c+4|0]|0;if((m<<24>>24|0)==58){j=4;k=2687;break}else if((m<<24>>24|0)==0){l=4;break}a[f+4|0]=m;m=a[c+5|0]|0;if((m<<24>>24|0)==58){j=5;k=2687;break}else if((m<<24>>24|0)==0){l=5;break}a[f+5|0]=m;m=a[c+6|0]|0;if((m<<24>>24|0)==58){j=6;k=2687;break}else if((m<<24>>24|0)==0){l=6;break}a[f+6|0]=m;m=a[c+7|0]|0;if((m<<24>>24|0)==58){j=7;k=2687;break}else if((m<<24>>24|0)==0){l=7;break}a[f+7|0]=m;m=a[c+8|0]|0;if((m<<24>>24|0)==58){j=8;k=2687;break}else if((m<<24>>24|0)==0){l=8;break}a[f+8|0]=m;m=a[c+9|0]|0;if((m<<24>>24|0)==58){j=9;k=2687;break}else if((m<<24>>24|0)==0){l=9;break}a[f+9|0]=m;m=a[c+10|0]|0;if((m<<24>>24|0)==58){j=10;k=2687;break}else if((m<<24>>24|0)==0){l=10;break}a[f+10|0]=m;m=a[c+11|0]|0;if((m<<24>>24|0)==58){j=11;k=2687;break}else if((m<<24>>24|0)==0){l=11;break}a[f+11|0]=m;m=a[c+12|0]|0;if((m<<24>>24|0)==58){j=12;k=2687;break}else if((m<<24>>24|0)==0){l=12;break}a[f+12|0]=m;m=a[c+13|0]|0;if((m<<24>>24|0)==58){j=13;k=2687;break}else if((m<<24>>24|0)==0){l=13;break}a[f+13|0]=m;m=a[c+14|0]|0;if((m<<24>>24|0)==58){j=14;k=2687;break}else if((m<<24>>24|0)==0){l=14;break}a[f+14|0]=m;m=a[c+15|0]|0;if((m<<24>>24|0)==58){j=15;k=2687;break}else if((m<<24>>24|0)==0){l=15;break}a[f+15|0]=m;h=1;i=e;return h|0}}while(0);if((k|0)==2687){a[f+j|0]=0;l=j}if((a[c+l|0]|0)==0){h=1;i=e;return h|0}j=aw(f|0,0,0)|0;f=xI(c+(l+1)|0)|0;l=to(f,0,0,0)|0;zI(f);if((l|0)==0){h=1;i=e;return h|0}s9(l,j);do{if((d|0)!=0){f=ts(b,j)|0;if((f|0)==0){break}tr(b,f)|0;tl(f)}}while(0);if((ty(b,l)|0)==0){h=0;i=e;return h|0}tl(l);h=1;i=e;return h|0}return 0}function w7(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=yd(a,0,34488)|0;if((e|0)==0){f=b;i=d;return f|0}else{g=b;h=e}while(1){j=yy(h)|0;if((j|0)==0){k=2720;break}e=tU(g,j)|0;if((e|0)==0){b=yS(g,j)|0;if((b|0)==0){k=2723;break}else{l=b}}else{l=e}td(l,0);e=tg(l)|0;xv(2,39512,30696,(x=i,i=i+16|0,c[x>>2]=e,c[x+8>>2]=j,x)|0);e=yd(a,h,34488)|0;if((e|0)==0){f=l;k=2728;break}else{g=l;h=e}}if((k|0)==2720){tl(g);f=0;i=d;return f|0}else if((k|0)==2728){i=d;return f|0}else if((k|0)==2723){k=tg(g)|0;xv(0,39512,32664,(x=i,i=i+16|0,c[x>>2]=k,c[x+8>>2]=j,x)|0);tl(g);f=0;i=d;return f|0}return 0}function w8(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;d=i;i=i+136|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;l=d+48|0;m=d+56|0;n=d+64|0;o=d+72|0;p=d+80|0;q=d+88|0;r=d+96|0;s=d+104|0;t=d+112|0;u=d+120|0;v=d+128|0;yj(a,28656,n,0)|0;ym(a,26976,v,25432)|0;yi(a,24232,s,0)|0;yi(a,22648,o,0)|0;yi(a,21496,p,0)|0;yi(a,41584,q,0)|0;do{if((yi(a,40512,r,0)|0)!=0){if((yi(a,38952,r,0)|0)==0){c[r>>2]=c[r>>2]&-512;break}if((yi(a,37968,r,0)|0)==0){c[r>>2]=c[r>>2]<<1;break}if((yi(a,37048,r,0)|0)==0){c[r>>2]=c[r>>2]<<11;break}if((yi(a,35136,r,0)|0)==0){c[r>>2]=c[r>>2]<<21;break}else{c[r>>2]=0;break}}}while(0);yl(a,34704,t,0)|0;yl(a,34448,u,0)|0;w=0;y=0;L3883:while(1){z=y;do{z=yd(a,z,34192)|0;if((z|0)==0){A=2782;break L3883}B=yy(z)|0;}while((B|0)==0);zI(w);C=xI(B)|0;if((C|0)==0){w=0;y=z;continue}D=bl(C|0,33984)|0;if((D|0)==0){w=C;y=z;continue}au(D|0)|0;D=c[v>>2]|0;L3891:do{if((aP(D|0,33584)|0)==0){E=zc(C,c[r>>2]|0,c[o>>2]|0,c[p>>2]|0,c[q>>2]|0,c[t>>2]|0)|0}else{if((aP(D|0,33152)|0)==0){E=t2(C,c[s>>2]|0,0,c[t>>2]|0)|0;break}if((aP(D|0,32464)|0)==0){E=tF(C,c[t>>2]|0)|0;break}if((aP(D|0,32216)|0)==0){E=tM(C,c[t>>2]|0)|0;break}if((aP(D|0,32024)|0)==0){E=tT(C,c[t>>2]|0)|0;break}if((aP(D|0,31856)|0)==0){F=c[o>>2]|0;G=c[p>>2]|0;H=c[q>>2]|0;I=c[t>>2]|0;c[h>>2]=I;J=yY(F,G,H,I)|0;if((J|0)==0){w=C;y=z;continue L3883}else{K=0}while(1){I=yc(a,K,31856)|0;if((I|0)==0){E=J;break L3891}yi(I,24232,j,0)|0;yi(I,28072,k,0)|0;yi(I,27992,l,0)|0;ym(I,34192,m,0)|0;yl(I,34704,h,0)|0;H=c[m>>2]|0;if((H|0)==0){A=2760;break}G=xI(H)|0;H=(yX(J,G,c[j>>2]|0,0,c[k>>2]|0,c[l>>2]|0,c[h>>2]|0)|0)==0;zI(G);if(H){K=I}else{A=2762;break}}if((A|0)==2760){A=0;tl(J);w=C;y=z;continue L3883}else if((A|0)==2762){A=0;tl(J);w=C;y=z;continue L3883}}if((aP(D|0,31760)|0)==0){E=s5(C,1,c[t>>2]|0)|0;break}if((aP(D|0,31672)|0)==0){E=s5(C,2,c[t>>2]|0)|0;break}if((aP(D|0,31520)|0)==0){E=s5(C,3,c[t>>2]|0)|0;break}if((aP(D|0,31384)|0)==0){E=s5(C,4,c[t>>2]|0)|0;break}if((aP(D|0,31272)|0)==0){E=s5(C,4,c[t>>2]|0)|0;break}if((aP(D|0,31016)|0)==0){E=s5(C,5,c[t>>2]|0)|0;break}if((aP(D|0,30560)|0)==0){E=s5(C,0,c[t>>2]|0)|0;break}if((aP(D|0,30416)|0)==0){E=s5(C,12,c[t>>2]|0)|0;break}if((aP(D|0,25432)|0)!=0){w=C;y=z;continue L3883}E=to(C,c[s>>2]|0,0,c[t>>2]|0)|0}}while(0);if((E|0)==0){w=C;y=z}else{break}}if((A|0)==2782){c[b>>2]=0;zI(w);if((c[u>>2]|0)!=0){L=0;i=d;return L|0}xt(0,30216,(x=i,i=i+8|0,c[x>>2]=c[n>>2],x)|0);L=1;i=d;return L|0}s9(E,c[n>>2]|0);do{if((c[o>>2]|0)==0){if((c[p>>2]|0)!=0){A=2787;break}if((c[q>>2]|0)!=0){A=2787}}else{A=2787}}while(0);if((A|0)==2787){w=th(E)|0;y=c[o>>2]|0;o=c[p>>2]|0;p=c[q>>2]|0;te(E,w,y,o,p)|0}p=c[v>>2]|0;v=c[E+28>>2]|0;o=E+32|0;y=c[o>>2]|0;w=E+36|0;q=c[w>>2]|0;s=E+40|0;K=c[s>>2]|0;h=(c[t>>2]|0)!=0?29832:29704;xv(2,39512,3e4,(x=i,i=i+64|0,c[x>>2]=c[n>>2],c[x+8>>2]=p,c[x+16>>2]=v,c[x+24>>2]=y,c[x+32>>2]=q,c[x+40>>2]=K,c[x+48>>2]=h,c[x+56>>2]=C,x)|0);zI(C);yi(a,28976,e,0)|0;yi(a,28488,f,0)|0;yi(a,28344,g,0)|0;C=c[e>>2]|0;if((C|0)==0){M=c[o>>2]|0}else{M=C}c[e>>2]=M;C=c[f>>2]|0;if((C|0)==0){N=c[w>>2]|0}else{N=C}c[f>>2]=N;C=c[g>>2]|0;if((C|0)==0){O=c[s>>2]|0}else{O=C}c[g>>2]=O;tf(E,M,N,O);do{if((c[o>>2]|0)==(c[e>>2]|0)){if((c[w>>2]|0)!=(c[f>>2]|0)){A=2797;break}if((c[s>>2]|0)!=(c[g>>2]|0)){A=2797}}else{A=2797}}while(0);if((A|0)==2797){A=tg(E)|0;g=c[E+44>>2]|0;s=c[E+48>>2]|0;f=c[E+52>>2]|0;xv(2,39512,28168,(x=i,i=i+32|0,c[x>>2]=A,c[x+8>>2]=g,c[x+16>>2]=s,c[x+24>>2]=f,x)|0)}f=w7(a,E)|0;if((f|0)!=0){c[b>>2]=f;L=0;i=d;return L|0}c[b>>2]=0;if((c[u>>2]|0)!=0){L=0;i=d;return L|0}xt(0,29368,(x=i,i=i+8|0,c[x>>2]=c[n>>2],x)|0);L=1;i=d;return L|0}function w9(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+32|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=(d|0)!=0;if(k){c[d>>2]=0}l=yc(b,0,34304)|0;if((l|0)==0){m=0;i=e;return m|0}L3985:do{if(k){n=l;while(1){ym(n,39440,f,0)|0;if((yi(n,32656,h,0)|0)!=0){yi(n,30688,h,0)|0}do{if((yi(n,28648,j,0)|0)==0){c[j>>2]=c[j>>2]<<20}else{if((yi(n,26968,j,0)|0)==0){c[j>>2]=c[j>>2]<<10;break}else{yi(n,25424,j,65536)|0;break}}}while(0);yj(n,24224,g,0)|0;o=xI(c[f>>2]|0)|0;p=c[j>>2]|0;q=(o|0)==0;xv(2,22640,21464,(x=i,i=i+24|0,c[x>>2]=c[h>>2],c[x+8>>2]=p,c[x+16>>2]=q?41576:o,x)|0);p=r0(c[h>>2]|0,c[j>>2]|0,1)|0;if((p|0)==0){r=o;s=2833;break L3985}r3(p,c[g>>2]&255);rK(p,0);r7(a,p,1);if((c[h>>2]|0)==0){c[d>>2]=p}if(!q){if((xh(p,o)|0)!=0){t=o;s=2836;break L3985}}zI(o);o=yc(b,n,34304)|0;if((o|0)==0){m=0;break}else{n=o}}i=e;return m|0}else{n=l;while(1){ym(n,39440,f,0)|0;if((yi(n,32656,h,0)|0)!=0){yi(n,30688,h,0)|0}do{if((yi(n,28648,j,0)|0)==0){c[j>>2]=c[j>>2]<<20}else{if((yi(n,26968,j,0)|0)==0){c[j>>2]=c[j>>2]<<10;break}else{yi(n,25424,j,65536)|0;break}}}while(0);yj(n,24224,g,0)|0;o=xI(c[f>>2]|0)|0;p=c[j>>2]|0;q=(o|0)==0;xv(2,22640,21464,(x=i,i=i+24|0,c[x>>2]=c[h>>2],c[x+8>>2]=p,c[x+16>>2]=q?41576:o,x)|0);p=r0(c[h>>2]|0,c[j>>2]|0,1)|0;if((p|0)==0){r=o;s=2833;break L3985}r3(p,c[g>>2]&255);rK(p,0);r7(a,p,1);if(!q){if((xh(p,o)|0)!=0){t=o;s=2836;break L3985}}zI(o);o=yc(b,n,34304)|0;if((o|0)==0){m=0;break}else{n=o}}i=e;return m|0}}while(0);if((s|0)==2833){xt(0,40472,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);zI(r);m=1;i=e;return m|0}else if((s|0)==2836){xt(0,38920,(x=i,i=i+8|0,c[x>>2]=t,x)|0);zI(t);m=1;i=e;return m|0}return 0}function xa(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+32|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=yc(b,0,37960)|0;if((j|0)==0){k=0;i=d;return k|0}else{l=j}while(1){ym(l,39440,e,0)|0;if((yi(l,32656,g,0)|0)!=0){yi(l,30688,g,0)|0}do{if((yi(l,28648,h,0)|0)==0){c[h>>2]=c[h>>2]<<20}else{if((yi(l,26968,h,0)|0)==0){c[h>>2]=c[h>>2]<<10;break}else{yi(l,25424,h,65536)|0;break}}}while(0);yj(l,24224,f,0)|0;m=xI(c[e>>2]|0)|0;j=c[h>>2]|0;n=(m|0)!=0;xv(2,37040,21464,(x=i,i=i+24|0,c[x>>2]=c[g>>2],c[x+8>>2]=j,c[x+16>>2]=n?m:41576,x)|0);j=r0(c[g>>2]|0,c[h>>2]|0,1)|0;if((j|0)==0){o=2853;break}r3(j,c[f>>2]&255);rK(j,1);r7(a,j,1);if(n){if((xh(j,m)|0)!=0){o=2856;break}}zI(m);j=yc(b,l,37960)|0;if((j|0)==0){k=0;o=2862;break}else{l=j}}if((o|0)==2853){xt(0,40472,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);zI(m);k=1;i=d;return k|0}else if((o|0)==2856){xt(0,35104,(x=i,i=i+8|0,c[x>>2]=m,x)|0);zI(m);k=1;i=d;return k|0}else if((o|0)==2862){i=d;return k|0}return 0}function xb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0;d=i;i=i+72|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;l=d+48|0;m=d+56|0;n=d+64|0;o=yc(a,0,34280)|0;ym(o,39424,m,32648)|0;p=(o|0)==0;L4054:do{if((b|0)==0){L4062:do{if(!p){q=o;while(1){r=c[m>>2]|0;if((aP(r|0,32648)|0)==0){s=q;break L4054}if((aP(r|0,34184)|0)==0){break}r=yc(a,q,34280)|0;ym(r,39424,m,32648)|0;if((r|0)==0){break L4062}else{q=r}}if((q|0)!=0){s=q;break L4054}}}while(0);c[m>>2]=32648;s=0}else{L4056:do{if(p){t=0}else{r=o;while(1){if((aP(b|0,c[m>>2]|0)|0)==0){t=r;break L4056}u=yc(a,r,34280)|0;ym(u,39424,m,32648)|0;if((u|0)==0){t=0;break}else{r=u}}}}while(0);c[m>>2]=b;s=t}}while(0);ym(s,30680,n,0)|0;yj(s,28632,h,4)|0;yj(s,26952,j,3)|0;yj(s,25416,f,512)|0;yj(s,24216,g,384)|0;yj(s,22632,e,1)|0;t=k|0;yk(s,21448,t,1)|0;b=k+4|0;yk(s,41560,b,1)|0;k=l|0;yk(s,40456,k,1)|0;a=l+4|0;yk(s,38904,a,1)|0;l=c[n>>2]|0;o=c[h>>2]|0;p=c[j>>2]|0;r=c[f>>2]|0;q=c[g>>2]|0;u=c[e>>2]|0;v=c[t>>2]|0;w=c[b>>2]|0;y=c[k>>2]|0;z=c[a>>2]|0;xv(2,37952,36960,(x=i,i=i+88|0,c[x>>2]=c[m>>2],c[x+8>>2]=(l|0)!=0?l:35096,c[x+16>>2]=o,c[x+24>>2]=p,c[x+32>>2]=r,c[x+40>>2]=q,c[x+48>>2]=u,c[x+56>>2]=v,c[x+64>>2]=w,c[x+72>>2]=y,c[x+80>>2]=z,x)|0);z=c[m>>2]|0;L4070:do{if((aP(z|0,34696)|0)==0){xt(0,34400,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0)}else{do{if((aP(z|0,34184)|0)==0){m=zz(s)|0;if((m|0)!=0){A=m;break}xt(0,33944,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);break L4070}else{if((aP(z|0,32648)|0)!=0){xt(0,33112,(x=i,i=i+8|0,c[x>>2]=z,x)|0);break L4070}m=zi(s)|0;if((m|0)!=0){A=m;break}xt(0,33544,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);break L4070}}while(0);m=c[n>>2]|0;if((m|0)!=0){zo(A,m)|0}y8(A,c[e>>2]|0);y7(A,c[f>>2]|0,c[g>>2]|0);y9(A,c[h>>2]|0,c[j>>2]|0);y6(A,c[t>>2]|0,c[b>>2]|0,c[k>>2]|0,c[a>>2]|0);B=A;i=d;return B|0}}while(0);xt(0,32432,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);B=0;i=d;return B|0}function xc(){c[10764]=0;return}function xd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=c[10764]|0;if(e>>>0>15){f=1;return f|0}c[43064+(e*12|0)>>2]=a;c[43068+(e*12|0)>>2]=(b|0)!=0;c[43072+(e*12|0)>>2]=d;c[10764]=e+1;f=0;return f|0}function xe(c,f,g){c=c|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;h=i;i=i+280|0;j=h|0;k=h+8|0;l=h+16|0;m=l+1|0;n=l+2|0;o=l|0;p=l+260|0;q=l+4|0;r=l+5|0;s=0;t=1;L4095:while(1){L4097:while(1){u=aS(c|0)|0;if((u|0)==(-1|0)){v=0;w=2923;break L4095}else if((u|0)==13|(u|0)==10){continue}else if((u|0)!=58){while(1){u=aS(c|0)|0;if((u|0)==(-1|0)|(u|0)==13|(u|0)==10){continue L4097}}}if((xf(c,m)|0)!=0){v=0;w=2924;break L4095}if((xf(c,j)|0)!=0){v=0;w=2921;break L4095}if((xf(c,k)|0)!=0){v=0;w=2922;break L4095}b[n>>1]=(d[j]|0)<<8|(d[k]|0);if((xf(c,o)|0)==0){x=0}else{v=0;w=2925;break L4095}while(1){if(x>>>0>=(d[m]|0)>>>0){break}if((xf(c,l+4+x|0)|0)==0){x=x+1|0}else{v=0;w=2926;break L4095}}if((xf(c,p)|0)!=0){v=0;w=2927;break L4095}do{u=aS(c|0)|0}while(!((u|0)==(-1|0)|(u|0)==13|(u|0)==10));u=a[p]|0;y=a[m]|0;z=e[n>>1]|0;A=y&255;B=a[o]|0;C=z+A+(z>>>8)+(B&255)&255;D=y<<24>>24==0;if(D){E=C}else{F=0;G=C;while(1){C=(a[l+4+F|0]|0)+G&255;H=F+1|0;if(H>>>0<A>>>0){F=H;G=C}else{E=C;break}}}if(u<<24>>24!=(-E&255)<<24>>24){v=1;w=2928;break L4095}if((B<<24>>24|0)==1){v=0;w=2929;break L4095}else if((B<<24>>24|0)==4){w=2915;break}else if((B<<24>>24|0)==2){w=2917;break}else if((B<<24>>24|0)!=0){continue}if(D){continue}if(t){G=0;while(1){b5[g&255](f,G+s+z|0,a[l+4+G|0]|0);F=G+1|0;if(F>>>0<A>>>0){G=F}else{continue L4097}}}else{G=0;while(1){b5[g&255](f,(z+G&65535)+s|0,a[l+4+G|0]|0);D=G+1|0;if(D>>>0<A>>>0){G=D}else{continue L4097}}}}if((w|0)==2915){w=0;if(y<<24>>24!=2){v=1;w=2930;break}s=((d[q]|0)<<8|(d[r]|0))<<16;t=1;continue}else if((w|0)==2917){w=0;if(y<<24>>24!=2){v=1;w=2931;break}s=((d[q]|0)<<8|(d[r]|0))<<4;t=0;continue}}if((w|0)==2926){i=h;return v|0}else if((w|0)==2923){i=h;return v|0}else if((w|0)==2924){i=h;return v|0}else if((w|0)==2925){i=h;return v|0}else if((w|0)==2927){i=h;return v|0}else if((w|0)==2928){i=h;return v|0}else if((w|0)==2931){i=h;return v|0}else if((w|0)==2929){i=h;return v|0}else if((w|0)==2930){i=h;return v|0}else if((w|0)==2921){i=h;return v|0}else if((w|0)==2922){i=h;return v|0}return 0}function xf(b,c){b=b|0;c=c|0;var e=0,f=0;a[c]=0;e=aS(b|0)|0;do{if((e-48|0)>>>0<10){a[c]=((d[c]|0)<<4|e+208)&255}else{if((e-65|0)>>>0<6){a[c]=((d[c]|0)<<4|e+201)&255;break}if((e-97|0)>>>0<6){a[c]=((d[c]|0)<<4|e+169)&255;break}else{f=1;return f|0}}}while(0);e=aS(b|0)|0;if((e-48|0)>>>0<10){a[c]=((d[c]|0)<<4|e+208)&255;f=0;return f|0}if((e-65|0)>>>0<6){a[c]=((d[c]|0)<<4|e+201)&255;f=0;return f|0}if((e-97|0)>>>0>=6){f=1;return f|0}a[c]=((d[c]|0)<<4|e+169)&255;f=0;return f|0}function xg(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;f=i;i=i+272|0;g=f|0;h=g|0;j=g+8|0;k=g+1|0;l=g+4|0;m=g+268|0;L4166:while(1){n=aS(b|0)|0;L4168:do{if((n|0)==83){o=aS(b|0)|0;do{if((o-48|0)>>>0<10){p=o+208&255}else{if((o-65|0)>>>0<6){p=o+201&255;break}if((o-97|0)>>>0>=6){break L4168}p=o+169&255}}while(0);a[h]=p;o=c[488+((p&255)<<2)>>2]|0;c[j>>2]=o;q=aS(b|0)|0;do{if((q-48|0)>>>0<10){r=q+208&255}else{if((q-65|0)>>>0<6){r=q+201&255;break}if((q-97|0)>>>0>=6){s=0;t=3022;break L4166}r=q+169&255}}while(0);q=aS(b|0)|0;do{if((q-48|0)>>>0<10){u=q+208&255}else{if((q-65|0)>>>0<6){u=q+201&255;break}if((q-97|0)>>>0>=6){s=0;t=3026;break L4166}u=q+169&255}}while(0);q=u&15|r<<4;a[k]=q;v=q&255;q=o+1|0;if(v>>>0<q>>>0){s=0;t=3028;break L4166}w=v-q&255;a[k]=w;c[l>>2]=0;q=0;v=0;do{x=aS(b|0)|0;do{if((x-48|0)>>>0<10){y=x+208&255}else{if((x-65|0)>>>0<6){y=x+201&255;break}if((x-97|0)>>>0>=6){s=0;t=3029;break L4166}y=x+169&255}}while(0);x=aS(b|0)|0;do{if((x-48|0)>>>0<10){z=x+208&255}else{if((x-65|0)>>>0<6){z=x+201&255;break}if((x-97|0)>>>0>=6){s=0;t=3025;break L4166}z=x+169&255}}while(0);v=(z&15|y<<4)&255|v<<8;c[l>>2]=v;q=q+1|0;}while(q>>>0<o>>>0);if(w<<24>>24==0){A=0}else{o=0;while(1){q=g+12+o|0;v=aS(b|0)|0;do{if((v-48|0)>>>0<10){B=v+208&255}else{if((v-65|0)>>>0<6){B=v+201&255;break}if((v-97|0)>>>0>=6){s=0;t=3032;break L4166}B=v+169&255}}while(0);v=aS(b|0)|0;do{if((v-48|0)>>>0<10){C=v+208&255}else{if((v-65|0)>>>0<6){C=v+201&255;break}if((v-97|0)>>>0>=6){s=0;t=3024;break L4166}C=v+169&255}}while(0);a[q]=C&15|B<<4;v=o+1|0;x=a[k]|0;if(v>>>0<(x&255)>>>0){o=v}else{A=x;break}}}o=aS(b|0)|0;do{if((o-48|0)>>>0<10){D=o+208&255}else{if((o-65|0)>>>0<6){D=o+201&255;break}if((o-97|0)>>>0>=6){s=0;t=3030;break L4166}D=o+169&255}}while(0);o=aS(b|0)|0;do{if((o-48|0)>>>0<10){E=o+208&255}else{if((o-65|0)>>>0<6){E=o+201&255;break}if((o-97|0)>>>0>=6){s=0;t=3021;break L4166}E=o+169&255}}while(0);o=E&15|D<<4;a[m]=o;do{w=aS(b|0)|0}while(!((w|0)==(-1|0)|(w|0)==13|(w|0)==10));w=A&255;x=c[l>>2]|0;v=(c[j>>2]|0)+1+w+x+(x>>>8)+(x>>>16)+(x>>>24)&255;F=A<<24>>24==0;if(F){G=v}else{H=0;I=v;while(1){v=(a[g+12+H|0]|0)+I&255;J=H+1|0;if(J>>>0<w>>>0){H=J;I=v}else{G=v;break}}}if(o<<24>>24!=~G<<24>>24){s=1;t=3023;break L4166}I=a[h]|0;if((I<<24>>24|0)==9|(I<<24>>24|0)==8|(I<<24>>24|0)==7){s=0;t=3031;break L4166}else if(!((I<<24>>24|0)==1|(I<<24>>24|0)==2|(I<<24>>24|0)==3)){continue L4166}if(F){continue L4166}else{K=0}while(1){b5[e&255](d,x+K|0,a[g+12+K|0]|0);I=K+1|0;if(I>>>0<w>>>0){K=I}else{continue L4166}}}else if((n|0)==(-1|0)){s=0;t=3027;break L4166}else if((n|0)==13|(n|0)==10){continue L4166}}while(0);while(1){n=aS(b|0)|0;if((n|0)==(-1|0)|(n|0)==13|(n|0)==10){continue L4166}}}if((t|0)==3021){i=f;return s|0}else if((t|0)==3022){i=f;return s|0}else if((t|0)==3023){i=f;return s|0}else if((t|0)==3024){i=f;return s|0}else if((t|0)==3025){i=f;return s|0}else if((t|0)==3026){i=f;return s|0}else if((t|0)==3027){i=f;return s|0}else if((t|0)==3028){i=f;return s|0}else if((t|0)==3029){i=f;return s|0}else if((t|0)==3030){i=f;return s|0}else if((t|0)==3031){i=f;return s|0}else if((t|0)==3032){i=f;return s|0}return 0}function xh(a,b){a=a|0;b=b|0;var d=0,e=0;d=bl(b|0,34232)|0;if((d|0)==0){e=1;return e|0}bK(c[a+44>>2]|0,1,c[a+40>>2]|0,d|0)|0;au(d|0)|0;e=0;return e|0}function xi(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;xv(2,39400,28592,(x=i,i=i+16|0,c[x>>2]=b,c[x+8>>2]=d,x)|0);f=bl(b|0,34232|0)|0;if((f|0)==0){g=1;i=e;return g|0}b=aS(f|0)|0;if((b|0)!=-1){h=d;d=b&255;while(1){sc(a,h,d);b=aS(f|0)|0;if((b|0)==-1){break}else{h=h+1|0;d=b&255}}}au(f|0)|0;g=0;i=e;return g|0}function xj(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;if((d|0)==0){h=1;i=g;return h|0}if((e|0)==0){j=d;k=0;l=3049}else{if((aP(e|0,26944)|0)==0){j=d;k=0;l=3049}else{m=e}}do{if((l|0)==3049){while(1){l=0;e=a[d+k|0]|0;if((e<<24>>24|0)==46){n=k+1|0;j=d+n|0;k=n;l=3049;continue}else if((e<<24>>24|0)==0){break}else{j=j;k=k+1|0;l=3049;continue}}if((zV(j|0,25408)|0)==0){m=25408;break}if((zV(j|0,24208)|0)==0){m=25408;break}if((zV(j|0,22624)|0)==0){m=22624;break}if((zV(j|0,21440)|0)==0){m=41552;break}else{h=1}i=g;return h|0}}while(0);if((aP(m|0,41552)|0)==0){h=xi(b,d,f)|0;i=g;return h|0}if((aP(m|0,25408)|0)==0){xv(2,39400,32568,(x=i,i=i+8|0,c[x>>2]=d,x)|0);f=bl(d|0,34232)|0;if((f|0)==0){h=1;i=g;return h|0}j=xe(f,b,142)|0;au(f|0)|0;h=j;i=g;return h|0}if((aP(m|0,22624)|0)!=0){h=1;i=g;return h|0}xv(2,39400,30656,(x=i,i=i+8|0,c[x>>2]=d,x)|0);m=bl(d|0,34232)|0;if((m|0)==0){h=1;i=g;return h|0}d=xg(m,b,142)|0;au(m|0)|0;h=d;i=g;return h|0}function xk(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;h=0;j=0;L4328:while(1){k=h;do{k=yc(b,k,40448)|0;if((k|0)==0){break L4328}ym(k,38896,e,41552)|0;ym(k,37936,f,0)|0;if((yi(k,36952,g,0)|0)!=0){yi(k,35088,g,0)|0}l=c[f>>2]|0;}while((l|0)==0);m=xI(l)|0;if((xj(a,m,c[e>>2]|0,c[g>>2]|0)|0)==0){n=j}else{xt(0,34664,(x=i,i=i+8|0,c[x>>2]=m,x)|0);n=1}zI(m);h=k;j=n}i=d;return j|0}function xl(a,b){a=a|0;b=b|0;var d=0,e=0;d=bl(a|0,34152)|0;if((d|0)==0){e=1;return e|0}a=c[10764]|0;if(a>>>0>15){au(d|0)|0;e=1;return e|0}else{c[43064+(a*12|0)>>2]=d;c[43068+(a*12|0)>>2]=1;c[43072+(a*12|0)>>2]=b;c[10764]=a+1;e=0;return e|0}return 0}function xm(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=c[10764]|0;e=0;while(1){if(e>>>0>=d>>>0){f=3097;break}if((c[43064+(e*12|0)>>2]|0)==(a|0)){break}else{e=e+1|0}}if((f|0)==3097){return}c[43072+(e*12|0)>>2]=b;return}function xn(a,b,d){a=a|0;b=b|0;d=d|0;c[a>>2]=d;c[a+4>>2]=b;return}function xo(a,b,d){a=a|0;b=b|0;d=d|0;c[a+8>>2]=d;c[a+12>>2]=b;return}function xp(a,b,d){a=a|0;b=b|0;d=d|0;c[a+16>>2]=b;c[a+20>>2]=d;return}function xq(a,b,d){a=a|0;b=b|0;d=d|0;c[a+24>>2]=b;c[a+28>>2]=d;return}function xr(a,b){a=a|0;b=b|0;c[a+32>>2]=b;return}function xs(b,c){b=b|0;c=c|0;a[b+56|0]=(c|0)!=0|0;return}function xt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+16|0;f=e|0;g=c[10764]|0;if((g|0)==0){i=e;return}h=f|0;j=f;f=0;k=g;while(1){if((c[43072+(f*12|0)>>2]|0)>>>0<a>>>0){l=k}else{c[j>>2]=d;c[j+4>>2]=0;g=43064+(f*12|0)|0;m=c[g>>2]|0;by(m|0,b|0,h|0)|0;m=c[g>>2]|0;ax(m|0)|0;l=c[10764]|0}m=f+1|0;if(m>>>0<l>>>0){f=m;k=l}else{break}}i=e;return}function xu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=c[10764]|0;if((e|0)==0){return}else{f=0;g=e}while(1){if((c[43072+(f*12|0)>>2]|0)>>>0<a>>>0){h=g}else{e=43064+(f*12|0)|0;i=c[e>>2]|0;by(i|0,b|0,d|0)|0;i=c[e>>2]|0;ax(i|0)|0;h=c[10764]|0}i=f+1|0;if(i>>>0<h>>>0){f=i;g=h}else{break}}return}function xv(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+16|0;g=f|0;h=(b|0)==0?44504:b;b=c[10764]|0;if((b|0)==0){i=f;return}j=g|0;k=g;g=0;l=b;while(1){if((c[43072+(g*12|0)>>2]|0)>>>0<a>>>0){m=l}else{c[k>>2]=e;c[k+4>>2]=0;b=43064+(g*12|0)|0;n=c[b>>2]|0;bN(n|0,32560,(x=i,i=i+8|0,c[x>>2]=h,x)|0)|0;n=c[b>>2]|0;by(n|0,d|0,j|0)|0;n=c[b>>2]|0;ax(n|0)|0;m=c[10764]|0}n=g+1|0;if(n>>>0<m>>>0){g=n;l=m}else{break}}i=f;return}function xw(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[d+40>>2]=0;b[d+44>>1]=0;e=d+48|0;c[e>>2]=0;f=d+52|0;c[f>>2]=0;a[d+56|0]=0;c[d+60>>2]=0;zP(d|0,0,38);d=zJ(0,120)|0;g=d;if((d|0)==0){return}c[f>>2]=g;f=1216;d=10;h=c[e>>2]|0;while(1){i=f|0;L4399:do{if((h|0)==0){j=0}else{k=h;while(1){l=k-1|0;m=g+(l*12|0)|0;if((aP(c[i>>2]|0,c[m>>2]|0)|0)>-1){j=k;break L4399}n=g+(k*12|0)|0;o=m;c[n>>2]=c[o>>2];c[n+4>>2]=c[o+4>>2];c[n+8>>2]=c[o+8>>2];if((l|0)==0){j=0;break}else{k=l}}}}while(0);i=g+(j*12|0)|0;k=f;c[i>>2]=c[k>>2];c[i+4>>2]=c[k+4>>2];c[i+8>>2]=c[k+8>>2];k=h+1|0;c[e>>2]=k;i=d-1|0;if((i|0)==0){break}else{f=f+12|0;d=i;h=k}}return}function xx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=a+52|0;f=a+48|0;a=zJ(c[e>>2]|0,((c[f>>2]|0)+d|0)*12|0)|0;g=a;if((a|0)==0){h=1;return h|0}c[e>>2]=g;if((d|0)==0){h=0;return h|0}e=b;b=d;d=c[f>>2]|0;while(1){a=e|0;L4414:do{if((d|0)==0){i=0}else{j=d;while(1){k=j-1|0;l=g+(k*12|0)|0;if((aP(c[a>>2]|0,c[l>>2]|0)|0)>-1){i=j;break L4414}m=g+(j*12|0)|0;n=l;c[m>>2]=c[n>>2];c[m+4>>2]=c[n+4>>2];c[m+8>>2]=c[n+8>>2];if((k|0)==0){i=0;break}else{j=k}}}}while(0);a=g+(i*12|0)|0;j=e;c[a>>2]=c[j>>2];c[a+4>>2]=c[j+4>>2];c[a+8>>2]=c[j+8>>2];j=d+1|0;c[f>>2]=j;a=b-1|0;if((a|0)==0){h=0;break}else{e=e+12|0;b=a;d=j}}return h|0}function xy(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=a+52|0;d=a+48|0;a=zJ(c[b>>2]|0,((c[d>>2]|0)*12|0)+48|0)|0;e=a;if((a|0)==0){f=1;return f|0}c[b>>2]=e;b=c[d>>2]|0;if((b|0)==0){c[a>>2]=c[292];c[a+4>>2]=c[293];c[a+8>>2]=c[294];a=b+1|0;c[d>>2]=a;g=a;h=3155}else{a=c[292]|0;i=b;while(1){j=i-1|0;k=e+(j*12|0)|0;if((aP(a|0,c[k>>2]|0)|0)>-1){l=i;break}m=e+(i*12|0)|0;n=k;c[m>>2]=c[n>>2];c[m+4>>2]=c[n+4>>2];c[m+8>>2]=c[n+8>>2];if((j|0)==0){l=0;break}else{i=j}}i=e+(l*12|0)|0;c[i>>2]=c[292];c[i+4>>2]=c[293];c[i+8>>2]=c[294];i=b+1|0;c[d>>2]=i;if((i|0)==0){o=0}else{g=i;h=3155}}L4431:do{if((h|0)==3155){i=c[295]|0;l=g;while(1){a=l-1|0;j=e+(a*12|0)|0;if((aP(i|0,c[j>>2]|0)|0)>-1){o=l;break L4431}n=e+(l*12|0)|0;m=j;c[n>>2]=c[m>>2];c[n+4>>2]=c[m+4>>2];c[n+8>>2]=c[m+8>>2];if((a|0)==0){o=0;break}else{l=a}}}}while(0);g=e+(o*12|0)|0;c[g>>2]=c[295];c[g+4>>2]=c[1184>>2];c[g+8>>2]=c[1188>>2];g=b+2|0;c[d>>2]=g;L4437:do{if((g|0)==0){p=0}else{o=c[298]|0;h=g;while(1){l=h-1|0;i=e+(l*12|0)|0;if((aP(o|0,c[i>>2]|0)|0)>-1){p=h;break L4437}a=e+(h*12|0)|0;m=i;c[a>>2]=c[m>>2];c[a+4>>2]=c[m+4>>2];c[a+8>>2]=c[m+8>>2];if((l|0)==0){p=0;break}else{h=l}}}}while(0);g=e+(p*12|0)|0;c[g>>2]=c[298];c[g+4>>2]=c[1196>>2];c[g+8>>2]=c[1200>>2];g=b+3|0;c[d>>2]=g;L4443:do{if((g|0)==0){q=0}else{p=c[301]|0;h=g;while(1){o=h-1|0;l=e+(o*12|0)|0;if((aP(p|0,c[l>>2]|0)|0)>-1){q=h;break L4443}m=e+(h*12|0)|0;a=l;c[m>>2]=c[a>>2];c[m+4>>2]=c[a+4>>2];c[m+8>>2]=c[a+8>>2];if((o|0)==0){q=0;break}else{h=o}}}}while(0);g=e+(q*12|0)|0;c[g>>2]=c[301];c[g+4>>2]=c[1208>>2];c[g+8>>2]=c[1212>>2];c[d>>2]=b+4;f=0;return f|0}function xz(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=a[b]|0;if(d<<24>>24==0){e=0;return e|0}else{f=b;g=d}while(1){if((aP(f|0,c|0)|0)==0){e=1;h=3175;break}else{i=f;j=g}while(1){if((j<<24>>24|0)==46|(j<<24>>24|0)==0){break}d=i+1|0;i=d;j=a[d]|0}d=j<<24>>24==46?i+1|0:i;b=a[d]|0;if(b<<24>>24==0){e=0;h=3176;break}else{f=d;g=b}}if((h|0)==3176){return e|0}else if((h|0)==3175){return e|0}return 0}function xA(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+8|0;f=e|0;g=aw(b|0,f|0,0)|0;h=c[f>>2]|0;do{if((h|0)==(b|0)){j=1}else{if((a[h]|0)!=0){j=1;break}c[d>>2]=g;j=0}}while(0);i=e;return j|0}function xB(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+8|0;f=e|0;g=aw(b|0,f|0,0)|0;h=c[f>>2]|0;do{if((h|0)==(b|0)){j=1}else{if((a[h]|0)!=0){j=1;break}c[d>>2]=g;j=0}}while(0);i=e;return j|0}function xC(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+8|0;f=e|0;g=az(b|0,f|0,0)|0;h=c[f>>2]|0;do{if((h|0)==(b|0)){j=1}else{if((a[h]|0)!=0){j=1;break}c[d>>2]=g;j=0}}while(0);i=e;return j|0}function xD(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;i=i+8|0;f=e|0;do{if((b|0)==0){g=3192}else{if((a[b]|0)==0){g=3192;break}if((aP(b|0,33800)|0)==0){c[d>>2]=1;h=0;break}if((aP(b|0,39296)|0)==0){c[d>>2]=0;h=0;break}j=aw(b|0,f|0,0)|0;k=c[f>>2]|0;if((k|0)==(b|0)){h=1;break}if((a[k]|0)!=0){h=1;break}c[d>>2]=(j|0)!=0;h=0}}while(0);if((g|0)==3192){c[d>>2]=0;h=0}i=e;return h|0}function xE(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=c[b>>2]|0;c[j>>2]=k;l=xT(k,e,j)|0;e=xR(l,32552,32552)|0;k=aw(e|0,h|0,0)|0;m=c[h>>2]|0;do{if((m|0)!=(e|0)){if((a[m]|0)!=0){break}c[d>>2]=k;zI(l);c[b>>2]=xS(c[j>>2]|0,f)|0;n=0;i=g;return n|0}}while(0);zI(l);n=1;i=g;return n|0}function xF(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+8|0;g=f|0;if((xE(a,g,d,e)|0)!=0){h=1;i=f;return h|0}c[b>>2]=c[g>>2];h=0;i=f;return h|0}function xG(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=zN(b|0)|0;while(1){if((e|0)==0){f=0;break}g=e-1|0;if((a[b+g|0]|0)==47){e=g}else{h=3216;break}}do{if((h|0)==3216){if((e|0)==1){if((a[b]|0)==46){f=0;break}}else if((e|0)==0){f=0;break}g=zH(e+1|0)|0;if((g|0)==0){i=1;return i|0}else{zO(g|0,b|0,e)|0;a[g+e|0]=0;f=g;break}}}while(0);e=zJ(c[10744]|0,(c[10746]<<2)+4|0)|0;b=e;if((e|0)==0){zI(f);i=1;return i|0}e=c[10746]|0;if((d|0)==0){if((e|0)!=0){d=e;while(1){h=d-1|0;c[b+(d<<2)>>2]=c[b+(h<<2)>>2];if((h|0)==0){break}else{d=h}}}c[b>>2]=f}else{c[b+(e<<2)>>2]=f}c[10746]=e+1;c[10744]=b;i=0;return i|0}function xH(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=a[b]|0;if((d<<24>>24|0)==45){e=0;f=b+1|0}else if((d<<24>>24|0)==43){e=1;f=b+1|0}else if((d<<24>>24|0)==61){d=b+1|0;g=c[10744]|0;if((c[10746]|0)==0){h=g}else{i=0;j=g;while(1){zI(c[j+(i<<2)>>2]|0);g=i+1|0;k=c[10744]|0;if(g>>>0<(c[10746]|0)>>>0){i=g;j=k}else{h=k;break}}}zI(h);c[10746]=0;c[10744]=0;e=1;f=d}else{e=1;f=b}return xG(f,e)|0}function xI(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((b|0)==0){d=0;return d|0}e=zN(b|0)|0;f=zH(e+1|0)|0;if((f|0)==0){d=0;return d|0}zO(f|0,b|0,e)|0;a[f+e|0]=0;if((a[f]|0)==47|(c[10746]|0)==0){d=f;return d|0}else{g=0}while(1){e=c[(c[10744]|0)+(g<<2)>>2]|0;if((e|0)==0){b=zN(f|0)|0;h=zH(b+1|0)|0;if((h|0)==0){i=3247;break}zO(h|0,f|0,b)|0;a[h+b|0]=0;j=h}else{h=zN(e|0)|0;b=zN(f|0)|0;k=b+h|0;l=zH(k+2|0)|0;if((l|0)==0){i=3247;break}zO(l|0,e|0,h)|0;a[l+h|0]=47;e=l+(h+1)|0;zO(e|0,f|0,b)|0;a[l+(k+1)|0]=0;j=l}m=bl(j|0,33760)|0;if((m|0)!=0){i=3249;break}zI(j);l=g+1|0;if(l>>>0<(c[10746]|0)>>>0){g=l}else{d=f;i=3257;break}}if((i|0)==3257){return d|0}else if((i|0)==3249){au(m|0)|0;zI(f);d=j;return d|0}else if((i|0)==3247){zI(f);d=0;return d|0}return 0}function xJ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=0;while(1){e=yd(b,d,39288)|0;if((e|0)==0){f=0;g=3269;break}h=yy(e)|0;if((h|0)==0){f=1;g=3270;break}i=a[h]|0;if((i<<24>>24|0)==43){j=1;k=h+1|0}else if((i<<24>>24|0)==61){l=h+1|0;m=c[10744]|0;if((c[10746]|0)==0){n=m}else{o=0;p=m;while(1){zI(c[p+(o<<2)>>2]|0);m=o+1|0;q=c[10744]|0;if(m>>>0<(c[10746]|0)>>>0){o=m;p=q}else{n=q;break}}}zI(n);c[10746]=0;c[10744]=0;j=1;k=l}else if((i<<24>>24|0)==45){j=0;k=h+1|0}else{j=1;k=h}if((xG(k,j)|0)==0){d=e}else{f=1;g=3271;break}}if((g|0)==3270){return f|0}else if((g|0)==3271){return f|0}else if((g|0)==3269){return f|0}return 0}function xK(b,c){b=b|0;c=c|0;if(a[784]|0){return}a[784]=1;return}function xL(){if(a[784]|0){return}a[784]=1;return}function xM(b){b=b|0;if((b|0)!=0){c[b>>2]=0}if(a[784]|0){return}a[784]=1;return}function xN(a){a=a|0;c[a>>2]=0;c[a+1028>>2]=0;c[a+1032>>2]=0;c[a+1040>>2]=0;c[a+1044>>2]=0;return}function xO(a,b){a=a|0;b=b|0;c[a+1044>>2]=b;return}function xP(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;if((b|0)==0){d=0}else{d=zN(b|0)|0}if((c|0)==0){e=0}else{e=zN(c|0)|0}f=e+d|0;g=zH(f+1|0)|0;if((g|0)==0){h=0;return h|0}if((d|0)!=0){zO(g|0,b|0,d)|0}if((e|0)!=0){b=g+d|0;zO(b|0,c|0,e)|0}a[g+f|0]=0;h=g;return h|0}function xQ(b){b=b|0;var c=0,d=0,e=0;if((b|0)==0){c=0}else{c=zN(b|0)|0}d=zH(c+1|0)|0;if((d|0)==0){e=0;return e|0}if((c|0)!=0){zO(d|0,b|0,c)|0}a[d+c|0]=0;e=d;return e|0}function xR(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((b|0)==0){e=0;return e|0}L4634:do{if((c|0)==0){f=b}else{g=b;while(1){h=a[g]|0;if(h<<24>>24==0){f=g;break L4634}if((aW(c|0,h<<24>>24|0)|0)==0){f=g;break}else{g=g+1|0}}}}while(0);if((d|0)==0){e=f;return e|0}c=zN(f|0)|0;while(1){if((c|0)==0){i=0;break}b=c-1|0;if((aW(d|0,a[f+b|0]|0)|0)==0){i=c;break}else{c=b}}a[f+i|0]=0;e=f;return e|0}function xS(b,c){b=b|0;c=c|0;var d=0,e=0,f=0;L4648:do{if((b|0)==0){d=0}else{if((c|0)==0){d=b;break}else{e=b}while(1){f=a[e]|0;if(f<<24>>24==0){d=e;break L4648}if((aW(c|0,f<<24>>24|0)|0)==0){d=e;break}else{e=e+1|0}}}}while(0);return d|0}function xT(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((b|0)==0){f=0;return f|0}else{g=0}while(1){h=a[b+g|0]|0;i=h<<24>>24==0;if(i){j=3333;break}k=g+1|0;if((aW(d|0,h<<24>>24|0)|0)==0){g=k}else{l=k;break}}if((j|0)==3333){l=g+1|0}j=zH(l)|0;if((j|0)==0){m=0}else{L4665:do{if((g|0)==0){n=0}else{d=0;while(1){k=a[b+d|0]|0;if(k<<24>>24==0){n=d;break L4665}a[j+d|0]=k;k=d+1|0;if(k>>>0<g>>>0){d=k}else{n=k;break}}}}while(0);a[j+n|0]=0;m=j}if((c[e>>2]|0)==0){f=m;return f|0}c[e>>2]=b+(i?g:l);f=m;return f|0}function xU(a){a=a|0;var b=0,d=0;b=i;i=i+8|0;d=b|0;c[d>>2]=(a>>>0)/1e6|0;c[d+4>>2]=((a>>>0)%1e6|0)*1e3|0;a=br(d|0,0)|0;i=b;return a|0}function xV(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;i=i+8|0;d=b|0;if((bx(d|0,0)|0)!=0){e=0;i=b;return e|0}f=((c[d>>2]|0)*1e6|0)+(c[d+4>>2]|0)|0;d=f-(c[a>>2]|0)|0;c[a>>2]=f;e=d;i=b;return e|0}function xW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=i;i=i+1304|0;d=c|0;xN(d);xO(d,b);if((xX(d,a,c+1048|0)|0)!=0){xY(d,33720,1);x$(d);e=1;i=c;return e|0}if((x1(d,0)|0)<<24>>24==0){x$(d);e=0;i=c;return e|0}else{xY(d,33720,1);x$(d);e=1;i=c;return e|0}return 0}function xX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0;e=i;i=i+32|0;f=e|0;g=e+16|0;if((x5(a,d,256)|0)==0){h=0;i=e;return h|0}j=f+8|0;k=f+12|0;l=g+8|0;L4695:while(1){if((aP(d|0,22608)|0)==0){if((x5(a,d,256)|0)==0){h=1;m=3438;break}}L4700:do{if((x9(a,21424)|0)==0){if((x9(a,40424)|0)!=0){yp(g,0);if((yE(a,b,g)|0)!=0){m=3375;break L4695}if((c[l>>2]|0)==0){m=3375;break L4695}if((yh(b,d,0)|0)==0){n=yh(b,d,1)|0;if((n|0)==0){m=3375;break L4695}yz(n,g)}yq(g);break}if((x9(a,38880)|0)!=0){n=yh(b,d,1)|0;if((n|0)==0){h=1;m=3439;break L4695}if((yE(a,b,n)|0)!=0){h=1;m=3446;break L4695}if((c[n+8>>2]|0)==0){h=1;m=3447;break L4695}else{break}}if((aP(d|0,37920)|0)!=0){if((aP(d|0,36944)|0)!=0){h=1;m=3444;break L4695}if((x6(a,d,256)|0)==0){h=1;m=3445;break L4695}if((x0(a,d,0,1)|0)==0){break}else{m=3418;break L4695}}yp(f,0);if((yE(a,b,f)|0)!=0){m=3383;break L4695}if((c[j>>2]|0)==1){if((c[k>>2]|0)==0){m=3386}else{o=b;p=1}}else{m=3386}if((m|0)==3386){m=0;o=0;p=0}yq(f);if((x9(a,21424)|0)==0){h=1;m=3449;break L4695}if((o|0)==0){n=ya(0)|0;if((n|0)==0){h=1;m=3442;break L4695}c[n+4>>2]=b;r=xX(a,n,d)|0;yb(n);s=r}else{s=xX(a,o,d)|0}if((s|0)!=0){h=1;m=3425;break L4695}if((x9(a,41536)|0)==0){h=1;m=3426;break L4695}else{t=p}while(1){if((x8(a,34392)|0)==0){break L4700}if((x8(a,37920)|0)==0){break}yp(f,0);if((yE(a,b,f)|0)!=0){m=3397;break L4695}do{if((c[j>>2]|0)==1){if((c[k>>2]|0)==0){u=0;break}u=(t|0)!=0?0:b}else{u=0}}while(0);r=(u|0)==0;n=r?t:1;yq(f);if((x9(a,21424)|0)==0){h=1;m=3436;break L4695}if(r){r=ya(0)|0;if((r|0)==0){h=1;m=3450;break L4695}c[r+4>>2]=b;v=xX(a,r,d)|0;yb(r);w=v}else{w=xX(a,u,d)|0}if((w|0)!=0){h=1;m=3451;break L4695}if((x9(a,41536)|0)==0){h=1;m=3429;break L4695}else{t=n}}n=(t|0)!=0?0:b;if((x9(a,21424)|0)==0){h=1;m=3430;break L4695}if((n|0)==0){v=ya(0)|0;if((v|0)==0){h=1;m=3431;break L4695}c[v+4>>2]=b;r=xX(a,v,d)|0;yb(v);y=r}else{y=xX(a,n,d)|0}if((y|0)!=0){h=1;m=3440;break L4695}if((x9(a,41536)|0)==0){h=1;m=3441;break L4695}}else{n=ye(b,d,1)|0;if((n|0)==0){h=1;m=3448;break L4695}if((xX(a,n,d)|0)!=0){h=1;m=3432;break L4695}if((x9(a,41536)|0)==0){h=1;m=3427;break L4695}}}while(0);x9(a,34656)|0;if((x5(a,d,256)|0)==0){h=0;m=3434;break}}if((m|0)==3444){i=e;return h|0}else if((m|0)==3445){i=e;return h|0}else if((m|0)==3446){i=e;return h|0}else if((m|0)==3447){i=e;return h|0}else if((m|0)==3448){i=e;return h|0}else if((m|0)==3449){i=e;return h|0}else if((m|0)==3450){i=e;return h|0}else if((m|0)==3418){b=a+1040|0;y=c[b>>2]|0;if((y|0)==0){z=0}else{z=c[y+4>>2]|0}y=a+1028|0;a=(c[y>>2]|0)+1|0;bN(c[q>>2]|0,30600,(x=i,i=i+24|0,c[x>>2]=(z|0)==0?32544:z,c[x+8>>2]=a,c[x+16>>2]=35056,x)|0)|0;aA(10,c[q>>2]|0)|0;a=c[b>>2]|0;if((a|0)==0){A=0}else{A=c[a+4>>2]|0}a=(c[y>>2]|0)+1|0;bN(c[q>>2]|0,30600,(x=i,i=i+24|0,c[x>>2]=(A|0)==0?32544:A,c[x+8>>2]=a,c[x+16>>2]=d,x)|0)|0;aA(10,c[q>>2]|0)|0;h=1;i=e;return h|0}else if((m|0)==3375){yq(g);h=1;i=e;return h|0}else if((m|0)==3397){yq(f);h=1;i=e;return h|0}else if((m|0)==3427){i=e;return h|0}else if((m|0)==3429){i=e;return h|0}else if((m|0)==3430){i=e;return h|0}else if((m|0)==3431){i=e;return h|0}else if((m|0)==3432){i=e;return h|0}else if((m|0)==3434){i=e;return h|0}else if((m|0)==3383){yq(f);h=1;i=e;return h|0}else if((m|0)==3425){i=e;return h|0}else if((m|0)==3426){i=e;return h|0}else if((m|0)==3451){i=e;return h|0}else if((m|0)==3436){i=e;return h|0}else if((m|0)==3438){i=e;return h|0}else if((m|0)==3439){i=e;return h|0}else if((m|0)==3440){i=e;return h|0}else if((m|0)==3441){i=e;return h|0}else if((m|0)==3442){i=e;return h|0}return 0}function xY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=c[a+1040>>2]|0;if((f|0)==0){g=0}else{g=c[f+4>>2]|0}f=(c[a+1028>>2]|0)+1|0;bN(c[q>>2]|0,30600,(x=i,i=i+24|0,c[x>>2]=(g|0)==0?32544:g,c[x+8>>2]=f,c[x+16>>2]=b,x)|0)|0;L4803:do{if((d|0)!=0){b=c[q>>2]|0;aB(28576,2,1,b|0)|0;b=0;while(1){f=x1(a,b)|0;if((f<<24>>24|0)==0){h=3457;break}else if((f<<24>>24|0)==13|(f<<24>>24|0)==10){h=3458;break}aA(f<<24>>24|0,c[q>>2]|0)|0;b=b+1|0;if(b>>>0>=64){break L4803}}if((h|0)==3457){b=c[q>>2]|0;aB(26928,5,1,b|0)|0;break}else if((h|0)==3458){aB(25392,4,1,c[q>>2]|0)|0;break}}}while(0);aA(10,c[q>>2]|0)|0;i=e;return}function xZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=i;i=i+1304|0;e=d|0;xN(e);do{if((x0(e,c,b,0)|0)==0){if((xX(e,a,d+1048|0)|0)!=0){xY(e,33720,1);x$(e);f=1;break}if((x1(e,0)|0)<<24>>24==0){x$(e);f=0;break}else{xY(e,33720,1);x$(e);f=1;break}}else{yb(a);f=1}}while(0);i=d;return f|0}function x_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=bl(b|0,39232|0)|0;if((c|0)==0){d=1;return d|0}e=xZ(a,c,b)|0;au(c|0)|0;d=e;return d|0}function x$(a){a=a|0;var b=0,d=0;if((a|0)==0){return}b=c[a+1040>>2]|0;if((b|0)==0){return}else{d=b}while(1){b=c[d>>2]|0;if((c[d+12>>2]|0)!=0){a=c[d+8>>2]|0;au(a|0)|0}zI(c[d+4>>2]|0);zI(d);if((b|0)==0){break}else{d=b}}return}function x0(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=zH(24)|0;if((g|0)==0){h=1;return h|0}i=g;zP(g|0,0,16);j=b+1040|0;k=c[j>>2]|0;do{if((k|0)==0){l=zN(d|0)|0;m=zH(l+1|0)|0;if((m|0)==0){n=i;o=3498;break}zO(m|0,d|0,l)|0;a[m+l|0]=0;p=m}else{m=c[k+4>>2]|0;L4846:do{if((a[d]|0)==47|(m|0)==0){q=0}else{l=zN(m|0)|0;while(1){if((l|0)==0){r=0;break}s=l-1|0;if((a[m+s|0]|0)==47){l=s}else{r=l;break}}while(1){if((r|0)==0){q=0;break L4846}l=r-1|0;if((a[m+l|0]|0)==47){q=r;break}else{r=l}}}}while(0);l=zN(d|0)|0;s=l+q|0;t=zH(s+1|0)|0;if((t|0)==0){u=0}else{if((q|0)!=0){zO(t|0,m|0,q)|0}v=t+q|0;zO(v|0,d|0,l)|0;a[t+s|0]=0;u=t}c[k+16>>2]=c[b+1028>>2];c[(c[j>>2]|0)+20>>2]=c[b+1032>>2];if((u|0)==0){n=i;o=3498}else{p=u}}}while(0);if((o|0)==3498){while(1){o=0;u=c[n>>2]|0;if((c[n+12>>2]|0)!=0){k=c[n+8>>2]|0;au(k|0)|0}zI(c[n+4>>2]|0);zI(n);if((u|0)==0){h=1;break}else{n=u;o=3498}}return h|0}c[g+4>>2]=p;do{if((e|0)==0){o=bl(p|0,33616)|0;c[g+8>>2]=o;if((o|0)==0){w=i}else{x=0;break}while(1){o=c[w>>2]|0;if((c[w+12>>2]|0)!=0){n=c[w+8>>2]|0;au(n|0)|0}zI(c[w+4>>2]|0);zI(w);if((o|0)==0){h=1;break}else{w=o}}return h|0}else{c[g+8>>2]=e;x=(f|0)!=0|0}}while(0);c[g+12>>2]=x;c[g>>2]=c[j>>2];c[j>>2]=i;c[b+1028>>2]=0;c[b+1032>>2]=0;h=0;return h|0}function x1(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;if(b>>>0>255){d=0;return d|0}e=a|0;L4886:do{if((c[e>>2]|0)>>>0<=b>>>0){while(1){f=(x2(a)|0)<<24>>24;c[a+4+(c[e>>2]<<2)>>2]=f;f=c[e>>2]|0;if((c[a+4+(f<<2)>>2]|0)==0){d=0;break}g=f+1|0;c[e>>2]=g;if(g>>>0>b>>>0){break L4886}}return d|0}}while(0);d=c[a+4+(b<<2)>>2]&255;return d|0}function x2(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b+1040|0;e=c[d>>2]|0;if((e|0)==0){f=b+1044|0;g=c[f>>2]|0;if((g|0)==0){h=0;return h|0}i=a[g]|0;if(i<<24>>24==0){h=0;return h|0}c[f>>2]=g+1;h=i;return h|0}i=b+1028|0;g=b+1032|0;b=e;while(1){j=aS(c[b+8>>2]|0)|0;if((j|0)!=-1){k=3525;break}e=c[d>>2]|0;if((e|0)==0){h=0;k=3535;break}f=e|0;c[d>>2]=c[f>>2];c[f>>2]=0;if((c[e+12>>2]|0)!=0){f=c[e+8>>2]|0;au(f|0)|0}zI(c[e+4>>2]|0);zI(e);e=c[d>>2]|0;if((e|0)==0){h=0;k=3537;break}c[i>>2]=c[e+16>>2];c[g>>2]=c[e+20>>2];b=e}if((k|0)==3535){return h|0}else if((k|0)==3537){return h|0}else if((k|0)==3525){h=j&255;return h|0}return 0}function x3(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=a|0;e=c[d>>2]|0;if(e>>>0>b>>>0){if((b|0)==0){f=0}else{g=a+1032|0;h=a+1028|0;i=a+1036|0;j=0;while(1){k=c[a+4+(j<<2)>>2]&255;do{if(k<<24>>24!=0){c[g>>2]=(c[g>>2]|0)+1;if((k<<24>>24|0)==10){if((c[i>>2]|0)==0){c[h>>2]=(c[h>>2]|0)+1}c[i>>2]=0;break}else if((k<<24>>24|0)==13){c[h>>2]=(c[h>>2]|0)+1;c[i>>2]=1;break}else{c[i>>2]=0;break}}}while(0);k=j+1|0;if(k>>>0<b>>>0){j=k}else{f=b;break}}}do{c[a+4+(f-b<<2)>>2]=c[a+4+(f<<2)>>2];f=f+1|0;l=c[d>>2]|0;}while(f>>>0<l>>>0);c[d>>2]=l-b;return}if((e|0)==0){m=0}else{l=a+1032|0;f=a+1028|0;j=a+1036|0;i=0;while(1){h=c[a+4+(i<<2)>>2]&255;do{if(h<<24>>24!=0){c[l>>2]=(c[l>>2]|0)+1;if((h<<24>>24|0)==13){c[f>>2]=(c[f>>2]|0)+1;c[j>>2]=1;break}else if((h<<24>>24|0)==10){if((c[j>>2]|0)==0){c[f>>2]=(c[f>>2]|0)+1}c[j>>2]=0;break}else{c[j>>2]=0;break}}}while(0);h=i+1|0;if(h>>>0<e>>>0){i=h}else{m=e;break}}}c[d>>2]=0;if((m|0)==(b|0)){return}d=a+1032|0;e=a+1028|0;i=a+1036|0;j=b-m|0;do{m=x2(a)|0;do{if(m<<24>>24!=0){c[d>>2]=(c[d>>2]|0)+1;if((m<<24>>24|0)==10){if((c[i>>2]|0)==0){c[e>>2]=(c[e>>2]|0)+1}c[i>>2]=0;break}else if((m<<24>>24|0)==13){c[e>>2]=(c[e>>2]|0)+1;c[i>>2]=1;break}else{c[i>>2]=0;break}}}while(0);j=j-1|0;}while((j|0)!=0);return}function x4(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=a|0;d=a+4|0;e=a+8|0;f=0;L4971:while(1){g=f;h=c[b>>2]|0;L4973:while(1){if((h|0)==0){while(1){i=(x2(a)|0)<<24>>24;c[a+4+(c[b>>2]<<2)>>2]=i;i=c[b>>2]|0;if((c[a+4+(i<<2)>>2]|0)==0){j=3612;break L4971}k=i+1|0;c[b>>2]=k;if((k|0)!=0){l=k;break}}}else{l=h}k=c[d>>2]&255;if((k<<24>>24|0)==32|(k<<24>>24|0)==9|(k<<24>>24|0)==13|(k<<24>>24|0)==10){j=3584;break}else if((k<<24>>24|0)==35){i=l;while(1){if((i|0)==0){while(1){m=(x2(a)|0)<<24>>24;c[a+4+(c[b>>2]<<2)>>2]=m;m=c[b>>2]|0;if((c[a+4+(m<<2)>>2]|0)==0){g=1;h=m;continue L4973}n=m+1|0;c[b>>2]=n;if((n|0)!=0){break}}}n=c[d>>2]&255;if(n<<24>>24==0){f=1;continue L4971}x3(a,1);if((n<<24>>24|0)==10){f=1;continue L4971}else if((n<<24>>24|0)==13){break}i=c[b>>2]|0}if((c[b>>2]|0)!=0){break}while(1){i=(x2(a)|0)<<24>>24;c[a+4+(c[b>>2]<<2)>>2]=i;i=c[b>>2]|0;if((c[a+4+(i<<2)>>2]|0)==0){g=1;h=i;continue L4973}n=i+1|0;c[b>>2]=n;if((n|0)!=0){break L4973}}}else if((k<<24>>24|0)!=47){j=3610;break L4971}if(l>>>0<=1){do{n=(x2(a)|0)<<24>>24;c[a+4+(c[b>>2]<<2)>>2]=n;n=c[b>>2]|0;if((c[a+4+(n<<2)>>2]|0)==0){j=3611;break L4971}i=n+1|0;c[b>>2]=i;}while(i>>>0<=1)}if((c[e>>2]&255)<<24>>24!=42){j=3613;break L4971}x3(a,2);k=0;i=0;while(1){if((c[b>>2]|0)==0){while(1){n=(x2(a)|0)<<24>>24;c[a+4+(c[b>>2]<<2)>>2]=n;n=c[b>>2]|0;if((c[a+4+(n<<2)>>2]|0)==0){g=1;h=n;continue L4973}m=n+1|0;c[b>>2]=m;if((m|0)!=0){break}}}m=c[d>>2]&255;if(m<<24>>24==0){f=1;continue L4971}x3(a,1);if(!(k<<24>>24==42&m<<24>>24==47)){n=k<<24>>24==47&m<<24>>24==42;k=n?0:m;i=(n&1)+i|0;continue}if((i|0)==0){f=1;continue L4971}k=0;i=i-1|0}}if((j|0)==3584){j=0;x3(a,1);f=1;continue}if((c[d>>2]&255)<<24>>24!=10){f=1;continue}x3(a,1);f=1}if((j|0)==3613){return g|0}else if((j|0)==3610){return g|0}else if((j|0)==3611){return g|0}else if((j|0)==3612){return g|0}return 0}function x5(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;x4(b)|0;f=b|0;L5023:do{if((c[f>>2]|0)==0){while(1){g=(x2(b)|0)<<24>>24;c[b+4+(c[f>>2]<<2)>>2]=g;g=c[f>>2]|0;if((c[b+4+(g<<2)>>2]|0)==0){h=0;break L5023}i=g+1|0;c[f>>2]=i;if((i|0)!=0){j=3617;break}}}else{j=3617}}while(0);if((j|0)==3617){h=c[b+4>>2]&255}do{if(!((h-97&255)<26|(h-65&255)<26)){if((h<<24>>24|0)==95|(h<<24>>24|0)==36){break}else{k=0}return k|0}}while(0);L5034:do{if((e|0)==0){l=0}else{j=0;i=h;L5035:while(1){g=j+1|0;m=d+j|0;a[m]=i;L5037:do{if(g>>>0>255){n=0}else{if((c[f>>2]|0)>>>0<=g>>>0){do{o=(x2(b)|0)<<24>>24;c[b+4+(c[f>>2]<<2)>>2]=o;o=c[f>>2]|0;if((c[b+4+(o<<2)>>2]|0)==0){n=0;break L5037}p=o+1|0;c[f>>2]=p;}while(p>>>0<=g>>>0)}n=c[b+4+(g<<2)>>2]&255}}while(0);do{if(!((n-97&255)<26|(n-65&255)<26|n<<24>>24==95|(n-48&255)<10)){if((n<<24>>24|0)==43){if((a[m]|0)==91&g>>>0<e>>>0){j=g;i=n;continue L5035}else{l=g;break L5034}}else if((n<<24>>24|0)==93|(n<<24>>24|0)==91|(n<<24>>24|0)==46){break}else if((n<<24>>24|0)==45){if((a[m]|0)==91&g>>>0<e>>>0){j=g;i=n;continue L5035}else{l=g;break L5034}}else{l=g;break L5034}}}while(0);if(g>>>0<e>>>0){j=g;i=n}else{l=g;break}}}}while(0);if(l>>>0>=e>>>0){k=0;return k|0}a[d+l|0]=0;x3(b,l);k=1;return k|0}function x6(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;x4(b)|0;f=b|0;L5057:do{if((c[f>>2]|0)==0){while(1){g=(x2(b)|0)<<24>>24;c[b+4+(c[f>>2]<<2)>>2]=g;g=c[f>>2]|0;if((c[b+4+(g<<2)>>2]|0)==0){h=0;break}i=g+1|0;c[f>>2]=i;if((i|0)!=0){break L5057}}return h|0}}while(0);if((c[b+4>>2]&255)<<24>>24!=34|(e|0)==0){h=0;return h|0}else{j=1;k=0}L5065:while(1){if(j>>>0>255){h=1;l=3691;break}i=c[f>>2]|0;if(i>>>0>j>>>0){m=i}else{while(1){i=(x2(b)|0)<<24>>24;c[b+4+(c[f>>2]<<2)>>2]=i;i=c[f>>2]|0;if((c[b+4+(i<<2)>>2]|0)==0){h=1;l=3687;break L5065}g=i+1|0;c[f>>2]=g;if(g>>>0>j>>>0){m=g;break}}}g=c[b+4+(j<<2)>>2]&255;L5073:do{if((g<<24>>24|0)==34){l=3679;break L5065}else if((g<<24>>24|0)==0){h=1;l=3692;break L5065}else if((g<<24>>24|0)==92){i=j+1|0;if(i>>>0>255){n=j;o=92;break}if(m>>>0>i>>>0){p=m}else{while(1){q=(x2(b)|0)<<24>>24;c[b+4+(c[f>>2]<<2)>>2]=q;q=c[f>>2]|0;if((c[b+4+(q<<2)>>2]|0)==0){n=j;o=92;break L5073}r=q+1|0;c[f>>2]=r;if(r>>>0>i>>>0){p=r;break}}}r=c[b+4+(i<<2)>>2]<<24>>24;if((r|0)==114){n=i;o=13;break}else if((r|0)==118){n=i;o=11;break}else if((r|0)==92){n=i;o=92;break}else if((r|0)==98){n=i;o=8;break}else if((r|0)==102){n=i;o=12;break}else if((r|0)==97){n=i;o=7;break}else if((r|0)==34){n=i;o=34;break}else if((r|0)==120){q=j+2|0;if(q>>>0>255){h=0;l=3693;break L5065}if(p>>>0>q>>>0){s=p}else{while(1){t=(x2(b)|0)<<24>>24;c[b+4+(c[f>>2]<<2)>>2]=t;t=c[f>>2]|0;if((c[b+4+(t<<2)>>2]|0)==0){h=0;l=3688;break L5065}u=t+1|0;c[f>>2]=u;if(u>>>0>q>>>0){s=u;break}}}u=c[b+4+(q<<2)>>2]&255;t=u-48&255;do{if((t&255)<10){v=t}else{if((u-97&255)<6){v=u-87&255;break}if((u-65&255)>=6){h=0;l=3686;break L5065}v=u-55&255}}while(0);u=j+3|0;if(u>>>0>255){h=0;l=3683;break L5065}if(s>>>0<=u>>>0){do{t=(x2(b)|0)<<24>>24;c[b+4+(c[f>>2]<<2)>>2]=t;t=c[f>>2]|0;if((c[b+4+(t<<2)>>2]|0)==0){h=0;l=3684;break L5065}q=t+1|0;c[f>>2]=q;}while(q>>>0<=u>>>0)}q=c[b+4+(u<<2)>>2]&255;t=q-48&255;do{if((t&255)<10){w=t}else{if((q-97&255)<6){w=q-87&255;break}if((q-65&255)>=6){h=0;l=3689;break L5065}w=q-55&255}}while(0);n=u;o=w+(v<<4)&255;break}else if((r|0)==110){n=i;o=10;break}else{n=j;o=92;break}}else{n=j;o=g}}while(0);g=k+1|0;a[d+k|0]=o;if(g>>>0<e>>>0){j=n+1|0;k=g}else{h=0;l=3690;break}}if((l|0)==3679){a[d+k|0]=0;x3(b,j+1|0);h=1;return h|0}else if((l|0)==3686){return h|0}else if((l|0)==3687){return h|0}else if((l|0)==3688){return h|0}else if((l|0)==3689){return h|0}else if((l|0)==3690){return h|0}else if((l|0)==3691){return h|0}else if((l|0)==3692){return h|0}else if((l|0)==3683){return h|0}else if((l|0)==3684){return h|0}else if((l|0)==3693){return h|0}return 0}function x7(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;x4(b)|0;e=b|0;f=0;while(1){g=d+f|0;if((a[g]|0)==0){h=1;i=3703;break}L5135:do{if(f>>>0>255){j=0}else{if((c[e>>2]|0)>>>0<=f>>>0){do{k=(x2(b)|0)<<24>>24;c[b+4+(c[e>>2]<<2)>>2]=k;k=c[e>>2]|0;if((c[b+4+(k<<2)>>2]|0)==0){j=0;break L5135}l=k+1|0;c[e>>2]=l;}while(l>>>0<=f>>>0)}j=c[b+4+(f<<2)>>2]&255}}while(0);if(j<<24>>24==(a[g]|0)){f=f+1|0}else{h=0;i=3704;break}}if((i|0)==3703){return h|0}else if((i|0)==3704){return h|0}return 0}function x8(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;x4(b)|0;e=b|0;f=0;while(1){g=d+f|0;h=(a[g]|0)==0;L5149:do{if(f>>>0>255){i=0}else{if((c[e>>2]|0)>>>0<=f>>>0){do{j=(x2(b)|0)<<24>>24;c[b+4+(c[e>>2]<<2)>>2]=j;j=c[e>>2]|0;if((c[b+4+(j<<2)>>2]|0)==0){i=0;break L5149}k=j+1|0;c[e>>2]=k;}while(k>>>0<=f>>>0)}i=c[b+4+(f<<2)>>2]&255}}while(0);if(h){break}if(i<<24>>24==(a[g]|0)){f=f+1|0}else{l=0;m=3717;break}}if((m|0)==3717){return l|0}if((i-97&255)<26|(i-65&255)<26|i<<24>>24==95|(i-48&255)<10){l=0;return l|0}x3(b,f);l=1;return l|0}function x9(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;x4(b)|0;e=b|0;f=0;while(1){g=d+f|0;if((a[g]|0)==0){break}L5169:do{if(f>>>0>255){h=0}else{if((c[e>>2]|0)>>>0<=f>>>0){do{i=(x2(b)|0)<<24>>24;c[b+4+(c[e>>2]<<2)>>2]=i;i=c[e>>2]|0;if((c[b+4+(i<<2)>>2]|0)==0){h=0;break L5169}j=i+1|0;c[e>>2]=j;}while(j>>>0<=f>>>0)}h=c[b+4+(f<<2)>>2]&255}}while(0);if(h<<24>>24==(a[g]|0)){f=f+1|0}else{k=0;l=3730;break}}if((l|0)==3730){return k|0}x3(b,f);k=1;return k|0}function ya(a){a=a|0;var b=0,d=0;b=zH(28)|0;if((b|0)==0){d=0;return d|0}c[b>>2]=0;c[b+4>>2]=0;c[b+8>>2]=bu(((a|0)==0?44480:a)|0)|0;zP(b+12|0,0,16);d=b;return d|0}function yb(a){a=a|0;var b=0;if((a|0)==0){return}else{b=a}while(1){a=c[b>>2]|0;yt(c[b+20>>2]|0);yb(c[b+12>>2]|0);zI(c[b+8>>2]|0);zI(b);if((a|0)==0){break}else{b=a}}return}function yc(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;do{if((b|0)==0){if((a|0)==0){e=0;break}f=a+12|0;g=3745}else{f=b|0;g=3745}}while(0);L5197:do{if((g|0)==3745){b=c[f>>2]|0;if((b|0)==0){e=0;break}if((d|0)==0){e=b;break}else{h=b}while(1){if((aP(c[h+8>>2]|0,d|0)|0)==0){e=h;break L5197}b=c[h>>2]|0;if((b|0)==0){e=0;break}else{h=b}}}}while(0);return e|0}function yd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;do{if((b|0)==0){if((a|0)==0){e=0;return e|0}else{f=a+20|0;break}}else{f=b|0}}while(0);b=c[f>>2]|0;if((b|0)==0|(d|0)==0){e=0;return e|0}else{g=b}while(1){if((aP(c[g+4>>2]|0,d|0)|0)==0){e=g;h=3760;break}b=c[g>>2]|0;if((b|0)==0){e=0;h=3761;break}else{g=b}}if((h|0)==3761){return e|0}else if((h|0)==3760){return e|0}return 0}function ye(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;f=i;i=i+296|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=f+32|0;c[g>>2]=d;if((b|0)==0){m=0;i=f;return m|0}n=f+40|0;o=(e|0)==0;p=(e|0)!=0;e=1;q=b;b=d;L5224:while(1){if((a[b]|0)==0){m=q;r=3809;break}if((yf(g,n,l,h,j,k)|0)!=0){m=0;r=3807;break}d=(a[c[g>>2]|0]|0)==0?e:0;L5228:do{if((c[j>>2]|0)==0){if(!((d|0)==0|o)){if((c[h>>2]|0)!=0){r=3769;break}}if((c[k>>2]|0)!=0){s=q+12|0;t=c[s>>2]|0;if((t|0)==0){u=0}else{v=0;w=t;while(1){t=(aP(c[w+8>>2]|0,n|0)|0)==0?w:v;x=c[w>>2]|0;if((x|0)==0){u=t;break}else{v=t;w=x}}}if(!(p&(u|0)==0)){y=u;break}w=zH(28)|0;if((w|0)==0){m=0;r=3808;break L5224}v=w;c[w>>2]=0;x=w+4|0;c[x>>2]=0;c[w+8>>2]=bu(n|0)|0;zP(w+12|0,0,16);if((q|0)==0){y=v;break}c[x>>2]=q;if((c[s>>2]|0)==0){c[s>>2]=v;z=q+16|0}else{x=q+16|0;c[c[x>>2]>>2]=v;z=x}c[z>>2]=v;y=v;break}v=c[l>>2]|0;x=q+12|0;w=c[x>>2]|0;if((w|0)==0){A=v}else{t=v;v=w;while(1){if((aP(c[v+8>>2]|0,n|0)|0)==0){if((t|0)==0){y=v;break L5228}B=t-1|0}else{B=t}w=c[v>>2]|0;if((w|0)==0){A=B;break}else{t=B;v=w}}}if(o){m=0;r=3811;break L5224}v=q+16|0;if((q|0)==0){t=A;while(1){s=zH(28)|0;if((s|0)==0){C=0}else{c[s>>2]=0;c[s+4>>2]=0;c[s+8>>2]=bu(n|0)|0;zP(s+12|0,0,16);C=s}if((t|0)==0){y=C;break L5228}if((C|0)==0){m=0;r=3813;break L5224}else{t=t-1|0}}}else{D=A}while(1){t=(D|0)==0;s=zH(28)|0;if((s|0)==0){E=0}else{w=s;c[s>>2]=0;F=s+4|0;c[F>>2]=0;c[s+8>>2]=bu(n|0)|0;zP(s+12|0,0,16);c[F>>2]=q;if((c[x>>2]|0)==0){c[x>>2]=w}else{c[c[v>>2]>>2]=w}c[v>>2]=w;E=w}if(t){y=E;break L5228}if((E|0)==0){m=0;r=3814;break L5224}else{D=D-1|0}}}else{r=3769}}while(0);do{if((r|0)==3769){r=0;v=zH(28)|0;if((v|0)==0){m=0;r=3810;break L5224}x=v;c[v>>2]=0;t=v+4|0;c[t>>2]=0;c[v+8>>2]=bu(n|0)|0;zP(v+12|0,0,16);if((q|0)==0){y=x;break}c[t>>2]=q;t=q+12|0;if((c[t>>2]|0)==0){c[t>>2]=x;G=q+16|0}else{t=q+16|0;c[c[t>>2]>>2]=x;G=t}c[G>>2]=x;y=x}}while(0);if((y|0)==0){m=0;r=3812;break}e=d;q=y;b=c[g>>2]|0}if((r|0)==3814){i=f;return m|0}else if((r|0)==3807){i=f;return m|0}else if((r|0)==3808){i=f;return m|0}else if((r|0)==3809){i=f;return m|0}else if((r|0)==3810){i=f;return m|0}else if((r|0)==3811){i=f;return m|0}else if((r|0)==3812){i=f;return m|0}else if((r|0)==3813){i=f;return m|0}return 0}function yf(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=c[b>>2]|0;c[e>>2]=0;c[f>>2]=1;c[g>>2]=0;c[h>>2]=0;j=a[i]|0;do{if((j-97&255)>=26){if((j-65&255)<26|j<<24>>24==95){break}else{k=1}return k|0}}while(0);a[d]=j;j=i+1|0;l=a[j]|0;do{if(l<<24>>24==0){m=j;n=i;o=1}else{p=1;q=i;r=j;s=l;while(1){if((s-97&255)>=26){if(!((s-65&255)<26|s<<24>>24==95|(s-48&255)<10)){t=p;u=q;v=r;break}}w=p+1|0;a[d+p|0]=s;x=r+1|0;y=a[x]|0;if(y<<24>>24!=0&w>>>0<256){p=w;q=r;r=x;s=y}else{t=w;u=r;v=x;break}}if(t>>>0>255){k=1}else{m=v;n=u;o=t;break}return k|0}}while(0);a[d+o|0]=0;o=a[m]|0;if((o<<24>>24|0)==0){c[b>>2]=m;k=0;return k|0}else if((o<<24>>24|0)==46){c[b>>2]=n+2;k=0;return k|0}else if((o<<24>>24|0)==91){o=n+2|0;m=a[o]|0;if((m<<24>>24|0)==43){c[g>>2]=1;z=n+3|0}else if((m<<24>>24|0)==45){c[h>>2]=1;z=n+3|0}else{if((m-48&255)>=10){k=1;return k|0}n=o;o=m;m=c[e>>2]|0;while(1){h=(o<<24>>24)-48+(m*10|0)|0;c[e>>2]=h;g=n+1|0;d=a[g]|0;if((d-48&255)<10){n=g;o=d;m=h}else{z=g;break}}}if((a[z]|0)!=93){k=1;return k|0}m=z+1|0;c[b>>2]=(a[m]|0)==46?z+2|0:m;c[f>>2]=0;k=0;return k|0}else{k=1;return k|0}return 0}function yg(a){a=a|0;c[a>>2]=0;c[a+4>>2]=0;c[a+8>>2]=0;return}function yh(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;f=i;i=i+296|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=f+32|0;c[g>>2]=d;if((b|0)==0){m=0;i=f;return m|0}n=f+40|0;o=(e|0)==0;p=(e|0)!=0;e=1;q=b;b=d;L5332:while(1){if((a[b]|0)==0){m=0;r=3927;break}if((yf(g,n,l,h,j,k)|0)!=0){m=0;r=3923;break}s=(c[j>>2]|0)==0;if((a[c[g>>2]|0]|0)==0){r=3848;break}L5337:do{if(s){if((c[k>>2]|0)!=0){d=q+12|0;t=c[d>>2]|0;if((t|0)==0){u=0}else{v=0;w=t;while(1){t=(aP(c[w+8>>2]|0,n|0)|0)==0?w:v;x=c[w>>2]|0;if((x|0)==0){u=t;break}else{v=t;w=x}}}if(!(p&(u|0)==0)){y=u;break}w=zH(28)|0;if((w|0)==0){m=0;r=3939;break L5332}v=w;c[w>>2]=0;x=w+4|0;c[x>>2]=0;c[w+8>>2]=bu(n|0)|0;zP(w+12|0,0,16);if((q|0)==0){y=v;break}c[x>>2]=q;if((c[d>>2]|0)==0){c[d>>2]=v;z=q+16|0}else{x=q+16|0;c[c[x>>2]>>2]=v;z=x}c[z>>2]=v;y=v;break}v=c[l>>2]|0;x=q+12|0;w=c[x>>2]|0;if((w|0)==0){A=v}else{t=v;v=w;while(1){if((aP(c[v+8>>2]|0,n|0)|0)==0){if((t|0)==0){y=v;break L5337}B=t-1|0}else{B=t}w=c[v>>2]|0;if((w|0)==0){A=B;break}else{t=B;v=w}}}if(o){m=0;r=3942;break L5332}v=q+16|0;if((q|0)==0){t=A;while(1){d=zH(28)|0;if((d|0)==0){C=0}else{c[d>>2]=0;c[d+4>>2]=0;c[d+8>>2]=bu(n|0)|0;zP(d+12|0,0,16);C=d}if((t|0)==0){y=C;break L5337}if((C|0)==0){m=0;r=3931;break L5332}else{t=t-1|0}}}else{D=A}while(1){t=(D|0)==0;d=zH(28)|0;if((d|0)==0){E=0}else{w=d;c[d>>2]=0;F=d+4|0;c[F>>2]=0;c[d+8>>2]=bu(n|0)|0;zP(d+12|0,0,16);c[F>>2]=q;if((c[x>>2]|0)==0){c[x>>2]=w}else{c[c[v>>2]>>2]=w}c[v>>2]=w;E=w}if(t){y=E;break L5337}if((E|0)==0){m=0;r=3921;break L5332}else{D=D-1|0}}}else{v=zH(28)|0;if((v|0)==0){m=0;r=3940;break L5332}x=v;c[v>>2]=0;t=v+4|0;c[t>>2]=0;c[v+8>>2]=bu(n|0)|0;zP(v+12|0,0,16);if((q|0)==0){y=x;break}c[t>>2]=q;t=q+12|0;if((c[t>>2]|0)==0){c[t>>2]=x;G=q+16|0}else{t=q+16|0;c[c[t>>2]>>2]=x;G=t}c[G>>2]=x;y=x}}while(0);if((y|0)==0){m=0;r=3922;break}e=0;q=y;b=c[g>>2]|0}if((r|0)==3848){do{if(s){if(!((e|0)==0|o)){if((c[h>>2]|0)!=0){break}}if((c[k>>2]|0)!=0){g=q+20|0;b=c[g>>2]|0;if((b|0)==0){H=0}else{y=0;G=b;while(1){b=(aP(c[G+4>>2]|0,n|0)|0)==0?G:y;D=c[G>>2]|0;if((D|0)==0){H=b;break}else{y=b;G=D}}}if(!(p&(H|0)==0)){m=H;i=f;return m|0}G=ys(n)|0;if((G|0)==0){m=0;i=f;return m|0}if((q|0)==0){m=G;i=f;return m|0}if((c[g>>2]|0)==0){c[g>>2]=G;I=q+24|0}else{y=q+24|0;c[c[y>>2]>>2]=G;I=y}c[I>>2]=G;m=G;i=f;return m|0}G=c[l>>2]|0;y=q+20|0;D=c[y>>2]|0;L5416:do{if((D|0)==0){J=G}else{b=G;E=D;while(1){if((aP(c[E+4>>2]|0,n|0)|0)==0){if((b|0)==0){m=E;break}K=b-1|0}else{K=b}A=c[E>>2]|0;if((A|0)==0){J=K;break L5416}else{b=K;E=A}}i=f;return m|0}}while(0);if(o){m=0;i=f;return m|0}D=q+24|0;if((q|0)==0){G=J;while(1){g=ys(n)|0;if((G|0)==0){m=g;r=3941;break}if((g|0)==0){m=0;r=3938;break}else{G=G-1|0}}if((r|0)==3938){i=f;return m|0}else if((r|0)==3941){i=f;return m|0}}else{L=J}while(1){G=(L|0)==0;g=ys(n)|0;if((g|0)==0){M=0}else{if((c[y>>2]|0)==0){c[y>>2]=g}else{c[c[D>>2]>>2]=g}c[D>>2]=g;M=g}if(G){m=M;r=3928;break}if((M|0)==0){m=0;r=3929;break}else{L=L-1|0}}if((r|0)==3928){i=f;return m|0}else if((r|0)==3929){i=f;return m|0}}}while(0);L=ys(n)|0;if((L|0)==0){m=0;i=f;return m|0}if((q|0)==0){m=L;i=f;return m|0}n=q+20|0;if((c[n>>2]|0)==0){c[n>>2]=L;N=q+24|0}else{n=q+24|0;c[c[n>>2]>>2]=L;N=n}c[N>>2]=L;m=L;i=f;return m|0}else if((r|0)==3921){i=f;return m|0}else if((r|0)==3922){i=f;return m|0}else if((r|0)==3923){i=f;return m|0}else if((r|0)==3927){i=f;return m|0}else if((r|0)==3931){i=f;return m|0}else if((r|0)==3939){i=f;return m|0}else if((r|0)==3940){i=f;return m|0}else if((r|0)==3942){i=f;return m|0}return 0}function yi(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;c[d>>2]=e;e=yh(a,b,0)|0;if((e|0)==0){f=1;return f|0}f=(yu(e,d)|0)!=0|0;return f|0}function yj(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;c[d>>2]=e;e=yh(a,b,0)|0;if((e|0)==0){f=1;return f|0}f=(yv(e,d)|0)!=0|0;return f|0}function yk(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;c[d>>2]=e;e=yh(a,b,0)|0;if((e|0)==0){f=1;return f|0}f=(yw(e,d)|0)!=0|0;return f|0}function yl(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;c[d>>2]=(e|0)!=0;e=yh(a,b,0)|0;if((e|0)==0){f=1;return f|0}f=(yx(e,d)|0)!=0|0;return f|0}function ym(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;c[d>>2]=e;e=yh(a,b,0)|0;do{if((e|0)==0){f=1}else{b=yy(e)|0;if((b|0)==0){f=0;break}c[d>>2]=b;f=0}}while(0);return f|0}function yn(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=(d|0)!=0;if(g){h=zN(d|0)|0}else{h=0}i=(e|0)!=0;if(i){j=zN(e|0)|0}else{j=0}k=(f|0)!=0;if(k){l=zN(f|0)|0}else{l=0}m=b|0;n=h+1+j+l+(c[m>>2]|0)|0;o=b+4|0;p=c[o>>2]|0;do{if(n>>>0>=p>>>0){q=(p|0)==0?256:p;while(1){if(n>>>0<q>>>0){break}else{q=q<<1}}r=b+8|0;s=zJ(c[r>>2]|0,q)|0;if((s|0)==0){t=1;return t|0}else{c[o>>2]=q;c[r>>2]=s;break}}}while(0);if(g){g=(c[b+8>>2]|0)+(c[m>>2]|0)|0;zO(g|0,d|0,h)|0}if(i){i=(c[b+8>>2]|0)+((c[m>>2]|0)+h)|0;zO(i|0,e|0,j)|0}if(k){k=b+8|0;e=j+h|0;i=(c[k>>2]|0)+(e+(c[m>>2]|0))|0;zO(i|0,f|0,l)|0;u=e;v=k}else{u=j+h|0;v=b+8|0}b=u+l+(c[m>>2]|0)|0;c[m>>2]=b;a[(c[v>>2]|0)+b|0]=0;t=0;return t|0}function yo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=a+8|0;a=xW(b,c[e>>2]|0)|0;if((d|0)==0){return a|0}zI(c[e>>2]|0);return a|0}function yp(a,b){a=a|0;b=b|0;var d=0;c[a>>2]=0;d=a+4|0;c[d>>2]=0;c[a+8>>2]=0;if((b|0)==0){return}c[d>>2]=bu(b|0)|0;return}function yq(a){a=a|0;var b=0;if((a|0)==0){return}b=a+8|0;if((c[b>>2]|0)==2){zI(c[a+12>>2]|0)}c[b>>2]=0;zI(c[a+4>>2]|0);return}function yr(a){a=a|0;var b=0;b=a+8|0;if((c[b>>2]|0)!=2){c[b>>2]=0;return}zI(c[a+12>>2]|0);c[b>>2]=0;return}function ys(a){a=a|0;var b=0,d=0,e=0,f=0;b=zH(16)|0;d=b;if((b|0)==0){e=0;return e|0}c[b>>2]=0;f=b+4|0;c[f>>2]=0;c[b+8>>2]=0;if((a|0)==0){e=d;return e|0}c[f>>2]=bu(a|0)|0;e=d;return e|0}function yt(a){a=a|0;var b=0,d=0;if((a|0)==0){return}else{b=a}while(1){a=c[b>>2]|0;d=b+8|0;if((c[d>>2]|0)==2){zI(c[b+12>>2]|0)}c[d>>2]=0;zI(c[b+4>>2]|0);zI(b);if((a|0)==0){break}else{b=a}}return}function yu(a,b){a=a|0;b=b|0;var d=0;if((c[a+8>>2]|0)!=1){d=1;return d|0}c[b>>2]=c[a+12>>2];d=0;return d|0}function yv(a,b){a=a|0;b=b|0;var d=0;if((c[a+8>>2]|0)!=1){d=1;return d|0}c[b>>2]=c[a+12>>2]&65535;d=0;return d|0}function yw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if((c[a+8>>2]|0)!=1){d=1;return d|0}e=c[a+12>>2]|0;if((e|0)<0){f=-(-e&2147483647)|0}else{f=e}if((f+32767|0)>>>0>65534){d=1;return d|0}c[b>>2]=f;d=0;return d|0}function yx(a,b){a=a|0;b=b|0;var d=0;if((c[a+8>>2]|0)!=1){d=1;return d|0}c[b>>2]=(c[a+12>>2]|0)!=0;d=0;return d|0}function yy(a){a=a|0;var b=0;if((c[a+8>>2]|0)!=2){b=0;return b|0}b=c[a+12>>2]|0;return b|0}function yz(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=c[b+8>>2]|0;if((d|0)==1){e=c[b+12>>2]|0;f=a+8|0;g=a+12|0;if((c[f>>2]|0)==2){zI(c[g>>2]|0)}c[f>>2]=1;c[g>>2]=e;return}else if((d|0)==2){d=c[b+12>>2]|0;b=a+8|0;e=a+12|0;if((c[b>>2]|0)==2){zI(c[e>>2]|0)}c[b>>2]=2;c[e>>2]=bu(d|0)|0;return}else{d=a+8|0;if((c[d>>2]|0)==2){zI(c[a+12>>2]|0)}c[d>>2]=0;return}}function yA(a,b){a=a|0;b=b|0;var d=0,e=0;d=a+8|0;e=a+12|0;if((c[d>>2]|0)==2){zI(c[e>>2]|0)}c[d>>2]=1;c[e>>2]=b;return}function yB(a,b){a=a|0;b=b|0;var d=0,e=0;d=a+8|0;e=a+12|0;if((c[d>>2]|0)==2){zI(c[e>>2]|0)}c[d>>2]=2;c[e>>2]=bu(b|0)|0;return}function yC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;f=c[b+20>>2]|0;L5620:do{if((f|0)!=0){if((d|0)==0){g=f;while(1){bN(a|0,26888,(x=i,i=i+8|0,c[x>>2]=c[g+4>>2],x)|0)|0;h=c[g+8>>2]|0;if((h|0)==1){j=c[g+12>>2]|0;bN(a|0,25376,(x=i,i=i+8|0,c[x>>2]=j,x)|0)|0}else if((h|0)==2){bN(a|0,24184,(x=i,i=i+8|0,c[x>>2]=c[g+12>>2],x)|0)|0}else{k=1;break}aA(10,a|0)|0;g=c[g>>2]|0;if((g|0)==0){break L5620}}i=e;return k|0}else{l=f}while(1){g=d;do{aA(9,a|0)|0;g=g-1|0;}while((g|0)!=0);bN(a|0,26888,(x=i,i=i+8|0,c[x>>2]=c[l+4>>2],x)|0)|0;g=c[l+8>>2]|0;if((g|0)==2){h=c[l+12>>2]|0;bN(a|0,24184,(x=i,i=i+8|0,c[x>>2]=h,x)|0)|0}else if((g|0)==1){bN(a|0,25376,(x=i,i=i+8|0,c[x>>2]=c[l+12>>2],x)|0)|0}else{k=1;break}aA(10,a|0)|0;l=c[l>>2]|0;if((l|0)==0){break L5620}}i=e;return k|0}}while(0);l=c[b+12>>2]|0;if((l|0)==0){k=0;i=e;return k|0}b=d+1|0;if((d|0)==0){f=l;while(1){aA(10,a|0)|0;bN(a|0,30592,(x=i,i=i+8|0,c[x>>2]=c[f+8>>2],x)|0)|0;if((yC(a,f,b)|0)!=0){k=1;m=4097;break}aB(28520,2,1,a|0)|0;g=c[f>>2]|0;if((g|0)==0){k=0;m=4099;break}else{f=g}}if((m|0)==4097){i=e;return k|0}else if((m|0)==4099){i=e;return k|0}}else{n=l}while(1){aA(10,a|0)|0;l=d;do{aA(9,a|0)|0;l=l-1|0;}while((l|0)!=0);bN(a|0,30592,(x=i,i=i+8|0,c[x>>2]=c[n+8>>2],x)|0)|0;if((yC(a,n,b)|0)==0){o=d}else{k=1;m=4101;break}do{aA(9,a|0)|0;o=o-1|0;}while((o|0)!=0);aB(28520,2,1,a|0)|0;l=c[n>>2]|0;if((l|0)==0){k=0;m=4102;break}else{n=l}}if((m|0)==4101){i=e;return k|0}else if((m|0)==4102){i=e;return k|0}return 0}function yD(a,b){a=a|0;b=b|0;var c=0,d=0;c=bl(a|0,39144)|0;if((c|0)==0){d=1;return d|0}aB(33352,37,1,c|0)|0;a=(yC(c,b,0)|0)!=0|0;au(c|0)|0;d=a;return d|0}function yE(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+16|0;f=e|0;do{if((yF(a,b,d)|0)==0){if((x9(a,33344)|0)==0){g=0;break}yp(f,0);if((c[d+8>>2]|0)==1){if((c[d+12>>2]|0)==0){h=4112}else{j=f;k=d}}else{h=4112}if((h|0)==4112){j=d;k=f}if((yF(a,b,k)|0)!=0){yq(f);g=1;break}if((x9(a,39136)|0)==0){yq(f);g=1;break}else{l=(yF(a,b,j)|0)!=0;yq(f);g=l&1;break}}else{g=1}}while(0);i=e;return g|0}function yF(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+16|0;f=e|0;if((yG(a,b,d)|0)!=0){g=1;i=e;return g|0}if((x9(a,32496)|0)==0){g=0;i=e;return g|0}h=d+8|0;j=f+8|0;k=d+12|0;d=k;l=f+12|0;m=k|0;while(1){yp(f,0);if((yG(a,b,f)|0)!=0){n=4123;break}k=c[h>>2]|0;if(!((k|0)==(c[j>>2]|0)&(k|0)==1)){n=4125;break}if((c[d>>2]|0)==0){o=(c[l>>2]|0)!=0|0}else{o=1}c[m>>2]=o;yq(f);if((x9(a,32496)|0)==0){g=0;n=4131;break}}if((n|0)==4123){yq(f);g=1;i=e;return g|0}else if((n|0)==4125){yq(f);g=1;i=e;return g|0}else if((n|0)==4131){i=e;return g|0}return 0}function yG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+16|0;f=e|0;if((yH(a,b,d)|0)!=0){g=1;i=e;return g|0}if((x9(a,30584)|0)==0){g=0;i=e;return g|0}h=d+8|0;j=f+8|0;k=d+12|0;d=k;l=k|0;k=f+12|0;while(1){yp(f,0);if((yH(a,b,f)|0)!=0){m=4139;break}n=c[h>>2]|0;if(!((n|0)==(c[j>>2]|0)&(n|0)==1)){m=4141;break}if((c[d>>2]|0)==0){o=0}else{o=(c[k>>2]|0)!=0|0}c[l>>2]=o;yq(f);if((x9(a,30584)|0)==0){g=0;m=4148;break}}if((m|0)==4141){yq(f);g=1;i=e;return g|0}else if((m|0)==4148){i=e;return g|0}else if((m|0)==4139){yq(f);g=1;i=e;return g|0}return 0}function yH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+16|0;f=e|0;L5724:do{if((yI(a,b,d)|0)==0){if((x7(a,32496)|0)!=0){g=0;break}h=d+8|0;j=f+8|0;k=d+12|0;l=k;m=f+12|0;n=k|0;while(1){if((x9(a,28512)|0)==0){g=0;break L5724}yp(f,0);if((yI(a,b,f)|0)!=0){o=4156;break}k=c[h>>2]|0;if(!((k|0)==(c[j>>2]|0)&(k|0)==1)){o=4158;break}c[n>>2]=c[m>>2]|c[l>>2];yq(f);if((x7(a,32496)|0)!=0){g=0;break L5724}}if((o|0)==4158){yq(f);g=1;break}else if((o|0)==4156){yq(f);g=1;break}}else{g=1}}while(0);i=e;return g|0}function yI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+16|0;f=e|0;L5737:do{if((yJ(a,b,d)|0)==0){if((x7(a,26880)|0)!=0){g=0;break}h=d+8|0;j=f+8|0;k=d+12|0;l=k;m=f+12|0;n=k|0;while(1){if((x9(a,25368)|0)==0){g=0;break L5737}yp(f,0);if((yJ(a,b,f)|0)!=0){o=4166;break}k=c[h>>2]|0;if(!((k|0)==(c[j>>2]|0)&(k|0)==1)){o=4168;break}c[n>>2]=c[m>>2]^c[l>>2];yq(f);if((x7(a,26880)|0)!=0){g=0;break L5737}}if((o|0)==4166){yq(f);g=1;break}else if((o|0)==4168){yq(f);g=1;break}}else{g=1}}while(0);i=e;return g|0}function yJ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+16|0;f=e|0;L5750:do{if((yK(a,b,d)|0)==0){if((x7(a,30584)|0)!=0){g=0;break}h=d+8|0;j=f+8|0;k=d+12|0;l=k;m=f+12|0;n=k|0;while(1){if((x9(a,24176)|0)==0){g=0;break L5750}yp(f,0);if((yK(a,b,f)|0)!=0){o=4176;break}k=c[h>>2]|0;if(!((k|0)==(c[j>>2]|0)&(k|0)==1)){o=4178;break}c[n>>2]=c[m>>2]&c[l>>2];yq(f);if((x7(a,30584)|0)!=0){g=0;break L5750}}if((o|0)==4178){yq(f);g=1;break}else if((o|0)==4176){yq(f);g=1;break}}else{g=1}}while(0);i=e;return g|0}function yK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+16|0;f=e|0;if((yL(a,b,d)|0)!=0){g=1;i=e;return g|0}h=d+8|0;j=f+8|0;k=d+12|0;l=k;m=f+12|0;n=k|0;k=d+12|0;o=f+12|0;L5766:while(1){if((x9(a,22584)|0)==0){if((x9(a,21408)|0)==0){g=0;p=4200;break}else{q=2}}else{q=1}yp(f,0);if((yL(a,b,f)|0)!=0){p=4186;break}do{if((q|0)==1){r=c[h>>2]|0;if((r|0)!=(c[j>>2]|0)){p=4196;break L5766}if((r|0)==2){yA(d,(aP(c[k>>2]|0,c[o>>2]|0)|0)==0|0);break}else if((r|0)==1){c[n>>2]=(c[l>>2]|0)==(c[m>>2]|0);break}else{p=4196;break L5766}}else if((q|0)==2){r=c[h>>2]|0;if((r|0)!=(c[j>>2]|0)){p=4196;break L5766}if((r|0)==1){c[n>>2]=(c[l>>2]|0)!=(c[m>>2]|0);break}else if((r|0)==2){yA(d,(aP(c[k>>2]|0,c[o>>2]|0)|0)!=0|0);break}else{p=4196;break L5766}}else{p=4196;break L5766}}while(0);yq(f)}if((p|0)==4186){yq(f);g=1;i=e;return g|0}else if((p|0)==4196){yq(f);g=1;i=e;return g|0}else if((p|0)==4200){i=e;return g|0}return 0}function yL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+16|0;f=e|0;if((yM(a,b,d)|0)!=0){g=1;i=e;return g|0}h=d+8|0;j=f+8|0;k=d+12|0;l=k;m=f+12|0;n=k|0;k=d+12|0;o=f+12|0;L5794:while(1){do{if((x9(a,41512)|0)==0){if((x9(a,40408)|0)!=0){p=4;break}if((x9(a,38864)|0)!=0){p=1;break}if((x9(a,37904)|0)==0){g=0;q=4231;break L5794}else{p=3}}else{p=2}}while(0);yp(f,0);if((yM(a,b,f)|0)!=0){q=4210;break}do{if((p|0)==1){r=c[h>>2]|0;if((r|0)!=(c[j>>2]|0)){q=4228;break L5794}if((r|0)==1){c[n>>2]=(c[l>>2]|0)>>>0<(c[m>>2]|0)>>>0;break}else if((r|0)==2){yA(d,(aP(c[k>>2]|0,c[o>>2]|0)|0)>>>31);break}else{q=4228;break L5794}}else if((p|0)==2){r=c[h>>2]|0;if((r|0)!=(c[j>>2]|0)){q=4228;break L5794}if((r|0)==1){c[n>>2]=(c[l>>2]|0)>>>0<=(c[m>>2]|0)>>>0;break}else if((r|0)==2){yA(d,(aP(c[k>>2]|0,c[o>>2]|0)|0)<1|0);break}else{q=4228;break L5794}}else if((p|0)==3){r=c[h>>2]|0;if((r|0)!=(c[j>>2]|0)){q=4228;break L5794}if((r|0)==1){c[n>>2]=(c[l>>2]|0)>>>0>(c[m>>2]|0)>>>0;break}else if((r|0)==2){yA(d,(aP(c[k>>2]|0,c[o>>2]|0)|0)>0|0);break}else{q=4228;break L5794}}else if((p|0)==4){r=c[h>>2]|0;if((r|0)!=(c[j>>2]|0)){q=4228;break L5794}if((r|0)==1){c[n>>2]=(c[l>>2]|0)>>>0>=(c[m>>2]|0)>>>0;break}else if((r|0)==2){yA(d,(aP(c[k>>2]|0,c[o>>2]|0)|0)>>>31^1);break}else{q=4228;break L5794}}else{q=4228;break L5794}}while(0);yq(f)}if((q|0)==4210){yq(f);g=1;i=e;return g|0}else if((q|0)==4228){yq(f);g=1;i=e;return g|0}else if((q|0)==4231){i=e;return g|0}return 0}function yM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+16|0;f=e|0;if((yN(a,b,d)|0)!=0){g=1;i=e;return g|0}h=d+8|0;j=f+8|0;k=d+12|0;d=k;l=f+12|0;m=k|0;while(1){if((x9(a,36920)|0)==0){if((x9(a,35048)|0)==0){g=0;n=4250;break}else{o=2}}else{o=1}yp(f,0);if((yN(a,b,f)|0)!=0){n=4240;break}if((o|0)==1){k=c[h>>2]|0;if(!((k|0)==(c[j>>2]|0)&(k|0)==1)){n=4246;break}p=c[d>>2]<<(c[l>>2]&31)}else if((o|0)==2){k=c[h>>2]|0;if(!((k|0)==(c[j>>2]|0)&(k|0)==1)){n=4246;break}p=(c[d>>2]|0)>>>((c[l>>2]&31)>>>0)}else{n=4246;break}c[m>>2]=p;yq(f)}if((n|0)==4240){yq(f);g=1;i=e;return g|0}else if((n|0)==4246){yq(f);g=1;i=e;return g|0}else if((n|0)==4250){i=e;return g|0}return 0}function yN(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0;f=i;i=i+48|0;g=f+32|0;if((yO(b,d,e)|0)!=0){h=1;i=f;return h|0}j=f|0;k=e+8|0;l=g+8|0;m=e+12|0;n=m;o=g+12|0;p=m|0;m=e+12|0;q=g+12|0;while(1){if((x9(b,34648)|0)==0){if((x9(b,34384)|0)==0){h=0;r=4292;break}else{s=2}}else{s=1}yp(g,0);if((yO(b,d,g)|0)!=0){r=4258;break}if((s|0)==2){t=c[k>>2]|0;if(!((t|0)==(c[l>>2]|0)&(t|0)==1)){r=4285;break}c[p>>2]=(c[n>>2]|0)-(c[o>>2]|0);yq(g);continue}else if((s|0)!=1){r=4285;break}t=c[k>>2]|0;u=c[l>>2]|0;v=(t|0)==1;w=(u|0)==1;if(v&w){c[p>>2]=(c[o>>2]|0)+(c[n>>2]|0);yq(g);continue}y=(t|0)==2;t=(u|0)==2;if(y&t){u=c[m>>2]|0;z=c[q>>2]|0;A=zN(u|0)|0;B=zN(z|0)|0;C=B+A|0;D=zH(C+1|0)|0;if((D|0)==0){r=4288;break}if((A|0)!=0){zO(D|0,u|0,A)|0}if((B|0)!=0){u=D+A|0;zO(u|0,z|0,B)|0}a[D+C|0]=0;yB(e,D);zI(D);yq(g);continue}if(y&w){w=c[o>>2]|0;a1(j|0,34176,(x=i,i=i+8|0,c[x>>2]=w,x)|0)|0;w=c[m>>2]|0;y=zN(w|0)|0;D=zN(j|0)|0;C=D+y|0;B=zH(C+1|0)|0;if((B|0)==0){r=4289;break}if((y|0)!=0){zO(B|0,w|0,y)|0}if((D|0)!=0){w=B+y|0;zO(w|0,j|0,D)|0}a[B+C|0]=0;yB(e,B);zI(B);yq(g);continue}if(!(v&t)){r=4287;break}a1(j|0,34176,(x=i,i=i+8|0,c[x>>2]=c[n>>2],x)|0)|0;t=c[q>>2]|0;v=zN(j|0)|0;B=zN(t|0)|0;C=B+v|0;D=zH(C+1|0)|0;if((D|0)==0){r=4286;break}if((v|0)!=0){zO(D|0,j|0,v)|0}if((B|0)!=0){w=D+v|0;zO(w|0,t|0,B)|0}a[D+C|0]=0;yB(e,D);zI(D);yq(g)}if((r|0)==4258){yq(g);h=1;i=f;return h|0}else if((r|0)==4285){yq(g);h=1;i=f;return h|0}else if((r|0)==4286){yq(g);h=1;i=f;return h|0}else if((r|0)==4287){yq(g);h=1;i=f;return h|0}else if((r|0)==4288){yq(g);h=1;i=f;return h|0}else if((r|0)==4289){yq(g);h=1;i=f;return h|0}else if((r|0)==4292){i=f;return h|0}return 0}function yO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+16|0;f=e|0;if((yP(a,b,d)|0)!=0){g=1;i=e;return g|0}h=d+8|0;j=f+8|0;k=d+12|0;d=k;l=f+12|0;m=k|0;L5915:while(1){do{if((x9(a,33936)|0)==0){if((x9(a,33536)|0)!=0){n=2;break}if((x9(a,33096)|0)==0){g=0;o=4318;break L5915}else{n=3}}else{n=1}}while(0);yp(f,0);if((yP(a,b,f)|0)!=0){o=4305;break}if((n|0)==2){k=c[h>>2]|0;if(!((k|0)==(c[j>>2]|0)&(k|0)==1)){o=4315;break}k=c[l>>2]|0;if((k|0)==0){o=4315;break}c[m>>2]=((c[d>>2]|0)>>>0)/(k>>>0)|0}else if((n|0)==1){k=c[h>>2]|0;if(!((k|0)==(c[j>>2]|0)&(k|0)==1)){o=4315;break}c[m>>2]=ac(c[l>>2]|0,c[d>>2]|0)|0}else if((n|0)==3){k=c[h>>2]|0;if(!((k|0)==(c[j>>2]|0)&(k|0)==1)){o=4315;break}k=c[l>>2]|0;if((k|0)==0){o=4315;break}c[m>>2]=((c[d>>2]|0)>>>0)%(k>>>0)|0}else{o=4315;break}yq(f)}if((o|0)==4305){yq(f);g=1;i=e;return g|0}else if((o|0)==4315){yq(f);g=1;i=e;return g|0}else if((o|0)==4318){i=e;return g|0}return 0}function yP(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0;do{if((x9(b,34648)|0)==0){if((x9(b,34384)|0)!=0){f=2;break}if((x9(b,32424)|0)!=0){f=3;break}f=(x9(b,32176)|0)==0?0:4}else{f=1}}while(0);if((yQ(b,d,e)|0)!=0){g=1;return g|0}if((f|0)==3){if((c[e+8>>2]|0)!=1){g=1;return g|0}d=e+12|0;c[d>>2]=~c[d>>2];g=0;return g|0}else if((f|0)==2){if((c[e+8>>2]|0)!=1){g=1;return g|0}d=e+12|0;c[d>>2]=-(c[d>>2]|0);g=0;return g|0}else if((f|0)==1){g=(c[e+8>>2]|0)!=1|0;return g|0}else if((f|0)==4){f=c[e+8>>2]|0;if((f|0)==1){d=e+12|0;c[d>>2]=(c[d>>2]|0)==0;g=0;return g|0}else if((f|0)==2){yA(e,(a[c[e+12>>2]|0]|0)==0|0);g=0;return g|0}else{g=1;return g|0}}else{g=0;return g|0}return 0}function yQ(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+256|0;g=f|0;if((x9(b,31840)|0)!=0){if((yE(b,d,e)|0)!=0){h=1;i=f;return h|0}x4(b)|0;h=(x9(b,31744)|0)==0|0;i=f;return h|0}j=g|0;if((x6(b,j,256)|0)!=0){yB(e,j);h=0;i=f;return h|0}if((x5(b,j,256)|0)!=0){if((aP(j|0,31656)|0)==0){if((yQ(b,d,e)|0)!=0){h=1;i=f;return h|0}yA(e,(c[e+8>>2]|0)!=0|0);h=0;i=f;return h|0}if((aP(j|0,31504)|0)==0){yA(e,1);h=0;i=f;return h|0}if((aP(j|0,31368)|0)==0){yA(e,0);h=0;i=f;return h|0}L5997:do{if((d|0)!=0){k=g+((a[j]|0)==36)|0;l=d;while(1){m=yh(l,k,0)|0;if((m|0)!=0){break}l=c[l+4>>2]|0;if((l|0)==0){break L5997}}yz(e,m);h=0;i=f;return h|0}}while(0);yr(e);h=0;i=f;return h|0}if((x9(b,31248)|0)==0){n=(x9(b,30992)|0)==0?10:2}else{n=16}m=x1(b,0)|0;if(m<<24>>24==0){h=1;i=f;return h|0}else{o=1;p=0;q=m}L6012:while(1){m=q<<24>>24;do{if((q-48&255)<10){r=m-48|0}else{if((q-97&255)<6){r=m-87|0;break}if((q-65&255)>=6){s=4377;break L6012}r=m-55|0}}while(0);if(r>>>0>=n>>>0){s=4377;break}m=r+(ac(p,n)|0)|0;x3(b,1);d=x1(b,0)|0;if(d<<24>>24==0){t=m;break}else{o=0;p=m;q=d}}do{if((s|0)==4377){if((o|0)!=0){h=1;i=f;return h|0}if((q<<24>>24|0)==107|(q<<24>>24|0)==75){x3(b,1);t=p<<10;break}else if((q<<24>>24|0)==109|(q<<24>>24|0)==77){x3(b,1);t=p<<20;break}else if((q<<24>>24|0)==103|(q<<24>>24|0)==71){x3(b,1);t=p<<30;break}else{t=p;break}}}while(0);yA(e,t);h=0;i=f;return h|0}function yR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 1}function yS(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+32|0;e=d|0;f=zH(104)|0;if((f|0)==0){g=0;i=d;return g|0}h=f;j=a;zO(f|0,j|0,68)|0;tb(h,5);c[f+4>>2]=188;c[f+8>>2]=16;c[f+12>>2]=36;c[f+16>>2]=10;c[f+20>>2]=66;c[f+60>>2]=0;c[f+64>>2]=f;c[f+68>>2]=a;a=f+28|0;j=((c[a>>2]|0)+7|0)>>>3;k=f+100|0;c[k>>2]=j;l=zH(j)|0;j=f+96|0;c[j>>2]=l;if((l|0)==0){zI(f);g=0;i=d;return g|0}l=bl(b|0,33104)|0;m=f+72|0;c[m>>2]=l;L6043:do{if((l|0)==0){n=bl(b|0,39080)|0;c[m>>2]=n;if((n|0)==0){o=4412;break}n=e|0;p=((c[a>>2]|0)+7|0)>>>3;c[k>>2]=p;q=f+80|0;c[q>>2]=20;c[q+4>>2]=0;r=f+88|0;c[r>>2]=p+531&1073741312;c[r+4>>2]=0;sS(n,0,1129273120);sS(n,4,0);sS(n,8,c[a>>2]|0);sS(n,12,c[q>>2]|0);sS(n,16,c[r>>2]|0);do{if((s8(c[m>>2]|0,n,0,0,20,0)|0)==0){zP(c[j>>2]|0,0,c[k>>2]|0);if((s8(c[m>>2]|0,c[j>>2]|0,c[q>>2]|0,c[q+4>>2]|0,c[k>>2]|0,0)|0)!=0){break}r=c[m>>2]|0;ax(r|0)|0;o=4413;break L6043}}while(0);q=c[m>>2]|0;au(q|0)|0;o=4412}else{q=e|0;do{if((s7(l,q,0,0,20,0)|0)==0){if((sR(q,0)|0)!=1129273120){break}if((sR(q,4)|0)!=0){break}n=sR(q,8)|0;if((n|0)!=(c[a>>2]|0)){break}n=f+80|0;c[n>>2]=sR(q,12)|0;c[n+4>>2]=0;r=f+88|0;c[r>>2]=sR(q,16)|0;c[r+4>>2]=0;if((s7(c[m>>2]|0,c[j>>2]|0,c[n>>2]|0,c[n+4>>2]|0,c[k>>2]|0,0)|0)==0){o=4413;break L6043}}}while(0);q=c[m>>2]|0;au(q|0)|0;o=4412}}while(0);if((o|0)==4412){zI(c[j>>2]|0);zI(f);g=0;i=d;return g|0}else if((o|0)==4413){tm(h,b);g=h;i=d;return g|0}return 0}function yT(a){a=a|0;var b=0;b=c[a+64>>2]|0;tl(c[b+68>>2]|0);au(c[b+72>>2]|0)|0;zI(c[b+96>>2]|0);zI(b);return}function yU(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;h=c[b+64>>2]|0;i=b+28|0;b=h+68|0;j=h+72|0;if((g|0)==0){k=0;return k|0}l=f;m=h+88|0;n=zW(c[m>>2]|0,c[m+4>>2]|0,l<<9|0>>>23,0<<9|l>>>23)|0;l=h+96|0;h=f;f=g;g=e;e=G;m=n;while(1){if(h>>>0>=(c[i>>2]|0)>>>0){k=1;o=4440;break}n=h>>>3;p=128>>>((h&7)>>>0);q=c[l>>2]|0;r=(d[q+n|0]&p|0)!=0;L6070:do{if(f>>>0<2){s=1}else{t=r<<31>>31;u=f-1|0;if((u|0)==0){s=1;break}v=n;w=p&255;x=u;u=1;while(1){L6075:do{if(w<<24>>24==1){y=v+1|0;if(x>>>0>7){z=x;A=y;B=u;while(1){if((a[q+A|0]|0)!=t<<24>>24){C=-128;D=z;E=A;F=B;break L6075}H=z-8|0;I=B+8|0;J=A+1|0;if(H>>>0>7){z=H;A=J;B=I}else{K=H;L=J;M=I;break}}}else{K=x;L=y;M=u}if((K|0)==0){s=M;break L6070}else{C=-128;D=K;E=L;F=M}}else{C=(w&255)>>>1;D=x;E=v;F=u}}while(0);if((a[q+E|0]&C)<<24>>24!=0^r){s=F;break L6070}B=F+1|0;A=D-1|0;if((A|0)==0){s=B;break}else{v=E;w=C;x=A;u=B}}}}while(0);if(r){q=s<<9;p=q;n=0;if((s7(c[j>>2]|0,g,m,e,p,n)|0)==0){N=q;O=n;P=p}else{k=1;o=4442;break}}else{if((tt(c[b>>2]|0,g,h,s)|0)!=0){k=1;o=4443;break}p=s<<9;N=p;O=0;P=p}p=zW(P,O,m,e)|0;if((f|0)==(s|0)){k=0;o=4444;break}else{h=s+h|0;f=f-s|0;g=g+N|0;e=G;m=p}}if((o|0)==4440){return k|0}else if((o|0)==4442){return k|0}else if((o|0)==4443){return k|0}else if((o|0)==4444){return k|0}return 0}function yV(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;if((a[b+56|0]|0)!=0){h=1;return h|0}i=c[b+64>>2]|0;L6100:do{if((g|0)==0){j=i+72|0}else{k=f;l=i+88|0;m=zW(c[l>>2]|0,c[l+4>>2]|0,k<<9|0>>>23,0<<9|k>>>23)|0;k=b+28|0;l=i+96|0;n=i+72|0;o=i+80|0;p=f;q=g;r=e;s=G;t=m;while(1){if(p>>>0>=(c[k>>2]|0)>>>0){h=1;u=4471;break}m=p>>>3;v=128>>>((p&7)>>>0);w=c[l>>2]|0;x=w+m|0;y=d[x]|0;z=(y&v|0)!=0;L6105:do{if(q>>>0<2){A=1}else{B=z<<31>>31;C=q-1|0;if((C|0)==0){A=1;break}D=m;E=v&255;F=C;C=1;while(1){L6110:do{if(E<<24>>24==1){H=D+1|0;if(F>>>0>7){I=F;J=H;K=C;while(1){if((a[w+J|0]|0)!=B<<24>>24){L=-128;M=I;N=J;O=K;break L6110}P=I-8|0;Q=K+8|0;R=J+1|0;if(P>>>0>7){I=P;J=R;K=Q}else{S=P;T=R;U=Q;break}}}else{S=F;T=H;U=C}if((S|0)==0){A=U;break L6105}else{L=-128;M=S;N=T;O=U}}else{L=(E&255)>>>1;M=F;N=D;O=C}}while(0);if((a[w+N|0]&L)<<24>>24!=0^z){A=O;break L6105}K=O+1|0;J=M-1|0;if((J|0)==0){A=K;break}else{D=N;E=L;F=J;C=K}}}}while(0);if(!z){w=p-1+A|0;C=w>>>3;F=128>>>((w&7)>>>0);w=v+255|v;E=F+255^255|F;do{if((m|0)==(C|0)){a[x]=(y|E&w)&255}else{a[x]=(y|w)&255;F=(c[l>>2]|0)+C|0;a[F]=(d[F]|E)&255;F=m+1|0;if(F>>>0<C>>>0){V=F}else{break}do{a[(c[l>>2]|0)+V|0]=-1;V=V+1|0;}while(V>>>0<C>>>0)}}while(0);E=c[n>>2]|0;w=(c[l>>2]|0)+m|0;y=zW(c[o>>2]|0,c[o+4>>2]|0,m,0)|0;x=G;v=1-m+C|0;z=0;s8(E,w,y,x,v,z)|0}z=A<<9;v=z;x=0;if((s8(c[n>>2]|0,r,t,s,v,x)|0)!=0){h=1;u=4473;break}y=zW(v,x,t,s)|0;if((q|0)==(A|0)){j=n;break L6100}else{p=A+p|0;q=q-A|0;r=r+z|0;s=G;t=y}}if((u|0)==4471){return h|0}else if((u|0)==4473){return h|0}}}while(0);ax(c[j>>2]|0)|0;h=0;return h|0}function yW(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;f=i;i=i+4096|0;if((aP(e|0,32488)|0)!=0){g=1;i=f;return g|0}e=c[b+64>>2]|0;b=e+100|0;h=c[b>>2]|0;do{if((h|0)==0){j=e+72|0;k=0}else{l=e+96|0;m=f|0;n=e+68|0;o=e+88|0;p=e+72|0;q=0;r=0;s=0;t=h;while(1){u=a[(c[l>>2]|0)+r|0]|0;if(u<<24>>24==0){v=q;w=s;x=t}else{y=q;z=s;A=r<<3;B=u;while(1){if(B<<24>>24>-1){u=A;C=B;while(1){D=C<<1;E=u+1|0;if(D<<24>>24>-1){u=E;C=D}else{F=E;H=D;break}}}else{F=A;H=B}C=0;u=H;do{C=C+1|0;u=u<<1;}while(u<<24>>24<=-1);L6156:do{if((C|0)==0){I=1}else{D=F;E=zW(c[o>>2]|0,c[o+4>>2]|0,D<<9|0>>>23,0<<9|D>>>23)|0;D=F;J=C;K=G;L=E;while(1){E=J>>>0>8?8:J;M=E<<9;N=M;O=0;if((s7(c[p>>2]|0,m,L,K,N,O)|0)!=0){I=0;break L6156}if((tv(c[n>>2]|0,m,D,E)|0)!=0){I=0;break L6156}zP(m|0,0,M|0);if((s8(c[p>>2]|0,m,L,K,N,O)|0)!=0){I=0;break L6156}if((E|0)!=0){M=0;do{P=M+D|0;Q=(c[l>>2]|0)+(P>>>3)|0;a[Q]=(128>>>((P&7)>>>0)^255)&(d[Q]|0)&255;M=M+1|0;}while(M>>>0<E>>>0)}M=zW(N,O,L,K)|0;if((J|0)==(E|0)){I=1;break}else{D=E+D|0;J=J-E|0;K=G;L=M}}}}while(0);R=I?y:1;S=(I?C:0)+z|0;if(u<<24>>24==0){break}else{y=R;z=S;A=C+F|0;B=u}}v=R;w=S;x=c[b>>2]|0}B=r+1|0;if(B>>>0<x>>>0){q=v;r=B;s=w;t=x}else{break}}if((w|0)==0){j=p;k=v;break}t=e+80|0;if((s8(c[p>>2]|0,c[l>>2]|0,c[t>>2]|0,c[t+4>>2]|0,x,0)|0)==0){t=c[p>>2]|0;ax(t|0)|0;j=p;k=v;break}else{g=1;i=f;return g|0}}}while(0);ax(c[j>>2]|0)|0;g=k;i=f;return g|0}function yX(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;if((h|0)==0){i=bl(b|0,39064)|0}else{i=bl(b|0,33064)|0}if((i|0)==0){j=1;return j|0}b=c[a+64>>2]|0;a=b+68|0;k=c[a>>2]|0;l=b+72|0;c[l+(k<<5)>>2]=f;c[l+(k<<5)+4>>2]=g;g=l+(k<<5)+8|0;c[g>>2]=d;c[g+4>>2]=e;c[l+(k<<5)+16>>2]=i;c[l+(k<<5)+20>>2]=1;c[l+(k<<5)+24>>2]=(h|0)!=0;c[a>>2]=k+1;j=0;return j|0}function yY(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=zH(584)|0;if((f|0)==0){g=0;return g|0}h=f;tk(h,f,0,a,b,d);td(h,e);c[f+4>>2]=124;c[f+8>>2]=32;c[f+12>>2]=20;c[f+68>>2]=0;g=h;return g|0}function yZ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+64>>2]|0;a=b+68|0;d=c[a>>2]|0;if((d|0)==0){zI(b);return}e=b+72|0;f=0;g=d;while(1){if((c[e+(f<<5)+20>>2]|0)==0){h=g}else{d=c[e+(f<<5)+16>>2]|0;au(d|0)|0;h=c[a>>2]|0}d=f+1|0;if(d>>>0<h>>>0){f=d;g=h}else{break}}zI(b);return}function y_(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function y$(a){a=a|0;return 0}function y0(a,b,c){a=a|0;b=b|0;c=c|0;return-1|0}function y1(a){a=a|0;return}function y2(a){a=a|0;return}function y3(a,b,d){a=a|0;b=b|0;d=d|0;c[a+4>>2]=b;c[a+8>>2]=d;return}function y4(a,b,d){a=a|0;b=b|0;d=d|0;c[a+12>>2]=b;c[a+16>>2]=d;return}function y5(a,b,d){a=a|0;b=b|0;d=d|0;c[a+20>>2]=b;c[a+24>>2]=d;return}function y6(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;c[a+100>>2]=b;c[a+104>>2]=d;c[a+108>>2]=0;c[a+112>>2]=e;c[a+116>>2]=f;c[a+120>>2]=0;return}function y7(a,b,d){a=a|0;b=b|0;d=d|0;c[a+92>>2]=b;c[a+96>>2]=d;return}function y8(a,b){a=a|0;b=b|0;c[a+80>>2]=(b|0)==0?1:b;c[a+132>>2]=0;c[a+136>>2]=0;c[a+140>>2]=c[a+64>>2];c[a+144>>2]=c[a+68>>2];return}function y9(a,b,d){a=a|0;b=b|0;d=d|0;c[a+84>>2]=b;c[a+88>>2]=d;return}function za(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((e+d|0)>>>0>(c[a+28>>2]|0)>>>0){f=1;return f|0}if((e|0)==0){f=0;return f|0}g=a+64|0;a=c[g>>2]|0;h=a+72|0;i=e;e=d;d=b;b=a;while(1){a=c[b+68>>2]|0;if((a|0)==0){j=4547;break}k=b+72|0;l=0;m=0;while(1){n=c[k+(l<<5)>>2]|0;if(n>>>0>e>>>0){o=n>>>0<(c[k+(m<<5)>>2]|0)>>>0?l:m}else{if((e-n|0)>>>0<(c[k+(l<<5)+4>>2]|0)>>>0){p=l;break}else{o=m}}n=l+1|0;if(n>>>0<a>>>0){l=n;m=o}else{j=4546;break}}if((j|0)==4546){j=0;if((c[k+(o<<5)>>2]|0)>>>0>e>>>0){p=o}else{j=4547;break}}m=c[h+(p<<5)>>2]|0;if(m>>>0>e>>>0){l=m-e|0;a=l>>>0>i>>>0?i:l;l=a<<9;zP(d|0,-2|0,l|0);q=l;r=a}else{a=e-m|0;m=(c[h+(p<<5)+4>>2]|0)-a|0;l=m>>>0>i>>>0?i:m;m=h+(p<<5)+8|0;n=a;a=zW(c[m>>2]|0,c[m+4>>2]|0,n<<9|0>>>23,0<<9|n>>>23)|0;n=l;m=n<<9|0>>>23;if((s7(c[h+(p<<5)+16>>2]|0,d,a,G,m,0<<9|n>>>23)|0)==0){q=m;r=l}else{f=1;j=4556;break}}if((i|0)==(r|0)){f=0;j=4558;break}i=i-r|0;e=r+e|0;d=d+q|0;b=c[g>>2]|0}if((j|0)==4547){zP(d|0,-2|0,i<<9|0);f=0;return f|0}else if((j|0)==4556){return f|0}else if((j|0)==4558){return f|0}return 0}function zb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((e+d|0)>>>0>(c[a+28>>2]|0)>>>0){f=1;return f|0}g=a+64|0;a=c[g>>2]|0;h=a+72|0;if((e|0)==0){f=0;return f|0}else{i=e;j=d;k=b;l=a}while(1){a=c[l+68>>2]|0;if((a|0)==0){f=0;m=4577;break}b=l+72|0;d=0;e=0;while(1){n=c[b+(d<<5)>>2]|0;if(n>>>0>j>>>0){o=n>>>0<(c[b+(e<<5)>>2]|0)>>>0?d:e}else{if((j-n|0)>>>0<(c[b+(d<<5)+4>>2]|0)>>>0){p=d;break}else{o=e}}n=d+1|0;if(n>>>0<a>>>0){d=n;e=o}else{m=4567;break}}if((m|0)==4567){m=0;if((c[b+(o<<5)>>2]|0)>>>0>j>>>0){p=o}else{f=0;m=4581;break}}e=c[h+(p<<5)>>2]|0;if(e>>>0>j>>>0){d=e-j|0;a=d>>>0>i>>>0?i:d;q=a<<9;r=a}else{if((c[h+(p<<5)+24>>2]|0)!=0){f=1;m=4582;break}a=j-e|0;e=(c[h+(p<<5)+4>>2]|0)-a|0;d=e>>>0>i>>>0?i:e;e=h+(p<<5)+8|0;n=a;a=zW(c[e>>2]|0,c[e+4>>2]|0,n<<9|0>>>23,0<<9|n>>>23)|0;n=d;e=n<<9|0>>>23;s=h+(p<<5)+16|0;if((s8(c[s>>2]|0,k,a,G,e,0<<9|n>>>23)|0)!=0){f=1;m=4579;break}n=c[s>>2]|0;ax(n|0)|0;q=e;r=d}if((i|0)==(r|0)){f=0;m=4580;break}i=i-r|0;j=r+j|0;k=k+q|0;l=c[g>>2]|0}if((m|0)==4577){return f|0}else if((m|0)==4579){return f|0}else if((m|0)==4580){return f|0}else if((m|0)==4581){return f|0}else if((m|0)==4582){return f|0}return 0}function zc(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;h=zH(72)|0;if((h|0)==0){i=0;return i|0}j=h;tk(j,h,b,d,e,f);tb(j,2);td(j,g);c[h+4>>2]=32;c[h+8>>2]=30;c[h+12>>2]=2;g=h+28|0;f=c[g>>2]<<9;e=zH(f)|0;d=h+68|0;c[d>>2]=e;if((e|0)==0){zI(h);i=0;return i|0}zP(e|0,0,f|0);if((a|0)==0){i=j;return i|0}f=bl(a|0,33032)|0;do{if((f|0)!=0){e=c[g>>2]|0;b=s7(f,c[d>>2]|0,0,0,e<<9|0>>>23,0<<9|e>>>23)|0;au(f|0)|0;if((b|0)!=0){break}tm(j,a);i=j;return i|0}}while(0);zI(c[d>>2]|0);zI(h);i=0;return i|0}function zd(a){a=a|0;var b=0;b=c[a+64>>2]|0;zI(c[b+68>>2]|0);zI(b);return}function ze(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;if((e+d|0)>>>0>(c[a+28>>2]|0)>>>0){f=1;return f|0}g=(c[(c[a+64>>2]|0)+68>>2]|0)+(d<<9)|0;d=e<<9;zO(b|0,g|0,d)|0;f=0;return f|0}function zf(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;if((a[b+56|0]|0)!=0){g=1;return g|0}if((f+e|0)>>>0>(c[b+28>>2]|0)>>>0){g=1;return g|0}h=(c[(c[b+64>>2]|0)+68>>2]|0)+(e<<9)|0;e=f<<9;zO(h|0,d|0,e)|0;g=0;return g|0}function zg(a){a=a|0;var b=0,d=0,e=0,f=0;b=5400;while(1){d=c[b+4>>2]|0;if((d|0)==0){e=0;f=4616;break}if((zV(d|0,a|0)|0)==0){break}else{b=b+8|0}}if((f|0)==4616){return e|0}e=c[b>>2]|0;return e|0}function zh(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+32|0;g=f|0;h=b;while(1){b=a[h]|0;if(!((b<<24>>24|0)==32|(b<<24>>24|0)==9)){j=h;k=0;l=b;break}h=h+1|0}while(1){if((l<<24>>24|0)==0|(l<<24>>24|0)==61|(l<<24>>24|0)==32){break}h=j+1|0;b=k+1|0;a[g+k|0]=l;if(b>>>0>=32){m=1;n=4634;break}j=h;k=b;l=a[h]|0}if((n|0)==4634){i=f;return m|0}if(k>>>0>31){m=1;i=f;return m|0}a[g+k|0]=0;k=j;while(1){j=a[k]|0;if((j<<24>>24|0)==61){o=k;n=4627;break}else if((j<<24>>24|0)!=32){p=k;break}k=k+1|0}if((n|0)==4627){while(1){n=0;k=o+1|0;if((a[k]|0)==32){o=k;n=4627}else{p=k;break}}}c[d>>2]=aw(g|0,0,0)|0;g=5400;while(1){d=c[g+4>>2]|0;if((d|0)==0){q=0;break}if((zV(d|0,p|0)|0)==0){n=4631;break}else{g=g+8|0}}if((n|0)==4631){q=c[g>>2]|0}c[e>>2]=q;m=0;i=f;return m|0}function zi(a){a=a|0;var b=0,d=0;a=zH(152)|0;if((a|0)==0){b=0;return b|0}d=a;zk(d,a);c[a+28>>2]=24;c[a+32>>2]=2;c[a+36>>2]=262;c[a+40>>2]=54;c[a+44>>2]=172;c[a+48>>2]=112;b=d;return b|0}function zj(a){a=a|0;if((a|0)==0){return}zI(a);return}function zk(a,b){a=a|0;b=b|0;c[a>>2]=b;zP(a+4|0,0,28);zP(a+40|0,0,16);c[a+56>>2]=1;zP(a+60|0,0,20);c[a+80>>2]=1;c[a+84>>2]=4;c[a+88>>2]=3;c[a+92>>2]=320;c[a+96>>2]=240;c[a+100>>2]=1;c[a+104>>2]=1;c[a+108>>2]=0;c[a+112>>2]=1;c[a+116>>2]=1;zP(a+120|0,0,32);return}function zl(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=a+52|0;if((c[e>>2]|0)!=0){f=0;return f|0}g=c[a+32>>2]|0;do{if((g|0)!=0){if((b4[g&127](c[a>>2]|0,b,d)|0)==0){break}else{f=1}return f|0}}while(0);c[e>>2]=1;f=0;return f|0}function zm(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+256|0;f=e|0;if((d|0)==0){g=4658}else{if((a[d]|0)==0){g=4658}else{h=d}}if((g|0)==4658){g=f|0;f=b+148|0;d=c[f>>2]|0;a1(g|0,32288,(x=i,i=i+8|0,c[x>>2]=d,x)|0)|0;c[f>>2]=(c[f>>2]|0)+1;h=g}g=bl(h|0,38768)|0;if((g|0)==0){j=1;i=e;return j|0}h=c[b+64>>2]|0;f=c[b+68>>2]|0;d=ac(h*3|0,f)|0;bN(g|0,32376,(x=i,i=i+24|0,c[x>>2]=h,c[x+8>>2]=f,c[x+16>>2]=255,x)|0)|0;f=aB(c[b+76>>2]|0,1,d|0,g|0)|0;au(g|0)|0;j=(f|0)!=(d|0)|0;i=e;return j|0}function zn(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;if((aP(b|0,30520)|0)==0){e=zg(d)|0;if((e|0)==0){f=0;return f|0}c[a+56>>2]=e;f=0;return f|0}if((aP(b|0,28456)|0)==0){zm(a,d)|0;f=0;return f|0}e=c[a+40>>2]|0;if((e|0)==0){f=-1;return f|0}f=b4[e&127](c[a>>2]|0,b,d)|0;return f|0}function zo(a,b){a=a|0;b=b|0;var d=0,e=0;d=zg(b)|0;if((d|0)==0){e=1;return e|0}c[a+56>>2]=d;e=0;return e|0}function zp(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((b|0)==0|(d|0)==0){zI(c[a+76>>2]|0);zP(a+64|0,0,16);return}e=a+64|0;do{if((c[e>>2]|0)==(b|0)){if((c[a+68>>2]|0)!=(d|0)){break}return}}while(0);f=ac(b*3|0,d)|0;g=a+72|0;do{if((c[g>>2]|0)!=(f|0)){h=a+76|0;i=zJ(c[h>>2]|0,f)|0;if((i|0)==0){return}else{c[h>>2]=i;c[g>>2]=f;break}}}while(0);c[e>>2]=b;c[a+68>>2]=d;c[a+132>>2]=0;c[a+136>>2]=0;c[a+140>>2]=b;c[a+144>>2]=d;return}function zq(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=a+64|0;g=(c[f>>2]|0)*3|0;h=c[a+76>>2]|0;i=h+(ac(g,d)|0)|0;L6409:do{if((e|0)==0){j=0;k=d;l=b;m=i}else{h=e;n=d;o=b;p=i;while(1){if((zS(p|0,o|0,g|0)|0)!=0){j=h;k=n;l=o;m=p;break L6409}q=o+g|0;r=p+g|0;s=n+1|0;t=h-1|0;if((t|0)==0){j=0;k=s;l=q;m=r;break}else{h=t;n=s;o=q;p=r}}}}while(0);i=ac(j,g)|0;b=j;while(1){if((b|0)==0){u=4711;break}j=i-g|0;if((zS(m+j|0,l+j|0,g|0)|0)==0){i=j;b=b-1|0}else{break}}if((u|0)==4711){return}u=ac(b,g)|0;zO(m|0,l|0,u)|0;c[a+132>>2]=0;c[a+140>>2]=c[f>>2];f=a+144|0;u=c[f>>2]|0;l=a+136|0;if((u|0)==0){c[l>>2]=k;c[f>>2]=b;return}a=c[l>>2]|0;if(k>>>0<a>>>0){m=u-k+a|0;c[f>>2]=m;c[l>>2]=k;v=k;w=m}else{v=a;w=u}u=b+k|0;if(u>>>0<=(w+v|0)>>>0){return}c[f>>2]=u-v;return}function zr(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=c[a+92>>2]|0;h=a+96|0;i=1;while(1){if((ac(i,b)|0)>>>0>=g>>>0){break}j=ac(i,d)|0;if(j>>>0<(c[h>>2]|0)>>>0){i=i+1|0}else{break}}h=a+80|0;g=i-1|0;c[e>>2]=g+(c[h>>2]|0);i=g+(c[h>>2]|0)|0;c[f>>2]=i;h=a+84|0;g=c[h>>2]|0;if((g|0)==0){return}j=a+88|0;a=c[j>>2]|0;if((a|0)==0){return}k=ac(c[e>>2]|0,b)|0;l=ac(i,d)|0;m=((ac(l,g)|0)>>>0)/(a>>>0)|0;n=((ac(k,a)|0)>>>0)/(g>>>0)|0;g=l+d|0;if(g>>>0<=n>>>0){l=g;g=i;do{g=g+1|0;l=l+d|0;}while(l>>>0<=n>>>0);c[f>>2]=g}g=k+b|0;if(g>>>0>m>>>0){o=k;p=g}else{k=g;g=c[e>>2]|0;while(1){q=g+1|0;r=k+b|0;if(r>>>0>m>>>0){break}else{k=r;g=q}}c[e>>2]=q;o=k;p=r}if(o>>>0>=m>>>0){return}r=ac(c[j>>2]|0,p-m|0)|0;if(r>>>0>=(ac(c[h>>2]|0,m-o|0)|0)>>>0){return}c[e>>2]=(c[e>>2]|0)+1;return}function zs(a){a=a|0;var b=0;if((c[a+140>>2]|0)==0){return}if((c[a+144>>2]|0)==0){return}b=c[a+44>>2]|0;if((b|0)!=0){b2[b&255](c[a>>2]|0)}zP(a+132|0,0,16);return}function zt(a){a=a|0;var b=0;b=c[a+48>>2]|0;if((b|0)==0){return}b2[b&255](c[a>>2]|0);return}function zu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=c[a+8>>2]|0;if((e|0)==0){f=1;return f|0}f=b4[e&127](c[a+4>>2]|0,b,d)|0;return f|0}function zv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;do{if((b|0)==1){e=(c[a+56>>2]|0)==(d|0);f=a+60|0;g=c[f>>2]|0;if(e){h=g^1;c[f>>2]=h;i=h}else{i=g}g=a+60|0;if((i&1|0)!=0){if(e){return}zw(a,3,d);return}do{if((d|0)==71){e=i|8;c[g>>2]=e;j=e}else if((d|0)==75){e=i|4;c[g>>2]=e;j=e}else if((d|0)==16){if((i&12|0)!=0){j=i;break}e=a+40|0;h=c[e>>2]|0;do{if((h|0)!=0){f=c[a>>2]|0;b4[h&127](f,26816,44440)|0;f=c[e>>2]|0;if((f|0)==0){break}k=c[a>>2]|0;b4[f&127](k,24096,22544)|0}}while(0);e=c[a+8>>2]|0;if((e|0)==0){return}b4[e&127](c[a+4>>2]|0,21360,41464)|0;return}else{j=i}}while(0);if((j&12|0)!=12){break}e=c[a+40>>2]|0;if((e|0)==0){l=j}else{h=c[a>>2]|0;b4[e&127](h,26816,44440)|0;l=c[g>>2]|0}c[g>>2]=l&-13}else if((b|0)==2){h=a+60|0;e=c[h>>2]|0;if((e&1|0)==0){if((d|0)==16){return}else if((d|0)==71){c[h>>2]=e&-9;break}else if((d|0)==75){c[h>>2]=e&-5;break}else{break}}else{if((c[a+56>>2]|0)==(d|0)){return}c[h>>2]=e&-2;return}}}while(0);zw(a,b,d);return}function zw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;do{if((b|0)==3){if((d|0)==19){e=c[a+8>>2]|0;if((e|0)==0){return}f=c[a+4>>2]|0;b4[e&127](f,40336,38808)|0;return}else if((d|0)==27){f=c[a+8>>2]|0;if((f|0)==0){return}b4[f&127](c[a+4>>2]|0,40336,22544)|0;return}else if((d|0)==49){f=c[a+40>>2]|0;if((f|0)==0){return}b4[f&127](c[a>>2]|0,33904,44440)|0;return}else if((d|0)==21){f=c[a+8>>2]|0;if((f|0)==0){return}b4[f&127](c[a+4>>2]|0,40336,36896)|0;return}else if((d|0)==32){f=a+40|0;e=c[f>>2]|0;do{if((e|0)!=0){g=a|0;h=c[g>>2]|0;b4[e&127](h,26816,44440)|0;h=c[f>>2]|0;if((h|0)==0){break}i=c[g>>2]|0;b4[h&127](i,24096,22544)|0}}while(0);f=c[a+8>>2]|0;if((f|0)==0){return}b4[f&127](c[a+4>>2]|0,21360,41464)|0;return}else if((d|0)==20){f=c[a+8>>2]|0;if((f|0)==0){return}b4[f&127](c[a+4>>2]|0,40336,37848)|0;return}else if((d|0)==25){f=c[a+8>>2]|0;if((f|0)==0){return}b4[f&127](c[a+4>>2]|0,40336,34144)|0;return}else if((d|0)==24){f=c[a+8>>2]|0;if((f|0)==0){return}b4[f&127](c[a+4>>2]|0,40336,34368)|0;return}else if((d|0)==65){f=a+40|0;e=c[f>>2]|0;do{if((e|0)!=0){i=a|0;h=c[i>>2]|0;b4[e&127](h,26816,44440)|0;h=c[f>>2]|0;if((h|0)==0){break}g=c[i>>2]|0;b4[h&127](g,24096,22544)|0}}while(0);f=c[a+8>>2]|0;if((f|0)==0){return}b4[f&127](c[a+4>>2]|0,33072,41464)|0;return}else if((d|0)==18){f=c[a+8>>2]|0;if((f|0)==0){return}b4[f&127](c[a+4>>2]|0,40336,41464)|0;return}else if((d|0)==41){f=c[a+8>>2]|0;if((f|0)==0){return}b4[f&127](c[a+4>>2]|0,32392,44440)|0;return}else if((d|0)==47){zm(a,0)|0;return}else if((d|0)==106|(d|0)==90){f=c[a+8>>2]|0;if((f|0)==0){return}b4[f&127](c[a+4>>2]|0,31960,31824)|0;return}else if((d|0)==35){f=c[a+8>>2]|0;if((f|0)==0){return}b4[f&127](c[a+4>>2]|0,32152,41464)|0;return}else if((d|0)==108|(d|0)==92){f=c[a+8>>2]|0;if((f|0)==0){return}b4[f&127](c[a+4>>2]|0,31960,31728)|0;return}else if((d|0)==105|(d|0)==87){f=a+80|0;e=(c[f>>2]|0)+1|0;c[f>>2]=(e|0)==0?1:e;c[a+132>>2]=0;c[a+136>>2]=0;c[a+140>>2]=c[a+64>>2];c[a+144>>2]=c[a+68>>2];return}else if((d|0)==107|(d|0)==94){e=a+80|0;f=c[e>>2]|0;if(f>>>0<=1){return}g=f-1|0;c[e>>2]=(g|0)==0?1:g;c[a+132>>2]=0;c[a+136>>2]=0;c[a+140>>2]=c[a+64>>2];c[a+144>>2]=c[a+68>>2];return}else if((d|0)==50){g=c[a+40>>2]|0;if((g|0)==0){return}b4[g&127](c[a>>2]|0,33512,44440)|0;return}else if((d|0)==22){g=c[a+8>>2]|0;if((g|0)==0){return}b4[g&127](c[a+4>>2]|0,40336,35024)|0;return}else if((d|0)==23){g=c[a+8>>2]|0;if((g|0)==0){return}b4[g&127](c[a+4>>2]|0,40336,34632)|0;return}else{break}}}while(0);g=c[a+16>>2]|0;if((g|0)==0){return}b5[g&255](c[a+12>>2]|0,b,d);return}function zx(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=ac(c[a+100>>2]|0,b)|0;b=a+108|0;g=f+(c[b>>2]|0)|0;f=c[a+104>>2]|0;h=(g|0)/(f|0)|0;c[b>>2]=g-(ac(h,f)|0);f=ac(c[a+112>>2]|0,d)|0;d=a+120|0;g=f+(c[d>>2]|0)|0;f=c[a+116>>2]|0;b=(g|0)/(f|0)|0;c[d>>2]=g-(ac(b,f)|0);f=c[a+24>>2]|0;if((f|0)==0){return}ca[f&3](c[a+20>>2]|0,h,b,e);return}function zy(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=(g|0)==1;if(i&(h|0)==1){j=d;return j|0}k=ac(g,e)|0;l=ac(ac(f*3|0,k)|0,h)|0;m=b+124|0;n=b+128|0;b=c[n>>2]|0;do{if(l>>>0>(c[m>>2]|0)>>>0){o=zJ(b,l)|0;if((o|0)==0){j=0;return j|0}else{c[n>>2]=o;c[m>>2]=l;p=o;break}}else{if((b|0)==0){j=0}else{p=b;break}return j|0}}while(0);if(i){i=e*3|0;if((f|0)==0){j=p;return j|0}if(h>>>0<=1){b=d;l=p;m=0;while(1){zO(l|0,b|0,i)|0;n=m+1|0;if(n>>>0<f>>>0){b=b+i|0;l=l+i|0;m=n}else{j=p;break}}return j|0}m=ac(i,h)|0;l=d;b=p;n=0;while(1){zO(b|0,l|0,i)|0;o=1;q=b;while(1){r=q+i|0;zO(r|0,q|0,i)|0;s=o+1|0;if(s>>>0<h>>>0){o=s;q=r}else{break}}q=n+1|0;if(q>>>0<f>>>0){l=l+i|0;b=b+m|0;n=q}else{j=p;break}}return j|0}if((g|0)!=2){n=e*3|0;m=ac(n,g)|0;if((f|0)==0){j=p;return j|0}b=(e|0)==0;i=(g|0)==0;l=h>>>0>1;q=-m|0;o=ac((h*3|0)-3|0,k)|0;r=g*3|0;s=k*3|0;k=d;t=p;u=0;while(1){if(b){v=k;w=t}else{if(i){x=t}else{y=k;z=t;A=0;while(1){B=y+1|0;C=y+2|0;D=0;E=z;while(1){a[E]=a[y]|0;a[E+1|0]=a[B]|0;a[E+2|0]=a[C]|0;F=D+1|0;if(F>>>0<g>>>0){D=F;E=E+3|0}else{break}}E=A+1|0;if(E>>>0<e>>>0){y=y+3|0;z=z+r|0;A=E}else{break}}x=t+s|0}v=k+n|0;w=x}if(l){A=1;z=w;while(1){y=z+q|0;zO(z|0,y|0,m)|0;y=A+1|0;if(y>>>0<h>>>0){A=y;z=z+m|0}else{break}}G=w+o|0}else{G=w}z=u+1|0;if(z>>>0<f>>>0){k=v;t=G;u=z}else{j=p;break}}return j|0}u=e*6|0;if((f|0)==0){j=p;return j|0}G=h>>>0>1;t=-u|0;if((e|0)==0){if(G){H=0}else{j=p;return j|0}while(1){v=1;k=p;while(1){w=k+t|0;zO(k|0,w|0,u)|0;w=v+1|0;if(w>>>0<h>>>0){v=w;k=k+u|0}else{break}}k=H+1|0;if(k>>>0<f>>>0){H=k}else{j=p;break}}return j|0}H=e*3|0;k=ac(u,h)|0;v=d;d=p;w=0;while(1){o=v;m=d;q=0;while(1){a[m]=a[o]|0;l=o+1|0;a[m+1|0]=a[l]|0;x=o+2|0;a[m+2|0]=a[x]|0;a[m+3|0]=a[o]|0;a[m+4|0]=a[l]|0;a[m+5|0]=a[x]|0;x=q+1|0;if(x>>>0<e>>>0){o=o+3|0;m=m+6|0;q=x}else{break}}q=v+H|0;m=d+u|0;if(G){o=1;x=m;while(1){l=x+t|0;zO(x|0,l|0,u)|0;l=o+1|0;if(l>>>0<h>>>0){o=l;x=x+u|0}else{break}}I=d+k|0}else{I=m}x=w+1|0;if(x>>>0<f>>>0){v=q;d=I;w=x}else{j=p;break}}return j|0}function zz(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=i;i=i+32|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=zH(208)|0;if((j|0)==0){k=0;i=d;return k|0}l=j;zk(l,j);c[j+28>>2]=22;c[j+32>>2]=88;c[j+36>>2]=452;c[j+40>>2]=20;c[j+44>>2]=110;c[j+48>>2]=116;zP(j+152|0,0,16);yl(b,32096,g,0)|0;a[j+168|0]=(c[g>>2]|0)!=0|0;g=j+180|0;yj(b,38720,g,0)|0;m=c[g>>2]|0;c[j+184>>2]=m;c[j+188>>2]=m;c[j+192>>2]=m;a[j+196|0]=0;c[j+172>>2]=0;c[j+176>>2]=0;yl(b,32360,h,0)|0;a[j+197|0]=(c[h>>2]|0)!=0|0;h=j+200|0;c[h>>2]=0;m=j+204|0;j=zH(864)|0;g=j;c[m>>2]=g;if((j|0)!=0){n=j;c[n>>2]=27;c[n+4>>2]=1;n=j+8|0;c[n>>2]=1082;c[n+4>>2]=2;n=2;j=g;while(1){g=6576+(n<<3)|0;o=j+(n<<3)|0;p=c[g+4>>2]|0;c[o>>2]=c[g>>2];c[o+4>>2]=p;p=n+1|0;if(p>>>0>=108){break}n=p;j=c[m>>2]|0}c[h>>2]=108}j=yd(b,0,30512)|0;if((j|0)==0){k=l;i=d;return k|0}else{q=j}while(1){j=yy(q)|0;do{if((j|0)!=0){if((zh(j,e,f)|0)!=0){break}n=c[e>>2]|0;p=c[f>>2]|0;o=c[h>>2]|0;g=c[m>>2]|0;r=0;while(1){if(r>>>0>=o>>>0){break}if((c[g+(r<<3)>>2]|0)==(n|0)){s=4947;break}else{r=r+1|0}}if((s|0)==4947){s=0;c[g+(r<<3)+4>>2]=p;break}t=zJ(g,(o<<3)+8|0)|0;u=t;if((t|0)==0){break}t=c[h>>2]|0;c[u+(t<<3)>>2]=n;c[u+(t<<3)+4>>2]=p;c[m>>2]=u;c[h>>2]=t+1}}while(0);j=yd(b,q,30512)|0;if((j|0)==0){k=l;break}else{q=j}}i=d;return k|0}function zA(a){a=a|0;zI(a);return}function zB(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f|0;h=f+8|0;j=(b|0)==0|(e|0)==0;k=j?480:e;e=j?640:b;zr(a|0,e,k,g,h);b=(c[a+188>>2]|0)+(c[a+180>>2]|0)|0;j=(c[a+192>>2]|0)+(c[a+184>>2]|0)|0;do{if((aI(32)|0)==0){if((bt(32)|0)<0){l=1}else{break}i=f;return l|0}}while(0);c[a+172>>2]=d[(c[(bq()|0)+8>>2]|0)+9|0]|0;c[a+176>>2]=0;bz(34360,34360);bo(500,30)|0;m;m=b+(ac(c[g>>2]|0,e)|0)|0;zG(a,m,j+(ac(c[h>>2]|0,k)|0)|0)|0;l=0;i=f;return l|0}function zC(b){b=b|0;var d=0;a[b+196|0]=0;a3(1)|0;d;d=b+152|0;b=c[d>>2]|0;if((b|0)==0){return 0}b$(b|0);c[d>>2]=0;return 0}function zD(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=(e|0)==0?44432:e;if((aP(d|0,41448)|0)==0){a[b+196|0]=1;a3(0)|0;g;h=0;return h|0}if((aP(d|0,40320)|0)==0){a[b+196|0]=0;a3(1)|0;i;h=0;return h|0}if((aP(d|0,38792)|0)==0){bz(f|0,f|0);h=0;return h|0}if((aP(d|0,37824)|0)==0){i=aw(f|0,0,0)|0;c[b+180>>2]=i;c[b+188>>2]=i;zE(b);h=0;return h|0}if((aP(d|0,36872)|0)==0){c[b+184>>2]=aw(f|0,0,0)|0;c[b+192>>2]=c[b+180>>2];zE(b);h=0;return h|0}if((aP(d|0,35e3)|0)==0){i=b+168|0;g=(a[i]|0)==0;e=c[b+152>>2]|0;if((e|0)!=0){bL(e|0)|0}a[i]=g&1;h=0;return h|0}if((aP(d|0,34616)|0)!=0){h=-1;return h|0}d=(az(f|0,0,0)|0)!=0;f=b+168|0;if(!(d^(a[f]|0)!=0)){h=0;return h|0}g=c[b+152>>2]|0;if((g|0)!=0){bL(g|0)|0}a[f]=d&1;h=0;return h|0}function zE(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+32|0;d=b|0;e=b+16|0;f=b+24|0;g=a|0;h=a+64|0;j=a+68|0;zr(g,c[h>>2]|0,c[j>>2]|0,e,f);k=ac(c[h>>2]|0,c[e>>2]|0)|0;l=ac(c[j>>2]|0,c[f>>2]|0)|0;m=a+180|0;n=a+184|0;if((zG(a,(c[m>>2]|0)+k+(c[a+188>>2]|0)|0,(c[n>>2]|0)+l+(c[a+192>>2]|0)|0)|0)!=0){i=b;return}l=zy(g,c[a+76>>2]|0,c[h>>2]|0,c[j>>2]|0,c[e>>2]|0,c[f>>2]|0)|0;j=c[e>>2]|0;e=ac(c[a+132>>2]|0,j)|0;h=c[f>>2]|0;f=ac(c[a+136>>2]|0,h)|0;g=ac(c[a+140>>2]|0,j)|0;j=ac(c[a+144>>2]|0,h)|0;h=bg(l+(((ac(f,k)|0)+e|0)*3|0)|0,g|0,j|0,24,k*3|0|0,255,65280,16711680,0)|0;c[d>>2]=(c[m>>2]|0)+e;c[d+4>>2]=(c[n>>2]|0)+f;if((h|0)==0){i=b;return}f=a+152|0;if((bU(h|0,0,c[f>>2]|0,d|0)|0)!=0){d=c[q>>2]|0;aB(22520,16,1,d|0)|0}b$(h|0);bs(c[f>>2]|0)|0;i=b;return}function zF(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;e=i;i=i+48|0;f=e|0;if((ba(f|0)|0)==0){i=e;return}g=f|0;h=f+16|0;j=d+200|0;k=d+204|0;l=d+197|0;m=d|0;n=f+20|0;o=d+196|0;p=d+168|0;r=d+152|0;s=f+8|0;t=d+164|0;u=d+24|0;d=f+20|0;v=f+24|0;w=0;do{y=c[g>>2]|0;L6815:do{if((y|0)==768){z=c[h>>2]|0;if((z|0)==96){A=5008}else if((z|0)==1094){zm(m,0)|0;break}do{if((A|0)==5008){A=0;if((b[n>>1]&64)==0){break}a[o]=0;a3(1)|0;B;if((a[p]|0)!=0){C=c[r>>2]|0;if((C|0)!=0){bL(C|0)|0}a[p]=0}zu(m,25304,26808)|0;break L6815}}while(0);C=c[j>>2]|0;D=0;while(1){if(D>>>0>=C>>>0){A=5017;break}E=c[k>>2]|0;if((c[E+(D<<3)>>2]|0)==(z|0)){break}else{D=D+1|0}}if((A|0)==5017){A=0;C=c[q>>2]|0;bN(C|0,24064,(x=i,i=i+8|0,c[x>>2]=z,x)|0)|0;break}C=c[E+(D<<3)+4>>2]|0;F=(C|0)==0;if((a[l]|0)!=0|F){G=c[q>>2]|0;bN(G|0,24064,(x=i,i=i+8|0,c[x>>2]=z,x)|0)|0;if(F){break}}zv(m,1,C);if((z|0)!=1107){break}zv(m,2,C)}else if((y|0)==1026){C=a[s]|0;F=C&255;if((F|0)==2){H=2}else if((F|0)==0){break}else{H=C<<24>>24==3?1:F-1|0}F=c[t>>2]&~(1<<H);c[t>>2]=F;if((a[o]|0)==0){a[o]=1;a3(0)|0;I;break}if((c[u>>2]|0)==0){break}zx(m,0,0,F)}else if((y|0)==1024){F=c[d>>2]|0;C=c[v>>2]|0;if((a[o]|0)==0){break}if((c[u>>2]|0)==0){break}G=(ay(0,0)|0)&255;J=G&1;zx(m,F,C,(G&4|0)==0?J:J|2)}else if((y|0)==769){J=c[h>>2]|0;G=c[j>>2]|0;C=0;while(1){if(C>>>0>=G>>>0){break L6815}K=c[k>>2]|0;if((c[K+(C<<3)>>2]|0)==(J|0)){break}else{C=C+1|0}}G=c[K+(C<<3)+4>>2]|0;if((J|0)==1094|(G|0)==0){break}if((J|0)==1107){zv(m,1,G)}zv(m,2,G)}else if((y|0)==1025){G=a[s]|0;z=G&255;if((z|0)==0){break}else if((z|0)==2){L=2}else{L=G<<24>>24==3?1:z-1|0}z=c[t>>2]|1<<L;c[t>>2]=z;if((a[o]|0)==0){break}if((c[u>>2]|0)==0){break}zx(m,0,0,z)}else if((y|0)==256){a[o]=0;a3(1)|0;M;zu(m,28440,26808)|0}}while(0);w=w+1|0;}while((ba(f|0)|0)!=0&w>>>0<8);i=e;return}function zG(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=b+152|0;g=c[f>>2]|0;if((g|0)!=0){do{if((c[b+156>>2]|0)==(d|0)){if((c[b+160>>2]|0)==(e|0)){h=0}else{break}return h|0}}while(0);b$(g|0)}c[f>>2]=0;g=(a[b+168|0]|0)==0?134217729:142606337;i=c[b+172>>2]|0;if((i|0)==4){j=bk(d|0,e|0,32,g|0)|0;c[f>>2]=j;c[b+176>>2]=4;k=j;l=5056}else if((i|0)==2){i=bk(d|0,e|0,16,g|0)|0;c[f>>2]=i;c[b+176>>2]=2;k=i;l=5056}else{l=5057}if((l|0)==5056){if((k|0)==0){l=5057}}do{if((l|0)==5057){k=bk(d|0,e|0,16,g|0)|0;c[f>>2]=k;c[b+176>>2]=2;if((k|0)==0){h=1}else{break}return h|0}}while(0);c[b+156>>2]=d;c[b+160>>2]=e;h=0;return h|0}
function zH(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0;do{if(a>>>0<245){if(a>>>0<11){b=16}else{b=a+11&-8}d=b>>>3;e=c[11130]|0;f=e>>>(d>>>0);if((f&3|0)!=0){g=(f&1^1)+d|0;h=g<<1;i=44560+(h<<2)|0;j=44560+(h+2<<2)|0;h=c[j>>2]|0;k=h+8|0;l=c[k>>2]|0;do{if((i|0)==(l|0)){c[11130]=e&~(1<<g)}else{if(l>>>0<(c[11134]|0)>>>0){bM();return 0}m=l+12|0;if((c[m>>2]|0)==(h|0)){c[m>>2]=i;c[j>>2]=l;break}else{bM();return 0}}}while(0);l=g<<3;c[h+4>>2]=l|3;j=h+(l|4)|0;c[j>>2]=c[j>>2]|1;n=k;return n|0}if(b>>>0<=(c[11132]|0)>>>0){o=b;break}if((f|0)!=0){j=2<<d;l=f<<d&(j|-j);j=(l&-l)-1|0;l=j>>>12&16;i=j>>>(l>>>0);j=i>>>5&8;m=i>>>(j>>>0);i=m>>>2&4;p=m>>>(i>>>0);m=p>>>1&2;q=p>>>(m>>>0);p=q>>>1&1;r=(j|l|i|m|p)+(q>>>(p>>>0))|0;p=r<<1;q=44560+(p<<2)|0;m=44560+(p+2<<2)|0;p=c[m>>2]|0;i=p+8|0;l=c[i>>2]|0;do{if((q|0)==(l|0)){c[11130]=e&~(1<<r)}else{if(l>>>0<(c[11134]|0)>>>0){bM();return 0}j=l+12|0;if((c[j>>2]|0)==(p|0)){c[j>>2]=q;c[m>>2]=l;break}else{bM();return 0}}}while(0);l=r<<3;m=l-b|0;c[p+4>>2]=b|3;q=p;e=q+b|0;c[q+(b|4)>>2]=m|1;c[q+l>>2]=m;l=c[11132]|0;if((l|0)!=0){q=c[11135]|0;d=l>>>3;l=d<<1;f=44560+(l<<2)|0;k=c[11130]|0;h=1<<d;do{if((k&h|0)==0){c[11130]=k|h;s=f;t=44560+(l+2<<2)|0}else{d=44560+(l+2<<2)|0;g=c[d>>2]|0;if(g>>>0>=(c[11134]|0)>>>0){s=g;t=d;break}bM();return 0}}while(0);c[t>>2]=q;c[s+12>>2]=q;c[q+8>>2]=s;c[q+12>>2]=f}c[11132]=m;c[11135]=e;n=i;return n|0}l=c[11131]|0;if((l|0)==0){o=b;break}h=(l&-l)-1|0;l=h>>>12&16;k=h>>>(l>>>0);h=k>>>5&8;p=k>>>(h>>>0);k=p>>>2&4;r=p>>>(k>>>0);p=r>>>1&2;d=r>>>(p>>>0);r=d>>>1&1;g=c[44824+((h|l|k|p|r)+(d>>>(r>>>0))<<2)>>2]|0;r=g;d=g;p=(c[g+4>>2]&-8)-b|0;while(1){g=c[r+16>>2]|0;if((g|0)==0){k=c[r+20>>2]|0;if((k|0)==0){break}else{u=k}}else{u=g}g=(c[u+4>>2]&-8)-b|0;k=g>>>0<p>>>0;r=u;d=k?u:d;p=k?g:p}r=d;i=c[11134]|0;if(r>>>0<i>>>0){bM();return 0}e=r+b|0;m=e;if(r>>>0>=e>>>0){bM();return 0}e=c[d+24>>2]|0;f=c[d+12>>2]|0;do{if((f|0)==(d|0)){q=d+20|0;g=c[q>>2]|0;if((g|0)==0){k=d+16|0;l=c[k>>2]|0;if((l|0)==0){v=0;break}else{w=l;x=k}}else{w=g;x=q}while(1){q=w+20|0;g=c[q>>2]|0;if((g|0)!=0){w=g;x=q;continue}q=w+16|0;g=c[q>>2]|0;if((g|0)==0){break}else{w=g;x=q}}if(x>>>0<i>>>0){bM();return 0}else{c[x>>2]=0;v=w;break}}else{q=c[d+8>>2]|0;if(q>>>0<i>>>0){bM();return 0}g=q+12|0;if((c[g>>2]|0)!=(d|0)){bM();return 0}k=f+8|0;if((c[k>>2]|0)==(d|0)){c[g>>2]=f;c[k>>2]=q;v=f;break}else{bM();return 0}}}while(0);L7087:do{if((e|0)!=0){f=d+28|0;i=44824+(c[f>>2]<<2)|0;do{if((d|0)==(c[i>>2]|0)){c[i>>2]=v;if((v|0)!=0){break}c[11131]=c[11131]&~(1<<c[f>>2]);break L7087}else{if(e>>>0<(c[11134]|0)>>>0){bM();return 0}q=e+16|0;if((c[q>>2]|0)==(d|0)){c[q>>2]=v}else{c[e+20>>2]=v}if((v|0)==0){break L7087}}}while(0);if(v>>>0<(c[11134]|0)>>>0){bM();return 0}c[v+24>>2]=e;f=c[d+16>>2]|0;do{if((f|0)!=0){if(f>>>0<(c[11134]|0)>>>0){bM();return 0}else{c[v+16>>2]=f;c[f+24>>2]=v;break}}}while(0);f=c[d+20>>2]|0;if((f|0)==0){break}if(f>>>0<(c[11134]|0)>>>0){bM();return 0}else{c[v+20>>2]=f;c[f+24>>2]=v;break}}}while(0);if(p>>>0<16){e=p+b|0;c[d+4>>2]=e|3;f=r+(e+4)|0;c[f>>2]=c[f>>2]|1}else{c[d+4>>2]=b|3;c[r+(b|4)>>2]=p|1;c[r+(p+b)>>2]=p;f=c[11132]|0;if((f|0)!=0){e=c[11135]|0;i=f>>>3;f=i<<1;q=44560+(f<<2)|0;k=c[11130]|0;g=1<<i;do{if((k&g|0)==0){c[11130]=k|g;y=q;z=44560+(f+2<<2)|0}else{i=44560+(f+2<<2)|0;l=c[i>>2]|0;if(l>>>0>=(c[11134]|0)>>>0){y=l;z=i;break}bM();return 0}}while(0);c[z>>2]=e;c[y+12>>2]=e;c[e+8>>2]=y;c[e+12>>2]=q}c[11132]=p;c[11135]=m}f=d+8|0;if((f|0)==0){o=b;break}else{n=f}return n|0}else{if(a>>>0>4294967231){o=-1;break}f=a+11|0;g=f&-8;k=c[11131]|0;if((k|0)==0){o=g;break}r=-g|0;i=f>>>8;do{if((i|0)==0){A=0}else{if(g>>>0>16777215){A=31;break}f=(i+1048320|0)>>>16&8;l=i<<f;h=(l+520192|0)>>>16&4;j=l<<h;l=(j+245760|0)>>>16&2;B=14-(h|f|l)+(j<<l>>>15)|0;A=g>>>((B+7|0)>>>0)&1|B<<1}}while(0);i=c[44824+(A<<2)>>2]|0;L6895:do{if((i|0)==0){C=0;D=r;E=0}else{if((A|0)==31){F=0}else{F=25-(A>>>1)|0}d=0;m=r;p=i;q=g<<F;e=0;while(1){B=c[p+4>>2]&-8;l=B-g|0;if(l>>>0<m>>>0){if((B|0)==(g|0)){C=p;D=l;E=p;break L6895}else{G=p;H=l}}else{G=d;H=m}l=c[p+20>>2]|0;B=c[p+16+(q>>>31<<2)>>2]|0;j=(l|0)==0|(l|0)==(B|0)?e:l;if((B|0)==0){C=G;D=H;E=j;break}else{d=G;m=H;p=B;q=q<<1;e=j}}}}while(0);if((E|0)==0&(C|0)==0){i=2<<A;r=k&(i|-i);if((r|0)==0){o=g;break}i=(r&-r)-1|0;r=i>>>12&16;e=i>>>(r>>>0);i=e>>>5&8;q=e>>>(i>>>0);e=q>>>2&4;p=q>>>(e>>>0);q=p>>>1&2;m=p>>>(q>>>0);p=m>>>1&1;I=c[44824+((i|r|e|q|p)+(m>>>(p>>>0))<<2)>>2]|0}else{I=E}if((I|0)==0){J=D;K=C}else{p=I;m=D;q=C;while(1){e=(c[p+4>>2]&-8)-g|0;r=e>>>0<m>>>0;i=r?e:m;e=r?p:q;r=c[p+16>>2]|0;if((r|0)!=0){p=r;m=i;q=e;continue}r=c[p+20>>2]|0;if((r|0)==0){J=i;K=e;break}else{p=r;m=i;q=e}}}if((K|0)==0){o=g;break}if(J>>>0>=((c[11132]|0)-g|0)>>>0){o=g;break}q=K;m=c[11134]|0;if(q>>>0<m>>>0){bM();return 0}p=q+g|0;k=p;if(q>>>0>=p>>>0){bM();return 0}e=c[K+24>>2]|0;i=c[K+12>>2]|0;do{if((i|0)==(K|0)){r=K+20|0;d=c[r>>2]|0;if((d|0)==0){j=K+16|0;B=c[j>>2]|0;if((B|0)==0){L=0;break}else{M=B;N=j}}else{M=d;N=r}while(1){r=M+20|0;d=c[r>>2]|0;if((d|0)!=0){M=d;N=r;continue}r=M+16|0;d=c[r>>2]|0;if((d|0)==0){break}else{M=d;N=r}}if(N>>>0<m>>>0){bM();return 0}else{c[N>>2]=0;L=M;break}}else{r=c[K+8>>2]|0;if(r>>>0<m>>>0){bM();return 0}d=r+12|0;if((c[d>>2]|0)!=(K|0)){bM();return 0}j=i+8|0;if((c[j>>2]|0)==(K|0)){c[d>>2]=i;c[j>>2]=r;L=i;break}else{bM();return 0}}}while(0);L6945:do{if((e|0)!=0){i=K+28|0;m=44824+(c[i>>2]<<2)|0;do{if((K|0)==(c[m>>2]|0)){c[m>>2]=L;if((L|0)!=0){break}c[11131]=c[11131]&~(1<<c[i>>2]);break L6945}else{if(e>>>0<(c[11134]|0)>>>0){bM();return 0}r=e+16|0;if((c[r>>2]|0)==(K|0)){c[r>>2]=L}else{c[e+20>>2]=L}if((L|0)==0){break L6945}}}while(0);if(L>>>0<(c[11134]|0)>>>0){bM();return 0}c[L+24>>2]=e;i=c[K+16>>2]|0;do{if((i|0)!=0){if(i>>>0<(c[11134]|0)>>>0){bM();return 0}else{c[L+16>>2]=i;c[i+24>>2]=L;break}}}while(0);i=c[K+20>>2]|0;if((i|0)==0){break}if(i>>>0<(c[11134]|0)>>>0){bM();return 0}else{c[L+20>>2]=i;c[i+24>>2]=L;break}}}while(0);do{if(J>>>0<16){e=J+g|0;c[K+4>>2]=e|3;i=q+(e+4)|0;c[i>>2]=c[i>>2]|1}else{c[K+4>>2]=g|3;c[q+(g|4)>>2]=J|1;c[q+(J+g)>>2]=J;i=J>>>3;if(J>>>0<256){e=i<<1;m=44560+(e<<2)|0;r=c[11130]|0;j=1<<i;do{if((r&j|0)==0){c[11130]=r|j;O=m;P=44560+(e+2<<2)|0}else{i=44560+(e+2<<2)|0;d=c[i>>2]|0;if(d>>>0>=(c[11134]|0)>>>0){O=d;P=i;break}bM();return 0}}while(0);c[P>>2]=k;c[O+12>>2]=k;c[q+(g+8)>>2]=O;c[q+(g+12)>>2]=m;break}e=p;j=J>>>8;do{if((j|0)==0){Q=0}else{if(J>>>0>16777215){Q=31;break}r=(j+1048320|0)>>>16&8;i=j<<r;d=(i+520192|0)>>>16&4;B=i<<d;i=(B+245760|0)>>>16&2;l=14-(d|r|i)+(B<<i>>>15)|0;Q=J>>>((l+7|0)>>>0)&1|l<<1}}while(0);j=44824+(Q<<2)|0;c[q+(g+28)>>2]=Q;c[q+(g+20)>>2]=0;c[q+(g+16)>>2]=0;m=c[11131]|0;l=1<<Q;if((m&l|0)==0){c[11131]=m|l;c[j>>2]=e;c[q+(g+24)>>2]=j;c[q+(g+12)>>2]=e;c[q+(g+8)>>2]=e;break}if((Q|0)==31){R=0}else{R=25-(Q>>>1)|0}l=J<<R;m=c[j>>2]|0;while(1){if((c[m+4>>2]&-8|0)==(J|0)){break}S=m+16+(l>>>31<<2)|0;j=c[S>>2]|0;if((j|0)==0){T=5213;break}else{l=l<<1;m=j}}if((T|0)==5213){if(S>>>0<(c[11134]|0)>>>0){bM();return 0}else{c[S>>2]=e;c[q+(g+24)>>2]=m;c[q+(g+12)>>2]=e;c[q+(g+8)>>2]=e;break}}l=m+8|0;j=c[l>>2]|0;i=c[11134]|0;if(m>>>0<i>>>0){bM();return 0}if(j>>>0<i>>>0){bM();return 0}else{c[j+12>>2]=e;c[l>>2]=e;c[q+(g+8)>>2]=j;c[q+(g+12)>>2]=m;c[q+(g+24)>>2]=0;break}}}while(0);q=K+8|0;if((q|0)==0){o=g;break}else{n=q}return n|0}}while(0);K=c[11132]|0;if(o>>>0<=K>>>0){S=K-o|0;J=c[11135]|0;if(S>>>0>15){R=J;c[11135]=R+o;c[11132]=S;c[R+(o+4)>>2]=S|1;c[R+K>>2]=S;c[J+4>>2]=o|3}else{c[11132]=0;c[11135]=0;c[J+4>>2]=K|3;S=J+(K+4)|0;c[S>>2]=c[S>>2]|1}n=J+8|0;return n|0}J=c[11133]|0;if(o>>>0<J>>>0){S=J-o|0;c[11133]=S;J=c[11136]|0;K=J;c[11136]=K+o;c[K+(o+4)>>2]=S|1;c[J+4>>2]=o|3;n=J+8|0;return n|0}do{if((c[11078]|0)==0){J=bJ(8)|0;if((J-1&J|0)==0){c[11080]=J;c[11079]=J;c[11081]=-1;c[11082]=2097152;c[11083]=0;c[11241]=0;c[11078]=(b0(0)|0)&-16^1431655768;break}else{bM();return 0}}}while(0);J=o+48|0;S=c[11080]|0;K=o+47|0;R=S+K|0;Q=-S|0;S=R&Q;if(S>>>0<=o>>>0){n=0;return n|0}O=c[11240]|0;do{if((O|0)!=0){P=c[11238]|0;L=P+S|0;if(L>>>0<=P>>>0|L>>>0>O>>>0){n=0}else{break}return n|0}}while(0);L7154:do{if((c[11241]&4|0)==0){O=c[11136]|0;L7156:do{if((O|0)==0){T=5243}else{L=O;P=44968;while(1){U=P|0;M=c[U>>2]|0;if(M>>>0<=L>>>0){V=P+4|0;if((M+(c[V>>2]|0)|0)>>>0>L>>>0){break}}M=c[P+8>>2]|0;if((M|0)==0){T=5243;break L7156}else{P=M}}if((P|0)==0){T=5243;break}L=R-(c[11133]|0)&Q;if(L>>>0>=2147483647){W=0;break}m=bA(L|0)|0;e=(m|0)==((c[U>>2]|0)+(c[V>>2]|0)|0);X=e?m:-1;Y=e?L:0;Z=m;_=L;T=5252}}while(0);do{if((T|0)==5243){O=bA(0)|0;if((O|0)==-1){W=0;break}g=O;L=c[11079]|0;m=L-1|0;if((m&g|0)==0){$=S}else{$=S-g+(m+g&-L)|0}L=c[11238]|0;g=L+$|0;if(!($>>>0>o>>>0&$>>>0<2147483647)){W=0;break}m=c[11240]|0;if((m|0)!=0){if(g>>>0<=L>>>0|g>>>0>m>>>0){W=0;break}}m=bA($|0)|0;g=(m|0)==(O|0);X=g?O:-1;Y=g?$:0;Z=m;_=$;T=5252}}while(0);L7176:do{if((T|0)==5252){m=-_|0;if((X|0)!=-1){aa=Y;ab=X;T=5263;break L7154}do{if((Z|0)!=-1&_>>>0<2147483647&_>>>0<J>>>0){g=c[11080]|0;O=K-_+g&-g;if(O>>>0>=2147483647){ac=_;break}if((bA(O|0)|0)==-1){bA(m|0)|0;W=Y;break L7176}else{ac=O+_|0;break}}else{ac=_}}while(0);if((Z|0)==-1){W=Y}else{aa=ac;ab=Z;T=5263;break L7154}}}while(0);c[11241]=c[11241]|4;ad=W;T=5260}else{ad=0;T=5260}}while(0);do{if((T|0)==5260){if(S>>>0>=2147483647){break}W=bA(S|0)|0;Z=bA(0)|0;if(!((Z|0)!=-1&(W|0)!=-1&W>>>0<Z>>>0)){break}ac=Z-W|0;Z=ac>>>0>(o+40|0)>>>0;Y=Z?W:-1;if((Y|0)!=-1){aa=Z?ac:ad;ab=Y;T=5263}}}while(0);do{if((T|0)==5263){ad=(c[11238]|0)+aa|0;c[11238]=ad;if(ad>>>0>(c[11239]|0)>>>0){c[11239]=ad}ad=c[11136]|0;L7196:do{if((ad|0)==0){S=c[11134]|0;if((S|0)==0|ab>>>0<S>>>0){c[11134]=ab}c[11242]=ab;c[11243]=aa;c[11245]=0;c[11139]=c[11078];c[11138]=-1;S=0;do{Y=S<<1;ac=44560+(Y<<2)|0;c[44560+(Y+3<<2)>>2]=ac;c[44560+(Y+2<<2)>>2]=ac;S=S+1|0;}while(S>>>0<32);S=ab+8|0;if((S&7|0)==0){ae=0}else{ae=-S&7}S=aa-40-ae|0;c[11136]=ab+ae;c[11133]=S;c[ab+(ae+4)>>2]=S|1;c[ab+(aa-36)>>2]=40;c[11137]=c[11082]}else{S=44968;while(1){af=c[S>>2]|0;ag=S+4|0;ah=c[ag>>2]|0;if((ab|0)==(af+ah|0)){T=5275;break}ac=c[S+8>>2]|0;if((ac|0)==0){break}else{S=ac}}do{if((T|0)==5275){if((c[S+12>>2]&8|0)!=0){break}ac=ad;if(!(ac>>>0>=af>>>0&ac>>>0<ab>>>0)){break}c[ag>>2]=ah+aa;ac=c[11136]|0;Y=(c[11133]|0)+aa|0;Z=ac;W=ac+8|0;if((W&7|0)==0){ai=0}else{ai=-W&7}W=Y-ai|0;c[11136]=Z+ai;c[11133]=W;c[Z+(ai+4)>>2]=W|1;c[Z+(Y+4)>>2]=40;c[11137]=c[11082];break L7196}}while(0);if(ab>>>0<(c[11134]|0)>>>0){c[11134]=ab}S=ab+aa|0;Y=44968;while(1){aj=Y|0;if((c[aj>>2]|0)==(S|0)){T=5285;break}Z=c[Y+8>>2]|0;if((Z|0)==0){break}else{Y=Z}}do{if((T|0)==5285){if((c[Y+12>>2]&8|0)!=0){break}c[aj>>2]=ab;S=Y+4|0;c[S>>2]=(c[S>>2]|0)+aa;S=ab+8|0;if((S&7|0)==0){ak=0}else{ak=-S&7}S=ab+(aa+8)|0;if((S&7|0)==0){al=0}else{al=-S&7}S=ab+(al+aa)|0;Z=S;W=ak+o|0;ac=ab+W|0;_=ac;K=S-(ab+ak)-o|0;c[ab+(ak+4)>>2]=o|3;do{if((Z|0)==(c[11136]|0)){J=(c[11133]|0)+K|0;c[11133]=J;c[11136]=_;c[ab+(W+4)>>2]=J|1}else{if((Z|0)==(c[11135]|0)){J=(c[11132]|0)+K|0;c[11132]=J;c[11135]=_;c[ab+(W+4)>>2]=J|1;c[ab+(J+W)>>2]=J;break}J=aa+4|0;X=c[ab+(J+al)>>2]|0;if((X&3|0)==1){$=X&-8;V=X>>>3;L7231:do{if(X>>>0<256){U=c[ab+((al|8)+aa)>>2]|0;Q=c[ab+(aa+12+al)>>2]|0;R=44560+(V<<1<<2)|0;do{if((U|0)!=(R|0)){if(U>>>0<(c[11134]|0)>>>0){bM();return 0}if((c[U+12>>2]|0)==(Z|0)){break}bM();return 0}}while(0);if((Q|0)==(U|0)){c[11130]=c[11130]&~(1<<V);break}do{if((Q|0)==(R|0)){am=Q+8|0}else{if(Q>>>0<(c[11134]|0)>>>0){bM();return 0}m=Q+8|0;if((c[m>>2]|0)==(Z|0)){am=m;break}bM();return 0}}while(0);c[U+12>>2]=Q;c[am>>2]=U}else{R=S;m=c[ab+((al|24)+aa)>>2]|0;P=c[ab+(aa+12+al)>>2]|0;do{if((P|0)==(R|0)){O=al|16;g=ab+(J+O)|0;L=c[g>>2]|0;if((L|0)==0){e=ab+(O+aa)|0;O=c[e>>2]|0;if((O|0)==0){an=0;break}else{ao=O;ap=e}}else{ao=L;ap=g}while(1){g=ao+20|0;L=c[g>>2]|0;if((L|0)!=0){ao=L;ap=g;continue}g=ao+16|0;L=c[g>>2]|0;if((L|0)==0){break}else{ao=L;ap=g}}if(ap>>>0<(c[11134]|0)>>>0){bM();return 0}else{c[ap>>2]=0;an=ao;break}}else{g=c[ab+((al|8)+aa)>>2]|0;if(g>>>0<(c[11134]|0)>>>0){bM();return 0}L=g+12|0;if((c[L>>2]|0)!=(R|0)){bM();return 0}e=P+8|0;if((c[e>>2]|0)==(R|0)){c[L>>2]=P;c[e>>2]=g;an=P;break}else{bM();return 0}}}while(0);if((m|0)==0){break}P=ab+(aa+28+al)|0;U=44824+(c[P>>2]<<2)|0;do{if((R|0)==(c[U>>2]|0)){c[U>>2]=an;if((an|0)!=0){break}c[11131]=c[11131]&~(1<<c[P>>2]);break L7231}else{if(m>>>0<(c[11134]|0)>>>0){bM();return 0}Q=m+16|0;if((c[Q>>2]|0)==(R|0)){c[Q>>2]=an}else{c[m+20>>2]=an}if((an|0)==0){break L7231}}}while(0);if(an>>>0<(c[11134]|0)>>>0){bM();return 0}c[an+24>>2]=m;R=al|16;P=c[ab+(R+aa)>>2]|0;do{if((P|0)!=0){if(P>>>0<(c[11134]|0)>>>0){bM();return 0}else{c[an+16>>2]=P;c[P+24>>2]=an;break}}}while(0);P=c[ab+(J+R)>>2]|0;if((P|0)==0){break}if(P>>>0<(c[11134]|0)>>>0){bM();return 0}else{c[an+20>>2]=P;c[P+24>>2]=an;break}}}while(0);aq=ab+(($|al)+aa)|0;ar=$+K|0}else{aq=Z;ar=K}J=aq+4|0;c[J>>2]=c[J>>2]&-2;c[ab+(W+4)>>2]=ar|1;c[ab+(ar+W)>>2]=ar;J=ar>>>3;if(ar>>>0<256){V=J<<1;X=44560+(V<<2)|0;P=c[11130]|0;m=1<<J;do{if((P&m|0)==0){c[11130]=P|m;as=X;at=44560+(V+2<<2)|0}else{J=44560+(V+2<<2)|0;U=c[J>>2]|0;if(U>>>0>=(c[11134]|0)>>>0){as=U;at=J;break}bM();return 0}}while(0);c[at>>2]=_;c[as+12>>2]=_;c[ab+(W+8)>>2]=as;c[ab+(W+12)>>2]=X;break}V=ac;m=ar>>>8;do{if((m|0)==0){au=0}else{if(ar>>>0>16777215){au=31;break}P=(m+1048320|0)>>>16&8;$=m<<P;J=($+520192|0)>>>16&4;U=$<<J;$=(U+245760|0)>>>16&2;Q=14-(J|P|$)+(U<<$>>>15)|0;au=ar>>>((Q+7|0)>>>0)&1|Q<<1}}while(0);m=44824+(au<<2)|0;c[ab+(W+28)>>2]=au;c[ab+(W+20)>>2]=0;c[ab+(W+16)>>2]=0;X=c[11131]|0;Q=1<<au;if((X&Q|0)==0){c[11131]=X|Q;c[m>>2]=V;c[ab+(W+24)>>2]=m;c[ab+(W+12)>>2]=V;c[ab+(W+8)>>2]=V;break}if((au|0)==31){av=0}else{av=25-(au>>>1)|0}Q=ar<<av;X=c[m>>2]|0;while(1){if((c[X+4>>2]&-8|0)==(ar|0)){break}aw=X+16+(Q>>>31<<2)|0;m=c[aw>>2]|0;if((m|0)==0){T=5358;break}else{Q=Q<<1;X=m}}if((T|0)==5358){if(aw>>>0<(c[11134]|0)>>>0){bM();return 0}else{c[aw>>2]=V;c[ab+(W+24)>>2]=X;c[ab+(W+12)>>2]=V;c[ab+(W+8)>>2]=V;break}}Q=X+8|0;m=c[Q>>2]|0;$=c[11134]|0;if(X>>>0<$>>>0){bM();return 0}if(m>>>0<$>>>0){bM();return 0}else{c[m+12>>2]=V;c[Q>>2]=V;c[ab+(W+8)>>2]=m;c[ab+(W+12)>>2]=X;c[ab+(W+24)>>2]=0;break}}}while(0);n=ab+(ak|8)|0;return n|0}}while(0);Y=ad;W=44968;while(1){ax=c[W>>2]|0;if(ax>>>0<=Y>>>0){ay=c[W+4>>2]|0;az=ax+ay|0;if(az>>>0>Y>>>0){break}}W=c[W+8>>2]|0}W=ax+(ay-39)|0;if((W&7|0)==0){aA=0}else{aA=-W&7}W=ax+(ay-47+aA)|0;ac=W>>>0<(ad+16|0)>>>0?Y:W;W=ac+8|0;_=ab+8|0;if((_&7|0)==0){aB=0}else{aB=-_&7}_=aa-40-aB|0;c[11136]=ab+aB;c[11133]=_;c[ab+(aB+4)>>2]=_|1;c[ab+(aa-36)>>2]=40;c[11137]=c[11082];c[ac+4>>2]=27;c[W>>2]=c[11242];c[W+4>>2]=c[44972>>2];c[W+8>>2]=c[44976>>2];c[W+12>>2]=c[44980>>2];c[11242]=ab;c[11243]=aa;c[11245]=0;c[11244]=W;W=ac+28|0;c[W>>2]=7;if((ac+32|0)>>>0<az>>>0){_=W;while(1){W=_+4|0;c[W>>2]=7;if((_+8|0)>>>0<az>>>0){_=W}else{break}}}if((ac|0)==(Y|0)){break}_=ac-ad|0;W=Y+(_+4)|0;c[W>>2]=c[W>>2]&-2;c[ad+4>>2]=_|1;c[Y+_>>2]=_;W=_>>>3;if(_>>>0<256){K=W<<1;Z=44560+(K<<2)|0;S=c[11130]|0;m=1<<W;do{if((S&m|0)==0){c[11130]=S|m;aC=Z;aD=44560+(K+2<<2)|0}else{W=44560+(K+2<<2)|0;Q=c[W>>2]|0;if(Q>>>0>=(c[11134]|0)>>>0){aC=Q;aD=W;break}bM();return 0}}while(0);c[aD>>2]=ad;c[aC+12>>2]=ad;c[ad+8>>2]=aC;c[ad+12>>2]=Z;break}K=ad;m=_>>>8;do{if((m|0)==0){aE=0}else{if(_>>>0>16777215){aE=31;break}S=(m+1048320|0)>>>16&8;Y=m<<S;ac=(Y+520192|0)>>>16&4;W=Y<<ac;Y=(W+245760|0)>>>16&2;Q=14-(ac|S|Y)+(W<<Y>>>15)|0;aE=_>>>((Q+7|0)>>>0)&1|Q<<1}}while(0);m=44824+(aE<<2)|0;c[ad+28>>2]=aE;c[ad+20>>2]=0;c[ad+16>>2]=0;Z=c[11131]|0;Q=1<<aE;if((Z&Q|0)==0){c[11131]=Z|Q;c[m>>2]=K;c[ad+24>>2]=m;c[ad+12>>2]=ad;c[ad+8>>2]=ad;break}if((aE|0)==31){aF=0}else{aF=25-(aE>>>1)|0}Q=_<<aF;Z=c[m>>2]|0;while(1){if((c[Z+4>>2]&-8|0)==(_|0)){break}aG=Z+16+(Q>>>31<<2)|0;m=c[aG>>2]|0;if((m|0)==0){T=5393;break}else{Q=Q<<1;Z=m}}if((T|0)==5393){if(aG>>>0<(c[11134]|0)>>>0){bM();return 0}else{c[aG>>2]=K;c[ad+24>>2]=Z;c[ad+12>>2]=ad;c[ad+8>>2]=ad;break}}Q=Z+8|0;_=c[Q>>2]|0;m=c[11134]|0;if(Z>>>0<m>>>0){bM();return 0}if(_>>>0<m>>>0){bM();return 0}else{c[_+12>>2]=K;c[Q>>2]=K;c[ad+8>>2]=_;c[ad+12>>2]=Z;c[ad+24>>2]=0;break}}}while(0);ad=c[11133]|0;if(ad>>>0<=o>>>0){break}_=ad-o|0;c[11133]=_;ad=c[11136]|0;Q=ad;c[11136]=Q+o;c[Q+(o+4)>>2]=_|1;c[ad+4>>2]=o|3;n=ad+8|0;return n|0}}while(0);c[(bB()|0)>>2]=12;n=0;return n|0}function zI(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;if((a|0)==0){return}b=a-8|0;d=b;e=c[11134]|0;if(b>>>0<e>>>0){bM()}f=c[a-4>>2]|0;g=f&3;if((g|0)==1){bM()}h=f&-8;i=a+(h-8)|0;j=i;L10:do{if((f&1|0)==0){k=c[b>>2]|0;if((g|0)==0){return}l=-8-k|0;m=a+l|0;n=m;o=k+h|0;if(m>>>0<e>>>0){bM()}if((n|0)==(c[11135]|0)){p=a+(h-4)|0;if((c[p>>2]&3|0)!=3){q=n;r=o;break}c[11132]=o;c[p>>2]=c[p>>2]&-2;c[a+(l+4)>>2]=o|1;c[i>>2]=o;return}p=k>>>3;if(k>>>0<256){k=c[a+(l+8)>>2]|0;s=c[a+(l+12)>>2]|0;t=44560+(p<<1<<2)|0;do{if((k|0)!=(t|0)){if(k>>>0<e>>>0){bM()}if((c[k+12>>2]|0)==(n|0)){break}bM()}}while(0);if((s|0)==(k|0)){c[11130]=c[11130]&~(1<<p);q=n;r=o;break}do{if((s|0)==(t|0)){u=s+8|0}else{if(s>>>0<e>>>0){bM()}v=s+8|0;if((c[v>>2]|0)==(n|0)){u=v;break}bM()}}while(0);c[k+12>>2]=s;c[u>>2]=k;q=n;r=o;break}t=m;p=c[a+(l+24)>>2]|0;v=c[a+(l+12)>>2]|0;do{if((v|0)==(t|0)){w=a+(l+20)|0;x=c[w>>2]|0;if((x|0)==0){y=a+(l+16)|0;z=c[y>>2]|0;if((z|0)==0){A=0;break}else{B=z;C=y}}else{B=x;C=w}while(1){w=B+20|0;x=c[w>>2]|0;if((x|0)!=0){B=x;C=w;continue}w=B+16|0;x=c[w>>2]|0;if((x|0)==0){break}else{B=x;C=w}}if(C>>>0<e>>>0){bM()}else{c[C>>2]=0;A=B;break}}else{w=c[a+(l+8)>>2]|0;if(w>>>0<e>>>0){bM()}x=w+12|0;if((c[x>>2]|0)!=(t|0)){bM()}y=v+8|0;if((c[y>>2]|0)==(t|0)){c[x>>2]=v;c[y>>2]=w;A=v;break}else{bM()}}}while(0);if((p|0)==0){q=n;r=o;break}v=a+(l+28)|0;m=44824+(c[v>>2]<<2)|0;do{if((t|0)==(c[m>>2]|0)){c[m>>2]=A;if((A|0)!=0){break}c[11131]=c[11131]&~(1<<c[v>>2]);q=n;r=o;break L10}else{if(p>>>0<(c[11134]|0)>>>0){bM()}k=p+16|0;if((c[k>>2]|0)==(t|0)){c[k>>2]=A}else{c[p+20>>2]=A}if((A|0)==0){q=n;r=o;break L10}}}while(0);if(A>>>0<(c[11134]|0)>>>0){bM()}c[A+24>>2]=p;t=c[a+(l+16)>>2]|0;do{if((t|0)!=0){if(t>>>0<(c[11134]|0)>>>0){bM()}else{c[A+16>>2]=t;c[t+24>>2]=A;break}}}while(0);t=c[a+(l+20)>>2]|0;if((t|0)==0){q=n;r=o;break}if(t>>>0<(c[11134]|0)>>>0){bM()}else{c[A+20>>2]=t;c[t+24>>2]=A;q=n;r=o;break}}else{q=d;r=h}}while(0);d=q;if(d>>>0>=i>>>0){bM()}A=a+(h-4)|0;e=c[A>>2]|0;if((e&1|0)==0){bM()}do{if((e&2|0)==0){if((j|0)==(c[11136]|0)){B=(c[11133]|0)+r|0;c[11133]=B;c[11136]=q;c[q+4>>2]=B|1;if((q|0)==(c[11135]|0)){c[11135]=0;c[11132]=0}if(B>>>0<=(c[11137]|0)>>>0){return}zK(0)|0;return}if((j|0)==(c[11135]|0)){B=(c[11132]|0)+r|0;c[11132]=B;c[11135]=q;c[q+4>>2]=B|1;c[d+B>>2]=B;return}B=(e&-8)+r|0;C=e>>>3;L115:do{if(e>>>0<256){u=c[a+h>>2]|0;g=c[a+(h|4)>>2]|0;b=44560+(C<<1<<2)|0;do{if((u|0)!=(b|0)){if(u>>>0<(c[11134]|0)>>>0){bM()}if((c[u+12>>2]|0)==(j|0)){break}bM()}}while(0);if((g|0)==(u|0)){c[11130]=c[11130]&~(1<<C);break}do{if((g|0)==(b|0)){D=g+8|0}else{if(g>>>0<(c[11134]|0)>>>0){bM()}f=g+8|0;if((c[f>>2]|0)==(j|0)){D=f;break}bM()}}while(0);c[u+12>>2]=g;c[D>>2]=u}else{b=i;f=c[a+(h+16)>>2]|0;t=c[a+(h|4)>>2]|0;do{if((t|0)==(b|0)){p=a+(h+12)|0;v=c[p>>2]|0;if((v|0)==0){m=a+(h+8)|0;k=c[m>>2]|0;if((k|0)==0){E=0;break}else{F=k;G=m}}else{F=v;G=p}while(1){p=F+20|0;v=c[p>>2]|0;if((v|0)!=0){F=v;G=p;continue}p=F+16|0;v=c[p>>2]|0;if((v|0)==0){break}else{F=v;G=p}}if(G>>>0<(c[11134]|0)>>>0){bM()}else{c[G>>2]=0;E=F;break}}else{p=c[a+h>>2]|0;if(p>>>0<(c[11134]|0)>>>0){bM()}v=p+12|0;if((c[v>>2]|0)!=(b|0)){bM()}m=t+8|0;if((c[m>>2]|0)==(b|0)){c[v>>2]=t;c[m>>2]=p;E=t;break}else{bM()}}}while(0);if((f|0)==0){break}t=a+(h+20)|0;u=44824+(c[t>>2]<<2)|0;do{if((b|0)==(c[u>>2]|0)){c[u>>2]=E;if((E|0)!=0){break}c[11131]=c[11131]&~(1<<c[t>>2]);break L115}else{if(f>>>0<(c[11134]|0)>>>0){bM()}g=f+16|0;if((c[g>>2]|0)==(b|0)){c[g>>2]=E}else{c[f+20>>2]=E}if((E|0)==0){break L115}}}while(0);if(E>>>0<(c[11134]|0)>>>0){bM()}c[E+24>>2]=f;b=c[a+(h+8)>>2]|0;do{if((b|0)!=0){if(b>>>0<(c[11134]|0)>>>0){bM()}else{c[E+16>>2]=b;c[b+24>>2]=E;break}}}while(0);b=c[a+(h+12)>>2]|0;if((b|0)==0){break}if(b>>>0<(c[11134]|0)>>>0){bM()}else{c[E+20>>2]=b;c[b+24>>2]=E;break}}}while(0);c[q+4>>2]=B|1;c[d+B>>2]=B;if((q|0)!=(c[11135]|0)){H=B;break}c[11132]=B;return}else{c[A>>2]=e&-2;c[q+4>>2]=r|1;c[d+r>>2]=r;H=r}}while(0);r=H>>>3;if(H>>>0<256){d=r<<1;e=44560+(d<<2)|0;A=c[11130]|0;E=1<<r;do{if((A&E|0)==0){c[11130]=A|E;I=e;J=44560+(d+2<<2)|0}else{r=44560+(d+2<<2)|0;h=c[r>>2]|0;if(h>>>0>=(c[11134]|0)>>>0){I=h;J=r;break}bM()}}while(0);c[J>>2]=q;c[I+12>>2]=q;c[q+8>>2]=I;c[q+12>>2]=e;return}e=q;I=H>>>8;do{if((I|0)==0){K=0}else{if(H>>>0>16777215){K=31;break}J=(I+1048320|0)>>>16&8;d=I<<J;E=(d+520192|0)>>>16&4;A=d<<E;d=(A+245760|0)>>>16&2;r=14-(E|J|d)+(A<<d>>>15)|0;K=H>>>((r+7|0)>>>0)&1|r<<1}}while(0);I=44824+(K<<2)|0;c[q+28>>2]=K;c[q+20>>2]=0;c[q+16>>2]=0;r=c[11131]|0;d=1<<K;do{if((r&d|0)==0){c[11131]=r|d;c[I>>2]=e;c[q+24>>2]=I;c[q+12>>2]=q;c[q+8>>2]=q}else{if((K|0)==31){L=0}else{L=25-(K>>>1)|0}A=H<<L;J=c[I>>2]|0;while(1){if((c[J+4>>2]&-8|0)==(H|0)){break}M=J+16+(A>>>31<<2)|0;E=c[M>>2]|0;if((E|0)==0){N=131;break}else{A=A<<1;J=E}}if((N|0)==131){if(M>>>0<(c[11134]|0)>>>0){bM()}else{c[M>>2]=e;c[q+24>>2]=J;c[q+12>>2]=q;c[q+8>>2]=q;break}}A=J+8|0;B=c[A>>2]|0;E=c[11134]|0;if(J>>>0<E>>>0){bM()}if(B>>>0<E>>>0){bM()}else{c[B+12>>2]=e;c[A>>2]=e;c[q+8>>2]=B;c[q+12>>2]=J;c[q+24>>2]=0;break}}}while(0);q=(c[11138]|0)-1|0;c[11138]=q;if((q|0)==0){O=44976}else{return}while(1){q=c[O>>2]|0;if((q|0)==0){break}else{O=q+8|0}}c[11138]=-1;return}function zJ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;if((a|0)==0){d=zH(b)|0;return d|0}if(b>>>0>4294967231){c[(bB()|0)>>2]=12;d=0;return d|0}if(b>>>0<11){e=16}else{e=b+11&-8}f=zL(a-8|0,e)|0;if((f|0)!=0){d=f+8|0;return d|0}f=zH(b)|0;if((f|0)==0){d=0;return d|0}e=c[a-4>>2]|0;g=(e&-8)-((e&3|0)==0?8:4)|0;e=g>>>0<b>>>0?g:b;zO(f|0,a|0,e)|0;zI(a);d=f;return d|0}function zK(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;do{if((c[11078]|0)==0){b=bJ(8)|0;if((b-1&b|0)==0){c[11080]=b;c[11079]=b;c[11081]=-1;c[11082]=2097152;c[11083]=0;c[11241]=0;c[11078]=(b0(0)|0)&-16^1431655768;break}else{bM();return 0}}}while(0);if(a>>>0>=4294967232){d=0;return d|0}b=c[11136]|0;if((b|0)==0){d=0;return d|0}e=c[11133]|0;do{if(e>>>0>(a+40|0)>>>0){f=c[11080]|0;g=ac((((-40-a-1+e+f|0)>>>0)/(f>>>0)|0)-1|0,f)|0;h=b;i=44968;while(1){j=c[i>>2]|0;if(j>>>0<=h>>>0){if((j+(c[i+4>>2]|0)|0)>>>0>h>>>0){k=i;break}}j=c[i+8>>2]|0;if((j|0)==0){k=0;break}else{i=j}}if((c[k+12>>2]&8|0)!=0){break}i=bA(0)|0;h=k+4|0;if((i|0)!=((c[k>>2]|0)+(c[h>>2]|0)|0)){break}j=bA(-(g>>>0>2147483646?-2147483648-f|0:g)|0)|0;l=bA(0)|0;if(!((j|0)!=-1&l>>>0<i>>>0)){break}j=i-l|0;if((i|0)==(l|0)){break}c[h>>2]=(c[h>>2]|0)-j;c[11238]=(c[11238]|0)-j;h=c[11136]|0;m=(c[11133]|0)-j|0;j=h;n=h+8|0;if((n&7|0)==0){o=0}else{o=-n&7}n=m-o|0;c[11136]=j+o;c[11133]=n;c[j+(o+4)>>2]=n|1;c[j+(m+4)>>2]=40;c[11137]=c[11082];d=(i|0)!=(l|0)|0;return d|0}}while(0);if((c[11133]|0)>>>0<=(c[11137]|0)>>>0){d=0;return d|0}c[11137]=-1;d=0;return d|0}function zL(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=a+4|0;e=c[d>>2]|0;f=e&-8;g=a;h=g+f|0;i=h;j=c[11134]|0;if(g>>>0<j>>>0){bM();return 0}k=e&3;if(!((k|0)!=1&g>>>0<h>>>0)){bM();return 0}l=g+(f|4)|0;m=c[l>>2]|0;if((m&1|0)==0){bM();return 0}if((k|0)==0){if(b>>>0<256){n=0;return n|0}do{if(f>>>0>=(b+4|0)>>>0){if((f-b|0)>>>0>c[11080]<<1>>>0){break}else{n=a}return n|0}}while(0);n=0;return n|0}if(f>>>0>=b>>>0){k=f-b|0;if(k>>>0<=15){n=a;return n|0}c[d>>2]=e&1|b|2;c[g+(b+4)>>2]=k|3;c[l>>2]=c[l>>2]|1;zM(g+b|0,k);n=a;return n|0}if((i|0)==(c[11136]|0)){k=(c[11133]|0)+f|0;if(k>>>0<=b>>>0){n=0;return n|0}l=k-b|0;c[d>>2]=e&1|b|2;c[g+(b+4)>>2]=l|1;c[11136]=g+b;c[11133]=l;n=a;return n|0}if((i|0)==(c[11135]|0)){l=(c[11132]|0)+f|0;if(l>>>0<b>>>0){n=0;return n|0}k=l-b|0;if(k>>>0>15){c[d>>2]=e&1|b|2;c[g+(b+4)>>2]=k|1;c[g+l>>2]=k;o=g+(l+4)|0;c[o>>2]=c[o>>2]&-2;p=g+b|0;q=k}else{c[d>>2]=e&1|l|2;e=g+(l+4)|0;c[e>>2]=c[e>>2]|1;p=0;q=0}c[11132]=q;c[11135]=p;n=a;return n|0}if((m&2|0)!=0){n=0;return n|0}p=(m&-8)+f|0;if(p>>>0<b>>>0){n=0;return n|0}q=p-b|0;e=m>>>3;L336:do{if(m>>>0<256){l=c[g+(f+8)>>2]|0;k=c[g+(f+12)>>2]|0;o=44560+(e<<1<<2)|0;do{if((l|0)!=(o|0)){if(l>>>0<j>>>0){bM();return 0}if((c[l+12>>2]|0)==(i|0)){break}bM();return 0}}while(0);if((k|0)==(l|0)){c[11130]=c[11130]&~(1<<e);break}do{if((k|0)==(o|0)){r=k+8|0}else{if(k>>>0<j>>>0){bM();return 0}s=k+8|0;if((c[s>>2]|0)==(i|0)){r=s;break}bM();return 0}}while(0);c[l+12>>2]=k;c[r>>2]=l}else{o=h;s=c[g+(f+24)>>2]|0;t=c[g+(f+12)>>2]|0;do{if((t|0)==(o|0)){u=g+(f+20)|0;v=c[u>>2]|0;if((v|0)==0){w=g+(f+16)|0;x=c[w>>2]|0;if((x|0)==0){y=0;break}else{z=x;A=w}}else{z=v;A=u}while(1){u=z+20|0;v=c[u>>2]|0;if((v|0)!=0){z=v;A=u;continue}u=z+16|0;v=c[u>>2]|0;if((v|0)==0){break}else{z=v;A=u}}if(A>>>0<j>>>0){bM();return 0}else{c[A>>2]=0;y=z;break}}else{u=c[g+(f+8)>>2]|0;if(u>>>0<j>>>0){bM();return 0}v=u+12|0;if((c[v>>2]|0)!=(o|0)){bM();return 0}w=t+8|0;if((c[w>>2]|0)==(o|0)){c[v>>2]=t;c[w>>2]=u;y=t;break}else{bM();return 0}}}while(0);if((s|0)==0){break}t=g+(f+28)|0;l=44824+(c[t>>2]<<2)|0;do{if((o|0)==(c[l>>2]|0)){c[l>>2]=y;if((y|0)!=0){break}c[11131]=c[11131]&~(1<<c[t>>2]);break L336}else{if(s>>>0<(c[11134]|0)>>>0){bM();return 0}k=s+16|0;if((c[k>>2]|0)==(o|0)){c[k>>2]=y}else{c[s+20>>2]=y}if((y|0)==0){break L336}}}while(0);if(y>>>0<(c[11134]|0)>>>0){bM();return 0}c[y+24>>2]=s;o=c[g+(f+16)>>2]|0;do{if((o|0)!=0){if(o>>>0<(c[11134]|0)>>>0){bM();return 0}else{c[y+16>>2]=o;c[o+24>>2]=y;break}}}while(0);o=c[g+(f+20)>>2]|0;if((o|0)==0){break}if(o>>>0<(c[11134]|0)>>>0){bM();return 0}else{c[y+20>>2]=o;c[o+24>>2]=y;break}}}while(0);if(q>>>0<16){c[d>>2]=p|c[d>>2]&1|2;y=g+(p|4)|0;c[y>>2]=c[y>>2]|1;n=a;return n|0}else{c[d>>2]=c[d>>2]&1|b|2;c[g+(b+4)>>2]=q|3;d=g+(p|4)|0;c[d>>2]=c[d>>2]|1;zM(g+b|0,q);n=a;return n|0}return 0}function zM(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;d=a;e=d+b|0;f=e;g=c[a+4>>2]|0;L412:do{if((g&1|0)==0){h=c[a>>2]|0;if((g&3|0)==0){return}i=d+(-h|0)|0;j=i;k=h+b|0;l=c[11134]|0;if(i>>>0<l>>>0){bM()}if((j|0)==(c[11135]|0)){m=d+(b+4)|0;if((c[m>>2]&3|0)!=3){n=j;o=k;break}c[11132]=k;c[m>>2]=c[m>>2]&-2;c[d+(4-h)>>2]=k|1;c[e>>2]=k;return}m=h>>>3;if(h>>>0<256){p=c[d+(8-h)>>2]|0;q=c[d+(12-h)>>2]|0;r=44560+(m<<1<<2)|0;do{if((p|0)!=(r|0)){if(p>>>0<l>>>0){bM()}if((c[p+12>>2]|0)==(j|0)){break}bM()}}while(0);if((q|0)==(p|0)){c[11130]=c[11130]&~(1<<m);n=j;o=k;break}do{if((q|0)==(r|0)){s=q+8|0}else{if(q>>>0<l>>>0){bM()}t=q+8|0;if((c[t>>2]|0)==(j|0)){s=t;break}bM()}}while(0);c[p+12>>2]=q;c[s>>2]=p;n=j;o=k;break}r=i;m=c[d+(24-h)>>2]|0;t=c[d+(12-h)>>2]|0;do{if((t|0)==(r|0)){u=16-h|0;v=d+(u+4)|0;w=c[v>>2]|0;if((w|0)==0){x=d+u|0;u=c[x>>2]|0;if((u|0)==0){y=0;break}else{z=u;A=x}}else{z=w;A=v}while(1){v=z+20|0;w=c[v>>2]|0;if((w|0)!=0){z=w;A=v;continue}v=z+16|0;w=c[v>>2]|0;if((w|0)==0){break}else{z=w;A=v}}if(A>>>0<l>>>0){bM()}else{c[A>>2]=0;y=z;break}}else{v=c[d+(8-h)>>2]|0;if(v>>>0<l>>>0){bM()}w=v+12|0;if((c[w>>2]|0)!=(r|0)){bM()}x=t+8|0;if((c[x>>2]|0)==(r|0)){c[w>>2]=t;c[x>>2]=v;y=t;break}else{bM()}}}while(0);if((m|0)==0){n=j;o=k;break}t=d+(28-h)|0;l=44824+(c[t>>2]<<2)|0;do{if((r|0)==(c[l>>2]|0)){c[l>>2]=y;if((y|0)!=0){break}c[11131]=c[11131]&~(1<<c[t>>2]);n=j;o=k;break L412}else{if(m>>>0<(c[11134]|0)>>>0){bM()}i=m+16|0;if((c[i>>2]|0)==(r|0)){c[i>>2]=y}else{c[m+20>>2]=y}if((y|0)==0){n=j;o=k;break L412}}}while(0);if(y>>>0<(c[11134]|0)>>>0){bM()}c[y+24>>2]=m;r=16-h|0;t=c[d+r>>2]|0;do{if((t|0)!=0){if(t>>>0<(c[11134]|0)>>>0){bM()}else{c[y+16>>2]=t;c[t+24>>2]=y;break}}}while(0);t=c[d+(r+4)>>2]|0;if((t|0)==0){n=j;o=k;break}if(t>>>0<(c[11134]|0)>>>0){bM()}else{c[y+20>>2]=t;c[t+24>>2]=y;n=j;o=k;break}}else{n=a;o=b}}while(0);a=c[11134]|0;if(e>>>0<a>>>0){bM()}y=d+(b+4)|0;z=c[y>>2]|0;do{if((z&2|0)==0){if((f|0)==(c[11136]|0)){A=(c[11133]|0)+o|0;c[11133]=A;c[11136]=n;c[n+4>>2]=A|1;if((n|0)!=(c[11135]|0)){return}c[11135]=0;c[11132]=0;return}if((f|0)==(c[11135]|0)){A=(c[11132]|0)+o|0;c[11132]=A;c[11135]=n;c[n+4>>2]=A|1;c[n+A>>2]=A;return}A=(z&-8)+o|0;s=z>>>3;L511:do{if(z>>>0<256){g=c[d+(b+8)>>2]|0;t=c[d+(b+12)>>2]|0;h=44560+(s<<1<<2)|0;do{if((g|0)!=(h|0)){if(g>>>0<a>>>0){bM()}if((c[g+12>>2]|0)==(f|0)){break}bM()}}while(0);if((t|0)==(g|0)){c[11130]=c[11130]&~(1<<s);break}do{if((t|0)==(h|0)){B=t+8|0}else{if(t>>>0<a>>>0){bM()}m=t+8|0;if((c[m>>2]|0)==(f|0)){B=m;break}bM()}}while(0);c[g+12>>2]=t;c[B>>2]=g}else{h=e;m=c[d+(b+24)>>2]|0;l=c[d+(b+12)>>2]|0;do{if((l|0)==(h|0)){i=d+(b+20)|0;p=c[i>>2]|0;if((p|0)==0){q=d+(b+16)|0;v=c[q>>2]|0;if((v|0)==0){C=0;break}else{D=v;E=q}}else{D=p;E=i}while(1){i=D+20|0;p=c[i>>2]|0;if((p|0)!=0){D=p;E=i;continue}i=D+16|0;p=c[i>>2]|0;if((p|0)==0){break}else{D=p;E=i}}if(E>>>0<a>>>0){bM()}else{c[E>>2]=0;C=D;break}}else{i=c[d+(b+8)>>2]|0;if(i>>>0<a>>>0){bM()}p=i+12|0;if((c[p>>2]|0)!=(h|0)){bM()}q=l+8|0;if((c[q>>2]|0)==(h|0)){c[p>>2]=l;c[q>>2]=i;C=l;break}else{bM()}}}while(0);if((m|0)==0){break}l=d+(b+28)|0;g=44824+(c[l>>2]<<2)|0;do{if((h|0)==(c[g>>2]|0)){c[g>>2]=C;if((C|0)!=0){break}c[11131]=c[11131]&~(1<<c[l>>2]);break L511}else{if(m>>>0<(c[11134]|0)>>>0){bM()}t=m+16|0;if((c[t>>2]|0)==(h|0)){c[t>>2]=C}else{c[m+20>>2]=C}if((C|0)==0){break L511}}}while(0);if(C>>>0<(c[11134]|0)>>>0){bM()}c[C+24>>2]=m;h=c[d+(b+16)>>2]|0;do{if((h|0)!=0){if(h>>>0<(c[11134]|0)>>>0){bM()}else{c[C+16>>2]=h;c[h+24>>2]=C;break}}}while(0);h=c[d+(b+20)>>2]|0;if((h|0)==0){break}if(h>>>0<(c[11134]|0)>>>0){bM()}else{c[C+20>>2]=h;c[h+24>>2]=C;break}}}while(0);c[n+4>>2]=A|1;c[n+A>>2]=A;if((n|0)!=(c[11135]|0)){F=A;break}c[11132]=A;return}else{c[y>>2]=z&-2;c[n+4>>2]=o|1;c[n+o>>2]=o;F=o}}while(0);o=F>>>3;if(F>>>0<256){z=o<<1;y=44560+(z<<2)|0;C=c[11130]|0;b=1<<o;do{if((C&b|0)==0){c[11130]=C|b;G=y;H=44560+(z+2<<2)|0}else{o=44560+(z+2<<2)|0;d=c[o>>2]|0;if(d>>>0>=(c[11134]|0)>>>0){G=d;H=o;break}bM()}}while(0);c[H>>2]=n;c[G+12>>2]=n;c[n+8>>2]=G;c[n+12>>2]=y;return}y=n;G=F>>>8;do{if((G|0)==0){I=0}else{if(F>>>0>16777215){I=31;break}H=(G+1048320|0)>>>16&8;z=G<<H;b=(z+520192|0)>>>16&4;C=z<<b;z=(C+245760|0)>>>16&2;o=14-(b|H|z)+(C<<z>>>15)|0;I=F>>>((o+7|0)>>>0)&1|o<<1}}while(0);G=44824+(I<<2)|0;c[n+28>>2]=I;c[n+20>>2]=0;c[n+16>>2]=0;o=c[11131]|0;z=1<<I;if((o&z|0)==0){c[11131]=o|z;c[G>>2]=y;c[n+24>>2]=G;c[n+12>>2]=n;c[n+8>>2]=n;return}if((I|0)==31){J=0}else{J=25-(I>>>1)|0}I=F<<J;J=c[G>>2]|0;while(1){if((c[J+4>>2]&-8|0)==(F|0)){break}K=J+16+(I>>>31<<2)|0;G=c[K>>2]|0;if((G|0)==0){L=437;break}else{I=I<<1;J=G}}if((L|0)==437){if(K>>>0<(c[11134]|0)>>>0){bM()}c[K>>2]=y;c[n+24>>2]=J;c[n+12>>2]=n;c[n+8>>2]=n;return}K=J+8|0;L=c[K>>2]|0;I=c[11134]|0;if(J>>>0<I>>>0){bM()}if(L>>>0<I>>>0){bM()}c[L+12>>2]=y;c[K>>2]=y;c[n+8>>2]=L;c[n+12>>2]=J;c[n+24>>2]=0;return}function zN(b){b=b|0;var c=0;c=b;while(a[c]|0){c=c+1|0}return c-b|0}function zO(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=b|0;if((b&3)==(d&3)){while(b&3){if((e|0)==0)return f|0;a[b]=a[d]|0;b=b+1|0;d=d+1|0;e=e-1|0}while((e|0)>=4){c[b>>2]=c[d>>2];b=b+4|0;d=d+4|0;e=e-4|0}}while((e|0)>0){a[b]=a[d]|0;b=b+1|0;d=d+1|0;e=e-1|0}return f|0}function zP(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=b+e|0;if((e|0)>=20){d=d&255;e=b&3;g=d|d<<8|d<<16|d<<24;h=f&~3;if(e){e=b+4-e|0;while((b|0)<(e|0)){a[b]=d;b=b+1|0}}while((b|0)<(h|0)){c[b>>2]=g;b=b+4|0}}while((b|0)<(f|0)){a[b]=d;b=b+1|0}}function zQ(b,c){b=b|0;c=c|0;var d=0;do{a[b+d|0]=a[c+d|0];d=d+1|0}while(a[c+(d-1)|0]|0);return b|0}function zR(b,c){b=b|0;c=c|0;var d=0,e=0;d=b+(zN(b)|0)|0;do{a[d+e|0]=a[c+e|0];e=e+1|0}while(a[c+(e-1)|0]|0);return b|0}function zS(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0,g=0;while((e|0)<(c|0)){f=d[a+e|0]|0;g=d[b+e|0]|0;if((f|0)!=(g|0))return((f|0)>(g|0)?1:-1)|0;e=e+1|0}return 0}function zT(a){a=a|0;if((a|0)<65)return a|0;if((a|0)>90)return a|0;return a-65+97|0}function zU(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;while(e>>>0<d>>>0){f=zT(a[b+e|0]|0)|0;g=zT(a[c+e|0]|0)|0;if((f|0)==(g|0)&(f|0)==0)return 0;if((f|0)==0)return-1;if((g|0)==0)return 1;if((f|0)==(g|0)){e=e+1|0;continue}else{return(f>>>0>g>>>0?1:-1)|0}}return 0}function zV(a,b){a=a|0;b=b|0;return zU(a,b,-1)|0}function zW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=a+c>>>0;return(G=b+d+(e>>>0<a>>>0|0)>>>0,e|0)|0}function zX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=b-d>>>0;e=b-d-(c>>>0>a>>>0|0)>>>0;return(G=e,a-c>>>0|0)|0}function zY(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){G=b<<c|(a&(1<<c)-1<<32-c)>>>32-c;return a<<c}G=a<<c-32;return 0}function zZ(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){G=b>>>c;return a>>>c|(b&(1<<c)-1)<<32-c}G=0;return b>>>c-32|0}function z_(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){G=b>>c;return a>>>c|(b&(1<<c)-1)<<32-c}G=(b|0)<0?-1:0;return b>>c-32|0}function z$(b){b=b|0;var c=0;c=a[n+(b>>>24)|0]|0;if((c|0)<8)return c|0;c=a[n+(b>>16&255)|0]|0;if((c|0)<8)return c+8|0;c=a[n+(b>>8&255)|0]|0;if((c|0)<8)return c+16|0;return(a[n+(b&255)|0]|0)+24|0}function z0(b){b=b|0;var c=0;c=a[m+(b&255)|0]|0;if((c|0)<8)return c|0;c=a[m+(b>>8&255)|0]|0;if((c|0)<8)return c+8|0;c=a[m+(b>>16&255)|0]|0;if((c|0)<8)return c+16|0;return(a[m+(b>>>24)|0]|0)+24|0}function z1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a&65535;d=b&65535;e=ac(d,c)|0;f=a>>>16;a=(e>>>16)+(ac(d,f)|0)|0;d=b>>>16;b=ac(d,c)|0;return(G=(a>>>16)+(ac(d,f)|0)+(((a&65535)+b|0)>>>16)|0,a+b<<16|e&65535|0)|0}function z2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b>>31|((b|0)<0?-1:0)<<1;f=((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1;g=d>>31|((d|0)<0?-1:0)<<1;h=((d|0)<0?-1:0)>>31|((d|0)<0?-1:0)<<1;i=zX(e^a,f^b,e,f)|0;b=G;a=g^e;e=h^f;f=zX((z7(i,b,zX(g^c,h^d,g,h)|0,G,0)|0)^a,G^e,a,e)|0;return(G=G,f)|0}function z3(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+8|0;g=f|0;h=b>>31|((b|0)<0?-1:0)<<1;j=((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1;k=e>>31|((e|0)<0?-1:0)<<1;l=((e|0)<0?-1:0)>>31|((e|0)<0?-1:0)<<1;m=zX(h^a,j^b,h,j)|0;b=G;a=zX(k^d,l^e,k,l)|0;z7(m,b,a,G,g)|0;a=zX(c[g>>2]^h,c[g+4>>2]^j,h,j)|0;j=G;i=f;return(G=j,a)|0}function z4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=a;a=c;c=z1(e,a)|0;f=G;return(G=(ac(b,a)|0)+(ac(d,e)|0)+f|f&0,c|0|0)|0}function z5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=z7(a,b,c,d,0)|0;return(G=G,e)|0}function z6(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;i=i+8|0;g=f|0;z7(a,b,d,e,g)|0;i=f;return(G=c[g+4>>2]|0,c[g>>2]|0)|0}function z7(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0;g=a;h=b;i=h;j=d;k=e;l=k;if((i|0)==0){m=(f|0)!=0;if((l|0)==0){if(m){c[f>>2]=(g>>>0)%(j>>>0);c[f+4>>2]=0}n=0;o=(g>>>0)/(j>>>0)>>>0;return(G=n,o)|0}else{if(!m){n=0;o=0;return(G=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=b&0;n=0;o=0;return(G=n,o)|0}}m=(l|0)==0;do{if((j|0)==0){if(m){if((f|0)!=0){c[f>>2]=(i>>>0)%(j>>>0);c[f+4>>2]=0}n=0;o=(i>>>0)/(j>>>0)>>>0;return(G=n,o)|0}if((g|0)==0){if((f|0)!=0){c[f>>2]=0;c[f+4>>2]=(i>>>0)%(l>>>0)}n=0;o=(i>>>0)/(l>>>0)>>>0;return(G=n,o)|0}p=l-1|0;if((p&l|0)==0){if((f|0)!=0){c[f>>2]=a|0;c[f+4>>2]=p&i|b&0}n=0;o=i>>>((z0(l|0)|0)>>>0);return(G=n,o)|0}p=(z$(l|0)|0)-(z$(i|0)|0)|0;if(p>>>0<=30){q=p+1|0;r=31-p|0;s=q;t=i<<r|g>>>(q>>>0);u=i>>>(q>>>0);v=0;w=g<<r;break}if((f|0)==0){n=0;o=0;return(G=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=h|b&0;n=0;o=0;return(G=n,o)|0}else{if(!m){r=(z$(l|0)|0)-(z$(i|0)|0)|0;if(r>>>0<=31){q=r+1|0;p=31-r|0;x=r-31>>31;s=q;t=g>>>(q>>>0)&x|i<<p;u=i>>>(q>>>0)&x;v=0;w=g<<p;break}if((f|0)==0){n=0;o=0;return(G=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=h|b&0;n=0;o=0;return(G=n,o)|0}p=j-1|0;if((p&j|0)!=0){x=(z$(j|0)|0)+33-(z$(i|0)|0)|0;q=64-x|0;r=32-x|0;y=r>>31;z=x-32|0;A=z>>31;s=x;t=r-1>>31&i>>>(z>>>0)|(i<<r|g>>>(x>>>0))&A;u=A&i>>>(x>>>0);v=g<<q&y;w=(i<<q|g>>>(z>>>0))&y|g<<r&x-33>>31;break}if((f|0)!=0){c[f>>2]=p&g;c[f+4>>2]=0}if((j|0)==1){n=h|b&0;o=a|0|0;return(G=n,o)|0}else{p=z0(j|0)|0;n=i>>>(p>>>0)|0;o=i<<32-p|g>>>(p>>>0)|0;return(G=n,o)|0}}}while(0);if((s|0)==0){B=w;C=v;D=u;E=t;F=0;H=0}else{g=d|0|0;d=k|e&0;e=zW(g,d,-1,-1)|0;k=G;i=w;w=v;v=u;u=t;t=s;s=0;while(1){I=w>>>31|i<<1;J=s|w<<1;j=u<<1|i>>>31|0;a=u>>>31|v<<1|0;zX(e,k,j,a)|0;b=G;h=b>>31|((b|0)<0?-1:0)<<1;K=h&1;L=zX(j,a,h&g,(((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1)&d)|0;M=G;b=t-1|0;if((b|0)==0){break}else{i=I;w=J;v=M;u=L;t=b;s=K}}B=I;C=J;D=M;E=L;F=0;H=K}K=C;C=0;if((f|0)!=0){c[f>>2]=E;c[f+4>>2]=D}n=(K|0)>>>31|(B|C)<<1|(C<<1|K>>>31)&0|F;o=(K<<1|0>>>31)&-2|H;return(G=n,o)|0}function z8(a,b){a=a|0;b=b|0;return b1[a&1023](b|0)|0}function z9(a,b){a=a|0;b=b|0;b2[a&255](b|0)}function Aa(a,b,c){a=a|0;b=b|0;c=c|0;b3[a&511](b|0,c|0)}function Ab(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return b4[a&127](b|0,c|0,d|0)|0}function Ac(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b5[a&255](b|0,c|0,d|0)}function Ad(a){a=a|0;b6[a&7]()}function Ae(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return b7[a&63](b|0,c|0,d|0,e|0)|0}function Af(a,b,c){a=a|0;b=b|0;c=c|0;return b8[a&255](b|0,c|0)|0}function Ag(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return b9[a&7](b|0,c|0,d|0,e|0,f|0)|0}function Ah(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ca[a&3](b|0,c|0,d|0,e|0)}function Ai(a){a=a|0;ad(0);return 0}function Aj(a){a=a|0;ad(1)}function Ak(a,b){a=a|0;b=b|0;ad(2)}function Al(a,b,c){a=a|0;b=b|0;c=c|0;ad(3);return 0}function Am(a,b,c){a=a|0;b=b|0;c=c|0;ad(4)}function An(){ad(5)}function Ao(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ad(6);return 0}function Ap(a,b){a=a|0;b=b|0;ad(7);return 0}function Aq(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ad(8);return 0}function Ar(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ad(9)}
// EMSCRIPTEN_END_FUNCS
var b1=[Ai,Ai,o1,Ai,n4,Ai,oZ,Ai,li,Ai,lk,Ai,ll,Ai,lm,Ai,ln,Ai,lo,Ai,lp,Ai,lq,Ai,lC,Ai,jG,Ai,jH,Ai,jy,Ai,jD,Ai,jw,Ai,jz,Ai,jA,Ai,lD,Ai,lE,Ai,lF,Ai,lG,Ai,lH,Ai,lI,Ai,wd,Ai,jJ,Ai,jK,Ai,jI,Ai,jC,Ai,jL,Ai,jB,Ai,l$,Ai,l1,Ai,l0,Ai,l3,Ai,l2,Ai,l5,Ai,l4,Ai,kB,Ai,kl,Ai,kk,Ai,kj,Ai,ko,Ai,kn,Ai,km,Ai,pg,Ai,lV,Ai,lW,Ai,lU,Ai,lZ,Ai,l_,Ai,lX,Ai,lY,Ai,lO,Ai,lN,Ai,lQ,Ai,lP,Ai,lS,Ai,lR,Ai,lT,Ai,ki,Ai,kh,Ai,kc,Ai,kb,Ai,ka,Ai,kg,Ai,kf,Ai,ke,Ai,kd,Ai,uC,Ai,ky,Ai,kz,Ai,kA,Ai,jk,Ai,ku,Ai,kv,Ai,kw,Ai,kx,Ai,kC,Ai,kD,Ai,hw,Ai,hv,Ai,hx,Ai,hs,Ai,hu,Ai,ht,Ai,kH,Ai,kY,Ai,kZ,Ai,kE,Ai,kF,Ai,kG,Ai,jR,Ai,ho,Ai,dv,Ai,hp,Ai,hq,Ai,j2,Ai,j0,Ai,pB,Ai,jr,Ai,jt,Ai,js,Ai,i8,Ai,ju,Ai,jv,Ai,lh,Ai,lg,Ai,lf,Ai,le,Ai,ld,Ai,lc,Ai,lb,Ai,la,Ai,jq,Ai,jp,Ai,jj,Ai,ji,Ai,jl,Ai,jn,Ai,jm,Ai,jo,Ai,i7,Ai,lj,Ai,dr,Ai,wf,Ai,o2,Ai,jN,Ai,iP,Ai,y$,Ai,iO,Ai,oE,Ai,iS,Ai,lL,Ai,jx,Ai,kJ,Ai,lM,Ai,jE,Ai,kI,Ai,ly,Ai,jF,Ai,kL,Ai,jO,Ai,jP,Ai,lz,Ai,kM,Ai,kP,Ai,on,Ai,l6,Ai,kO,Ai,ma,Ai,mb,Ai,mc,Ai,md,Ai,jQ,Ai,l7,Ai,l8,Ai,l9,Ai,mg,Ai,mh,Ai,me,Ai,mf,Ai,mx,Ai,my,Ai,mi,Ai,mw,Ai,hP,Ai,i9,Ai,i0,Ai,i1,Ai,i2,Ai,i3,Ai,k_,Ai,k$,Ai,hy,Ai,hO,Ai,ja,Ai,jb,Ai,k0,Ai,k1,Ai,mA,Ai,mz,Ai,mC,Ai,mB,Ai,mE,Ai,mD,Ai,mG,Ai,mF,Ai,oT,Ai,jf,Ai,jg,Ai,jh,Ai,jc,Ai,jd,Ai,je,Ai,k5,Ai,k6,Ai,k4,Ai,k9,Ai,k7,Ai,k8,Ai,pf,Ai,hn,Ai,jY,Ai,iV,Ai,kK,Ai,lv,Ai,lu,Ai,uu,Ai,lK,Ai,lJ,Ai,lr,Ai,lB,Ai,lA,Ai,pC,Ai,lt,Ai,ls,Ai,lx,Ai,lw,Ai,i4,Ai,i6,Ai,jM,Ai,hQ,Ai,hr,Ai,zC,Ai,t7,Ai,uy,Ai,ur,Ai,c5,Ai,k2,Ai,k3,Ai,qs,Ai,pS,Ai,iY,Ai,iX,Ai,iW,Ai,j1,Ai,hT,Ai,i_,Ai,iZ,Ai,kS,Ai,kU,Ai,kT,Ai,kW,Ai,kV,Ai,kX,Ai,i5,Ai,kR,Ai,kQ,Ai,iN,Ai,iM,Ai,iT,Ai,iR,Ai,iQ,Ai,kt,Ai,kr,Ai,ks,Ai,iU,Ai,kN,Ai,kp,Ai,j3,Ai,kq,Ai,pT,Ai,qr,Ai,jZ,Ai,jW,Ai,jX,Ai,jU,Ai,jV,Ai,jS,Ai,jT,Ai,j_,Ai,j$,Ai,q7,Ai,i$,Ai,j9,Ai,j7,Ai,j8,Ai,j5,Ai,j6,Ai,j4,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai,Ai];var b2=[Aj,Aj,rs,Aj,t8,Aj,ro,Aj,nz,Aj,nB,Aj,nE,Aj,ov,Aj,rA,Aj,is,Aj,uv,Aj,zA,Aj,zj,Aj,rw,Aj,rv,Aj,oY,Aj,zd,Aj,oA,Aj,qV,Aj,wB,Aj,sF,Aj,us,Aj,rq,Aj,oJ,Aj,oD,Aj,t3,Aj,rr,Aj,rC,Aj,rZ,Aj,pj,Aj,wy,Aj,rp,Aj,s1,Aj,dR,Aj,il,Aj,im,Aj,ij,Aj,ik,Aj,iq,Aj,ir,Aj,io,Aj,ip,Aj,pG,Aj,o$,Aj,p$,Aj,we,Aj,oN,Aj,ou,Aj,qo,Aj,q2,Aj,ox,Aj,tI,Aj,o6,Aj,ru,Aj,oC,Aj,zE,Aj,y2,Aj,wD,Aj,zF,Aj,uz,Aj,op,Aj,uD,Aj,yZ,Aj,h6,Aj,h8,Aj,h7,Aj,ia,Aj,h9,Aj,ib,Aj,h2,Aj,h0,Aj,rx,Aj,tC,Aj,oS,Aj,hZ,Aj,hY,Aj,h$,Aj,h_,Aj,h1,Aj,h3,Aj,h5,Aj,h4,Aj,oB,Aj,ow,Aj,dS,Aj,d$,Aj,y1,Aj,r_,Aj,oy,Aj,wg,Aj,tQ,Aj,rt,Aj,sE,Aj,qm,Aj,yT,Aj,ry,Aj,qf,Aj,oz,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj,Aj];var b3=[Ak,Ak,oU,Ak,gW,Ak,gX,Ak,gY,Ak,gZ,Ak,g_,Ak,g$,Ak,nC,Ak,nF,Ak,nA,Ak,qQ,Ak,o9,Ak,oP,Ak,oF,Ak,pJ,Ak,dw,Ak,fo,Ak,fp,Ak,fm,Ak,fh,Ak,fi,Ak,pa,Ak,qw,Ak,eO,Ak,eP,Ak,ph,Ak,n2,Ak,pm,Ak,ft,Ak,fs,Ak,gQ,Ak,gS,Ak,gR,Ak,gU,Ak,gT,Ak,gV,Ak,oH,Ak,or,Ak,gH,Ak,gG,Ak,gJ,Ak,gI,Ak,gL,Ak,gK,Ak,gN,Ak,gM,Ak,gP,Ak,gO,Ak,nG,Ak,oL,Ak,nD,Ak,n0,Ak,n$,Ak,n1,Ak,nY,Ak,nX,Ak,n_,Ak,nZ,Ak,fS,Ak,fQ,Ak,fR,Ak,fU,Ak,fV,Ak,eN,Ak,ff,Ak,fc,Ak,fX,Ak,fW,Ak,f_,Ak,fY,Ak,fZ,Ak,e6,Ak,e2,Ak,fa,Ak,e9,Ak,sq,Ak,q3,Ak,ql,Ak,fg,Ak,hW,Ak,fe,Ak,fd,Ak,pK,Ak,fb,Ak,pp,Ak,p2,Ak,dx,Ak,fT,Ak,oO,Ak,fP,Ak,nv,Ak,q8,Ak,hf,Ak,gC,Ak,gz,Ak,gy,Ak,e8,Ak,e7,Ak,e5,Ak,e4,Ak,e3,Ak,qv,Ak,gl,Ak,gk,Ak,gh,Ak,gg,Ak,gF,Ak,gE,Ak,fO,Ak,fL,Ak,fK,Ak,gf,Ak,fJ,Ak,fn,Ak,eY,Ak,po,Ak,fl,Ak,pI,Ak,ot,Ak,fj,Ak,fk,Ak,hg,Ak,eQ,Ak,eJ,Ak,eK,Ak,eL,Ak,eM,Ak,eR,Ak,eS,Ak,wF,Ak,ds,Ak,wz,Ak,qe,Ak,ol,Ak,eW,Ak,eX,Ak,e0,Ak,eT,Ak,eU,Ak,eV,Ak,f7,Ak,mK,Ak,mL,Ak,he,Ak,gD,Ak,hd,Ak,gB,Ak,gA,Ak,hh,Ak,gu,Ak,gv,Ak,hi,Ak,pn,Ak,oQ,Ak,gs,Ak,gr,Ak,gq,Ak,gp,Ak,go,Ak,gn,Ak,gm,Ak,gx,Ak,gw,Ak,p4,Ak,gt,Ak,e1,Ak,oI,Ak,hk,Ak,hj,Ak,fN,Ak,fM,Ak,gj,Ak,sr,Ak,g9,Ak,g8,Ak,g7,Ak,hc,Ak,hb,Ak,ha,Ak,p1,Ak,eZ,Ak,g6,Ak,g5,Ak,g0,Ak,g4,Ak,g3,Ak,g2,Ak,g1,Ak,fu,Ak,fr,Ak,dy,Ak,fq,Ak,f8,Ak,f3,Ak,f4,Ak,f5,Ak,f6,Ak,f0,Ak,f1,Ak,f2,Ak,fE,Ak,fG,Ak,fF,Ak,fI,Ak,fH,Ak,e$,Ak,fv,Ak,gc,Ak,gd,Ak,ge,Ak,f9,Ak,ga,Ak,gb,Ak,om,Ak,fw,Ak,fy,Ak,fx,Ak,fA,Ak,fz,Ak,e_,Ak,fB,Ak,fD,Ak,fC,Ak,pb,Ak,oG,Ak,oR,Ak,gi,Ak,wC,Ak,oK,Ak,pL,Ak,p3,Ak,f$,Ak,cN,Ak,qx,Ak,qu,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak,Ak];var b4=[Al,Al,y_,Al,ut,Al,em,Al,wb,Al,ec,Al,tV,Al,dZ,Al,uE,Al,eg,Al,zD,Al,t9,Al,tL,Al,ep,Al,s4,Al,el,Al,eh,Al,ei,Al,o8,Al,pH,Al,d0,Al,ua,Al,d9,Al,tY,Al,eo,Al,ws,Al,pl,Al,y0,Al,ee,Al,dX,Al,p0,Al,wE,Al,ej,Al,yW,Al,uw,Al,d8,Al,ek,Al,dW,Al,dU,Al,qq,Al,ea,Al,q4,Al,d6,Al,ux,Al,zB,Al,ub,Al,ef,Al,uA,Al,uB,Al,eb,Al,ed,Al,dY,Al,wh,Al,en,Al,wr,Al,dT,Al,dV,Al,d5,Al,d7,Al,Al,Al,Al,Al,Al,Al,Al,Al,Al,Al];var b5=[Am,Am,oh,Am,nu,Am,pu,Am,qR,Am,dm,Am,oq,Am,cV,Am,pD,Am,c2,Am,sJ,Am,qc,Am,rj,Am,pd,Am,qP,Am,qt,Am,mM,Am,rG,Am,nK,Am,sh,Am,qk,Am,qS,Am,o5,Am,du,Am,qB,Am,qb,Am,hB,Am,sd,Am,pU,Am,hC,Am,sH,Am,pY,Am,ps,Am,dA,Am,mR,Am,dL,Am,wj,Am,o0,Am,pc,Am,si,Am,rI,Am,pZ,Am,qO,Am,sL,Am,og,Am,cW,Am,pE,Am,qC,Am,pq,Am,nJ,Am,pv,Am,of,Am,st,Am,sz,Am,mN,Am,sA,Am,nL,Am,su,Am,qj,Am,ra,Am,rH,Am,sg,Am,nt,Am,pN,Am,qy,Am,pV,Am,dp,Am,se,Am,cO,Am,ns,Am,pM,Am,sc,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am,Am];var b6=[An,An,dQ,An,cI,An,An,An];var b7=[Ao,Ao,zf,Ao,wi,Ao,tp,Ao,tO,Ao,yR,Ao,t4,Ao,tS,Ao,yU,Ao,t5,Ao,zb,Ao,s3,Ao,wc,Ao,tR,Ao,s2,Ao,ze,Ao,za,Ao,tJ,Ao,yV,Ao,tD,Ao,tE,Ao,tK,Ao,Ao,Ao,Ao,Ao,Ao,Ao,Ao,Ao,Ao,Ao,Ao,Ao,Ao,Ao,Ao,Ao,Ao,Ao,Ao,Ao];var b8=[Ap,Ap,pw,Ap,px,Ap,rF,Ap,p5,Ap,qA,Ap,qT,Ap,cL,Ap,mQ,Ap,nV,Ap,sv,Ap,pW,Ap,sI,Ap,qU,Ap,o3,Ap,cJ,Ap,pP,Ap,dz,Ap,o4,Ap,n7,Ap,nl,Ap,uc,Ap,nn,Ap,qa,Ap,sl,Ap,mP,Ap,p9,Ap,pt,Ap,nT,Ap,qi,Ap,sn,Ap,so,Ap,qz,Ap,rD,Ap,nU,Ap,dt,Ap,qD,Ap,n6,Ap,sG,Ap,rE,Ap,sa,Ap,dn,Ap,pX,Ap,pO,Ap,ri,Ap,dl,Ap,mO,Ap,q9,Ap,ud,Ap,qE,Ap,sk,Ap,sj,Ap,hA,Ap,cK,Ap,oo,Ap,tZ,Ap,n8,Ap,hz,Ap,qX,Ap,p6,Ap,pr,Ap,t$,Ap,qh,Ap,nm,Ap,sw,Ap,sb,Ap,qW,Ap,sK,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap,Ap];var b9=[Aq,Aq,t_,Aq,ue,Aq,Aq,Aq];var ca=[Ar,Ar,dq,Ar];return{_memcmp:zS,_strlen:zN,_strcat:zR,_free:zI,_main:d_,_realloc:zJ,_tolower:zT,_memset:zP,_malloc:zH,_memcpy:zO,_strcasecmp:zV,_strncasecmp:zU,_strcpy:zQ,runPostSets:cr,stackAlloc:cb,stackSave:cc,stackRestore:cd,setThrew:ce,setTempRet0:ch,setTempRet1:ci,setTempRet2:cj,setTempRet3:ck,setTempRet4:cl,setTempRet5:cm,setTempRet6:cn,setTempRet7:co,setTempRet8:cp,setTempRet9:cq,dynCall_ii:z8,dynCall_vi:z9,dynCall_vii:Aa,dynCall_iiii:Ab,dynCall_viii:Ac,dynCall_v:Ad,dynCall_iiiii:Ae,dynCall_iii:Af,dynCall_iiiiii:Ag,dynCall_viiii:Ah}})
// EMSCRIPTEN_END_ASM
({ "Math": Math, "Int8Array": Int8Array, "Int16Array": Int16Array, "Int32Array": Int32Array, "Uint8Array": Uint8Array, "Uint16Array": Uint16Array, "Uint32Array": Uint32Array, "Float32Array": Float32Array, "Float64Array": Float64Array }, { "abort": abort, "assert": assert, "asmPrintInt": asmPrintInt, "asmPrintFloat": asmPrintFloat, "min": Math_min, "invoke_ii": invoke_ii, "invoke_vi": invoke_vi, "invoke_vii": invoke_vii, "invoke_iiii": invoke_iiii, "invoke_viii": invoke_viii, "invoke_v": invoke_v, "invoke_iiiii": invoke_iiiii, "invoke_iii": invoke_iii, "invoke_iiiiii": invoke_iiiiii, "invoke_viiii": invoke_viiii, "_llvm_lifetime_end": _llvm_lifetime_end, "_lseek": _lseek, "_fclose": _fclose, "_SDL_EventState": _SDL_EventState, "_strtoul": _strtoul, "_fflush": _fflush, "_SDL_GetMouseState": _SDL_GetMouseState, "_strtol": _strtol, "_fputc": _fputc, "_fwrite": _fwrite, "_ptsname": _ptsname, "_send": _send, "_tcflush": _tcflush, "_fputs": _fputs, "_emscripten_cancel_main_loop": _emscripten_cancel_main_loop, "_localtime": _localtime, "_SDL_WasInit": _SDL_WasInit, "_read": _read, "_fileno": _fileno, "_fsync": _fsync, "_signal": _signal, "_SDL_PauseAudio": _SDL_PauseAudio, "_SDL_LockAudio": _SDL_LockAudio, "_strcmp": _strcmp, "_strncmp": _strncmp, "_snprintf": _snprintf, "_fgetc": _fgetc, "_atexit": _atexit, "_close": _close, "_tcsetattr": _tcsetattr, "_strchr": _strchr, "_tcgetattr": _tcgetattr, "_poll": _poll, "___setErrNo": ___setErrNo, "_grantpt": _grantpt, "_ftell": _ftell, "_exit": _exit, "_sprintf": _sprintf, "_fcntl": _fcntl, "_SDL_ShowCursor": _SDL_ShowCursor, "_gmtime": _gmtime, "_localtime_r": _localtime_r, "_symlink": _symlink, "_ftruncate": _ftruncate, "_recv": _recv, "_cos": _cos, "_SDL_PollEvent": _SDL_PollEvent, "_SDL_Init": _SDL_Init, "__exit": __exit, "_SDL_WM_GrabInput": _SDL_WM_GrabInput, "_llvm_va_end": _llvm_va_end, "_tzset": _tzset, "_SDL_CreateRGBSurfaceFrom": _SDL_CreateRGBSurfaceFrom, "_printf": _printf, "_unlockpt": _unlockpt, "_pread": _pread, "_SDL_SetVideoMode": _SDL_SetVideoMode, "_fopen": _fopen, "_open": _open, "_usleep": _usleep, "_SDL_EnableKeyRepeat": _SDL_EnableKeyRepeat, "_puts": _puts, "_SDL_GetVideoInfo": _SDL_GetVideoInfo, "_nanosleep": _nanosleep, "_SDL_Flip": _SDL_Flip, "_SDL_InitSubSystem": _SDL_InitSubSystem, "_strdup": _strdup, "_SDL_GetError": _SDL_GetError, "__formatString": __formatString, "_gettimeofday": _gettimeofday, "_vfprintf": _vfprintf, "_SDL_WM_SetCaption": _SDL_WM_SetCaption, "_sbrk": _sbrk, "___errno_location": ___errno_location, "_SDL_CloseAudio": _SDL_CloseAudio, "_isspace": _isspace, "_llvm_lifetime_start": _llvm_lifetime_start, "__parseInt": __parseInt, "_SDL_OpenAudio": _SDL_OpenAudio, "_SDL_UnlockAudio": _SDL_UnlockAudio, "_gmtime_r": _gmtime_r, "_sysconf": _sysconf, "_fread": _fread, "_SDL_WM_ToggleFullScreen": _SDL_WM_ToggleFullScreen, "_abort": _abort, "_fprintf": _fprintf, "_tan": _tan, "__reallyNegative": __reallyNegative, "_posix_openpt": _posix_openpt, "_feof": _feof, "_fseek": _fseek, "_write": _write, "_SDL_UpperBlit": _SDL_UpperBlit, "_rewind": _rewind, "_sin": _sin, "_truncate": _truncate, "_emscripten_set_main_loop": _emscripten_set_main_loop, "_unlink": _unlink, "_pwrite": _pwrite, "_SDL_FreeSurface": _SDL_FreeSurface, "_time": _time, "STACKTOP": STACKTOP, "STACK_MAX": STACK_MAX, "tempDoublePtr": tempDoublePtr, "ABORT": ABORT, "cttz_i8": cttz_i8, "ctlz_i8": ctlz_i8, "NaN": NaN, "Infinity": Infinity, "_stdout": _stdout, "_stdin": _stdin, "_stderr": _stderr }, buffer);
var _memcmp = Module["_memcmp"] = asm["_memcmp"];
var _strlen = Module["_strlen"] = asm["_strlen"];
var _strcat = Module["_strcat"] = asm["_strcat"];
var _free = Module["_free"] = asm["_free"];
var _main = Module["_main"] = asm["_main"];
var _realloc = Module["_realloc"] = asm["_realloc"];
var _tolower = Module["_tolower"] = asm["_tolower"];
var _memset = Module["_memset"] = asm["_memset"];
var _malloc = Module["_malloc"] = asm["_malloc"];
var _memcpy = Module["_memcpy"] = asm["_memcpy"];
var _strcasecmp = Module["_strcasecmp"] = asm["_strcasecmp"];
var _strncasecmp = Module["_strncasecmp"] = asm["_strncasecmp"];
var _strcpy = Module["_strcpy"] = asm["_strcpy"];
var runPostSets = Module["runPostSets"] = asm["runPostSets"];
var dynCall_ii = Module["dynCall_ii"] = asm["dynCall_ii"];
var dynCall_vi = Module["dynCall_vi"] = asm["dynCall_vi"];
var dynCall_vii = Module["dynCall_vii"] = asm["dynCall_vii"];
var dynCall_iiii = Module["dynCall_iiii"] = asm["dynCall_iiii"];
var dynCall_viii = Module["dynCall_viii"] = asm["dynCall_viii"];
var dynCall_v = Module["dynCall_v"] = asm["dynCall_v"];
var dynCall_iiiii = Module["dynCall_iiiii"] = asm["dynCall_iiiii"];
var dynCall_iii = Module["dynCall_iii"] = asm["dynCall_iii"];
var dynCall_iiiiii = Module["dynCall_iiiiii"] = asm["dynCall_iiiiii"];
var dynCall_viiii = Module["dynCall_viiii"] = asm["dynCall_viiii"];
Runtime.stackAlloc = function(size) { return asm['stackAlloc'](size) };
Runtime.stackSave = function() { return asm['stackSave']() };
Runtime.stackRestore = function(top) { asm['stackRestore'](top) };
// TODO: strip out parts of this we do not need
//======= begin closure i64 code =======
// Copyright 2009 The Closure Library Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS-IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
/**
 * @fileoverview Defines a Long class for representing a 64-bit two's-complement
 * integer value, which faithfully simulates the behavior of a Java "long". This
 * implementation is derived from LongLib in GWT.
 *
 */
var i64Math = (function() { // Emscripten wrapper
  var goog = { math: {} };
  /**
   * Constructs a 64-bit two's-complement integer, given its low and high 32-bit
   * values as *signed* integers.  See the from* functions below for more
   * convenient ways of constructing Longs.
   *
   * The internal representation of a long is the two given signed, 32-bit values.
   * We use 32-bit pieces because these are the size of integers on which
   * Javascript performs bit-operations.  For operations like addition and
   * multiplication, we split each number into 16-bit pieces, which can easily be
   * multiplied within Javascript's floating-point representation without overflow
   * or change in sign.
   *
   * In the algorithms below, we frequently reduce the negative case to the
   * positive case by negating the input(s) and then post-processing the result.
   * Note that we must ALWAYS check specially whether those values are MIN_VALUE
   * (-2^63) because -MIN_VALUE == MIN_VALUE (since 2^63 cannot be represented as
   * a positive number, it overflows back into a negative).  Not handling this
   * case would often result in infinite recursion.
   *
   * @param {number} low  The low (signed) 32 bits of the long.
   * @param {number} high  The high (signed) 32 bits of the long.
   * @constructor
   */
  goog.math.Long = function(low, high) {
    /**
     * @type {number}
     * @private
     */
    this.low_ = low | 0;  // force into 32 signed bits.
    /**
     * @type {number}
     * @private
     */
    this.high_ = high | 0;  // force into 32 signed bits.
  };
  // NOTE: Common constant values ZERO, ONE, NEG_ONE, etc. are defined below the
  // from* methods on which they depend.
  /**
   * A cache of the Long representations of small integer values.
   * @type {!Object}
   * @private
   */
  goog.math.Long.IntCache_ = {};
  /**
   * Returns a Long representing the given (32-bit) integer value.
   * @param {number} value The 32-bit integer in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromInt = function(value) {
    if (-128 <= value && value < 128) {
      var cachedObj = goog.math.Long.IntCache_[value];
      if (cachedObj) {
        return cachedObj;
      }
    }
    var obj = new goog.math.Long(value | 0, value < 0 ? -1 : 0);
    if (-128 <= value && value < 128) {
      goog.math.Long.IntCache_[value] = obj;
    }
    return obj;
  };
  /**
   * Returns a Long representing the given value, provided that it is a finite
   * number.  Otherwise, zero is returned.
   * @param {number} value The number in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromNumber = function(value) {
    if (isNaN(value) || !isFinite(value)) {
      return goog.math.Long.ZERO;
    } else if (value <= -goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MIN_VALUE;
    } else if (value + 1 >= goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MAX_VALUE;
    } else if (value < 0) {
      return goog.math.Long.fromNumber(-value).negate();
    } else {
      return new goog.math.Long(
          (value % goog.math.Long.TWO_PWR_32_DBL_) | 0,
          (value / goog.math.Long.TWO_PWR_32_DBL_) | 0);
    }
  };
  /**
   * Returns a Long representing the 64-bit integer that comes by concatenating
   * the given high and low bits.  Each is assumed to use 32 bits.
   * @param {number} lowBits The low 32-bits.
   * @param {number} highBits The high 32-bits.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromBits = function(lowBits, highBits) {
    return new goog.math.Long(lowBits, highBits);
  };
  /**
   * Returns a Long representation of the given string, written using the given
   * radix.
   * @param {string} str The textual representation of the Long.
   * @param {number=} opt_radix The radix in which the text is written.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromString = function(str, opt_radix) {
    if (str.length == 0) {
      throw Error('number format error: empty string');
    }
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }
    if (str.charAt(0) == '-') {
      return goog.math.Long.fromString(str.substring(1), radix).negate();
    } else if (str.indexOf('-') >= 0) {
      throw Error('number format error: interior "-" character: ' + str);
    }
    // Do several (8) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 8));
    var result = goog.math.Long.ZERO;
    for (var i = 0; i < str.length; i += 8) {
      var size = Math.min(8, str.length - i);
      var value = parseInt(str.substring(i, i + size), radix);
      if (size < 8) {
        var power = goog.math.Long.fromNumber(Math.pow(radix, size));
        result = result.multiply(power).add(goog.math.Long.fromNumber(value));
      } else {
        result = result.multiply(radixToPower);
        result = result.add(goog.math.Long.fromNumber(value));
      }
    }
    return result;
  };
  // NOTE: the compiler should inline these constant values below and then remove
  // these variables, so there should be no runtime penalty for these.
  /**
   * Number used repeated below in calculations.  This must appear before the
   * first call to any from* function below.
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_16_DBL_ = 1 << 16;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_24_DBL_ = 1 << 24;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_32_DBL_ =
      goog.math.Long.TWO_PWR_16_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_31_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ / 2;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_48_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_64_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_32_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_63_DBL_ =
      goog.math.Long.TWO_PWR_64_DBL_ / 2;
  /** @type {!goog.math.Long} */
  goog.math.Long.ZERO = goog.math.Long.fromInt(0);
  /** @type {!goog.math.Long} */
  goog.math.Long.ONE = goog.math.Long.fromInt(1);
  /** @type {!goog.math.Long} */
  goog.math.Long.NEG_ONE = goog.math.Long.fromInt(-1);
  /** @type {!goog.math.Long} */
  goog.math.Long.MAX_VALUE =
      goog.math.Long.fromBits(0xFFFFFFFF | 0, 0x7FFFFFFF | 0);
  /** @type {!goog.math.Long} */
  goog.math.Long.MIN_VALUE = goog.math.Long.fromBits(0, 0x80000000 | 0);
  /**
   * @type {!goog.math.Long}
   * @private
   */
  goog.math.Long.TWO_PWR_24_ = goog.math.Long.fromInt(1 << 24);
  /** @return {number} The value, assuming it is a 32-bit integer. */
  goog.math.Long.prototype.toInt = function() {
    return this.low_;
  };
  /** @return {number} The closest floating-point representation to this value. */
  goog.math.Long.prototype.toNumber = function() {
    return this.high_ * goog.math.Long.TWO_PWR_32_DBL_ +
           this.getLowBitsUnsigned();
  };
  /**
   * @param {number=} opt_radix The radix in which the text should be written.
   * @return {string} The textual representation of this value.
   */
  goog.math.Long.prototype.toString = function(opt_radix) {
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }
    if (this.isZero()) {
      return '0';
    }
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        // We need to change the Long value before it can be negated, so we remove
        // the bottom-most digit in this base and then recurse to do the rest.
        var radixLong = goog.math.Long.fromNumber(radix);
        var div = this.div(radixLong);
        var rem = div.multiply(radixLong).subtract(this);
        return div.toString(radix) + rem.toInt().toString(radix);
      } else {
        return '-' + this.negate().toString(radix);
      }
    }
    // Do several (6) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 6));
    var rem = this;
    var result = '';
    while (true) {
      var remDiv = rem.div(radixToPower);
      var intval = rem.subtract(remDiv.multiply(radixToPower)).toInt();
      var digits = intval.toString(radix);
      rem = remDiv;
      if (rem.isZero()) {
        return digits + result;
      } else {
        while (digits.length < 6) {
          digits = '0' + digits;
        }
        result = '' + digits + result;
      }
    }
  };
  /** @return {number} The high 32-bits as a signed value. */
  goog.math.Long.prototype.getHighBits = function() {
    return this.high_;
  };
  /** @return {number} The low 32-bits as a signed value. */
  goog.math.Long.prototype.getLowBits = function() {
    return this.low_;
  };
  /** @return {number} The low 32-bits as an unsigned value. */
  goog.math.Long.prototype.getLowBitsUnsigned = function() {
    return (this.low_ >= 0) ?
        this.low_ : goog.math.Long.TWO_PWR_32_DBL_ + this.low_;
  };
  /**
   * @return {number} Returns the number of bits needed to represent the absolute
   *     value of this Long.
   */
  goog.math.Long.prototype.getNumBitsAbs = function() {
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        return 64;
      } else {
        return this.negate().getNumBitsAbs();
      }
    } else {
      var val = this.high_ != 0 ? this.high_ : this.low_;
      for (var bit = 31; bit > 0; bit--) {
        if ((val & (1 << bit)) != 0) {
          break;
        }
      }
      return this.high_ != 0 ? bit + 33 : bit + 1;
    }
  };
  /** @return {boolean} Whether this value is zero. */
  goog.math.Long.prototype.isZero = function() {
    return this.high_ == 0 && this.low_ == 0;
  };
  /** @return {boolean} Whether this value is negative. */
  goog.math.Long.prototype.isNegative = function() {
    return this.high_ < 0;
  };
  /** @return {boolean} Whether this value is odd. */
  goog.math.Long.prototype.isOdd = function() {
    return (this.low_ & 1) == 1;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long equals the other.
   */
  goog.math.Long.prototype.equals = function(other) {
    return (this.high_ == other.high_) && (this.low_ == other.low_);
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long does not equal the other.
   */
  goog.math.Long.prototype.notEquals = function(other) {
    return (this.high_ != other.high_) || (this.low_ != other.low_);
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than the other.
   */
  goog.math.Long.prototype.lessThan = function(other) {
    return this.compare(other) < 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than or equal to the other.
   */
  goog.math.Long.prototype.lessThanOrEqual = function(other) {
    return this.compare(other) <= 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than the other.
   */
  goog.math.Long.prototype.greaterThan = function(other) {
    return this.compare(other) > 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than or equal to the other.
   */
  goog.math.Long.prototype.greaterThanOrEqual = function(other) {
    return this.compare(other) >= 0;
  };
  /**
   * Compares this Long with the given one.
   * @param {goog.math.Long} other Long to compare against.
   * @return {number} 0 if they are the same, 1 if the this is greater, and -1
   *     if the given one is greater.
   */
  goog.math.Long.prototype.compare = function(other) {
    if (this.equals(other)) {
      return 0;
    }
    var thisNeg = this.isNegative();
    var otherNeg = other.isNegative();
    if (thisNeg && !otherNeg) {
      return -1;
    }
    if (!thisNeg && otherNeg) {
      return 1;
    }
    // at this point, the signs are the same, so subtraction will not overflow
    if (this.subtract(other).isNegative()) {
      return -1;
    } else {
      return 1;
    }
  };
  /** @return {!goog.math.Long} The negation of this value. */
  goog.math.Long.prototype.negate = function() {
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.MIN_VALUE;
    } else {
      return this.not().add(goog.math.Long.ONE);
    }
  };
  /**
   * Returns the sum of this and the given Long.
   * @param {goog.math.Long} other Long to add to this one.
   * @return {!goog.math.Long} The sum of this and the given Long.
   */
  goog.math.Long.prototype.add = function(other) {
    // Divide each number into 4 chunks of 16 bits, and then sum the chunks.
    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;
    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;
    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 + b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 + b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 + b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 + b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };
  /**
   * Returns the difference of this and the given Long.
   * @param {goog.math.Long} other Long to subtract from this.
   * @return {!goog.math.Long} The difference of this and the given Long.
   */
  goog.math.Long.prototype.subtract = function(other) {
    return this.add(other.negate());
  };
  /**
   * Returns the product of this and the given long.
   * @param {goog.math.Long} other Long to multiply with this.
   * @return {!goog.math.Long} The product of this and the other.
   */
  goog.math.Long.prototype.multiply = function(other) {
    if (this.isZero()) {
      return goog.math.Long.ZERO;
    } else if (other.isZero()) {
      return goog.math.Long.ZERO;
    }
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return other.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return this.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    }
    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().multiply(other.negate());
      } else {
        return this.negate().multiply(other).negate();
      }
    } else if (other.isNegative()) {
      return this.multiply(other.negate()).negate();
    }
    // If both longs are small, use float multiplication
    if (this.lessThan(goog.math.Long.TWO_PWR_24_) &&
        other.lessThan(goog.math.Long.TWO_PWR_24_)) {
      return goog.math.Long.fromNumber(this.toNumber() * other.toNumber());
    }
    // Divide each long into 4 chunks of 16 bits, and then add up 4x4 products.
    // We can skip products that would overflow.
    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;
    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;
    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 * b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 * b00;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c16 += a00 * b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 * b00;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a16 * b16;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a00 * b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 * b00 + a32 * b16 + a16 * b32 + a00 * b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };
  /**
   * Returns this Long divided by the given one.
   * @param {goog.math.Long} other Long by which to divide.
   * @return {!goog.math.Long} This Long divided by the given one.
   */
  goog.math.Long.prototype.div = function(other) {
    if (other.isZero()) {
      throw Error('division by zero');
    } else if (this.isZero()) {
      return goog.math.Long.ZERO;
    }
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      if (other.equals(goog.math.Long.ONE) ||
          other.equals(goog.math.Long.NEG_ONE)) {
        return goog.math.Long.MIN_VALUE;  // recall that -MIN_VALUE == MIN_VALUE
      } else if (other.equals(goog.math.Long.MIN_VALUE)) {
        return goog.math.Long.ONE;
      } else {
        // At this point, we have |other| >= 2, so |this/other| < |MIN_VALUE|.
        var halfThis = this.shiftRight(1);
        var approx = halfThis.div(other).shiftLeft(1);
        if (approx.equals(goog.math.Long.ZERO)) {
          return other.isNegative() ? goog.math.Long.ONE : goog.math.Long.NEG_ONE;
        } else {
          var rem = this.subtract(other.multiply(approx));
          var result = approx.add(rem.div(other));
          return result;
        }
      }
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.ZERO;
    }
    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().div(other.negate());
      } else {
        return this.negate().div(other).negate();
      }
    } else if (other.isNegative()) {
      return this.div(other.negate()).negate();
    }
    // Repeat the following until the remainder is less than other:  find a
    // floating-point that approximates remainder / other *from below*, add this
    // into the result, and subtract it from the remainder.  It is critical that
    // the approximate value is less than or equal to the real value so that the
    // remainder never becomes negative.
    var res = goog.math.Long.ZERO;
    var rem = this;
    while (rem.greaterThanOrEqual(other)) {
      // Approximate the result of division. This may be a little greater or
      // smaller than the actual value.
      var approx = Math.max(1, Math.floor(rem.toNumber() / other.toNumber()));
      // We will tweak the approximate result by changing it in the 48-th digit or
      // the smallest non-fractional digit, whichever is larger.
      var log2 = Math.ceil(Math.log(approx) / Math.LN2);
      var delta = (log2 <= 48) ? 1 : Math.pow(2, log2 - 48);
      // Decrease the approximation until it is smaller than the remainder.  Note
      // that if it is too large, the product overflows and is negative.
      var approxRes = goog.math.Long.fromNumber(approx);
      var approxRem = approxRes.multiply(other);
      while (approxRem.isNegative() || approxRem.greaterThan(rem)) {
        approx -= delta;
        approxRes = goog.math.Long.fromNumber(approx);
        approxRem = approxRes.multiply(other);
      }
      // We know the answer can't be zero... and actually, zero would cause
      // infinite recursion since we would make no progress.
      if (approxRes.isZero()) {
        approxRes = goog.math.Long.ONE;
      }
      res = res.add(approxRes);
      rem = rem.subtract(approxRem);
    }
    return res;
  };
  /**
   * Returns this Long modulo the given one.
   * @param {goog.math.Long} other Long by which to mod.
   * @return {!goog.math.Long} This Long modulo the given one.
   */
  goog.math.Long.prototype.modulo = function(other) {
    return this.subtract(this.div(other).multiply(other));
  };
  /** @return {!goog.math.Long} The bitwise-NOT of this value. */
  goog.math.Long.prototype.not = function() {
    return goog.math.Long.fromBits(~this.low_, ~this.high_);
  };
  /**
   * Returns the bitwise-AND of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to AND.
   * @return {!goog.math.Long} The bitwise-AND of this and the other.
   */
  goog.math.Long.prototype.and = function(other) {
    return goog.math.Long.fromBits(this.low_ & other.low_,
                                   this.high_ & other.high_);
  };
  /**
   * Returns the bitwise-OR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to OR.
   * @return {!goog.math.Long} The bitwise-OR of this and the other.
   */
  goog.math.Long.prototype.or = function(other) {
    return goog.math.Long.fromBits(this.low_ | other.low_,
                                   this.high_ | other.high_);
  };
  /**
   * Returns the bitwise-XOR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to XOR.
   * @return {!goog.math.Long} The bitwise-XOR of this and the other.
   */
  goog.math.Long.prototype.xor = function(other) {
    return goog.math.Long.fromBits(this.low_ ^ other.low_,
                                   this.high_ ^ other.high_);
  };
  /**
   * Returns this Long with bits shifted to the left by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the left by the given amount.
   */
  goog.math.Long.prototype.shiftLeft = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var low = this.low_;
      if (numBits < 32) {
        var high = this.high_;
        return goog.math.Long.fromBits(
            low << numBits,
            (high << numBits) | (low >>> (32 - numBits)));
      } else {
        return goog.math.Long.fromBits(0, low << (numBits - 32));
      }
    }
  };
  /**
   * Returns this Long with bits shifted to the right by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount.
   */
  goog.math.Long.prototype.shiftRight = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >> numBits);
      } else {
        return goog.math.Long.fromBits(
            high >> (numBits - 32),
            high >= 0 ? 0 : -1);
      }
    }
  };
  /**
   * Returns this Long with bits shifted to the right by the given amount, with
   * the new top bits matching the current sign bit.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount, with
   *     zeros placed into the new leading bits.
   */
  goog.math.Long.prototype.shiftRightUnsigned = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >>> numBits);
      } else if (numBits == 32) {
        return goog.math.Long.fromBits(high, 0);
      } else {
        return goog.math.Long.fromBits(high >>> (numBits - 32), 0);
      }
    }
  };
  //======= begin jsbn =======
  var navigator = { appName: 'Modern Browser' }; // polyfill a little
  // Copyright (c) 2005  Tom Wu
  // All Rights Reserved.
  // http://www-cs-students.stanford.edu/~tjw/jsbn/
  /*
   * Copyright (c) 2003-2005  Tom Wu
   * All Rights Reserved.
   *
   * Permission is hereby granted, free of charge, to any person obtaining
   * a copy of this software and associated documentation files (the
   * "Software"), to deal in the Software without restriction, including
   * without limitation the rights to use, copy, modify, merge, publish,
   * distribute, sublicense, and/or sell copies of the Software, and to
   * permit persons to whom the Software is furnished to do so, subject to
   * the following conditions:
   *
   * The above copyright notice and this permission notice shall be
   * included in all copies or substantial portions of the Software.
   *
   * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
   * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
   * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
   *
   * IN NO EVENT SHALL TOM WU BE LIABLE FOR ANY SPECIAL, INCIDENTAL,
   * INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY DAMAGES WHATSOEVER
   * RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER OR NOT ADVISED OF
   * THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF LIABILITY, ARISING OUT
   * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   *
   * In addition, the following condition applies:
   *
   * All redistributions must retain an intact copy of this copyright notice
   * and disclaimer.
   */
  // Basic JavaScript BN library - subset useful for RSA encryption.
  // Bits per digit
  var dbits;
  // JavaScript engine analysis
  var canary = 0xdeadbeefcafe;
  var j_lm = ((canary&0xffffff)==0xefcafe);
  // (public) Constructor
  function BigInteger(a,b,c) {
    if(a != null)
      if("number" == typeof a) this.fromNumber(a,b,c);
      else if(b == null && "string" != typeof a) this.fromString(a,256);
      else this.fromString(a,b);
  }
  // return new, unset BigInteger
  function nbi() { return new BigInteger(null); }
  // am: Compute w_j += (x*this_i), propagate carries,
  // c is initial carry, returns final carry.
  // c < 3*dvalue, x < 2*dvalue, this_i < dvalue
  // We need to select the fastest one that works in this environment.
  // am1: use a single mult and divide to get the high bits,
  // max digit bits should be 26 because
  // max internal value = 2*dvalue^2-2*dvalue (< 2^53)
  function am1(i,x,w,j,c,n) {
    while(--n >= 0) {
      var v = x*this[i++]+w[j]+c;
      c = Math.floor(v/0x4000000);
      w[j++] = v&0x3ffffff;
    }
    return c;
  }
  // am2 avoids a big mult-and-extract completely.
  // Max digit bits should be <= 30 because we do bitwise ops
  // on values up to 2*hdvalue^2-hdvalue-1 (< 2^31)
  function am2(i,x,w,j,c,n) {
    var xl = x&0x7fff, xh = x>>15;
    while(--n >= 0) {
      var l = this[i]&0x7fff;
      var h = this[i++]>>15;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x7fff)<<15)+w[j]+(c&0x3fffffff);
      c = (l>>>30)+(m>>>15)+xh*h+(c>>>30);
      w[j++] = l&0x3fffffff;
    }
    return c;
  }
  // Alternately, set max digit bits to 28 since some
  // browsers slow down when dealing with 32-bit numbers.
  function am3(i,x,w,j,c,n) {
    var xl = x&0x3fff, xh = x>>14;
    while(--n >= 0) {
      var l = this[i]&0x3fff;
      var h = this[i++]>>14;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x3fff)<<14)+w[j]+c;
      c = (l>>28)+(m>>14)+xh*h;
      w[j++] = l&0xfffffff;
    }
    return c;
  }
  if(j_lm && (navigator.appName == "Microsoft Internet Explorer")) {
    BigInteger.prototype.am = am2;
    dbits = 30;
  }
  else if(j_lm && (navigator.appName != "Netscape")) {
    BigInteger.prototype.am = am1;
    dbits = 26;
  }
  else { // Mozilla/Netscape seems to prefer am3
    BigInteger.prototype.am = am3;
    dbits = 28;
  }
  BigInteger.prototype.DB = dbits;
  BigInteger.prototype.DM = ((1<<dbits)-1);
  BigInteger.prototype.DV = (1<<dbits);
  var BI_FP = 52;
  BigInteger.prototype.FV = Math.pow(2,BI_FP);
  BigInteger.prototype.F1 = BI_FP-dbits;
  BigInteger.prototype.F2 = 2*dbits-BI_FP;
  // Digit conversions
  var BI_RM = "0123456789abcdefghijklmnopqrstuvwxyz";
  var BI_RC = new Array();
  var rr,vv;
  rr = "0".charCodeAt(0);
  for(vv = 0; vv <= 9; ++vv) BI_RC[rr++] = vv;
  rr = "a".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  rr = "A".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  function int2char(n) { return BI_RM.charAt(n); }
  function intAt(s,i) {
    var c = BI_RC[s.charCodeAt(i)];
    return (c==null)?-1:c;
  }
  // (protected) copy this to r
  function bnpCopyTo(r) {
    for(var i = this.t-1; i >= 0; --i) r[i] = this[i];
    r.t = this.t;
    r.s = this.s;
  }
  // (protected) set from integer value x, -DV <= x < DV
  function bnpFromInt(x) {
    this.t = 1;
    this.s = (x<0)?-1:0;
    if(x > 0) this[0] = x;
    else if(x < -1) this[0] = x+DV;
    else this.t = 0;
  }
  // return bigint initialized to value
  function nbv(i) { var r = nbi(); r.fromInt(i); return r; }
  // (protected) set from string and radix
  function bnpFromString(s,b) {
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 256) k = 8; // byte array
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else { this.fromRadix(s,b); return; }
    this.t = 0;
    this.s = 0;
    var i = s.length, mi = false, sh = 0;
    while(--i >= 0) {
      var x = (k==8)?s[i]&0xff:intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-") mi = true;
        continue;
      }
      mi = false;
      if(sh == 0)
        this[this.t++] = x;
      else if(sh+k > this.DB) {
        this[this.t-1] |= (x&((1<<(this.DB-sh))-1))<<sh;
        this[this.t++] = (x>>(this.DB-sh));
      }
      else
        this[this.t-1] |= x<<sh;
      sh += k;
      if(sh >= this.DB) sh -= this.DB;
    }
    if(k == 8 && (s[0]&0x80) != 0) {
      this.s = -1;
      if(sh > 0) this[this.t-1] |= ((1<<(this.DB-sh))-1)<<sh;
    }
    this.clamp();
    if(mi) BigInteger.ZERO.subTo(this,this);
  }
  // (protected) clamp off excess high words
  function bnpClamp() {
    var c = this.s&this.DM;
    while(this.t > 0 && this[this.t-1] == c) --this.t;
  }
  // (public) return string representation in given radix
  function bnToString(b) {
    if(this.s < 0) return "-"+this.negate().toString(b);
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else return this.toRadix(b);
    var km = (1<<k)-1, d, m = false, r = "", i = this.t;
    var p = this.DB-(i*this.DB)%k;
    if(i-- > 0) {
      if(p < this.DB && (d = this[i]>>p) > 0) { m = true; r = int2char(d); }
      while(i >= 0) {
        if(p < k) {
          d = (this[i]&((1<<p)-1))<<(k-p);
          d |= this[--i]>>(p+=this.DB-k);
        }
        else {
          d = (this[i]>>(p-=k))&km;
          if(p <= 0) { p += this.DB; --i; }
        }
        if(d > 0) m = true;
        if(m) r += int2char(d);
      }
    }
    return m?r:"0";
  }
  // (public) -this
  function bnNegate() { var r = nbi(); BigInteger.ZERO.subTo(this,r); return r; }
  // (public) |this|
  function bnAbs() { return (this.s<0)?this.negate():this; }
  // (public) return + if this > a, - if this < a, 0 if equal
  function bnCompareTo(a) {
    var r = this.s-a.s;
    if(r != 0) return r;
    var i = this.t;
    r = i-a.t;
    if(r != 0) return (this.s<0)?-r:r;
    while(--i >= 0) if((r=this[i]-a[i]) != 0) return r;
    return 0;
  }
  // returns bit length of the integer x
  function nbits(x) {
    var r = 1, t;
    if((t=x>>>16) != 0) { x = t; r += 16; }
    if((t=x>>8) != 0) { x = t; r += 8; }
    if((t=x>>4) != 0) { x = t; r += 4; }
    if((t=x>>2) != 0) { x = t; r += 2; }
    if((t=x>>1) != 0) { x = t; r += 1; }
    return r;
  }
  // (public) return the number of bits in "this"
  function bnBitLength() {
    if(this.t <= 0) return 0;
    return this.DB*(this.t-1)+nbits(this[this.t-1]^(this.s&this.DM));
  }
  // (protected) r = this << n*DB
  function bnpDLShiftTo(n,r) {
    var i;
    for(i = this.t-1; i >= 0; --i) r[i+n] = this[i];
    for(i = n-1; i >= 0; --i) r[i] = 0;
    r.t = this.t+n;
    r.s = this.s;
  }
  // (protected) r = this >> n*DB
  function bnpDRShiftTo(n,r) {
    for(var i = n; i < this.t; ++i) r[i-n] = this[i];
    r.t = Math.max(this.t-n,0);
    r.s = this.s;
  }
  // (protected) r = this << n
  function bnpLShiftTo(n,r) {
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<cbs)-1;
    var ds = Math.floor(n/this.DB), c = (this.s<<bs)&this.DM, i;
    for(i = this.t-1; i >= 0; --i) {
      r[i+ds+1] = (this[i]>>cbs)|c;
      c = (this[i]&bm)<<bs;
    }
    for(i = ds-1; i >= 0; --i) r[i] = 0;
    r[ds] = c;
    r.t = this.t+ds+1;
    r.s = this.s;
    r.clamp();
  }
  // (protected) r = this >> n
  function bnpRShiftTo(n,r) {
    r.s = this.s;
    var ds = Math.floor(n/this.DB);
    if(ds >= this.t) { r.t = 0; return; }
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<bs)-1;
    r[0] = this[ds]>>bs;
    for(var i = ds+1; i < this.t; ++i) {
      r[i-ds-1] |= (this[i]&bm)<<cbs;
      r[i-ds] = this[i]>>bs;
    }
    if(bs > 0) r[this.t-ds-1] |= (this.s&bm)<<cbs;
    r.t = this.t-ds;
    r.clamp();
  }
  // (protected) r = this - a
  function bnpSubTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]-a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c -= a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c -= a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c -= a.s;
    }
    r.s = (c<0)?-1:0;
    if(c < -1) r[i++] = this.DV+c;
    else if(c > 0) r[i++] = c;
    r.t = i;
    r.clamp();
  }
  // (protected) r = this * a, r != this,a (HAC 14.12)
  // "this" should be the larger one if appropriate.
  function bnpMultiplyTo(a,r) {
    var x = this.abs(), y = a.abs();
    var i = x.t;
    r.t = i+y.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < y.t; ++i) r[i+x.t] = x.am(0,y[i],r,i,0,x.t);
    r.s = 0;
    r.clamp();
    if(this.s != a.s) BigInteger.ZERO.subTo(r,r);
  }
  // (protected) r = this^2, r != this (HAC 14.16)
  function bnpSquareTo(r) {
    var x = this.abs();
    var i = r.t = 2*x.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < x.t-1; ++i) {
      var c = x.am(i,x[i],r,2*i,0,1);
      if((r[i+x.t]+=x.am(i+1,2*x[i],r,2*i+1,c,x.t-i-1)) >= x.DV) {
        r[i+x.t] -= x.DV;
        r[i+x.t+1] = 1;
      }
    }
    if(r.t > 0) r[r.t-1] += x.am(i,x[i],r,2*i,0,1);
    r.s = 0;
    r.clamp();
  }
  // (protected) divide this by m, quotient and remainder to q, r (HAC 14.20)
  // r != q, this != m.  q or r may be null.
  function bnpDivRemTo(m,q,r) {
    var pm = m.abs();
    if(pm.t <= 0) return;
    var pt = this.abs();
    if(pt.t < pm.t) {
      if(q != null) q.fromInt(0);
      if(r != null) this.copyTo(r);
      return;
    }
    if(r == null) r = nbi();
    var y = nbi(), ts = this.s, ms = m.s;
    var nsh = this.DB-nbits(pm[pm.t-1]);	// normalize modulus
    if(nsh > 0) { pm.lShiftTo(nsh,y); pt.lShiftTo(nsh,r); }
    else { pm.copyTo(y); pt.copyTo(r); }
    var ys = y.t;
    var y0 = y[ys-1];
    if(y0 == 0) return;
    var yt = y0*(1<<this.F1)+((ys>1)?y[ys-2]>>this.F2:0);
    var d1 = this.FV/yt, d2 = (1<<this.F1)/yt, e = 1<<this.F2;
    var i = r.t, j = i-ys, t = (q==null)?nbi():q;
    y.dlShiftTo(j,t);
    if(r.compareTo(t) >= 0) {
      r[r.t++] = 1;
      r.subTo(t,r);
    }
    BigInteger.ONE.dlShiftTo(ys,t);
    t.subTo(y,y);	// "negative" y so we can replace sub with am later
    while(y.t < ys) y[y.t++] = 0;
    while(--j >= 0) {
      // Estimate quotient digit
      var qd = (r[--i]==y0)?this.DM:Math.floor(r[i]*d1+(r[i-1]+e)*d2);
      if((r[i]+=y.am(0,qd,r,j,0,ys)) < qd) {	// Try it out
        y.dlShiftTo(j,t);
        r.subTo(t,r);
        while(r[i] < --qd) r.subTo(t,r);
      }
    }
    if(q != null) {
      r.drShiftTo(ys,q);
      if(ts != ms) BigInteger.ZERO.subTo(q,q);
    }
    r.t = ys;
    r.clamp();
    if(nsh > 0) r.rShiftTo(nsh,r);	// Denormalize remainder
    if(ts < 0) BigInteger.ZERO.subTo(r,r);
  }
  // (public) this mod a
  function bnMod(a) {
    var r = nbi();
    this.abs().divRemTo(a,null,r);
    if(this.s < 0 && r.compareTo(BigInteger.ZERO) > 0) a.subTo(r,r);
    return r;
  }
  // Modular reduction using "classic" algorithm
  function Classic(m) { this.m = m; }
  function cConvert(x) {
    if(x.s < 0 || x.compareTo(this.m) >= 0) return x.mod(this.m);
    else return x;
  }
  function cRevert(x) { return x; }
  function cReduce(x) { x.divRemTo(this.m,null,x); }
  function cMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  function cSqrTo(x,r) { x.squareTo(r); this.reduce(r); }
  Classic.prototype.convert = cConvert;
  Classic.prototype.revert = cRevert;
  Classic.prototype.reduce = cReduce;
  Classic.prototype.mulTo = cMulTo;
  Classic.prototype.sqrTo = cSqrTo;
  // (protected) return "-1/this % 2^DB"; useful for Mont. reduction
  // justification:
  //         xy == 1 (mod m)
  //         xy =  1+km
  //   xy(2-xy) = (1+km)(1-km)
  // x[y(2-xy)] = 1-k^2m^2
  // x[y(2-xy)] == 1 (mod m^2)
  // if y is 1/x mod m, then y(2-xy) is 1/x mod m^2
  // should reduce x and y(2-xy) by m^2 at each step to keep size bounded.
  // JS multiply "overflows" differently from C/C++, so care is needed here.
  function bnpInvDigit() {
    if(this.t < 1) return 0;
    var x = this[0];
    if((x&1) == 0) return 0;
    var y = x&3;		// y == 1/x mod 2^2
    y = (y*(2-(x&0xf)*y))&0xf;	// y == 1/x mod 2^4
    y = (y*(2-(x&0xff)*y))&0xff;	// y == 1/x mod 2^8
    y = (y*(2-(((x&0xffff)*y)&0xffff)))&0xffff;	// y == 1/x mod 2^16
    // last step - calculate inverse mod DV directly;
    // assumes 16 < DB <= 32 and assumes ability to handle 48-bit ints
    y = (y*(2-x*y%this.DV))%this.DV;		// y == 1/x mod 2^dbits
    // we really want the negative inverse, and -DV < y < DV
    return (y>0)?this.DV-y:-y;
  }
  // Montgomery reduction
  function Montgomery(m) {
    this.m = m;
    this.mp = m.invDigit();
    this.mpl = this.mp&0x7fff;
    this.mph = this.mp>>15;
    this.um = (1<<(m.DB-15))-1;
    this.mt2 = 2*m.t;
  }
  // xR mod m
  function montConvert(x) {
    var r = nbi();
    x.abs().dlShiftTo(this.m.t,r);
    r.divRemTo(this.m,null,r);
    if(x.s < 0 && r.compareTo(BigInteger.ZERO) > 0) this.m.subTo(r,r);
    return r;
  }
  // x/R mod m
  function montRevert(x) {
    var r = nbi();
    x.copyTo(r);
    this.reduce(r);
    return r;
  }
  // x = x/R mod m (HAC 14.32)
  function montReduce(x) {
    while(x.t <= this.mt2)	// pad x so am has enough room later
      x[x.t++] = 0;
    for(var i = 0; i < this.m.t; ++i) {
      // faster way of calculating u0 = x[i]*mp mod DV
      var j = x[i]&0x7fff;
      var u0 = (j*this.mpl+(((j*this.mph+(x[i]>>15)*this.mpl)&this.um)<<15))&x.DM;
      // use am to combine the multiply-shift-add into one call
      j = i+this.m.t;
      x[j] += this.m.am(0,u0,x,i,0,this.m.t);
      // propagate carry
      while(x[j] >= x.DV) { x[j] -= x.DV; x[++j]++; }
    }
    x.clamp();
    x.drShiftTo(this.m.t,x);
    if(x.compareTo(this.m) >= 0) x.subTo(this.m,x);
  }
  // r = "x^2/R mod m"; x != r
  function montSqrTo(x,r) { x.squareTo(r); this.reduce(r); }
  // r = "xy/R mod m"; x,y != r
  function montMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  Montgomery.prototype.convert = montConvert;
  Montgomery.prototype.revert = montRevert;
  Montgomery.prototype.reduce = montReduce;
  Montgomery.prototype.mulTo = montMulTo;
  Montgomery.prototype.sqrTo = montSqrTo;
  // (protected) true iff this is even
  function bnpIsEven() { return ((this.t>0)?(this[0]&1):this.s) == 0; }
  // (protected) this^e, e < 2^32, doing sqr and mul with "r" (HAC 14.79)
  function bnpExp(e,z) {
    if(e > 0xffffffff || e < 1) return BigInteger.ONE;
    var r = nbi(), r2 = nbi(), g = z.convert(this), i = nbits(e)-1;
    g.copyTo(r);
    while(--i >= 0) {
      z.sqrTo(r,r2);
      if((e&(1<<i)) > 0) z.mulTo(r2,g,r);
      else { var t = r; r = r2; r2 = t; }
    }
    return z.revert(r);
  }
  // (public) this^e % m, 0 <= e < 2^32
  function bnModPowInt(e,m) {
    var z;
    if(e < 256 || m.isEven()) z = new Classic(m); else z = new Montgomery(m);
    return this.exp(e,z);
  }
  // protected
  BigInteger.prototype.copyTo = bnpCopyTo;
  BigInteger.prototype.fromInt = bnpFromInt;
  BigInteger.prototype.fromString = bnpFromString;
  BigInteger.prototype.clamp = bnpClamp;
  BigInteger.prototype.dlShiftTo = bnpDLShiftTo;
  BigInteger.prototype.drShiftTo = bnpDRShiftTo;
  BigInteger.prototype.lShiftTo = bnpLShiftTo;
  BigInteger.prototype.rShiftTo = bnpRShiftTo;
  BigInteger.prototype.subTo = bnpSubTo;
  BigInteger.prototype.multiplyTo = bnpMultiplyTo;
  BigInteger.prototype.squareTo = bnpSquareTo;
  BigInteger.prototype.divRemTo = bnpDivRemTo;
  BigInteger.prototype.invDigit = bnpInvDigit;
  BigInteger.prototype.isEven = bnpIsEven;
  BigInteger.prototype.exp = bnpExp;
  // public
  BigInteger.prototype.toString = bnToString;
  BigInteger.prototype.negate = bnNegate;
  BigInteger.prototype.abs = bnAbs;
  BigInteger.prototype.compareTo = bnCompareTo;
  BigInteger.prototype.bitLength = bnBitLength;
  BigInteger.prototype.mod = bnMod;
  BigInteger.prototype.modPowInt = bnModPowInt;
  // "constants"
  BigInteger.ZERO = nbv(0);
  BigInteger.ONE = nbv(1);
  // jsbn2 stuff
  // (protected) convert from radix string
  function bnpFromRadix(s,b) {
    this.fromInt(0);
    if(b == null) b = 10;
    var cs = this.chunkSize(b);
    var d = Math.pow(b,cs), mi = false, j = 0, w = 0;
    for(var i = 0; i < s.length; ++i) {
      var x = intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-" && this.signum() == 0) mi = true;
        continue;
      }
      w = b*w+x;
      if(++j >= cs) {
        this.dMultiply(d);
        this.dAddOffset(w,0);
        j = 0;
        w = 0;
      }
    }
    if(j > 0) {
      this.dMultiply(Math.pow(b,j));
      this.dAddOffset(w,0);
    }
    if(mi) BigInteger.ZERO.subTo(this,this);
  }
  // (protected) return x s.t. r^x < DV
  function bnpChunkSize(r) { return Math.floor(Math.LN2*this.DB/Math.log(r)); }
  // (public) 0 if this == 0, 1 if this > 0
  function bnSigNum() {
    if(this.s < 0) return -1;
    else if(this.t <= 0 || (this.t == 1 && this[0] <= 0)) return 0;
    else return 1;
  }
  // (protected) this *= n, this >= 0, 1 < n < DV
  function bnpDMultiply(n) {
    this[this.t] = this.am(0,n-1,this,0,0,this.t);
    ++this.t;
    this.clamp();
  }
  // (protected) this += n << w words, this >= 0
  function bnpDAddOffset(n,w) {
    if(n == 0) return;
    while(this.t <= w) this[this.t++] = 0;
    this[w] += n;
    while(this[w] >= this.DV) {
      this[w] -= this.DV;
      if(++w >= this.t) this[this.t++] = 0;
      ++this[w];
    }
  }
  // (protected) convert to radix string
  function bnpToRadix(b) {
    if(b == null) b = 10;
    if(this.signum() == 0 || b < 2 || b > 36) return "0";
    var cs = this.chunkSize(b);
    var a = Math.pow(b,cs);
    var d = nbv(a), y = nbi(), z = nbi(), r = "";
    this.divRemTo(d,y,z);
    while(y.signum() > 0) {
      r = (a+z.intValue()).toString(b).substr(1) + r;
      y.divRemTo(d,y,z);
    }
    return z.intValue().toString(b) + r;
  }
  // (public) return value as integer
  function bnIntValue() {
    if(this.s < 0) {
      if(this.t == 1) return this[0]-this.DV;
      else if(this.t == 0) return -1;
    }
    else if(this.t == 1) return this[0];
    else if(this.t == 0) return 0;
    // assumes 16 < DB < 32
    return ((this[1]&((1<<(32-this.DB))-1))<<this.DB)|this[0];
  }
  // (protected) r = this + a
  function bnpAddTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]+a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c += a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c += a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += a.s;
    }
    r.s = (c<0)?-1:0;
    if(c > 0) r[i++] = c;
    else if(c < -1) r[i++] = this.DV+c;
    r.t = i;
    r.clamp();
  }
  BigInteger.prototype.fromRadix = bnpFromRadix;
  BigInteger.prototype.chunkSize = bnpChunkSize;
  BigInteger.prototype.signum = bnSigNum;
  BigInteger.prototype.dMultiply = bnpDMultiply;
  BigInteger.prototype.dAddOffset = bnpDAddOffset;
  BigInteger.prototype.toRadix = bnpToRadix;
  BigInteger.prototype.intValue = bnIntValue;
  BigInteger.prototype.addTo = bnpAddTo;
  //======= end jsbn =======
  // Emscripten wrapper
  var Wrapper = {
    abs: function(l, h) {
      var x = new goog.math.Long(l, h);
      var ret;
      if (x.isNegative()) {
        ret = x.negate();
      } else {
        ret = x;
      }
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
    },
    ensureTemps: function() {
      if (Wrapper.ensuredTemps) return;
      Wrapper.ensuredTemps = true;
      Wrapper.two32 = new BigInteger();
      Wrapper.two32.fromString('4294967296', 10);
      Wrapper.two64 = new BigInteger();
      Wrapper.two64.fromString('18446744073709551616', 10);
      Wrapper.temp1 = new BigInteger();
      Wrapper.temp2 = new BigInteger();
    },
    lh2bignum: function(l, h) {
      var a = new BigInteger();
      a.fromString(h.toString(), 10);
      var b = new BigInteger();
      a.multiplyTo(Wrapper.two32, b);
      var c = new BigInteger();
      c.fromString(l.toString(), 10);
      var d = new BigInteger();
      c.addTo(b, d);
      return d;
    },
    stringify: function(l, h, unsigned) {
      var ret = new goog.math.Long(l, h).toString();
      if (unsigned && ret[0] == '-') {
        // unsign slowly using jsbn bignums
        Wrapper.ensureTemps();
        var bignum = new BigInteger();
        bignum.fromString(ret, 10);
        ret = new BigInteger();
        Wrapper.two64.addTo(bignum, ret);
        ret = ret.toString(10);
      }
      return ret;
    },
    fromString: function(str, base, min, max, unsigned) {
      Wrapper.ensureTemps();
      var bignum = new BigInteger();
      bignum.fromString(str, base);
      var bigmin = new BigInteger();
      bigmin.fromString(min, 10);
      var bigmax = new BigInteger();
      bigmax.fromString(max, 10);
      if (unsigned && bignum.compareTo(BigInteger.ZERO) < 0) {
        var temp = new BigInteger();
        bignum.addTo(Wrapper.two64, temp);
        bignum = temp;
      }
      var error = false;
      if (bignum.compareTo(bigmin) < 0) {
        bignum = bigmin;
        error = true;
      } else if (bignum.compareTo(bigmax) > 0) {
        bignum = bigmax;
        error = true;
      }
      var ret = goog.math.Long.fromString(bignum.toString()); // min-max checks should have clamped this to a range goog.math.Long can handle well
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
      if (error) throw 'range error';
    }
  };
  return Wrapper;
})();
//======= end closure i64 code =======
// === Auto-generated postamble setup entry stuff ===
Module['callMain'] = function callMain(args) {
  assert(runDependencies == 0, 'cannot call main when async dependencies remain! (listen on __ATMAIN__)');
  assert(!Module['preRun'] || Module['preRun'].length == 0, 'cannot call main when preRun functions remain to be called');
  args = args || [];
  ensureInitRuntime();
  var argc = args.length+1;
  function pad() {
    for (var i = 0; i < 4-1; i++) {
      argv.push(0);
    }
  }
  var argv = [allocate(intArrayFromString("/bin/this.program"), 'i8', ALLOC_NORMAL) ];
  pad();
  for (var i = 0; i < argc-1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), 'i8', ALLOC_NORMAL));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, 'i32', ALLOC_NORMAL);
  var ret;
  var initialStackTop = STACKTOP;
  try {
    ret = Module['_main'](argc, argv, 0);
  }
  catch(e) {
    if (e.name == 'ExitStatus') {
      return e.status;
    } else if (e == 'SimulateInfiniteLoop') {
      Module['noExitRuntime'] = true;
    } else {
      throw e;
    }
  } finally {
    STACKTOP = initialStackTop;
  }
  return ret;
}
function run(args) {
  args = args || Module['arguments'];
  if (runDependencies > 0) {
    Module.printErr('run() called, but dependencies remain, so not running');
    return 0;
  }
  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    var toRun = Module['preRun'];
    Module['preRun'] = [];
    for (var i = toRun.length-1; i >= 0; i--) {
      toRun[i]();
    }
    if (runDependencies > 0) {
      // a preRun added a dependency, run will be called later
      return 0;
    }
  }
  function doRun() {
    ensureInitRuntime();
    preMain();
    var ret = 0;
    calledRun = true;
    if (Module['_main'] && shouldRunNow) {
      ret = Module['callMain'](args);
      if (!Module['noExitRuntime']) {
        exitRuntime();
      }
    }
    if (Module['postRun']) {
      if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
      while (Module['postRun'].length > 0) {
        Module['postRun'].pop()();
      }
    }
    return ret;
  }
  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      if (!ABORT) doRun();
    }, 1);
    return 0;
  } else {
    return doRun();
  }
}
Module['run'] = Module.run = run;
// {{PRE_RUN_ADDITIONS}}
(function() {
function assert(check, msg) {
  if (!check) throw msg + new Error().stack;
}
Module['FS_createPath']('/', 'roms', true, true);
Module['FS_createPath']('/roms', 'rom', true, true);
    function DataRequest() {}
    DataRequest.prototype = {
      requests: {},
      open: function(mode, name) {
        this.requests[name] = this;
      },
      send: function() {}
    };
    var filePreload0 = new DataRequest();
    filePreload0.open('GET', 'roms/cas1.cas', true);
    filePreload0.responseType = 'arraybuffer';
    filePreload0.onload = function() {
      var arrayBuffer = filePreload0.response;
      assert(arrayBuffer, 'Loading file roms/cas1.cas failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms', 'cas1.cas', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/cas1.cas');
      });
    };
    Module['addRunDependency']('fp roms/cas1.cas');
    filePreload0.send(null);
    var filePreload1 = new DataRequest();
    filePreload1.open('GET', 'roms/doswin.img', true);
    filePreload1.responseType = 'arraybuffer';
    filePreload1.onload = function() {
      var arrayBuffer = filePreload1.response;
      assert(arrayBuffer, 'Loading file roms/doswin.img failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms', 'doswin.img', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/doswin.img');
      });
    };
    Module['addRunDependency']('fp roms/doswin.img');
    filePreload1.send(null);
    var filePreload2 = new DataRequest();
    filePreload2.open('GET', 'roms/fd0.img', true);
    filePreload2.responseType = 'arraybuffer';
    filePreload2.onload = function() {
      var arrayBuffer = filePreload2.response;
      assert(arrayBuffer, 'Loading file roms/fd0.img failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms', 'fd0.img', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/fd0.img');
      });
    };
    Module['addRunDependency']('fp roms/fd0.img');
    filePreload2.send(null);
    var filePreload3 = new DataRequest();
    filePreload3.open('GET', 'roms/fd1.pfdc', true);
    filePreload3.responseType = 'arraybuffer';
    filePreload3.onload = function() {
      var arrayBuffer = filePreload3.response;
      assert(arrayBuffer, 'Loading file roms/fd1.pfdc failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms', 'fd1.pfdc', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/fd1.pfdc');
      });
    };
    Module['addRunDependency']('fp roms/fd1.pfdc');
    filePreload3.send(null);
    var filePreload4 = new DataRequest();
    filePreload4.open('GET', 'roms/games.img', true);
    filePreload4.responseType = 'arraybuffer';
    filePreload4.onload = function() {
      var arrayBuffer = filePreload4.response;
      assert(arrayBuffer, 'Loading file roms/games.img failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms', 'games.img', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/games.img');
      });
    };
    Module['addRunDependency']('fp roms/games.img');
    filePreload4.send(null);
    var filePreload5 = new DataRequest();
    filePreload5.open('GET', 'roms/parport1.out', true);
    filePreload5.responseType = 'arraybuffer';
    filePreload5.onload = function() {
      var arrayBuffer = filePreload5.response;
      assert(arrayBuffer, 'Loading file roms/parport1.out failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms', 'parport1.out', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/parport1.out');
      });
    };
    Module['addRunDependency']('fp roms/parport1.out');
    filePreload5.send(null);
    var filePreload6 = new DataRequest();
    filePreload6.open('GET', 'roms/parport2.out', true);
    filePreload6.responseType = 'arraybuffer';
    filePreload6.onload = function() {
      var arrayBuffer = filePreload6.response;
      assert(arrayBuffer, 'Loading file roms/parport2.out failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms', 'parport2.out', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/parport2.out');
      });
    };
    Module['addRunDependency']('fp roms/parport2.out');
    filePreload6.send(null);
    var filePreload7 = new DataRequest();
    filePreload7.open('GET', 'roms/pce-config.cfg', true);
    filePreload7.responseType = 'arraybuffer';
    filePreload7.onload = function() {
      var arrayBuffer = filePreload7.response;
      assert(arrayBuffer, 'Loading file roms/pce-config.cfg failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms', 'pce-config.cfg', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/pce-config.cfg');
      });
    };
    Module['addRunDependency']('fp roms/pce-config.cfg');
    filePreload7.send(null);
    var filePreload8 = new DataRequest();
    filePreload8.open('GET', 'roms/serport1.out', true);
    filePreload8.responseType = 'arraybuffer';
    filePreload8.onload = function() {
      var arrayBuffer = filePreload8.response;
      assert(arrayBuffer, 'Loading file roms/serport1.out failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms', 'serport1.out', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/serport1.out');
      });
    };
    Module['addRunDependency']('fp roms/serport1.out');
    filePreload8.send(null);
    var filePreload9 = new DataRequest();
    filePreload9.open('GET', 'roms/speaker.wav', true);
    filePreload9.responseType = 'arraybuffer';
    filePreload9.onload = function() {
      var arrayBuffer = filePreload9.response;
      assert(arrayBuffer, 'Loading file roms/speaker.wav failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms', 'speaker.wav', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/speaker.wav');
      }, function() { Module['removeRunDependency']('fp roms/speaker.wav') });
    };
    Module['addRunDependency']('fp roms/speaker.wav');
    filePreload9.send(null);
    var filePreload10 = new DataRequest();
    filePreload10.open('GET', 'roms/win3.img', true);
    filePreload10.responseType = 'arraybuffer';
    filePreload10.onload = function() {
      var arrayBuffer = filePreload10.response;
      assert(arrayBuffer, 'Loading file roms/win3.img failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms', 'win3.img', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/win3.img');
      });
    };
    Module['addRunDependency']('fp roms/win3.img');
    filePreload10.send(null);
    var filePreload11 = new DataRequest();
    filePreload11.open('GET', 'roms/rom/basic-1.10.rom', true);
    filePreload11.responseType = 'arraybuffer';
    filePreload11.onload = function() {
      var arrayBuffer = filePreload11.response;
      assert(arrayBuffer, 'Loading file roms/rom/basic-1.10.rom failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms/rom', 'basic-1.10.rom', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/rom/basic-1.10.rom');
      });
    };
    Module['addRunDependency']('fp roms/rom/basic-1.10.rom');
    filePreload11.send(null);
    var filePreload12 = new DataRequest();
    filePreload12.open('GET', 'roms/rom/dtc-hdc-1988-05-31.rom', true);
    filePreload12.responseType = 'arraybuffer';
    filePreload12.onload = function() {
      var arrayBuffer = filePreload12.response;
      assert(arrayBuffer, 'Loading file roms/rom/dtc-hdc-1988-05-31.rom failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms/rom', 'dtc-hdc-1988-05-31.rom', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/rom/dtc-hdc-1988-05-31.rom');
      });
    };
    Module['addRunDependency']('fp roms/rom/dtc-hdc-1988-05-31.rom');
    filePreload12.send(null);
    var filePreload13 = new DataRequest();
    filePreload13.open('GET', 'roms/rom/genoa.rom', true);
    filePreload13.responseType = 'arraybuffer';
    filePreload13.onload = function() {
      var arrayBuffer = filePreload13.response;
      assert(arrayBuffer, 'Loading file roms/rom/genoa.rom failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms/rom', 'genoa.rom', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/rom/genoa.rom');
      });
    };
    Module['addRunDependency']('fp roms/rom/genoa.rom');
    filePreload13.send(null);
    var filePreload14 = new DataRequest();
    filePreload14.open('GET', 'roms/rom/ibm-hdc-1985-10-28.rom', true);
    filePreload14.responseType = 'arraybuffer';
    filePreload14.onload = function() {
      var arrayBuffer = filePreload14.response;
      assert(arrayBuffer, 'Loading file roms/rom/ibm-hdc-1985-10-28.rom failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms/rom', 'ibm-hdc-1985-10-28.rom', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/rom/ibm-hdc-1985-10-28.rom');
      });
    };
    Module['addRunDependency']('fp roms/rom/ibm-hdc-1985-10-28.rom');
    filePreload14.send(null);
    var filePreload15 = new DataRequest();
    filePreload15.open('GET', 'roms/rom/ibm-pc-1982.rom', true);
    filePreload15.responseType = 'arraybuffer';
    filePreload15.onload = function() {
      var arrayBuffer = filePreload15.response;
      assert(arrayBuffer, 'Loading file roms/rom/ibm-pc-1982.rom failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms/rom', 'ibm-pc-1982.rom', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/rom/ibm-pc-1982.rom');
      });
    };
    Module['addRunDependency']('fp roms/rom/ibm-pc-1982.rom');
    filePreload15.send(null);
    var filePreload16 = new DataRequest();
    filePreload16.open('GET', 'roms/rom/ibm-xt-1982.rom', true);
    filePreload16.responseType = 'arraybuffer';
    filePreload16.onload = function() {
      var arrayBuffer = filePreload16.response;
      assert(arrayBuffer, 'Loading file roms/rom/ibm-xt-1982.rom failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms/rom', 'ibm-xt-1982.rom', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/rom/ibm-xt-1982.rom');
      });
    };
    Module['addRunDependency']('fp roms/rom/ibm-xt-1982.rom');
    filePreload16.send(null);
    var filePreload17 = new DataRequest();
    filePreload17.open('GET', 'roms/rom/ibmega.rom', true);
    filePreload17.responseType = 'arraybuffer';
    filePreload17.onload = function() {
      var arrayBuffer = filePreload17.response;
      assert(arrayBuffer, 'Loading file roms/rom/ibmega.rom failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms/rom', 'ibmega.rom', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/rom/ibmega.rom');
      });
    };
    Module['addRunDependency']('fp roms/rom/ibmega.rom');
    filePreload17.send(null);
    var filePreload18 = new DataRequest();
    filePreload18.open('GET', 'roms/rom/ibmpc-pcex.rom', true);
    filePreload18.responseType = 'arraybuffer';
    filePreload18.onload = function() {
      var arrayBuffer = filePreload18.response;
      assert(arrayBuffer, 'Loading file roms/rom/ibmpc-pcex.rom failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms/rom', 'ibmpc-pcex.rom', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/rom/ibmpc-pcex.rom');
      });
    };
    Module['addRunDependency']('fp roms/rom/ibmpc-pcex.rom');
    filePreload18.send(null);
    var filePreload19 = new DataRequest();
    filePreload19.open('GET', 'roms/rom/ibmvga.rom', true);
    filePreload19.responseType = 'arraybuffer';
    filePreload19.onload = function() {
      var arrayBuffer = filePreload19.response;
      assert(arrayBuffer, 'Loading file roms/rom/ibmvga.rom failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms/rom', 'ibmvga.rom', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/rom/ibmvga.rom');
      });
    };
    Module['addRunDependency']('fp roms/rom/ibmvga.rom');
    filePreload19.send(null);
    var filePreload20 = new DataRequest();
    filePreload20.open('GET', 'roms/rom/README', true);
    filePreload20.responseType = 'arraybuffer';
    filePreload20.onload = function() {
      var arrayBuffer = filePreload20.response;
      assert(arrayBuffer, 'Loading file roms/rom/README failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms/rom', 'README', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/rom/README');
      });
    };
    Module['addRunDependency']('fp roms/rom/README');
    filePreload20.send(null);
    var filePreload21 = new DataRequest();
    filePreload21.open('GET', 'roms/rom/sms-hdc-1986.rom', true);
    filePreload21.responseType = 'arraybuffer';
    filePreload21.onload = function() {
      var arrayBuffer = filePreload21.response;
      assert(arrayBuffer, 'Loading file roms/rom/sms-hdc-1986.rom failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms/rom', 'sms-hdc-1986.rom', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/rom/sms-hdc-1986.rom');
      });
    };
    Module['addRunDependency']('fp roms/rom/sms-hdc-1986.rom');
    filePreload21.send(null);
    var filePreload22 = new DataRequest();
    filePreload22.open('GET', 'roms/rom/t9000b-pce.rom', true);
    filePreload22.responseType = 'arraybuffer';
    filePreload22.onload = function() {
      var arrayBuffer = filePreload22.response;
      assert(arrayBuffer, 'Loading file roms/rom/t9000b-pce.rom failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms/rom', 't9000b-pce.rom', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/rom/t9000b-pce.rom');
      });
    };
    Module['addRunDependency']('fp roms/rom/t9000b-pce.rom');
    filePreload22.send(null);
    var filePreload23 = new DataRequest();
    filePreload23.open('GET', 'roms/rom/t9000b.rom', true);
    filePreload23.responseType = 'arraybuffer';
    filePreload23.onload = function() {
      var arrayBuffer = filePreload23.response;
      assert(arrayBuffer, 'Loading file roms/rom/t9000b.rom failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms/rom', 't9000b.rom', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/rom/t9000b.rom');
      });
    };
    Module['addRunDependency']('fp roms/rom/t9000b.rom');
    filePreload23.send(null);
    if (!Module.expectedDataFileDownloads) {
      Module.expectedDataFileDownloads = 0;
      Module.finishedDataFileDownloads = 0;
    }
    Module.expectedDataFileDownloads++;
    var PACKAGE_PATH = window['encodeURIComponent'](window.location.pathname.toString().substring(0, window.location.pathname.toString().lastIndexOf('/')) + '/');
    var PACKAGE_NAME = '/Users/jfriend/dev/jsmac/empce/pce20130508/build/bin/pce-ibmpc.data';
    var REMOTE_PACKAGE_NAME = 'pce-ibmpc.data';
    var PACKAGE_UUID = '4cc5b729-65ba-443e-9841-f9d57c71b875';
    function fetchRemotePackage(packageName, callback, errback) {
      var xhr = new XMLHttpRequest();
      xhr.open('GET', packageName, true);
      xhr.responseType = 'arraybuffer';
      xhr.onprogress = function(event) {
        var url = packageName;
        if (event.loaded && event.total) {
          if (!xhr.addedTotal) {
            xhr.addedTotal = true;
            if (!Module.dataFileDownloads) Module.dataFileDownloads = {};
            Module.dataFileDownloads[url] = {
              loaded: event.loaded,
              total: event.total
            };
          } else {
            Module.dataFileDownloads[url].loaded = event.loaded;
          }
          var total = 0;
          var loaded = 0;
          var num = 0;
          for (var download in Module.dataFileDownloads) {
          var data = Module.dataFileDownloads[download];
            total += data.total;
            loaded += data.loaded;
            num++;
          }
          total = Math.ceil(total * Module.expectedDataFileDownloads/num);
          Module['setStatus']('Downloading data... (' + loaded + '/' + total + ')');
        } else if (!Module.dataFileDownloads) {
          Module['setStatus']('Downloading data...');
        }
      };
      xhr.onload = function(event) {
        var packageData = xhr.response;
        callback(packageData);
      };
      xhr.send(null);
    };
    function processPackageData(arrayBuffer) {
      Module.finishedDataFileDownloads++;
      assert(arrayBuffer, 'Loading data file failed.');
      var byteArray = new Uint8Array(arrayBuffer);
      var curr;
        curr = DataRequest.prototype.requests['roms/cas1.cas'];
        var data = byteArray.subarray(0, 17742);
        var ptr = Module['_malloc'](17742);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 17742);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/doswin.img'];
        var data = byteArray.subarray(17742, 17843534);
        var ptr = Module['_malloc'](17825792);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 17825792);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/fd0.img'];
        var data = byteArray.subarray(17843534, 18212174);
        var ptr = Module['_malloc'](368640);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 368640);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/fd1.pfdc'];
        var data = byteArray.subarray(18212174, 18228855);
        var ptr = Module['_malloc'](16681);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 16681);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/games.img'];
        var data = byteArray.subarray(18228855, 60171895);
        var ptr = Module['_malloc'](41943040);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 41943040);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/parport1.out'];
        var data = byteArray.subarray(60171895, 60171895);
        var ptr = Module['_malloc'](0);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 0);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/parport2.out'];
        var data = byteArray.subarray(60171895, 60171895);
        var ptr = Module['_malloc'](0);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 0);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/pce-config.cfg'];
        var data = byteArray.subarray(60171895, 60187162);
        var ptr = Module['_malloc'](15267);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 15267);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/serport1.out'];
        var data = byteArray.subarray(60187162, 60187162);
        var ptr = Module['_malloc'](0);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 0);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/speaker.wav'];
        var data = byteArray.subarray(60187162, 60187206);
        var ptr = Module['_malloc'](44);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 44);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/win3.img'];
        var data = byteArray.subarray(60187206, 102130246);
        var ptr = Module['_malloc'](41943040);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 41943040);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/rom/basic-1.10.rom'];
        var data = byteArray.subarray(102130246, 102163014);
        var ptr = Module['_malloc'](32768);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 32768);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/rom/dtc-hdc-1988-05-31.rom'];
        var data = byteArray.subarray(102163014, 102171206);
        var ptr = Module['_malloc'](8192);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 8192);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/rom/genoa.rom'];
        var data = byteArray.subarray(102171206, 102187590);
        var ptr = Module['_malloc'](16384);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 16384);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/rom/ibm-hdc-1985-10-28.rom'];
        var data = byteArray.subarray(102187590, 102191686);
        var ptr = Module['_malloc'](4096);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 4096);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/rom/ibm-pc-1982.rom'];
        var data = byteArray.subarray(102191686, 102199878);
        var ptr = Module['_malloc'](8192);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 8192);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/rom/ibm-xt-1982.rom'];
        var data = byteArray.subarray(102199878, 102208070);
        var ptr = Module['_malloc'](8192);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 8192);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/rom/ibmega.rom'];
        var data = byteArray.subarray(102208070, 102224454);
        var ptr = Module['_malloc'](16384);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 16384);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/rom/ibmpc-pcex.rom'];
        var data = byteArray.subarray(102224454, 102226053);
        var ptr = Module['_malloc'](1599);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 1599);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/rom/ibmvga.rom'];
        var data = byteArray.subarray(102226053, 102250629);
        var ptr = Module['_malloc'](24576);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 24576);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/rom/README'];
        var data = byteArray.subarray(102250629, 102251134);
        var ptr = Module['_malloc'](505);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 505);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/rom/sms-hdc-1986.rom'];
        var data = byteArray.subarray(102251134, 102259326);
        var ptr = Module['_malloc'](8192);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 8192);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/rom/t9000b-pce.rom'];
        var data = byteArray.subarray(102259326, 102292094);
        var ptr = Module['_malloc'](32768);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 32768);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/rom/t9000b.rom'];
        var data = byteArray.subarray(102292094, 102324862);
        var ptr = Module['_malloc'](32768);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 32768);
        curr.onload();
                Module['removeRunDependency']('datafile_/Users/jfriend/dev/jsmac/empce/pce20130508/build/bin/pce-ibmpc.data');
    };
    Module['addRunDependency']('datafile_/Users/jfriend/dev/jsmac/empce/pce20130508/build/bin/pce-ibmpc.data');
    function handleError(error) {
      console.error('package error:', error);
    };
    if (!Module.preloadResults)
      Module.preloadResults = {};
      Module.preloadResults[PACKAGE_NAME] = {fromCache: false};
      fetchRemotePackage(REMOTE_PACKAGE_NAME, processPackageData, handleError);
})();
if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}
// shouldRunNow refers to calling main(), not run().
var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}
run();
// {{POST_RUN_ADDITIONS}}
  // {{MODULE_ADDITIONS}}
