// Note: For maximum-speed code, see "Optimizing Code" on the Emscripten wiki, https://github.com/kripken/emscripten/wiki/Optimizing-Code
// Note: Some Emscripten settings may limit the speed of the generated code.
try {
  this['Module'] = Module;
  Module.test;
} catch(e) {
  this['Module'] = Module = {};
}
// The environment setup code below is customized to use Module.
// *** Environment setup code ***
var ENVIRONMENT_IS_NODE = typeof process === 'object' && typeof require === 'function';
var ENVIRONMENT_IS_WEB = typeof window === 'object';
var ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
var ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;
if (ENVIRONMENT_IS_NODE) {
  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  Module['print'] = function(x) {
    process['stdout'].write(x + '\n');
  };
  Module['printErr'] = function(x) {
    process['stderr'].write(x + '\n');
  };
  var nodeFS = require('fs');
  var nodePath = require('path');
  Module['read'] = function(filename, binary) {
    filename = nodePath['normalize'](filename);
    var ret = nodeFS['readFileSync'](filename);
    // The path is absolute if the normalized version is the same as the resolved.
    if (!ret && filename != nodePath['resolve'](filename)) {
      filename = path.join(__dirname, '..', 'src', filename);
      ret = nodeFS['readFileSync'](filename);
    }
    if (ret && !binary) ret = ret.toString();
    return ret;
  };
  Module['readBinary'] = function(filename) { return Module['read'](filename, true) };
  Module['load'] = function(f) {
    globalEval(read(f));
  };
  if (!Module['arguments']) {
    Module['arguments'] = process['argv'].slice(2);
  }
  module.exports = Module;
}
if (ENVIRONMENT_IS_SHELL) {
  Module['print'] = print;
  if (typeof printErr != 'undefined') Module['printErr'] = printErr; // not present in v8 or older sm
  Module['read'] = read;
  Module['readBinary'] = function(f) {
    return read(f, 'binary');
  };
  if (!Module['arguments']) {
    if (typeof scriptArgs != 'undefined') {
      Module['arguments'] = scriptArgs;
    } else if (typeof arguments != 'undefined') {
      Module['arguments'] = arguments;
    }
  }
  this['Module'] = Module;
}
if (ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_WORKER) {
  if (!Module['print']) {
    Module['print'] = function(x) {
      console.log(x);
    };
  }
  if (!Module['printErr']) {
    Module['printErr'] = function(x) {
      console.log(x);
    };
  }
  this['Module'] = Module;
}
if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  Module['read'] = function(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, false);
    xhr.send(null);
    return xhr.responseText;
  };
  if (!Module['arguments']) {
    if (typeof arguments != 'undefined') {
      Module['arguments'] = arguments;
    }
  }
}
if (ENVIRONMENT_IS_WORKER) {
  // We can do very little here...
  var TRY_USE_DUMP = false;
  if (!Module['print']) {
    Module['print'] = (TRY_USE_DUMP && (typeof(dump) !== "undefined") ? (function(x) {
      dump(x);
    }) : (function(x) {
      // self.postMessage(x); // enable this if you want stdout to be sent as messages
    }));
  }
  Module['load'] = importScripts;
}
if (!ENVIRONMENT_IS_WORKER && !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_SHELL) {
  // Unreachable because SHELL is dependant on the others
  throw 'Unknown runtime environment. Where are we?';
}
function globalEval(x) {
  eval.call(null, x);
}
if (!Module['load'] == 'undefined' && Module['read']) {
  Module['load'] = function(f) {
    globalEval(Module['read'](f));
  };
}
if (!Module['print']) {
  Module['print'] = function(){};
}
if (!Module['printErr']) {
  Module['printErr'] = Module['print'];
}
if (!Module['arguments']) {
  Module['arguments'] = [];
}
// *** Environment setup code ***
// Closure helpers
Module.print = Module['print'];
Module.printErr = Module['printErr'];
// Callbacks
if (!Module['preRun']) Module['preRun'] = [];
if (!Module['postRun']) Module['postRun'] = [];
// === Auto-generated preamble library stuff ===
//========================================
// Runtime code shared with compiler
//========================================
var Runtime = {
  stackSave: function () {
    return STACKTOP;
  },
  stackRestore: function (stackTop) {
    STACKTOP = stackTop;
  },
  forceAlign: function (target, quantum) {
    quantum = quantum || 4;
    if (quantum == 1) return target;
    if (isNumber(target) && isNumber(quantum)) {
      return Math.ceil(target/quantum)*quantum;
    } else if (isNumber(quantum) && isPowerOfTwo(quantum)) {
      var logg = log2(quantum);
      return '((((' +target + ')+' + (quantum-1) + ')>>' + logg + ')<<' + logg + ')';
    }
    return 'Math.ceil((' + target + ')/' + quantum + ')*' + quantum;
  },
  isNumberType: function (type) {
    return type in Runtime.INT_TYPES || type in Runtime.FLOAT_TYPES;
  },
  isPointerType: function isPointerType(type) {
  return type[type.length-1] == '*';
},
  isStructType: function isStructType(type) {
  if (isPointerType(type)) return false;
  if (isArrayType(type)) return true;
  if (/<?{ ?[^}]* ?}>?/.test(type)) return true; // { i32, i8 } etc. - anonymous struct types
  // See comment in isStructPointerType()
  return type[0] == '%';
},
  INT_TYPES: {"i1":0,"i8":0,"i16":0,"i32":0,"i64":0},
  FLOAT_TYPES: {"float":0,"double":0},
  or64: function (x, y) {
    var l = (x | 0) | (y | 0);
    var h = (Math.round(x / 4294967296) | Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  and64: function (x, y) {
    var l = (x | 0) & (y | 0);
    var h = (Math.round(x / 4294967296) & Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  xor64: function (x, y) {
    var l = (x | 0) ^ (y | 0);
    var h = (Math.round(x / 4294967296) ^ Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  getNativeTypeSize: function (type, quantumSize) {
    if (Runtime.QUANTUM_SIZE == 1) return 1;
    var size = {
      '%i1': 1,
      '%i8': 1,
      '%i16': 2,
      '%i32': 4,
      '%i64': 8,
      "%float": 4,
      "%double": 8
    }['%'+type]; // add '%' since float and double confuse Closure compiler as keys, and also spidermonkey as a compiler will remove 's from '_i8' etc
    if (!size) {
      if (type.charAt(type.length-1) == '*') {
        size = Runtime.QUANTUM_SIZE; // A pointer
      } else if (type[0] == 'i') {
        var bits = parseInt(type.substr(1));
        assert(bits % 8 == 0);
        size = bits/8;
      }
    }
    return size;
  },
  getNativeFieldSize: function (type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  },
  dedup: function dedup(items, ident) {
  var seen = {};
  if (ident) {
    return items.filter(function(item) {
      if (seen[item[ident]]) return false;
      seen[item[ident]] = true;
      return true;
    });
  } else {
    return items.filter(function(item) {
      if (seen[item]) return false;
      seen[item] = true;
      return true;
    });
  }
},
  set: function set() {
  var args = typeof arguments[0] === 'object' ? arguments[0] : arguments;
  var ret = {};
  for (var i = 0; i < args.length; i++) {
    ret[args[i]] = 0;
  }
  return ret;
},
  STACK_ALIGN: 8,
  getAlignSize: function (type, size, vararg) {
    // we align i64s and doubles on 64-bit boundaries, unlike x86
    if (type == 'i64' || type == 'double' || vararg) return 8;
    if (!type) return Math.min(size, 8); // align structures internally to 64 bits
    return Math.min(size || (type ? Runtime.getNativeFieldSize(type) : 0), Runtime.QUANTUM_SIZE);
  },
  calculateStructAlignment: function calculateStructAlignment(type) {
    type.flatSize = 0;
    type.alignSize = 0;
    var diffs = [];
    var prev = -1;
    type.flatIndexes = type.fields.map(function(field) {
      var size, alignSize;
      if (Runtime.isNumberType(field) || Runtime.isPointerType(field)) {
        size = Runtime.getNativeTypeSize(field); // pack char; char; in structs, also char[X]s.
        alignSize = Runtime.getAlignSize(field, size);
      } else if (Runtime.isStructType(field)) {
        size = Types.types[field].flatSize;
        alignSize = Runtime.getAlignSize(null, Types.types[field].alignSize);
      } else if (field[0] == 'b') {
        // bN, large number field, like a [N x i8]
        size = field.substr(1)|0;
        alignSize = 1;
      } else {
        throw 'Unclear type in struct: ' + field + ', in ' + type.name_ + ' :: ' + dump(Types.types[type.name_]);
      }
      if (type.packed) alignSize = 1;
      type.alignSize = Math.max(type.alignSize, alignSize);
      var curr = Runtime.alignMemory(type.flatSize, alignSize); // if necessary, place this on aligned memory
      type.flatSize = curr + size;
      if (prev >= 0) {
        diffs.push(curr-prev);
      }
      prev = curr;
      return curr;
    });
    type.flatSize = Runtime.alignMemory(type.flatSize, type.alignSize);
    if (diffs.length == 0) {
      type.flatFactor = type.flatSize;
    } else if (Runtime.dedup(diffs).length == 1) {
      type.flatFactor = diffs[0];
    }
    type.needsFlattening = (type.flatFactor != 1);
    return type.flatIndexes;
  },
  generateStructInfo: function (struct, typeName, offset) {
    var type, alignment;
    if (typeName) {
      offset = offset || 0;
      type = (typeof Types === 'undefined' ? Runtime.typeInfo : Types.types)[typeName];
      if (!type) return null;
      if (type.fields.length != struct.length) {
        printErr('Number of named fields must match the type for ' + typeName + ': possibly duplicate struct names. Cannot return structInfo');
        return null;
      }
      alignment = type.flatIndexes;
    } else {
      var type = { fields: struct.map(function(item) { return item[0] }) };
      alignment = Runtime.calculateStructAlignment(type);
    }
    var ret = {
      __size__: type.flatSize
    };
    if (typeName) {
      struct.forEach(function(item, i) {
        if (typeof item === 'string') {
          ret[item] = alignment[i] + offset;
        } else {
          // embedded struct
          var key;
          for (var k in item) key = k;
          ret[key] = Runtime.generateStructInfo(item[key], type.fields[i], alignment[i]);
        }
      });
    } else {
      struct.forEach(function(item, i) {
        ret[item[1]] = alignment[i];
      });
    }
    return ret;
  },
  dynCall: function (sig, ptr, args) {
    if (args && args.length) {
      if (!args.splice) args = Array.prototype.slice.call(args);
      args.splice(0, 0, ptr);
      return Module['dynCall_' + sig].apply(null, args);
    } else {
      return Module['dynCall_' + sig].call(null, ptr);
    }
  },
  functionPointers: [],
  addFunction: function (func) {
    for (var i = 0; i < Runtime.functionPointers.length; i++) {
      if (!Runtime.functionPointers[i]) {
        Runtime.functionPointers[i] = func;
        return 2 + 2*i;
      }
    }
    throw 'Finished up all reserved function pointers. Use a higher value for RESERVED_FUNCTION_POINTERS.';
  },
  removeFunction: function (index) {
    Runtime.functionPointers[(index-2)/2] = null;
  },
  warnOnce: function (text) {
    if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
    if (!Runtime.warnOnce.shown[text]) {
      Runtime.warnOnce.shown[text] = 1;
      Module.printErr(text);
    }
  },
  funcWrappers: {},
  getFuncWrapper: function (func, sig) {
    assert(sig);
    if (!Runtime.funcWrappers[func]) {
      Runtime.funcWrappers[func] = function() {
        return Runtime.dynCall(sig, func, arguments);
      };
    }
    return Runtime.funcWrappers[func];
  },
  UTF8Processor: function () {
    var buffer = [];
    var needed = 0;
    this.processCChar = function (code) {
      code = code & 0xff;
      if (needed) {
        buffer.push(code);
        needed--;
      }
      if (buffer.length == 0) {
        if (code < 128) return String.fromCharCode(code);
        buffer.push(code);
        if (code > 191 && code < 224) {
          needed = 1;
        } else {
          needed = 2;
        }
        return '';
      }
      if (needed > 0) return '';
      var c1 = buffer[0];
      var c2 = buffer[1];
      var c3 = buffer[2];
      var ret;
      if (c1 > 191 && c1 < 224) {
        ret = String.fromCharCode(((c1 & 31) << 6) | (c2 & 63));
      } else {
        ret = String.fromCharCode(((c1 & 15) << 12) | ((c2 & 63) << 6) | (c3 & 63));
      }
      buffer.length = 0;
      return ret;
    }
    this.processJSString = function(string) {
      string = unescape(encodeURIComponent(string));
      var ret = [];
      for (var i = 0; i < string.length; i++) {
        ret.push(string.charCodeAt(i));
      }
      return ret;
    }
  },
  stackAlloc: function (size) { var ret = STACKTOP;STACKTOP = (STACKTOP + size)|0;STACKTOP = ((((STACKTOP)+7)>>3)<<3); return ret; },
  staticAlloc: function (size) { var ret = STATICTOP;STATICTOP = (STATICTOP + size)|0;STATICTOP = ((((STATICTOP)+7)>>3)<<3); return ret; },
  dynamicAlloc: function (size) { var ret = DYNAMICTOP;DYNAMICTOP = (DYNAMICTOP + size)|0;DYNAMICTOP = ((((DYNAMICTOP)+7)>>3)<<3); if (DYNAMICTOP >= TOTAL_MEMORY) enlargeMemory();; return ret; },
  alignMemory: function (size,quantum) { var ret = size = Math.ceil((size)/(quantum ? quantum : 8))*(quantum ? quantum : 8); return ret; },
  makeBigInt: function (low,high,unsigned) { var ret = (unsigned ? ((+(((low)>>>(0))))+((+(((high)>>>(0))))*(+(4294967296)))) : ((+(((low)>>>(0))))+((+(((high)|(0))))*(+(4294967296))))); return ret; },
  GLOBAL_BASE: 8,
  QUANTUM_SIZE: 4,
  __dummy__: 0
}
//========================================
// Runtime essentials
//========================================
var __THREW__ = 0; // Used in checking for thrown exceptions.
var ABORT = false; // whether we are quitting the application. no code should run after this. set in exit() and abort()
var undef = 0;
// tempInt is used for 32-bit signed values or smaller. tempBigInt is used
// for 32-bit unsigned values or more than 32 bits. TODO: audit all uses of tempInt
var tempValue, tempInt, tempBigInt, tempInt2, tempBigInt2, tempPair, tempBigIntI, tempBigIntR, tempBigIntS, tempBigIntP, tempBigIntD;
var tempI64, tempI64b;
var tempRet0, tempRet1, tempRet2, tempRet3, tempRet4, tempRet5, tempRet6, tempRet7, tempRet8, tempRet9;
function abort(text) {
  Module.print(text + ':\n' + (new Error).stack);
  ABORT = true;
  throw "Assertion: " + text;
}
function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}
var globalScope = this;
// C calling interface. A convenient way to call C functions (in C files, or
// defined with extern "C").
//
// Note: LLVM optimizations can inline and remove functions, after which you will not be
//       able to call them. Closure can also do so. To avoid that, add your function to
//       the exports using something like
//
//         -s EXPORTED_FUNCTIONS='["_main", "_myfunc"]'
//
// @param ident      The name of the C function (note that C++ functions will be name-mangled - use extern "C")
// @param returnType The return type of the function, one of the JS types 'number', 'string' or 'array' (use 'number' for any C pointer, and
//                   'array' for JavaScript arrays and typed arrays; note that arrays are 8-bit).
// @param argTypes   An array of the types of arguments for the function (if there are no arguments, this can be ommitted). Types are as in returnType,
//                   except that 'array' is not possible (there is no way for us to know the length of the array)
// @param args       An array of the arguments to the function, as native JS values (as in returnType)
//                   Note that string arguments will be stored on the stack (the JS string will become a C string on the stack).
// @return           The return value, as a native JS value (as in returnType)
function ccall(ident, returnType, argTypes, args) {
  return ccallFunc(getCFunc(ident), returnType, argTypes, args);
}
Module["ccall"] = ccall;
// Returns the C function with a specified identifier (for C++, you need to do manual name mangling)
function getCFunc(ident) {
  try {
    var func = globalScope['Module']['_' + ident]; // closure exported function
    if (!func) func = eval('_' + ident); // explicit lookup
  } catch(e) {
  }
  assert(func, 'Cannot call unknown function ' + ident + ' (perhaps LLVM optimizations or closure removed it?)');
  return func;
}
// Internal function that does a C call using a function, not an identifier
function ccallFunc(func, returnType, argTypes, args) {
  var stack = 0;
  function toC(value, type) {
    if (type == 'string') {
      if (value === null || value === undefined || value === 0) return 0; // null string
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length+1);
      writeStringToMemory(value, ret);
      return ret;
    } else if (type == 'array') {
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length);
      writeArrayToMemory(value, ret);
      return ret;
    }
    return value;
  }
  function fromC(value, type) {
    if (type == 'string') {
      return Pointer_stringify(value);
    }
    assert(type != 'array');
    return value;
  }
  var i = 0;
  var cArgs = args ? args.map(function(arg) {
    return toC(arg, argTypes[i++]);
  }) : [];
  var ret = fromC(func.apply(null, cArgs), returnType);
  if (stack) Runtime.stackRestore(stack);
  return ret;
}
// Returns a native JS wrapper for a C function. This is similar to ccall, but
// returns a function you can call repeatedly in a normal way. For example:
//
//   var my_function = cwrap('my_c_function', 'number', ['number', 'number']);
//   alert(my_function(5, 22));
//   alert(my_function(99, 12));
//
function cwrap(ident, returnType, argTypes) {
  var func = getCFunc(ident);
  return function() {
    return ccallFunc(func, returnType, argTypes, Array.prototype.slice.call(arguments));
  }
}
Module["cwrap"] = cwrap;
// Sets a value in memory in a dynamic way at run-time. Uses the
// type data. This is the same as makeSetValue, except that
// makeSetValue is done at compile-time and generates the needed
// code then, whereas this function picks the right code at
// run-time.
// Note that setValue and getValue only do *aligned* writes and reads!
// Note that ccall uses JS types as for defining types, while setValue and
// getValue need LLVM types ('i8', 'i32') - this is a lower-level operation
function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[(ptr)]=value; break;
      case 'i8': HEAP8[(ptr)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': (tempI64 = [value>>>0,((Math.min((+(Math.floor((value)/(+(4294967296))))), (+(4294967295))))|0)>>>0],HEAP32[((ptr)>>2)]=tempI64[0],HEAP32[(((ptr)+(4))>>2)]=tempI64[1]); break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': HEAPF64[((ptr)>>3)]=value; break;
      default: abort('invalid type for setValue: ' + type);
    }
}
Module['setValue'] = setValue;
// Parallel to setValue.
function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[(ptr)];
      case 'i8': return HEAP8[(ptr)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return HEAPF64[((ptr)>>3)];
      default: abort('invalid type for setValue: ' + type);
    }
  return null;
}
Module['getValue'] = getValue;
var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
var ALLOC_DYNAMIC = 3; // Cannot be freed except through sbrk
var ALLOC_NONE = 4; // Do not allocate
Module['ALLOC_NORMAL'] = ALLOC_NORMAL;
Module['ALLOC_STACK'] = ALLOC_STACK;
Module['ALLOC_STATIC'] = ALLOC_STATIC;
Module['ALLOC_DYNAMIC'] = ALLOC_DYNAMIC;
Module['ALLOC_NONE'] = ALLOC_NONE;
// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
function allocate(slab, types, allocator, ptr) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }
  var singleType = typeof types === 'string' ? types : null;
  var ret;
  if (allocator == ALLOC_NONE) {
    ret = ptr;
  } else {
    ret = [_malloc, Runtime.stackAlloc, Runtime.staticAlloc, Runtime.dynamicAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  }
  if (zeroinit) {
    var ptr = ret, stop;
    assert((ret & 3) == 0);
    stop = ret + (size & ~3);
    for (; ptr < stop; ptr += 4) {
      HEAP32[((ptr)>>2)]=0;
    }
    stop = ret + size;
    while (ptr < stop) {
      HEAP8[((ptr++)|0)]=0;
    }
    return ret;
  }
  if (singleType === 'i8') {
    if (slab.subarray || slab.slice) {
      HEAPU8.set(slab, ret);
    } else {
      HEAPU8.set(new Uint8Array(slab), ret);
    }
    return ret;
  }
  var i = 0, type, typeSize, previousType;
  while (i < size) {
    var curr = slab[i];
    if (typeof curr === 'function') {
      curr = Runtime.getFunctionIndex(curr);
    }
    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }
    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later
    setValue(ret+i, curr, type);
    // no need to look up size unless type changes, so cache it
    if (previousType !== type) {
      typeSize = Runtime.getNativeTypeSize(type);
      previousType = type;
    }
    i += typeSize;
  }
  return ret;
}
Module['allocate'] = allocate;
function Pointer_stringify(ptr, /* optional */ length) {
  // Find the length, and check for UTF while doing so
  var hasUtf = false;
  var t;
  var i = 0;
  while (1) {
    t = HEAPU8[(((ptr)+(i))|0)];
    if (t >= 128) hasUtf = true;
    else if (t == 0 && !length) break;
    i++;
    if (length && i == length) break;
  }
  if (!length) length = i;
  var ret = '';
  if (!hasUtf) {
    var MAX_CHUNK = 1024; // split up into chunks, because .apply on a huge string can overflow the stack
    var curr;
    while (length > 0) {
      curr = String.fromCharCode.apply(String, HEAPU8.subarray(ptr, ptr + Math.min(length, MAX_CHUNK)));
      ret = ret ? ret + curr : curr;
      ptr += MAX_CHUNK;
      length -= MAX_CHUNK;
    }
    return ret;
  }
  var utf8 = new Runtime.UTF8Processor();
  for (i = 0; i < length; i++) {
    t = HEAPU8[(((ptr)+(i))|0)];
    ret += utf8.processCChar(t);
  }
  return ret;
}
Module['Pointer_stringify'] = Pointer_stringify;
// Memory management
var PAGE_SIZE = 4096;
function alignMemoryPage(x) {
  return ((x+4095)>>12)<<12;
}
var HEAP;
var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;
var STATIC_BASE = 0, STATICTOP = 0, staticSealed = false; // static area
var STACK_BASE = 0, STACKTOP = 0, STACK_MAX = 0; // stack area
var DYNAMIC_BASE = 0, DYNAMICTOP = 0; // dynamic area handled by sbrk
function enlargeMemory() {
  abort('Cannot enlarge memory arrays in asm.js. Either (1) compile with -s TOTAL_MEMORY=X with X higher than the current value, or (2) set Module.TOTAL_MEMORY before the program runs.');
}
var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 268435456;
var FAST_MEMORY = Module['FAST_MEMORY'] || 2097152;
// Initialize the runtime's memory
// check for full engine support (use string 'subarray' to avoid closure compiler confusion)
assert(!!Int32Array && !!Float64Array && !!(new Int32Array(1)['subarray']) && !!(new Int32Array(1)['set']),
       'Cannot fallback to non-typed array case: Code is too specialized');
var buffer = new ArrayBuffer(TOTAL_MEMORY);
HEAP8 = new Int8Array(buffer);
HEAP16 = new Int16Array(buffer);
HEAP32 = new Int32Array(buffer);
HEAPU8 = new Uint8Array(buffer);
HEAPU16 = new Uint16Array(buffer);
HEAPU32 = new Uint32Array(buffer);
HEAPF32 = new Float32Array(buffer);
HEAPF64 = new Float64Array(buffer);
// Endianness check (note: assumes compiler arch was little-endian)
HEAP32[0] = 255;
assert(HEAPU8[0] === 255 && HEAPU8[3] === 0, 'Typed arrays 2 must be run on a little-endian system');
Module['HEAP'] = HEAP;
Module['HEAP8'] = HEAP8;
Module['HEAP16'] = HEAP16;
Module['HEAP32'] = HEAP32;
Module['HEAPU8'] = HEAPU8;
Module['HEAPU16'] = HEAPU16;
Module['HEAPU32'] = HEAPU32;
Module['HEAPF32'] = HEAPF32;
Module['HEAPF64'] = HEAPF64;
function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    if (typeof callback == 'function') {
      callback();
      continue;
    }
    var func = callback.func;
    if (typeof func === 'number') {
      if (callback.arg === undefined) {
        Runtime.dynCall('v', func);
      } else {
        Runtime.dynCall('vi', func, [callback.arg]);
      }
    } else {
      func(callback.arg === undefined ? null : callback.arg);
    }
  }
}
var __ATINIT__ = []; // functions called during startup
var __ATMAIN__ = []; // functions called when main() is to be run
var __ATEXIT__ = []; // functions called during shutdown
var runtimeInitialized = false;
function ensureInitRuntime() {
  if (runtimeInitialized) return;
  runtimeInitialized = true;
  callRuntimeCallbacks(__ATINIT__);
}
function preMain() {
  callRuntimeCallbacks(__ATMAIN__);
}
function exitRuntime() {
  callRuntimeCallbacks(__ATEXIT__);
}
// Tools
// This processes a JS string into a C-line array of numbers, 0-terminated.
// For LLVM-originating strings, see parser.js:parseLLVMString function
function intArrayFromString(stringy, dontAddNull, length /* optional */) {
  var ret = (new Runtime.UTF8Processor()).processJSString(stringy);
  if (length) {
    ret.length = length;
  }
  if (!dontAddNull) {
    ret.push(0);
  }
  return ret;
}
Module['intArrayFromString'] = intArrayFromString;
function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}
Module['intArrayToString'] = intArrayToString;
// Write a Javascript array to somewhere in the heap
function writeStringToMemory(string, buffer, dontAddNull) {
  var array = intArrayFromString(string, dontAddNull);
  var i = 0;
  while (i < array.length) {
    var chr = array[i];
    HEAP8[(((buffer)+(i))|0)]=chr
    i = i + 1;
  }
}
Module['writeStringToMemory'] = writeStringToMemory;
function writeArrayToMemory(array, buffer) {
  for (var i = 0; i < array.length; i++) {
    HEAP8[(((buffer)+(i))|0)]=array[i];
  }
}
Module['writeArrayToMemory'] = writeArrayToMemory;
function unSign(value, bits, ignore, sig) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
}
function reSign(value, bits, ignore, sig) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}
if (!Math['imul']) Math['imul'] = function(a, b) {
  var ah  = a >>> 16;
  var al = a & 0xffff;
  var bh  = b >>> 16;
  var bl = b & 0xffff;
  return (al*bl + ((ah*bl + al*bh) << 16))|0;
};
// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// PRE_RUN_ADDITIONS (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyTracking = {};
var calledInit = false, calledRun = false;
var runDependencyWatcher = null;
function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(!runDependencyTracking[id]);
    runDependencyTracking[id] = 1;
  } else {
    Module.printErr('warning: run dependency added without ID');
  }
}
Module['addRunDependency'] = addRunDependency;
function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(runDependencyTracking[id]);
    delete runDependencyTracking[id];
  } else {
    Module.printErr('warning: run dependency removed without ID');
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    } 
    // If run has never been called, and we should call run (INVOKE_RUN is true, and Module.noInitialRun is not false)
    if (!calledRun && shouldRunNow) run();
  }
}
Module['removeRunDependency'] = removeRunDependency;
Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data
function addPreRun(func) {
  if (!Module['preRun']) Module['preRun'] = [];
  else if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
  Module['preRun'].push(func);
}
function loadMemoryInitializer(filename) {
  function applyData(data) {
    HEAPU8.set(data, STATIC_BASE);
  }
  // always do this asynchronously, to keep shell and web as similar as possible
  addPreRun(function() {
    if (ENVIRONMENT_IS_NODE || ENVIRONMENT_IS_SHELL) {
      applyData(Module['readBinary'](filename));
    } else {
      Browser.asyncLoad(filename, function(data) {
        applyData(data);
      }, function(data) {
        throw 'could not load memory initializer ' + filename;
      });
    }
  });
}
// === Body ===
STATIC_BASE = 8;
STATICTOP = STATIC_BASE + 58736;
/* global initializers */ __ATINIT__.push({ func: function() { runPostSets() } });
var _stdout;
var _stdin;
var _stderr;
var _stdout = _stdout=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
var _stdin = _stdin=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
var _stderr = _stderr=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
/* memory initializer */ allocate([0,131,3,0,0,0,0,0,0,130,2,0,0,44,0,0,0,132,4,0,0,4,0,0,0,134,6,0,0,48,0,0,1,132,4,0,0,80,0,0,1,130,2,0,0,46,0,0,1,131,3,0,0,88,0,0,1,134,6,0,0,12,0,0,0,1,2,0,0,24,0,0,0,138,2,0,0,18,0,0,0,129,2,0,0,0,0,0,0,139,2,0,0,20,0,0,0,130,2,0,0,2,0,0,0,2,2,0,0,26,0,0,0,131,2,0,0,4,0,0,0,3,2,0,0,28,0,0,0,132,2,0,0,6,0,0,0,4,2,0,0,30,0,0,0,133,2,0,0,8,0,0,0,5,2,0,0,32,0,0,0,134,2,0,0,10,0,0,0,6,2,0,0,34,0,0,0,135,2,0,0,12,0,0,0,7,2,0,0,36,0,0,0,136,2,0,0,14,0,0,0,8,2,0,0,38,0,0,0,137,2,0,0,16,0,0,1,144,2,0,0,84,0,0,1,135,2,0,0,56,0,0,1,145,2,0,0,86,0,0,1,136,2,0,0,58,0,0,1,146,2,0,0,88,0,0,1,137,2,0,0,60,0,0,1,147,2,0,0,90,0,0,1,138,2,0,0,62,0,0,1,129,2,0,0,22,0,0,1,139,2,0,0,64,0,0,1,130,2,0,0,46,0,0,1,140,2,0,0,66,0,0,1,131,2,0,0,48,0,0,1,141,2,0,0,68,0,0,1,132,2,0,0,50,0,0,1,142,2,0,0,70,0,0,1,133,2,0,0,52,0,0,1,143,2,0,0,72,0,0,1,134,2,0,0,54,0,0,80,0,0,0,0,92,0,0,38,0,0,0,72,0,0,0,8,0,0,0,8,0,0,0,0,160,0,0,192,154,0,0,1,160,0,0,232,201,0,0,2,160,0,0,160,180,0,0,3,160,0,0,112,167,0,0,4,160,0,0,64,153,0,0,5,160,0,0,208,141,0,0,6,160,0,0,136,130,0,0,7,160,0,0,128,122,0,0,8,160,0,0,176,117,0,0,9,160,0,0,8,114,0,0,10,160,0,0,232,214,0,0,11,160,0,0,24,211,0,0,12,160,0,0,248,206,0,0,13,160,0,0,136,204,0,0,14,160,0,0,168,201,0,0,15,160,0,0,184,198,0,0,16,160,0,0,216,195,0,0,17,160,0,0,232,193,0,0,18,160,0,0,0,192,0,0,19,160,0,0,48,190,0,0,20,160,0,0,112,188,0,0,21,160,0,0,120,186,0,0,22,160,0,0,144,183,0,0,23,160,0,0,0,182,0,0,24,160,0,0,136,180,0,0,25,160,0,0,40,179,0,0,26,160,0,0,8,178,0,0,27,160,0,0,232,176,0,0,28,160,0,0,184,175,0,0,29,160,0,0,120,174,0,0,30,160,0,0,64,173,0,0,31,160,0,0,248,171,0,0,32,160,0,0,216,169,0,0,33,160,0,0,128,168,0,0,34,160,0,0,80,167,0,0,35,160,0,0,208,165,0,0,36,160,0,0,184,164,0,0,37,160,0,0,128,163,0,0,38,160,0,0,96,162,0,0,39,160,0,0,240,160,0,0,40,160,0,0,136,159,0,0,41,160,0,0,32,158,0,0,42,160,0,0,240,155,0,0,43,160,0,0,160,154,0,0,44,160,0,0,32,153,0,0,45,160,0,0,16,152,0,0,46,160,0,0,48,151,0,0,47,160,0,0,80,150,0,0,48,160,0,0,88,149,0,0,49,160,0,0,96,148,0,0,50,160,0,0,104,147,0,0,51,160,0,0,0,146,0,0,52,160,0,0,24,144,0,0,53,160,0,0,216,142,0,0,54,160,0,0,176,141,0,0,56,160,0,0,176,140,0,0,57,160,0,0,224,139,0,0,58,160,0,0,248,138,0,0,59,160,0,0,8,138,0,0,60,160,0,0,72,137,0,0,61,160,0,0,56,136,0,0,62,160,0,0,232,134,0,0,63,160,0,0,40,133,0,0,64,160,0,0,208,131,0,0,65,160,0,0,120,130,0,0,66,160,0,0,112,129,0,0,67,160,0,0,64,128,0,0,68,160,0,0,88,127,0,0,69,160,0,0,120,126,0,0,70,160,0,0,216,125,0,0,71,160,0,0,112,125,0,0,72,160,0,0,248,124,0,0,73,160,0,0,200,123,0,0,74,160,0,0,32,123,0,0,75,160,0,0,112,122,0,0,76,160,0,0,0,122,0,0,77,160,0,0,64,121,0,0,78,160,0,0,200,120,0,0,79,160,0,0,88,120,0,0,80,160,0,0,40,120,0,0,84,160,0,0,192,119,0,0,85,160,0,0,112,119,0,0,87,160,0,0,136,118,0,0,88,160,0,0,32,118,0,0,89,160,0,0,168,117,0,0,90,160,0,0,96,117,0,0,93,160,0,0,32,117,0,0,96,160,0,0,232,116,0,0,97,160,0,0,192,116,0,0,98,160,0,0,136,116,0,0,99,160,0,0,48,116,0,0,100,160,0,0,192,115,0,0,101,160,0,0,184,114,0,0,102,160,0,0,80,114,0,0,103,160,0,0,248,113,0,0,104,160,0,0,208,113,0,0,105,160,0,0,160,113,0,0,106,160,0,0,88,113,0,0,110,160,0,0,16,113,0,0,111,160,0,0,192,112,0,0,112,160,0,0,192,216,0,0,113,160,0,0,112,216,0,0,114,160,0,0,144,215,0,0,117,160,0,0,56,215,0,0,118,160,0,0,216,214,0,0,119,160,0,0,168,214,0,0,120,160,0,0,120,214,0,0,121,160,0,0,56,214,0,0,122,160,0,0,16,214,0,0,123,160,0,0,216,213,0,0,124,160,0,0,160,213,0,0,125,160,0,0,128,213,0,0,126,160,0,0,136,212,0,0,127,160,0,0,248,211,0,0,128,160,0,0,72,211,0,0,129,160,0,0,240,210,0,0,130,160,0,0,64,210,0,0,131,160,0,0,160,209,0,0,132,160,0,0,104,209,0,0,144,160,0,0,48,209,0,0,8,168,0,0,232,208,0,0,9,168,0,0,192,208,0,0,10,168,0,0,216,207,0,0,11,168,0,0,120,207,0,0,12,168,0,0,16,207,0,0,13,168,0,0,224,206,0,0,14,168,0,0,168,206,0,0,15,168,0,0,136,206,0,0,16,168,0,0,88,206,0,0,17,168,0,0,48,206,0,0,18,168,0,0,248,205,0,0,19,168,0,0,208,205,0,0,21,168,0,0,120,205,0,0,22,168,0,0,248,204,0,0,23,168,0,0,160,204,0,0,24,168,0,0,104,204,0,0,28,168,0,0,64,204,0,0,31,168,0,0,240,203,0,0,32,168,0,0,192,203,0,0,33,168,0,0,128,203,0,0,38,168,0,0,64,203,0,0,39,168,0,0,32,203,0,0,40,168,0,0,128,202,0,0,43,168,0,0,24,202,0,0,44,168,0,0,192,201,0,0,45,168,0,0,152,201,0,0,46,168,0,0,120,201,0,0,47,168,0,0,88,201,0,0,48,168,0,0,72,201,0,0,49,168,0,0,8,201,0,0,52,168,0,0,216,200,0,0,53,168,0,0,192,200,0,0,55,168,0,0,88,200,0,0,56,168,0,0,144,199,0,0,57,168,0,0,168,198,0,0,58,168,0,0,144,198,0,0,59,168,0,0,64,198,0,0,60,168,0,0,32,198,0,0,61,168,0,0,8,198,0,0,62,168,0,0,240,197,0,0,63,168,0,0,200,197,0,0,64,168,0,0,176,197,0,0,65,168,0,0,16,197,0,0,66,168,0,0,88,196,0,0,67,168,0,0,240,195,0,0,68,168,0,0,200,195,0,0,69,168,0,0,176,195,0,0,70,168,0,0,160,195,0,0,71,168,0,0,136,195,0,0,72,168,0,0,112,195,0,0,73,168,0,0,72,195,0,0,74,168,0,0,56,195,0,0,75,168,0,0,184,194,0,0,77,168,0,0,16,194,0,0,78,168,0,0,248,193,0,0,79,168,0,0,216,193,0,0,80,168,0,0,192,193,0,0,81,168,0,0,176,193,0,0,82,168,0,0,160,193,0,0,83,168,0,0,96,193,0,0,85,168,0,0,64,193,0,0,86,168,0,0,48,193,0,0,88,168,0,0,232,192,0,0,89,168,0,0,64,192,0,0,90,168,0,0,248,191,0,0,91,168,0,0,208,191,0,0,92,168,0,0,176,191,0,0,93,168,0,0,152,191,0,0,94,168,0,0,144,191,0,0,95,168,0,0,136,191,0,0,96,168,0,0,80,191,0,0,97,168,0,0,64,191,0,0,98,168,0,0,128,190,0,0,99,168,0,0,88,190,0,0,100,168,0,0,64,190,0,0,101,168,0,0,24,190,0,0,102,168,0,0,0,190,0,0,103,168,0,0,240,189,0,0,104,168,0,0,208,189,0,0,105,168,0,0,176,189,0,0,106,168,0,0,120,189,0,0,107,168,0,0,112,189,0,0,108,168,0,0,0,189,0,0,109,168,0,0,152,188,0,0,110,168,0,0,120,188,0,0,111,168,0,0,88,188,0,0,112,168,0,0,64,188,0,0,113,168,0,0,40,188,0,0,114,168,0,0,8,188,0,0,115,168,0,0,248,187,0,0,116,168,0,0,208,187,0,0,117,168,0,0,184,187,0,0,118,168,0,0,88,187,0,0,119,168,0,0,248,186,0,0,120,168,0,0,184,186,0,0,121,168,0,0,88,186,0,0,122,168,0,0,208,185,0,0,123,168,0,0,160,185,0,0,124,168,0,0,64,185,0,0,125,168,0,0,240,184,0,0,125,168,0,0,152,184,0,0,126,168,0,0,128,184,0,0,127,168,0,0,48,184,0,0,128,168,0,0,208,183,0,0,129,168,0,0,160,183,0,0,130,168,0,0,128,183,0,0,131,168,0,0,88,183,0,0,132,168,0,0,64,183,0,0,133,168,0,0,40,183,0,0,134,168,0,0,16,183,0,0,135,168,0,0,240,182,0,0,136,168,0,0,200,182,0,0,137,168,0,0,152,182,0,0,138,168,0,0,32,182,0,0,139,168,0,0,8,182,0,0,140,168,0,0,232,181,0,0,141,168,0,0,208,181,0,0,142,168,0,0,168,181,0,0,144,168,0,0,144,181,0,0,145,168,0,0,96,181,0,0,146,168,0,0,72,181,0,0,147,168,0,0,56,181,0,0,148,168,0,0,240,180,0,0,149,168,0,0,168,180,0,0,150,168,0,0,144,180,0,0,151,168,0,0,120,180,0,0,152,168,0,0,96,180,0,0,153,168,0,0,48,180,0,0,154,168,0,0,32,180,0,0,155,168,0,0,24,180,0,0,156,168,0,0,240,179,0,0,157,168,0,0,224,179,0,0,158,168,0,0,168,179,0,0,160,168,0,0,80,179,0,0,161,168,0,0,56,179,0,0,162,168,0,0,8,179,0,0,163,168,0,0,248,178,0,0,164,168,0,0,224,178,0,0,165,168,0,0,208,178,0,0,166,168,0,0,192,178,0,0,167,168,0,0,176,178,0,0,168,168,0,0,160,178,0,0,169,168,0,0,96,178,0,0,170,168,0,0,32,178,0,0,171,168,0,0,16,178,0,0,172,168,0,0,0,178,0,0,173,168,0,0,240,177,0,0,174,168,0,0,224,177,0,0,175,168,0,0,200,177,0,0,177,168,0,0,176,177,0,0,178,168,0,0,152,177,0,0,179,168,0,0,136,177,0,0,180,168,0,0,72,177,0,0,181,168,0,0,248,176,0,0,182,168,0,0,240,176,0,0,183,168,0,0,216,176,0,0,184,168,0,0,200,176,0,0,185,168,0,0,184,176,0,0,186,168,0,0,168,176,0,0,187,168,0,0,152,176,0,0,188,168,0,0,96,176,0,0,189,168,0,0,88,176,0,0,190,168,0,0,48,176,0,0,191,168,0,0,208,175,0,0,192,168,0,0,192,175,0,0,193,168,0,0,168,175,0,0,194,168,0,0,160,175,0,0,195,168,0,0,144,175,0,0,196,168,0,0,80,175,0,0,197,168,0,0,72,175,0,0,198,168,0,0,40,175,0,0,199,168,0,0,24,175,0,0,200,168,0,0,232,174,0,0,201,168,0,0,144,174,0,0,202,168,0,0,128,174,0,0,203,168,0,0,104,174,0,0,204,168,0,0,88,174,0,0,205,168,0,0,72,174,0,0,206,168,0,0,40,174,0,0,207,168,0,0,24,174,0,0,208,168,0,0,224,173,0,0,209,168,0,0,216,173,0,0,210,168,0,0,176,173,0,0,211,168,0,0,96,173,0,0,212,168,0,0,72,173,0,0,213,168,0,0,48,173,0,0,214,168,0,0,40,173,0,0,216,168,0,0,32,173,0,0,217,168,0,0,8,173,0,0,218,168,0,0,0,173,0,0,219,168,0,0,232,172,0,0,220,168,0,0,224,172,0,0,221,168,0,0,192,172,0,0,222,168,0,0,64,172,0,0,223,168,0,0,16,172,0,0,224,168,0,0,232,171,0,0,225,168,0,0,152,171,0,0,226,168,0,0,112,171,0,0,227,168,0,0,240,170,0,0,228,168,0,0,184,170,0,0,229,168,0,0,160,170,0,0,230,168,0,0,136,170,0,0,231,168,0,0,72,170,0,0,232,168,0,0,16,170,0,0,233,168,0,0,232,169,0,0,234,168,0,0,200,169,0,0,235,168,0,0,192,169,0,0,236,168,0,0,152,169,0,0,237,168,0,0,128,169,0,0,238,168,0,0,112,169,0,0,239,168,0,0,88,169,0,0,240,168,0,0,72,169,0,0,241,168,0,0,32,169,0,0,242,168,0,0,192,168,0,0,243,168,0,0,144,168,0,0,244,168,0,0,112,168,0,0,245,168,0,0,96,168,0,0,246,168,0,0,80,168,0,0,248,168,0,0,64,168,0,0,249,168,0,0,32,168,0,0,250,168,0,0,16,168,0,0,251,168,0,0,8,168,0,0,252,168,0,0,208,167,0,0,254,168,0,0,120,167,0,0,255,168,0,0,96,167,0,0,0,169,0,0,72,167,0,0,1,169,0,0,56,167,0,0,2,169,0,0,40,167,0,0,3,169,0,0,248,166,0,0,4,169,0,0,232,166,0,0,5,169,0,0,192,166,0,0,6,169,0,0,176,166,0,0,7,169,0,0,96,166,0,0,8,169,0,0,232,165,0,0,9,169,0,0,224,165,0,0,10,169,0,0,192,165,0,0,11,169,0,0,168,165,0,0,12,169,0,0,152,165,0,0,13,169,0,0,120,165,0,0,14,169,0,0,112,165,0,0,15,169,0,0,96,165,0,0,16,169,0,0,80,165,0,0,17,169,0,0,24,165,0,0,18,169,0,0,216,164,0,0,19,169,0,0,200,164,0,0,20,169,0,0,168,164,0,0,21,169,0,0,136,164,0,0,22,169,0,0,120,164,0,0,23,169,0,0,80,164,0,0,24,169,0,0,56,164,0,0,25,169,0,0,24,164,0,0,26,169,0,0,8,164,0,0,27,169,0,0,232,163,0,0,28,169,0,0,160,163,0,0,29,169,0,0,144,163,0,0,30,169,0,0,112,163,0,0,31,169,0,0,96,163,0,0,32,169,0,0,80,163,0,0,33,169,0,0,48,163,0,0,34,169,0,0,24,163,0,0,35,169,0,0,0,163,0,0,36,169,0,0,200,162,0,0,37,169,0,0,184,162,0,0,38,169,0,0,128,162,0,0,39,169,0,0,112,162,0,0,40,169,0,0,80,162,0,0,41,169,0,0,64,162,0,0,42,169,0,0,48,162,0,0,43,169,0,0,24,162,0,0,44,169,0,0,8,162,0,0,45,169,0,0,208,161,0,0,46,169,0,0,192,161,0,0,47,169,0,0,128,161,0,0,48,169,0,0,16,161,0,0,49,169,0,0,0,161,0,0,50,169,0,0,224,160,0,0,51,169,0,0,208,160,0,0,52,169,0,0,192,160,0,0,53,169,0,0,168,160,0,0,54,169,0,0,152,160,0,0,55,169,0,0,48,160,0,0,56,169,0,0,32,160,0,0,57,169,0,0,0,160,0,0,58,169,0,0,168,159,0,0,59,169,0,0,152,159,0,0,60,169,0,0,120,159,0,0,61,169,0,0,104,159,0,0,62,169,0,0,96,159,0,0,63,169,0,0,72,159,0,0,64,169,0,0,56,159,0,0,65,169,0,0,32,159,0,0,66,169,0,0,16,159,0,0,67,169,0,0,232,158,0,0,68,169,0,0,96,158,0,0,69,169,0,0,48,158,0,0,70,169,0,0,16,158,0,0,71,169,0,0,216,157,0,0,72,169,0,0,144,157,0,0,73,169,0,0,64,157,0,0,74,169,0,0,240,156,0,0,75,169,0,0,176,156,0,0,76,169,0,0,152,156,0,0,77,169,0,0,96,156,0,0,78,169,0,0,40,156,0,0,79,169,0,0,248,155,0,0,80,169,0,0,224,155,0,0,81,169,0,0,208,155,0,0,82,169,0,0,176,155,0,0,83,169,0,0,136,155,0,0,84,169,0,0,120,155,0,0,85,169,0,0,96,155,0,0,86,169,0,0,80,155,0,0,87,169,0,0,40,155,0,0,88,169,0,0,8,155,0,0,89,169,0,0,176,154,0,0,90,169,0,0,144,154,0,0,91,169,0,0,128,154,0,0,92,169,0,0,112,154,0,0,93,169,0,0,72,154,0,0,94,169,0,0,32,154,0,0,95,169,0,0,8,154,0,0,96,169,0,0,248,153,0,0,97,169,0,0,152,153,0,0,98,169,0,0,96,153,0,0,99,169,0,0,48,153,0,0,100,169,0,0,16,153,0,0,101,169,0,0,0,153,0,0,102,169,0,0,240,152,0,0,103,169,0,0,216,152,0,0,104,169,0,0,176,152,0,0,105,169,0,0,144,152,0,0,106,169,0,0,128,152,0,0,107,169,0,0,88,152,0,0,108,169,0,0,48,152,0,0,109,169,0,0,32,152,0,0,110,169,0,0,8,152,0,0,111,169,0,0,0,152,0,0,112,169,0,0,224,151,0,0,113,169,0,0,208,151,0,0,114,169,0,0,192,151,0,0,115,169,0,0,168,151,0,0,116,169,0,0,160,151,0,0,117,169,0,0,128,151,0,0,118,169,0,0,80,151,0,0,119,169,0,0,64,151,0,0,120,169,0,0,32,151,0,0,121,169,0,0,16,151,0,0,122,169,0,0,0,151,0,0,123,169,0,0,232,150,0,0,124,169,0,0,208,150,0,0,125,169,0,0,176,150,0,0,126,169,0,0,160,150,0,0,127,169,0,0,144,150,0,0,128,169,0,0,112,150,0,0,129,169,0,0,96,150,0,0,130,169,0,0,64,150,0,0,131,169,0,0,48,150,0,0,132,169,0,0,32,150,0,0,133,169,0,0,16,150,0,0,134,169,0,0,0,150,0,0,135,169,0,0,232,149,0,0,136,169,0,0,216,149,0,0,137,169,0,0,136,149,0,0,138,169,0,0,120,149,0,0,139,169,0,0,104,149,0,0,140,169,0,0,72,149,0,0,141,169,0,0,56,149,0,0,142,169,0,0,40,149,0,0,143,169,0,0,16,149,0,0,144,169,0,0,0,149,0,0,145,169,0,0,224,148,0,0,146,169,0,0,208,148,0,0,147,169,0,0,184,148,0,0,148,169,0,0,128,148,0,0,149,169,0,0,112,148,0,0,150,169,0,0,72,148,0,0,151,169,0,0,56,148,0,0,152,169,0,0,40,148,0,0,153,169,0,0,16,148,0,0,154,169,0,0,0,148,0,0,155,169,0,0,224,147,0,0,156,169,0,0,208,147,0,0,157,169,0,0,176,147,0,0,158,169,0,0,136,147,0,0,159,169,0,0,120,147,0,0,160,169,0,0,88,147,0,0,161,169,0,0,64,147,0,0,162,169,0,0,48,147,0,0,163,169,0,0,24,147,0,0,164,169,0,0,8,147,0,0,165,169,0,0,200,146,0,0,166,169,0,0,184,146,0,0,167,169,0,0,152,146,0,0,168,169,0,0,64,146,0,0,169,169,0,0,24,146,0,0,170,169,0,0,240,145,0,0,171,169,0,0,184,145,0,0,172,169,0,0,128,145,0,0,173,169,0,0,48,145,0,0,174,169,0,0,0,145,0,0,175,169,0,0,184,144,0,0,176,169,0,0,160,144,0,0,176,169,0,0,104,144,0,0,177,169,0,0,72,144,0,0,178,169,0,0,32,144,0,0,179,169,0,0,8,144,0,0,180,169,0,0,248,143,0,0,181,169,0,0,216,143,0,0,182,169,0,0,192,143,0,0,183,169,0,0,176,143,0,0,184,169,0,0,144,143,0,0,185,169,0,0,128,143,0,0,186,169,0,0,64,143,0,0,187,169,0,0,16,143,0,0,188,169,0,0,224,142,0,0,189,169,0,0,200,142,0,0,190,169,0,0,184,142,0,0,191,169,0,0,168,142,0,0,192,169,0,0,144,142,0,0,193,169,0,0,104,142,0,0,194,169,0,0,88,142,0,0,195,169,0,0,72,142,0,0,196,169,0,0,248,141,0,0,197,169,0,0,216,141,0,0,198,169,0,0,192,141,0,0,199,169,0,0,160,141,0,0,200,169,0,0,152,141,0,0,201,169,0,0,136,141,0,0,203,169,0,0,112,141,0,0,204,169,0,0,104,141,0,0,205,169,0,0,64,141,0,0,206,169,0,0,56,141,0,0,207,169,0,0,8,141,0,0,208,169,0,0,208,140,0,0,209,169,0,0,192,140,0,0,210,169,0,0,168,140,0,0,211,169,0,0,152,140,0,0,212,169,0,0,144,140,0,0,213,169,0,0,104,140,0,0,214,169,0,0,96,140,0,0,215,169,0,0,56,140,0,0,216,169,0,0,40,140,0,0,217,169,0,0,8,140,0,0,218,169,0,0,248,139,0,0,219,169,0,0,240,139,0,0,220,169,0,0,216,139,0,0,221,169,0,0,200,139,0,0,222,169,0,0,184,139,0,0,223,169,0,0,160,139,0,0,224,169,0,0,144,139,0,0,225,169,0,0,120,139,0,0,226,169,0,0,104,139,0,0,227,169,0,0,48,139,0,0,228,169,0,0,24,139,0,0,229,169,0,0,8,139,0,0,230,169,0,0,232,138,0,0,231,169,0,0,224,138,0,0,232,169,0,0,216,138,0,0,233,169,0,0,200,138,0,0,234,169,0,0,192,138,0,0,235,169,0,0,168,138,0,0,235,169,0,0,160,138,0,0,236,169,0,0,80,138,0,0,236,169,0,0,24,138,0,0,237,169,0,0,16,138,0,0,238,169,0,0,0,138,0,0,239,169,0,0,240,137,0,0,240,169,0,0,232,137,0,0,241,169,0,0,208,137,0,0,242,169,0,0,200,137,0,0,243,169,0,0,184,137,0,0,244,169,0,0,168,137,0,0,245,169,0,0,136,137,0,0,246,169,0,0,104,137,0,0,247,169,0,0,88,137,0,0,249,169,0,0,56,137,0,0,250,169,0,0,32,137,0,0,251,169,0,0,16,137,0,0,252,169,0,0,248,136,0,0,253,169,0,0,232,136,0,0,254,169,0,0,184,136,0,0,0,170,0,0,168,136,0,0,1,170,0,0,112,136,0,0,3,170,0,0,88,136,0,0,4,170,0,0,72,136,0,0,5,170,0,0,40,136,0,0,6,170,0,0,24,136,0,0,7,170,0,0,8,136,0,0,8,170,0,0,240,135,0,0,9,170,0,0,224,135,0,0,10,170,0,0,192,135,0,0,11,170,0,0,176,135,0,0,12,170,0,0,88,135,0,0,13,170,0,0,56,135,0,0,14,170,0,0,24,135,0,0,15,170,0,0,216,134,0,0,16,170,0,0,160,134,0,0,17,170,0,0,104,134,0,0,18,170,0,0,56,134,0,0,19,170,0,0,16,134,0,0,20,170,0,0,192,133,0,0,21,170,0,0,168,133,0,0,22,170,0,0,112,133,0,0,23,170,0,0,88,133,0,0,24,170,0,0,56,133,0,0,25,170,0,0,24,133,0,0,26,170,0,0,8,133,0,0,27,170,0,0,232,132,0,0,28,170,0,0,208,132,0,0,29,170,0,0,192,132,0,0,30,170,0,0,120,132,0,0,31,170,0,0,104,132,0,0,33,170,0,0,48,132,0,0,34,170,0,0,24,132,0,0,35,170,0,0,224,131,0,0,36,170,0,0,192,131,0,0,37,170,0,0,176,131,0,0,38,170,0,0,160,131,0,0,39,170,0,0,136,131,0,0,41,170,0,0,80,131,0,0,42,170,0,0,16,131,0,0,43,170,0,0,0,131,0,0,44,170,0,0,200,130,0,0,45,170,0,0,160,130,0,0,46,170,0,0,144,130,0,0,47,170,0,0,104,130,0,0,48,170,0,0,88,130,0,0,49,170,0,0,72,130,0,0,50,170,0,0,48,130,0,0,51,170,0,0,32,130,0,0,52,170,0,0,232,129,0,0,53,170,0,0,216,129,0,0,54,170,0,0,168,129,0,0,55,170,0,0,144,129,0,0,57,170,0,0,128,129,0,0,58,170,0,0,96,129,0,0,59,170,0,0,88,129,0,0,60,170,0,0,72,129,0,0,61,170,0,0,48,129,0,0,62,170,0,0,8,129,0,0,63,170,0,0,200,128,0,0,64,170,0,0,192,128,0,0,65,170,0,0,144,128,0,0,66,170,0,0,112,128,0,0,67,170,0,0,96,128,0,0,68,170,0,0,80,128,0,0,69,170,0,0,48,128,0,0,70,170,0,0,32,128,0,0,71,170,0,0,8,128,0,0,72,170,0,0,248,127,0,0,73,170,0,0,208,127,0,0,74,170,0,0,192,127,0,0,75,170,0,0,144,127,0,0,76,170,0,0,120,127,0,0,77,170,0,0,112,127,0,0,79,170,0,0,96,127,0,0,80,170,0,0,72,127,0,0,96,170,0,0,56,127,0,0,97,170,0,0,32,127,0,0,98,170,0,0,16,127,0,0,99,170,0,0,240,126,0,0,100,170,0,0,224,126,0,0,101,170,0,0,176,126,0,0,102,170,0,0,144,126,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,192,206,0,0,44,0,0,0,104,183,0,0,20,0,0,0,168,169,0,0,80,0,0,0,192,155,0,0,96,0,0,0,232,143,0,0,28,0,0,0,248,132,0,0,88,0,0,0,184,123,0,0,100,0,0,0,120,118,0,0,98,0,0,0,168,114,0,0,6,0,0,0,128,215,0,0,12,0,0,0,48,212,0,0,78,0,0,0,144,207,0,0,32,0,0,0,32,205,0,0,2,0,0,0,40,202,0,0,52,0,0,0,168,199,0,0,102,0,0,0,168,196,0,0,70,0,0,0,24,194,0,0,18,0,0,0,80,192,0,0,82,0,0,0,104,190,0,0,42,0,0,0,176,188,0,0,66,0,0,0,16,187,0,0,10,0,0,0,224,183,0,0,62,0,0,0,0,0,0,0,0,0,0,0,0,43,48,42,47,4,53,41,46,12,58,3,52,25,9,40,45,55,14,11,57,32,30,2,51,28,17,24,8,21,63,39,44,49,5,54,13,59,26,10,56,15,33,31,29,18,22,1,50,6,60,27,16,34,19,23,7,61,35,20,62,36,37,38,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,119,0,0,200,115,0,0,128,216,0,0,80,213,0,0,96,208,0,0,0,0,0,0,83,79,70,84,87,65,82,69,32,80,73,82,65,84,69,83,168,146,0,0,120,144,0,0,80,143,0,0,8,142,0,0,88,227,0,0,24,141,0,0,24,140,0,0,64,139,0,0,96,138,0,0,152,137,0,0,128,136,0,0,104,135,0,0,32,134,0,0,128,133,0,0,56,132,0,0,128,124,0,0,224,130,0,0,184,129,0,0,232,118,0,0,160,128,0,0,160,127,0,0,32,115,0,0,88,227,0,0,192,126,0,0,0,157,0,0,248,125,0,0,136,125,0,0,8,216,0,0,64,125,0,0,0,124,0,0,184,212,0,0,88,227,0,0,80,123,0,0,16,145,0,0,152,122,0,0,136,125,0,0,240,207,0,0,24,122,0,0,88,121,0,0,136,205,0,0,224,120,0,0,112,120,0,0,248,147,0,0,216,197,0,0,168,177,0,0,16,163,0,0,240,148,0,0,216,146,0,0,224,136,0,0,176,125,0,0,224,119,0,0,104,116,0,0,152,227,0,0,200,213,0,0,176,208,0,0,8,206,0,0,80,203,0,0,240,200,0,0,216,197,0,0,120,197,0,0,88,195,0,0,152,227,0,0,88,195,0,0,80,193,0,0,152,227,0,0,96,191,0,0,128,189,0,0,216,187,0,0,168,184,0,0,0,183,0,0,80,181,0,0,248,179,0,0,184,178,0,0,216,197,0,0,96,177,0,0,144,176,0,0,56,175,0,0,240,173,0,0,0,1,59,2,60,40,54,3,61,32,49,41,55,19,35,4,62,52,30,33,50,12,14,42,56,16,27,20,36,23,44,5,63,58,39,53,31,48,18,34,51,29,11,13,15,26,22,43,57,38,47,17,28,10,25,21,37,46,9,24,45,8,7,6,63,0,0,0,80,187,0,0,0,0,0,0,24,184,0,0,98,0,1,0,136,182,0,0,232,180,0,0,128,179,0,0,66,0,2,0,80,178,0,0,56,177,0,0,24,176,0,0,99,0,1,0,208,174,0,0,160,173,0,0,152,172,0,0,100,0,1,0,64,170,0,0,160,173,0,0,248,168,0,0,105,0,1,0,192,167,0,0,160,173,0,0,40,166,0,0,73,0,1,0,0,165,0,0,160,173,0,0,184,163,0,0,108,0,1,0,168,162,0,0,160,173,0,0,80,161,0,0,112,0,1,0,72,209,0,0,160,173,0,0,224,159,0,0,113,0,0,0,176,158,0,0,0,0,0,0,56,156,0,0,114,0,0,0,24,155,0,0,0,0,0,0,112,153,0,0,82,0,0,0,64,152,0,0,0,0,0,0,88,151,0,0,115,0,1,0,128,150,0,0,152,149,0,0,144,148,0,0,116,0,1,0,152,147,0,0,160,173,0,0,80,146,0,0,118,0,0,0,88,144,0,0,0,0,0,0,24,143,0,0,86,0,0,0,232,141,0,0,0,0,0,0,224,140,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,203,0,0,144,203,0,0,104,203,0,0,48,203,0,0,240,202,0,0,32,202,0,0,224,201,0,0,160,201,0,0,136,201,0,0,112,201,0,0,80,201,0,0,16,201,0,0,248,200,0,0,208,200,0,0,112,200,0,0,160,199,0,0,0,199,0,0,160,198,0,0,80,198,0,0,56,198,0,0,24,198,0,0,0,198,0,0,224,197,0,0,192,197,0,0,64,197,0,0,104,196,0,0,24,196,0,0,208,195,0,0,184,195,0,0,168,195,0,0,144,195,0,0,120,195,0,0,64,209,0,0,8,209,0,0,208,208,0,0,48,208,0,0,136,207,0,0,64,207,0,0,240,206,0,0,184,206,0,0,152,206,0,0,104,206,0,0,64,206,0,0,16,206,0,0,224,205,0,0,160,205,0,0,0,205,0,0,200,204,0,0,31,0,0,0,28,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,31,0,0,0,29,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,224,185,0,0,2,0,0,0,88,208,0,0,3,0,0,0,88,184,0,0,4,0,0,0,96,170,0,0,5,0,0,0,128,156,0,0,6,0,0,0,128,144,0,0,7,0,0,0,144,133,0,0,8,0,0,0,40,124,0,0,9,0,0,0,192,118,0,0,10,0,0,0,224,114,0,0,11,0,0,0,200,215,0,0,12,0,0,0,104,212,0,0,13,0,0,0,192,207,0,0,14,0,0,0,88,205,0,0,14,0,0,0,104,202,0,0,15,0,0,0,16,200,0,0,15,0,0,0,216,196,0,0,16,0,0,0,64,194,0,0,17,0,0,0,112,192,0,0,17,0,0,0,168,190,0,0,18,0,0,0,208,188,0,0,19,0,0,0,64,187,0,0,20,0,0,0,8,184,0,0,21,0,0,0,120,182,0,0,22,0,0,0,224,180,0,0,23,0,0,0,112,179,0,0,24,0,0,0,64,178,0,0,25,0,0,0,40,177,0,0,26,0,0,0,8,176,0,0,27,0,0,0,200,174,0,0,28,0,0,0,152,173,0,0,28,0,0,0,136,172,0,0,29,0,0,0,56,170,0,0,29,0,0,0,240,168,0,0,30,0,0,0,176,167,0,0,31,0,0,0,88,166,0,0,32,0,0,0,16,165,0,0,33,0,0,0,224,163,0,0,34,0,0,0,176,162,0,0,35,0,0,0,112,161,0,0,36,0,0,0,248,159,0,0,37,0,0,0,184,158,0,0,38,0,0,0,88,156,0,0,39,0,0,0,32,155,0,0,40,0,0,0,144,153,0,0,41,0,0,0,80,152,0,0,42,0,0,0,112,151,0,0,42,0,0,0,136,150,0,0,43,0,0,0,160,149,0,0,43,0,0,0,168,148,0,0,44,0,0,0,168,147,0,0,45,0,0,0,104,146,0,0,46,0,0,0,96,144,0,0,47,0,0,0,56,143,0,0,48,0,0,0,240,141,0,0,49,0,0,0,0,141,0,0,50,0,0,0,0,140,0,0,51,0,0,0,40,139,0,0,52,0,0,0,72,138,0,0,53,0,0,0,128,137,0,0,54,0,0,0,104,136,0,0,55,0,0,0,72,135,0,0,55,0,0,0,104,133,0,0,56,0,0,0,40,132,0,0,56,0,0,0,184,130,0,0,56,0,0,0,160,129,0,0,57,0,0,0,128,128,0,0,57,0,0,0,136,127,0,0,58,0,0,0,160,126,0,0,58,0,0,0,240,125,0,0,59,0,0,0,128,125,0,0,59,0,0,0,56,125,0,0,60,0,0,0,248,123,0,0,61,0,0,0,72,123,0,0,62,0,0,0,144,122,0,0,63,0,0,0,16,122,0,0,64,0,0,0,80,121,0,0,66,0,0,0,216,120,0,0,65,0,0,0,104,120,0,0,67,0,0,0,64,120,0,0,67,0,0,0,208,119,0,0,68,0,0,0,160,119,0,0,68,0,0,0,184,118,0,0,69,0,0,0,72,118,0,0,69,0,0,0,184,117,0,0,71,0,0,0,112,117,0,0,71,0,0,0,48,117,0,0,73,0,0,0,248,116,0,0,73,0,0,0,208,116,0,0,72,0,0,0,160,116,0,0,72,0,0,0,64,116,0,0,72,0,0,0,232,115,0,0,74,0,0,0,216,114,0,0,75,0,0,0,128,114,0,0,75,0,0,0,16,114,0,0,76,0,0,0,224,113,0,0,77,0,0,0,176,113,0,0,78,0,0,0,104,113,0,0,79,0,0,0,32,113,0,0,79,0,0,0,216,112,0,0,79,0,0,0,208,216,0,0,80,0,0,0,160,216,0,0,81,0,0,0,184,215,0,0,82,0,0,0,88,215,0,0,83,0,0,0,240,214,0,0,84,0,0,0,184,214,0,0,85,0,0,0,136,214,0,0,86,0,0,0,72,214,0,0,87,0,0,0,32,214,0,0,88,0,0,0,240,213,0,0,89,0,0,0,168,213,0,0,90,0,0,0,112,213,0,0,91,0,0,0,96,212,0,0,92,0,0,0,232,211,0,0,93,0,0,0,32,211,0,0,94,0,0,0,184,210,0,0,95,0,0,0,0,210,0,0,96,0,0,0,144,209,0,0,97,0,0,0,88,209,0,0,98,0,0,0,32,209,0,0,99,0,0,0,216,208,0,0,100,0,0,0,160,208,0,0,101,0,0,0,184,207,0,0,102,0,0,0,104,207,0,0,103,0,0,0,8,207,0,0,104,0,0,0,208,206,0,0,105,0,0,0,160,206,0,0,106,0,0,0,120,206,0,0,107,0,0,0,80,206,0,0,108,0,0,0,40,206,0,0,109,0,0,0,232,205,0,0,110,0,0,0,192,205,0,0,111,0,0,0,80,205,0,0,112,0,0,0,240,204,0,0,113,0,0,0,152,204,0,0,114,0,0,0,96,204,0,0,115,0,0,0,48,204,0,0,116,0,0,0,232,203,0,0,117,0,0,0,152,203,0,0,118,0,0,0,120,203,0,0,119,0,0,0,56,203,0,0,120,0,0,0,16,203,0,0,121,0,0,0,96,202,0,0,122,0,0,0,16,202,0,0,123,0,0,0,184,201,0,0,124,0,0,0,144,201,0,0,0,0,0,0,0,0,0,0,86,0,0,0,115,0,0,0,87,0,0,0,62,0,0,0,88,0,0,0,116,0,0,0,90,0,0,0,59,0,0,0,91,0,0,0,87,0,0,0,92,0,0,0,60,0,0,0,93,0,0,0,119,0,0,0,94,0,0,0,61,0,0,0,95,0,0,0,121,0,0,0,97,0,0,0,114,0,0,0,98,0,0,0,117,0,0,0,96,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,86,0,0,0,89,0,0,0,87,0,0,0,91,0,0,0,88,0,0,0,92,0,0,0,90,0,0,0,86,0,0,0,91,0,0,0,87,0,0,0,92,0,0,0,88,0,0,0,93,0,0,0,83,0,0,0,94,0,0,0,84,0,0,0,95,0,0,0,85,0,0,0,97,0,0,0,82,0,0,0,98,0,0,0,65,0,0,0,96,0,0,0,76,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,53,0,0,0,2,0,0,0,122,0,0,0,3,0,0,0,120,0,0,0,4,0,0,0,99,0,0,0,5,0,0,0,118,0,0,0,6,0,0,0,96,0,0,0,7,0,0,0,97,0,0,0,8,0,0,0,98,0,0,0,9,0,0,0,100,0,0,0,10,0,0,0,101,0,0,0,11,0,0,0,109,0,0,0,12,0,0,0,103,0,0,0,13,0,0,0,111,0,0,0,17,0,0,0,50,0,0,0,18,0,0,0,18,0,0,0,19,0,0,0,19,0,0,0,20,0,0,0,20,0,0,0,21,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,23,0,0,0,22,0,0,0,24,0,0,0,26,0,0,0,25,0,0,0,28,0,0,0,26,0,0,0,25,0,0,0,27,0,0,0,29,0,0,0,28,0,0,0,27,0,0,0,29,0,0,0,24,0,0,0,30,0,0,0,51,0,0,0,31,0,0,0,48,0,0,0,32,0,0,0,12,0,0,0,33,0,0,0,13,0,0,0,34,0,0,0,14,0,0,0,35,0,0,0,15,0,0,0,36,0,0,0,17,0,0,0,37,0,0,0,16,0,0,0,38,0,0,0,32,0,0,0,39,0,0,0,34,0,0,0,40,0,0,0,31,0,0,0,41,0,0,0,35,0,0,0,42,0,0,0,33,0,0,0,43,0,0,0,30,0,0,0,57,0,0,0,42,0,0,0,45,0,0,0,57,0,0,0,46,0,0,0,0,0,0,0,47,0,0,0,1,0,0,0,48,0,0,0,2,0,0,0,49,0,0,0,3,0,0,0,50,0,0,0,5,0,0,0,51,0,0,0,4,0,0,0,52,0,0,0,38,0,0,0,53,0,0,0,40,0,0,0,54,0,0,0,37,0,0,0,55,0,0,0,41,0,0,0,56,0,0,0,39,0,0,0,44,0,0,0,36,0,0,0,58,0,0,0,56,0,0,0,60,0,0,0,6,0,0,0,61,0,0,0,7,0,0,0,62,0,0,0,8,0,0,0,63,0,0,0,9,0,0,0,64,0,0,0,11,0,0,0,66,0,0,0,45,0,0,0,65,0,0,0,46,0,0,0,67,0,0,0,43,0,0,0,68,0,0,0,47,0,0,0,69,0,0,0,44,0,0,0,70,0,0,0,56,0,0,0,71,0,0,0,54,0,0,0,72,0,0,0,58,0,0,0,74,0,0,0,58,0,0,0,75,0,0,0,55,0,0,0,76,0,0,0,49,0,0,0,77,0,0,0,55,0,0,0,81,0,0,0,54,0,0,0,99,0,0,0,114,0,0,0,100,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,102,0,0,0,117,0,0,0,103,0,0,0,119,0,0,0,104,0,0,0,121,0,0,0,105,0,0,0,62,0,0,0,106,0,0,0,59,0,0,0,108,0,0,0,60,0,0,0,107,0,0,0,61,0,0,0,82,0,0,0,71,0,0,0,83,0,0,0,75,0,0,0,84,0,0,0,67,0,0,0,86,0,0,0,89,0,0,0,87,0,0,0,91,0,0,0,88,0,0,0,92,0,0,0,85,0,0,0,78,0,0,0,90,0,0,0,86,0,0,0,91,0,0,0,87,0,0,0,92,0,0,0,88,0,0,0,89,0,0,0,69,0,0,0,93,0,0,0,83,0,0,0,94,0,0,0,84,0,0,0,95,0,0,0,85,0,0,0,96,0,0,0,76,0,0,0,97,0,0,0,82,0,0,0,98,0,0,0,65,0,0,0,0,0,0,0,0,0,0,0,27,0,0,0,1,0,0,0,58,4,0,0,2,0,0,0,59,4,0,0,3,0,0,0,60,4,0,0,4,0,0,0,61,4,0,0,5,0,0,0,62,4,0,0,6,0,0,0,63,4,0,0,7,0,0,0,64,4,0,0,8,0,0,0,65,4,0,0,9,0,0,0,66,4,0,0,10,0,0,0,67,4,0,0,11,0,0,0,68,4,0,0,12,0,0,0,69,4,0,0,13,0,0,0,70,4,0,0,14,0,0,0,71,4,0,0,15,0,0,0,72,4,0,0,16,0,0,0,96,0,0,0,17,0,0,0,49,0,0,0,18,0,0,0,50,0,0,0,19,0,0,0,51,0,0,0,20,0,0,0,52,0,0,0,21,0,0,0,53,0,0,0,22,0,0,0,54,0,0,0,23,0,0,0,55,0,0,0,24,0,0,0,56,0,0,0,25,0,0,0,57,0,0,0,26,0,0,0,48,0,0,0,27,0,0,0,45,0,0,0,28,0,0,0,61,0,0,0,29,0,0,0,8,0,0,0,30,0,0,0,9,0,0,0,31,0,0,0,113,0,0,0,32,0,0,0,119,0,0,0,33,0,0,0,101,0,0,0,34,0,0,0,114,0,0,0,35,0,0,0,116,0,0,0,36,0,0,0,121,0,0,0,37,0,0,0,117,0,0,0,38,0,0,0,105,0,0,0,39,0,0,0,111,0,0,0,40,0,0,0,112,0,0,0,41,0,0,0,91,0,0,0,42,0,0,0,93,0,0,0,43,0,0,0,13,0,0,0,44,0,0,0,57,4,0,0,45,0,0,0,97,0,0,0,46,0,0,0,115,0,0,0,47,0,0,0,100,0,0,0,48,0,0,0,102,0,0,0,49,0,0,0,103,0,0,0,50,0,0,0,104,0,0,0,51,0,0,0,106,0,0,0,52,0,0,0,107,0,0,0,53,0,0,0,108,0,0,0,54,0,0,0,59,0,0,0,55,0,0,0,39,0,0,0,56,0,0,0,92,0,0,0,57,0,0,0,225,4,0,0,58,0,0,0,60,0,0,0,59,0,0,0,122,0,0,0,60,0,0,0,120,0,0,0,61,0,0,0,99,0,0,0,62,0,0,0,118,0,0,0,63,0,0,0,98,0,0,0,64,0,0,0,110,0,0,0,66,0,0,0,109,0,0,0,65,0,0,0,44,0,0,0,67,0,0,0,46,0,0,0,68,0,0,0,47,0,0,0,69,0,0,0,229,4,0,0,70,0,0,0,224,4,0,0,71,0,0,0,227,4,0,0,73,0,0,0,227,4,0,0,72,0,0,0,226,4,0,0,75,0,0,0,1,5,0,0,74,0,0,0,32,0,0,0,76,0,0,0,230,4,0,0,77,0,0,0,231,4,0,0,78,0,0,0,231,4,0,0,79,0,0,0,118,4,0,0,80,0,0,0,228,4,0,0,81,0,0,0,83,4,0,0,82,0,0,0,84,4,0,0,83,0,0,0,85,4,0,0,84,0,0,0,86,4,0,0,85,0,0,0,95,4,0,0,86,0,0,0,96,4,0,0,87,0,0,0,97,4,0,0,88,0,0,0,87,4,0,0,89,0,0,0,92,4,0,0,90,0,0,0,93,4,0,0,91,0,0,0,94,4,0,0,92,0,0,0,89,4,0,0,93,0,0,0,90,4,0,0,94,0,0,0,91,4,0,0,95,0,0,0,88,4,0,0,96,0,0,0,98,4,0,0,97,0,0,0,99,4,0,0,98,0,0,0,73,4,0,0,99,0,0,0,74,4,0,0,100,0,0,0,75,4,0,0,101,0,0,0,127,0,0,0,102,0,0,0,77,4,0,0,103,0,0,0,78,4,0,0,104,0,0,0].concat([82,4,0,0,105,0,0,0,80,4,0,0,106,0,0,0,81,4,0,0,107,0,0,0,79,4,0,0,108,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,1,0,101,0,0,0,0,0,0,0,1,0,229,0,0,0,0,0,0,0,18,0,0,0,1,0,37,0,0,0,0,0,0,0,1,0,165,0,0,0,0,0,0,0,19,0,0,0,1,0,39,0,0,0,0,0,0,0,1,0,167,0,0,0,0,0,0,0,20,0,0,0,1,0,41,0,0,0,0,0,0,0,1,0,169,0,0,0,0,0,0,0,21,0,0,0,1,0,43,0,0,0,0,0,0,0,1,0,171,0,0,0,0,0,0,0,22,0,0,0,1,0,47,0,0,0,0,0,0,0,1,0,175,0,0,0,0,0,0,0,23,0,0,0,1,0,45,0,0,0,0,0,0,0,1,0,173,0,0,0,0,0,0,0,24,0,0,0,1,0,53,0,0,0,0,0,0,0,1,0,181,0,0,0,0,0,0,0,25,0,0,0,1,0,57,0,0,0,0,0,0,0,1,0,185,0,0,0,0,0,0,0,26,0,0,0,1,0,51,0,0,0,0,0,0,0,1,0,179,0,0,0,0,0,0,0,27,0,0,0,1,0,59,0,0,0,0,0,0,0,1,0,187,0,0,0,0,0,0,0,28,0,0,0,1,0,55,0,0,0,0,0,0,0,1,0,183,0,0,0,0,0,0,0,29,0,0,0,1,0,49,0,0,0,0,0,0,0,1,0,177,0,0,0,0,0,0,0,30,0,0,0,1,0,103,0,0,0,0,0,0,0,1,0,231,0,0,0,0,0,0,0,31,0,0,0,1,0,97,0,0,0,0,0,0,0,1,0,225,0,0,0,0,0,0,0,32,0,0,0,1,0,25,0,0,0,0,0,0,0,1,0,153,0,0,0,0,0,0,0,33,0,0,0,1,0,27,0,0,0,0,0,0,0,1,0,155,0,0,0,0,0,0,0,34,0,0,0,1,0,29,0,0,0,0,0,0,0,1,0,157,0,0,0,0,0,0,0,35,0,0,0,1,0,31,0,0,0,0,0,0,0,1,0,159,0,0,0,0,0,0,0,36,0,0,0,1,0,35,0,0,0,0,0,0,0,1,0,163,0,0,0,0,0,0,0,37,0,0,0,1,0,33,0,0,0,0,0,0,0,1,0,161,0,0,0,0,0,0,0,38,0,0,0,1,0,65,0,0,0,0,0,0,0,1,0,193,0,0,0,0,0,0,0,39,0,0,0,1,0,69,0,0,0,0,0,0,0,1,0,197,0,0,0,0,0,0,0,40,0,0,0,1,0,63,0,0,0,0,0,0,0,1,0,191,0,0,0,0,0,0,0,41,0,0,0,1,0,71,0,0,0,0,0,0,0,1,0,199,0,0,0,0,0,0,0,42,0,0,0,1,0,67,0,0,0,0,0,0,0,1,0,195,0,0,0,0,0,0,0,43,0,0,0,1,0,61,0,0,0,0,0,0,0,1,0,189,0,0,0,0,0,0,0,57,0,0,0,1,0,85,0,0,0,0,0,0,0,1,0,213,0,0,0,0,0,0,0,44,0,0,0,1,0,73,0,0,0,0,0,0,0,1,0,201,0,0,0,0,0,0,0,45,0,0,0,1,0,115,0,0,0,0,0,0,0,1,0,243,0,0,0,0,0,0,0,46,0,0,0,1,0,1,0,0,0,0,0,0,0,1,0,129,0,0,0,0,0,0,0,47,0,0,0,1,0,3,0,0,0,0,0,0,0,1,0,131,0,0,0,0,0,0,0,48,0,0,0,1,0,5,0,0,0,0,0,0,0,1,0,133,0,0,0,0,0,0,0,49,0,0,0,1,0,7,0,0,0,0,0,0,0,1,0,135,0,0,0,0,0,0,0,50,0,0,0,1,0,11,0,0,0,0,0,0,0,1,0,139,0,0,0,0,0,0,0,51,0,0,0,1,0,9,0,0,0,0,0,0,0,1,0,137,0,0,0,0,0,0,0,52,0,0,0,1,0,77,0,0,0,0,0,0,0,1,0,205,0,0,0,0,0,0,0,53,0,0,0,1,0,81,0,0,0,0,0,0,0,1,0,209,0,0,0,0,0,0,0,54,0,0,0,1,0,75,0,0,0,0,0,0,0,1,0,203,0,0,0,0,0,0,0,55,0,0,0,1,0,83,0,0,0,0,0,0,0,1,0,211,0,0,0,0,0,0,0,56,0,0,0,1,0,79,0,0,0,0,0,0,0,1,0,207,0,0,0,0,0,0,0,58,0,0,0,1,0,113,0,0,0,0,0,0,0,1,0,241,0,0,0,0,0,0,0,70,0,0,0,1,0,113,0,0,0,0,0,0,0,1,0,241,0,0,0,0,0,0,0,60,0,0,0,1,0,13,0,0,0,0,0,0,0,1,0,141,0,0,0,0,0,0,0,61,0,0,0,1,0,15,0,0,0,0,0,0,0,1,0,143,0,0,0,0,0,0,0,62,0,0,0,1,0,17,0,0,0,0,0,0,0,1,0,145,0,0,0,0,0,0,0,63,0,0,0,1,0,19,0,0,0,0,0,0,0,1,0,147,0,0,0,0,0,0,0,64,0,0,0,1,0,23,0,0,0,0,0,0,0,1,0,151,0,0,0,0,0,0,0,66,0,0,0,1,0,91,0,0,0,0,0,0,0,1,0,219,0,0,0,0,0,0,0,65,0,0,0,1,0,93,0,0,0,0,0,0,0,1,0,221,0,0,0,0,0,0,0,67,0,0,0,1,0,87,0,0,0,0,0,0,0,1,0,215,0,0,0,0,0,0,0,68,0,0,0,1,0,95,0,0,0,0,0,0,0,1,0,223,0,0,0,0,0,0,0,69,0,0,0,1,0,89,0,0,0,0,0,0,0,1,0,217,0,0,0,0,0,0,0,71,0,0,0,1,0,117,0,0,0,0,0,0,0,1,0,245,0,0,0,0,0,0,0,81,0,0,0,1,0,117,0,0,0,0,0,0,0,1,0,245,0,0,0,0,0,0,0,75,0,0,0,1,0,111,0,0,0,0,0,0,0,1,0,239,0,0,0,0,0,0,0,77,0,0,0,1,0,105,0,0,0,0,0,0,0,1,0,233,0,0,0,0,0,0,0,76,0,0,0,1,0,99,0,0,0,0,0,0,0,1,0,227,0,0,0,0,0,0,0,82,0,0,0,2,0,121,15,0,0,0,0,0,0,2,0,121,143,0,0,0,0,0,0,83,0,0,0,3,0,113,121,27,0,0,0,0,0,3,0,121,155,241,0,0,0,0,0,84,0,0,0,3,0,113,121,5,0,0,0,0,0,3,0,121,133,241,0,0,0,0,0,85,0,0,0,2,0,121,29,0,0,0,0,0,0,2,0,121,157,0,0,0,0,0,0,86,0,0,0,2,0,121,51,0,0,0,0,0,0,2,0,121,179,0,0,0,0,0,0,87,0,0,0,2,0,121,55,0,0,0,0,0,0,2,0,121,183,0,0,0,0,0,0,88,0,0,0,2,0,121,57,0,0,0,0,0,0,2,0,121,185,0,0,0,0,0,0,89,0,0,0,3,0,113,121,13,0,0,0,0,0,3,0,121,141,241,0,0,0,0,0,90,0,0,0,2,0,121,45,0,0,0,0,0,0,2,0,121,173,0,0,0,0,0,0,91,0,0,0,2,0,121,47,0,0,0,0,0,0,2,0,121,175,0,0,0,0,0,0,92,0,0,0,2,0,121,49,0,0,0,0,0,0,2,0,121,177,0,0,0,0,0,0,93,0,0,0,2,0,121,39,0,0,0,0,0,0,2,0,121,167,0,0,0,0,0,0,94,0,0,0,2,0,121,41,0,0,0,0,0,0,2,0,121,169,0,0,0,0,0,0,95,0,0,0,2,0,121,43,0,0,0,0,0,0,2,0,121,171,0,0,0,0,0,0,96,0,0,0,2,0,121,25,0,0,0,0,0,0,2,0,121,153,0,0,0,0,0,0,97,0,0,0,2,0,121,37,0,0,0,0,0,0,2,0,121,165,0,0,0,0,0,0,98,0,0,0,2,0,121,3,0,0,0,0,0,0,2,0,121,131,0,0,0,0,0,0,105,0,0,0,2,0,121,27,0,0,0,0,0,0,2,0,121,155,0,0,0,0,0,0,106,0,0,0,2,0,121,13,0,0,0,0,0,0,2,0,121,141,0,0,0,0,0,0,108,0,0,0,2,0,121,5,0,0,0,0,0,0,2,0,121,133,0,0,0,0,0,0,107,0,0,0,2,0,121,17,0,0,0,0,0,0,2,0,121,145,0,0,0,0,0,0,100,0,0,0,2,0,121,103,0,0,0,0,0,0,2,0,121,231,0,0,0,0,0,0,103,0,0,0,2,0,121,111,0,0,0,0,0,0,2,0,121,239,0,0,0,0,0,0,101,0,0,0,2,0,121,105,0,0,0,0,0,0,2,0,121,233,0,0,0,0,0,0,104,0,0,0,2,0,121,115,0,0,0,0,0,0,2,0,121,243,0,0,0,0,0,0,99,0,0,0,2,0,121,101,0,0,0,0,0,0,2,0,121,101,0,0,0,0,0,0,102,0,0,0,2,0,121,107,0,0,0,0,0,0,2,0,121,235,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,1,0,101,0,0,0,0,0,0,0,1,0,229,0,0,0,0,0,0,0,18,0,0,0,1,0,39,0,0,0,0,0,0,0,1,0,167,0,0,0,0,0,0,0,19,0,0,0,1,0,39,0,0,0,0,0,0,0,1,0,167,0,0,0,0,0,0,0,20,0,0,0,1,0,41,0,0,0,0,0,0,0,1,0,169,0,0,0,0,0,0,0,21,0,0,0,1,0,43,0,0,0,0,0,0,0,1,0,171,0,0,0,0,0,0,0,22,0,0,0,1,0,47,0,0,0,0,0,0,0,1,0,175,0,0,0,0,0,0,0,23,0,0,0,1,0,45,0,0,0,0,0,0,0,1,0,173,0,0,0,0,0,0,0,24,0,0,0,1,0,53,0,0,0,0,0,0,0,1,0,181,0,0,0,0,0,0,0,25,0,0,0,1,0,57,0,0,0,0,0,0,0,1,0,185,0,0,0,0,0,0,0,26,0,0,0,1,0,51,0,0,0,0,0,0,0,1,0,179,0,0,0,0,0,0,0,27,0,0,0,1,0,59,0,0,0,0,0,0,0,1,0,187,0,0,0,0,0,0,0,28,0,0,0,1,0,55,0,0,0,0,0,0,0,1,0,183,0,0,0,0,0,0,0,29,0,0,0,1,0,49,0,0,0,0,0,0,0,1,0,177,0,0,0,0,0,0,0,30,0,0,0,1,0,103,0,0,0,0,0,0,0,1,0,231,0,0,0,0,0,0,0,31,0,0,0,1,0,97,0,0,0,0,0,0,0,1,0,225,0,0,0,0,0,0,0,32,0,0,0,1,0,25,0,0,0,0,0,0,0,1,0,153,0,0,0,0,0,0,0,33,0,0,0,1,0,27,0,0,0,0,0,0,0,1,0,155,0,0,0,0,0,0,0,34,0,0,0,1,0,29,0,0,0,0,0,0,0,1,0,157,0,0,0,0,0,0,0,35,0,0,0,1,0,31,0,0,0,0,0,0,0,1,0,159,0,0,0,0,0,0,0,36,0,0,0,1,0,35,0,0,0,0,0,0,0,1,0,163,0,0,0,0,0,0,0,37,0,0,0,1,0,33,0,0,0,0,0,0,0,1,0,161,0,0,0,0,0,0,0,38,0,0,0,1,0,65,0,0,0,0,0,0,0,1,0,193,0,0,0,0,0,0,0,39,0,0,0,1,0,69,0,0,0,0,0,0,0,1,0,197,0,0,0,0,0,0,0,40,0,0,0,1,0,63,0,0,0,0,0,0,0,1,0,191,0,0,0,0,0,0,0,41,0,0,0,1,0,71,0,0,0,0,0,0,0,1,0,199,0,0,0,0,0,0,0,42,0,0,0,1,0,67,0,0,0,0,0,0,0,1,0,195,0,0,0,0,0,0,0,43,0,0,0,1,0,61,0,0,0,0,0,0,0,1,0,189,0,0,0,0,0,0,0,44,0,0,0,1,0,85,0,0,0,0,0,0,0,1,0,213,0,0,0,0,0,0,0,45,0,0,0,1,0,115,0,0,0,0,0,0,0,1,0,243,0,0,0,0,0,0,0,46,0,0,0,1,0,1,0,0,0,0,0,0,0,1,0,129,0,0,0,0,0,0,0,47,0,0,0,1,0,3,0,0,0,0,0,0,0,1,0,131,0,0,0,0,0,0,0,48,0,0,0,1,0,5,0,0,0,0,0,0,0,1,0,133,0,0,0,0,0,0,0,49,0,0,0,1,0,7,0,0,0,0,0,0,0,1,0,135,0,0,0,0,0,0,0,50,0,0,0,1,0,11,0,0,0,0,0,0,0,1,0,139,0,0,0,0,0,0,0,51,0,0,0,1,0,9,0,0,0,0,0,0,0,1,0,137,0,0,0,0,0,0,0,52,0,0,0,1,0,77,0,0,0,0,0,0,0,1,0,205,0,0,0,0,0,0,0,53,0,0,0,1,0,81,0,0,0,0,0,0,0,1,0,209,0,0,0,0,0,0,0,54,0,0,0,1,0,75,0,0,0,0,0,0,0,1,0,203,0,0,0,0,0,0,0,55,0,0,0,1,0,83,0,0,0,0,0,0,0,1,0,211,0,0,0,0,0,0,0,56,0,0,0,1,0,79,0,0,0,0,0,0,0,1,0,207,0,0,0,0,0,0,0,57,0,0,0,1,0,73,0,0,0,0,0,0,0,1,0,201,0,0,0,0,0,0,0,58,0,0,0,1,0,113,0,0,0,0,0,0,0,1,0,241,0,0,0,0,0,0,0,70,0,0,0,1,0,113,0,0,0,0,0,0,0,1,0,241,0,0,0,0,0,0,0,59,0,0,0,1,0,13,0,0,0,0,0,0,0,1,0,141,0,0,0,0,0,0,0,60,0,0,0,1,0,15,0,0,0,0,0,0,0,1,0,143,0,0,0,0,0,0,0,61,0,0,0,1,0,17,0,0,0,0,0,0,0,1,0,145,0,0,0,0,0,0,0,62,0,0,0,1,0,19,0,0,0,0,0,0,0,1,0,147,0,0,0,0,0,0,0,63,0,0,0,1,0,23,0,0,0,0,0,0,0,1,0,151,0,0,0,0,0,0,0,64,0,0,0,1,0,91,0,0,0,0,0,0,0,1,0,219,0,0,0,0,0,0,0,66,0,0,0,1,0,93,0,0,0,0,0,0,0,1,0,221,0,0,0,0,0,0,0,65,0,0,0,1,0,87,0,0,0,0,0,0,0,1,0,215,0,0,0,0,0,0,0,67,0,0,0,1,0,95,0,0,0,0,0,0,0,1,0,223,0,0,0,0,0,0,0,68,0,0,0,1,0,89,0,0,0,0,0,0,0,1,0,217,0,0,0,0,0,0,0,69,0,0,0,1,0,21,0,0,0,0,0,0,0,1,0,149,0,0,0,0,0,0,0,71,0,0,0,1,0,117,0,0,0,0,0,0,0,1,0,245,0,0,0,0,0,0,0,81,0,0,0,1,0,117,0,0,0,0,0,0,0,1,0,245,0,0,0,0,0,0,0,75,0,0,0,1,0,111,0,0,0,0,0,0,0,1,0,239,0,0,0,0,0,0,0,77,0,0,0,1,0,99,0,0,0,0,0,0,0,1,0,227,0,0,0,0,0,0,0,76,0,0,0,1,0,105,0,0,0,0,0,0,0,1,0,233,0,0,0,0,0,0,0,82,0,0,0,2,0,121,15,0,0,0,0,0,0,2,0,121,143,0,0,0,0,0,0,83,0,0,0,3,0,113,121,27,0,0,0,0,0,3,0,121,155,241,0,0,0,0,0,84,0,0,0,3,0,113,121,5,0,0,0,0,0,3,0,121,133,241,0,0,0,0,0,85,0,0,0,2,0,121,29,0,0,0,0,0,0,2,0,121,157,0,0,0,0,0,0,86,0,0,0,2,0,121,51,0,0,0,0,0,0,2,0,121,179,0,0,0,0,0,0,87,0,0,0,2,0,121,55,0,0,0,0,0,0,2,0,121,183,0,0,0,0,0,0,88,0,0,0,2,0,121,57,0,0,0,0,0,0,2,0,121,185,0,0,0,0,0,0,89,0,0,0,3,0,113,121,13,0,0,0,0,0,3,0,121,141,241,0,0,0,0,0,90,0,0,0,2,0,121,45,0,0,0,0,0,0,2,0,121,173,0,0,0,0,0,0,91,0,0,0,2,0,121,47,0,0,0,0,0,0,2,0,121,175,0,0,0,0,0,0,92,0,0,0,2,0,121,49,0,0,0,0,0,0,2,0,121,177,0,0,0,0,0,0,93,0,0,0,2,0,121,39,0,0,0,0,0,0,2,0,121,167,0,0,0,0,0,0,94,0,0,0,2,0,121,41,0,0,0,0,0,0,2,0,121,169,0,0,0,0,0,0,95,0,0,0,2,0,121,43,0,0,0,0,0,0,2,0,121,171,0,0,0,0,0,0,96,0,0,0,2,0,121,25,0,0,0,0,0,0,2,0,121,153,0,0,0,0,0,0,97,0,0,0,2,0,121,37,0,0,0,0,0,0,2,0,121,165,0,0,0,0,0,0,98,0,0,0,2,0,121,3,0,0,0,0,0,0,2,0,121,131,0,0,0,0,0,0,105,0,0,0,2,0,121,27,0,0,0,0,0,0,2,0,121,155,0,0,0,0,0,0,106,0,0,0,2,0,121,13,0,0,0,0,0,0,2,0,121,141,0,0,0,0,0,0,108,0,0,0,2,0,121,5,0,0,0,0,0,0,2,0,121,133,0,0,0,0,0,0,107,0,0,0,2,0,121,17,0,0,0,0,0,0,2,0,121,145,0,0,0,0,0,0,100,0,0,0,2,0,121,103,0,0,0,0,0,0,2,0,121,231,0,0,0,0,0,0,103,0,0,0,2,0,121,111,0,0,0,0,0,0,2,0,121,239,0,0,0,0,0,0,101,0,0,0,2,0,121,105,0,0,0,0,0,0,2,0,121,233,0,0,0,0,0,0,104,0,0,0,2,0,121,115,0,0,0,0,0,0,2,0,121,243,0,0,0,0,0,0,99,0,0,0,2,0,121,101,0,0,0,0,0,0,2,0,121,229,0,0,0,0,0,0,102,0,0,0,2,0,121,107,0,0,0,0,0,0,2,0,121,235,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,86,0,0,0,2,0,121,51,0,0,0,0,0,0,2,0,121,179,0,0,0,0,0,0,87,0,0,0,2,0,121,55,0,0,0,0,0,0,2,0,121,183,0,0,0,0,0,0,88,0,0,0,2,0,121,57,0,0,0,0,0,0,2,0,121,185,0,0,0,0,0,0,90,0,0,0,2,0,121,45,0,0,0,0,0,0,2,0,121,173,0,0,0,0,0,0,91,0,0,0,2,0,121,47,0,0,0,0,0,0,2,0,121,175,0,0,0,0,0,0,92,0,0,0,2,0,121,49,0,0,0,0,0,0,2,0,121,177,0,0,0,0,0,0,93,0,0,0,2,0,121,39,0,0,0,0,0,0,2,0,121,167,0,0,0,0,0,0,94,0,0,0,2,0,121,41,0,0,0,0,0,0,2,0,121,169,0,0,0,0,0,0,95,0,0,0,2,0,121,43,0,0,0,0,0,0,2,0,121,171,0,0,0,0,0,0,97,0,0,0,2,0,121,37,0,0,0,0,0,0,2,0,121,165,0,0,0,0,0,0,98,0,0,0,2,0,121,3,0,0,0,0,0,0,2,0,121,131,0,0,0,0,0,0,96,0,0,0,2,0,121,25,0,0,0,0,0,0,2,0,121,153,0,0,0,0,0,0,100,0,0,0,2,0,121,103,0,0,0,0,0,0,2,0,121,231,0,0,0,0,0,0,105,0,0,0,2,0,121,27,0,0,0,0,0,0,2,0,121,155,0,0,0,0,0,0,101,0,0,0,2,0,121,105,0,0,0,0,0,0,2,0,121,233,0,0,0,0,0,0,106,0,0,0,2,0,121,13,0,0,0,0,0,0,2,0,121,141,0,0,0,0,0,0,108,0,0,0,2,0,121,5,0,0,0,0,0,0,2,0,121,133,0,0,0,0,0,0,103,0,0,0,2,0,121,111,0,0,0,0,0,0,2,0,121,239,0,0,0,0,0,0,107,0,0,0,2,0,121,17,0,0,0,0,0,0,2,0,121,145,0,0,0,0,0,0,104,0,0,0,2,0,121,115,0,0,0,0,0,0,2,0,121,243,0,0,0,0,0,0,99,0,0,0,2,0,121,101,0,0,0,0,0,0,2,0,121,101,0,0,0,0,0,0,102,0,0,0,2,0,121,107,0,0,0,0,0,0,2,0,121,235,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,86,0,0,0,2,0,121,103,0,0,0,0,0,0,2,0,121,231,0,0,0,0,0,0,87,0,0,0,2,0,121,27,0,0,0,0,0,0,2,0,121,155,0,0,0,0,0,0,88,0,0,0,2,0,121,105,0,0,0,0,0,0,2,0,121,233,0,0,0,0,0,0,90,0,0,0,2,0,121,13,0,0,0,0,0,0,2,0,121,141,0,0,0,0,0,0,91,0,0,0,2,0,121,25,0,0,0,0,0,0,2,0,121,153,0,0,0,0,0,0,92,0,0,0,2,0,121,5,0,0,0,0,0,0,2,0,121,133,0,0,0,0,0,0,93,0,0,0,2,0,121,111,0,0,0,0,0,0,2,0,121,239,0,0,0,0,0,0,94,0,0,0,2,0,121,17,0,0,0,0,0,0,2,0,121,145,0,0,0,0,0,0,95,0,0,0,2,0,121,115,0,0,0,0,0,0,2,0,121,243,0,0,0,0,0,0,97,0,0,0,2,0,121,101,0,0,0,0,0,0,2,0,121,101,0,0,0,0,0,0,98,0,0,0,2,0,121,107,0,0,0,0,0,0,2,0,121,235,0,0,0,0,0,0,96,0,0,0,1,0,73,0,0,0,0,0,0,0,1,0,201,0,0,0,0,0,0,0,100,0,0,0,2,0,121,51,0,0,0,0,0,0,2,0,121,179,0,0,0,0,0,0,105,0,0,0,2,0,121,55,0,0,0,0,0,0,2,0,121,183,0,0,0,0,0,0,101,0,0,0,2,0,121,57,0,0,0,0,0,0,2,0,121,185,0,0,0,0,0,0,106,0,0,0,2,0,121,45,0,0,0,0,0,0,2,0,121,173,0,0,0,0,0,0,108,0,0,0,2,0,121,49,0,0,0,0,0,0,2,0,121,177,0,0,0,0,0,0,103,0,0,0,2,0,121,39,0,0,0,0,0,0,2,0,121,167,0,0,0,0,0,0,107,0,0,0,2,0,121,41,0,0,0,0,0,0,2,0,121,169,0,0,0,0,0,0,104,0,0,0,2,0,121,43,0,0,0,0,0,0,2,0,121,171,0,0,0,0,0,0,99,0,0,0,2,0,121,37,0,0,0,0,0,0,2,0,121,165,0,0,0,0,0,0,102,0,0,0,2,0,121,3,0,0,0,0,0,0,2,0,121,131,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,230,41,1,0,14,17,1,0,52,248,0,0,102,223,0,0,150,198,0,0,0,0,0,0,230,41,1,0,14,17,1,0,52,248,0,0,102,223,0,0,150,198,0,0,0,0,0,0,150,151,154,155,157,158,159,166,167,171,172,173,174,175,178,179,180,181,182,183,185,186,187,188,189,190,191,203,205,206,207,211,214,215,217,218,219,220,221,222,223,229,230,231,233,234,235,236,237,238,239,242,243,244,245,246,247,249,250,251,252,253,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,1,255,255,2,3,255,4,5,6,255,255,255,255,255,255,7,8,255,255,255,9,10,11,12,13,255,255,14,15,16,17,18,19,255,20,21,22,23,24,25,26,255,255,255,255,255,255,255,255,255,255,255,27,255,28,29,30,255,255,255,31,255,255,32,33,255,34,35,36,37,38,39,40,255,255,255,255,255,41,42,43,255,44,45,46,47,48,49,50,255,255,51,52,53,54,55,56,255,57,58,59,60,61,62,63,132,1,0,0,84,1,0,0,150,1,0,0,0,0,0,0,148,0,0,0,102,0,0,0,10,1,0,0,30,0,0,0,158,0,0,0,86,0,0,0,44,0,0,0,0,0,0,0,148,0,0,0,102,0,0,0,10,1,0,0,30,0,0,0,124,1,0,0,74,1,0,0,114,0,0,0,0,0,0,0,148,0,0,0,102,0,0,0,10,1,0,0,30,0,0,0,248,0,0,0,32,1,0,0,72,1,0,0,0,0,0,0,148,0,0,0,102,0,0,0,10,1,0,0,30,0,0,0,78,0,0,0,130,0,0,0,120,1,0,0,228,0,0,0,148,0,0,0,102,0,0,0,10,1,0,0,30,0,0,0,240,0,0,0,190,0,0,0,64,1,0,0,0,0,0,0,148,0,0,0,102,0,0,0,10,1,0,0,30,0,0,0,92,0,0,0,46,0,0,0,146,1,0,0,0,0,0,0,148,0,0,0,102,0,0,0,10,1,0,0,30,0,0,0,86,1,0,0,140,1,0,0,150,0,0,0,0,0,0,0,148,0,0,0,102,0,0,0,10,1,0,0,30,0,0,0,132,0,0,0,0,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,0,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,0,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,0,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,0,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,0,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,0,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,0,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,132,0,0,0,218,0,0,0,8,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,8,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,8,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,8,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,8,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,8,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,8,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,8,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,218,0,0,0,50,1,0,0,122,0,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,122,0,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,122,0,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,122,0,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,122,0,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,122,0,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,122,0,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,122,0,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,50,1,0,0,12,0,0,0,68,1,0,0,112,0,0,0,52,0,0,0,0,0,0,0,0,0,0,0,164,0,0,0,222,0,0,0,244,0,0,0,30,1,0,0,98,1,0,0,96,0,0,0,0,0,0,0,0,0,0,0,164,0,0,0,222,0,0,0,40,1,0,0,78,1,0,0,144,1,0,0,22,0,0,0,0,0,0,0,0,0,0,0,164,0,0,0,222,0,0,0,154,0,0,0,116,0,0,0,40,0,0,0,252,0,0,0,0,0,0,0,0,0,0,0,164,0,0,0,222,0,0,0,198,0,0,0,142,0,0,0,90,0,0,0,6,1,0,0,0,0,0,0,0,0,0,0,164,0,0,0,134,1,0,0,20,0,0,0,94,0,0,0,232,0,0,0,136,1,0,0,0,0,0,0,0,0,0,0,164,0,0,0,222,0,0,0,0,0,0,0,0,0,0,0,148,1,0,0,110,1,0,0,0,0,0,0,0,0,0,0,164,0,0,0,222,0,0,0,0,0,0,0,8,1,0,0,26,0,0,0,12,1,0,0,0,0,0,0,0,0,0,0,164,0,0,0,222,0,0,0,254,0,0,0,202,0,0,0,144,0,0,0,54,0,0,0,106,1,0,0,54,1,0,0,0,1,0,0,126,0,0,0,254,0,0,0,202,0,0,0,144,0,0,0,14,1,0,0,106,1,0,0,54,1,0,0,0,1,0,0,230,0,0,0,254,0,0,0,202,0,0,0,144,0,0,0,162,0,0,0,106,1,0,0,54,1,0,0,0,1,0,0,242,0,0,0,254,0,0,0,202,0,0,0,144,0,0,0,92,1,0,0,106,1,0,0,54,1,0,0,0,1,0,0,66,1,0,0,254,0,0,0,202,0,0,0,144,0,0,0,18,1,0,0,106,1,0,0,54,1,0,0,0,1,0,0,44,1,0,0,254,0,0,0,202,0,0,0,144,0,0,0,76,0,0,0,106,1,0,0,54,1,0,0,0,1,0,0,184,0,0,0,254,0,0,0,202,0,0,0,144,0,0,0,160,0,0,0,106,1,0,0,54,1,0,0,0,1,0,0,108,0,0,0,254,0,0,0,202,0,0,0,144,0,0,0,186,0,0,0,106,1,0,0,54,1,0,0,0,1,0,0,48,1,0,0,96,1,0,0,96,1,0,0,96,1,0,0,96,1,0,0,236,0,0,0,236,0,0,0,236,0,0,0,236,0,0,0,110,0,0,0,110,0,0,0,110,0,0,0,110,0,0,0,112,1,0,0,112,1,0,0,112,1,0,0,112,1,0,0,72,0,0,0,72,0,0,0,72,0,0,0,72,0,0,0,80,1,0,0,80,1,0,0,80,1,0,0,80,1,0,0,224,0,0,0,224,0,0,0,224,0,0,0,224,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,102,1,0,0,102,1,0,0,102,1,0,0,102,1,0,0,250,0,0,0,250,0,0,0,250,0,0,0,250,0,0,0,118,0,0,0,118,0,0,0,118,0,0,0,118,0,0,0,134,0,0,0,134,0,0,0,134,0,0,0,134,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,16,1,0,0,16,1,0,0,16,1,0,0,16,1,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,0,0,0,2,1,0,0,106,0,0,0,52,1,0,0,74,0,0,0,24,0,0,0,118,1,0,0,108,1,0,0,206,0,0,0,2,1,0,0,106,0,0,0,52,1,0,0,74,0,0,0,24,0,0,0,118,1,0,0,108,1,0,0,206,0,0,0,2,1,0,0,106,0,0,0,52,1,0,0,74,0,0,0,24,0,0,0,118,1,0,0,108,1,0,0,206,0,0,0,2,1,0,0,106,0,0,0,52,1,0,0,74,0,0,0,24,0,0,0,118,1,0,0,108,1,0,0,206,0,0,0,2,1,0,0,106,0,0,0,52,1,0,0,74,0,0,0,24,0,0,0,118,1,0,0,108,1,0,0,206,0,0,0,2,1,0,0,106,0,0,0,52,1,0,0,74,0,0,0,24,0,0,0,118,1,0,0,108,1,0,0,206,0,0,0,2,1,0,0,106,0,0,0,52,1,0,0,74,0,0,0,24,0,0,0,118,1,0,0,108,1,0,0,206,0,0,0,2,1,0,0,106,0,0,0,52,1,0,0,74,0,0,0,24,0,0,0,118,1,0,0,108,1,0,0,88,1,0,0,142,1,0,0,42,0,0,0,192,0,0,0,68,0,0,0,124,0,0,0,176,0,0,0,168,0,0,0,88,1,0,0,142,1,0,0,42,0,0,0,192,0,0,0,68,0,0,0,124,0,0,0,176,0,0,0,168,0,0,0,88,1,0,0,142,1,0,0,42,0,0,0,192,0,0,0,68,0,0,0,124,0,0,0,176,0,0,0,168,0,0,0,88,1,0,0,142,1,0,0,42,0,0,0,192,0,0,0,68,0,0,0,124,0,0,0,176,0,0,0,168,0,0,0,88,1,0,0,142,1,0,0,42,0,0,0,192,0,0,0,68,0,0,0,124,0,0,0,176,0,0,0,168,0,0,0,88,1,0,0,142,1,0,0,42,0,0,0,192,0,0,0,68,0,0,0,124,0,0,0,176,0,0,0,168,0,0,0,88,1,0,0,142,1,0,0,42,0,0,0,192,0,0,0,68,0,0,0,124,0,0,0,176,0,0,0,168,0,0,0,88,1,0,0,142,1,0,0,42,0,0,0,192,0,0,0,68,0,0,0,124,0,0,0,176,0,0,0,168,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,212,0,0,0,34,1,0,0,82,1,0,0,138,1,0,0,114,1,0,0,174,0,0,0,216,0,0,0,116,1,0,0,58,0,0,0,34,1,0,0,82,1,0,0,138,1,0,0,114,1,0,0,174,0,0,0,216,0,0,0,116,1,0,0,58,0,0,0,34,1,0,0,82,1,0,0,138,1,0,0,114,1,0,0,174,0,0,0,216,0,0,0,116,1,0,0,58,0,0,0,34,1,0,0,82,1,0,0,138,1,0,0,114,1,0,0,174,0,0,0,216,0,0,0,116,1,0,0,58,0,0,0,34,1,0,0,82,1,0,0,138,1,0,0,114,1,0,0,174,0,0,0,216,0,0,0,116,1,0,0,58,0,0,0,34,1,0,0,82,1,0,0,138,1,0,0,114,1,0,0,174,0,0,0,216,0,0,0,116,1,0,0,58,0,0,0,34,1,0,0,82,1,0,0,138,1,0,0,114,1,0,0,174,0,0,0,216,0,0,0,116,1,0,0,58,0,0,0,34,1,0,0,82,1,0,0,138,1,0,0,114,1,0,0,174,0,0,0,216,0,0,0,116,1,0,0,58,0,0,0,128,0,0,0,178,0,0,0,28,0,0,0,128,1,0,0,4,1,0,0,208,0,0,0,90,1,0,0,104,1,0,0,128,0,0,0,178,0,0,0,28,0,0,0,128,1,0,0,4,1,0,0,208,0,0,0,90,1,0,0,104,1,0,0,128,0,0,0,178,0,0,0,28,0,0,0,128,1,0,0,4,1,0,0,208,0,0,0,90,1,0,0,104,1,0,0,128,0,0,0,178,0,0,0,28,0,0,0,128,1,0,0,4,1,0,0,208,0,0,0,90,1,0,0,104,1,0,0,128,0,0,0,178,0,0,0,28,0,0,0,128,1,0,0,4,1,0,0,208,0,0,0,90,1,0,0,104,1,0,0,128,0,0,0,178,0,0,0,28,0,0,0,128,1,0,0,4,1,0,0,208,0,0,0,90,1,0,0,104,1,0,0,128,0,0,0,178,0,0,0,28,0,0,0,128,1,0,0,4,1,0,0,208,0,0,0,90,1,0,0,104,1,0,0,128,0,0,0,178,0,0,0,28,0,0,0,128,1,0,0,4,1,0,0,208,0,0,0,90,1,0,0,104,1,0,0,28,1,0,0,246,0,0,0,14,0,0,0,32,0,0,0,166,0,0,0,238,0,0,0,140,0,0,0,60,0,0,0,28,1,0,0,246,0,0,0,14,0,0,0,32,0,0,0,166,0,0,0,238,0,0,0,140,0,0,0,60,0,0,0,28,1,0,0,246,0,0,0,14,0,0,0,32,0,0,0,166,0,0,0,238,0,0,0,140,0,0,0,60,0,0,0,28,1,0,0,246,0,0,0,14,0,0,0,32,0,0,0,166,0,0,0,238,0,0,0,140,0,0,0,60,0,0,0,28,1,0,0,246,0,0,0,14,0,0,0,32,0,0,0,166,0,0,0,238,0,0,0,140,0,0,0,60,0,0,0,28,1,0,0,246,0,0,0,14,0,0,0,32,0,0,0,166,0,0,0,238,0,0,0,140,0,0,0,60,0,0,0,28,1,0,0,246,0,0,0,14,0,0,0,32,0,0,0,166,0,0,0,238,0,0,0,140,0,0,0,60,0,0,0,28,1,0,0,246,0,0,0,14,0,0,0,32,0,0,0,166,0,0,0,238,0,0,0,140,0,0,0,60,0,0,0,146,0,0,0,98,0,0,0,18,0,0,0,38,0,0,0,36,0,0,0,204,0,0,0,152,0,0,0,100,1,0,0,146,0,0,0,98,0,0,0,18,0,0,0,220,0,0,0,36,0,0,0,204,0,0,0,152,0,0,0,50,0,0,0,146,0,0,0,98,0,0,0,18,0,0,0,138,0,0,0,36,0,0,0,204,0,0,0,152,0,0,0,66,0,0,0,146,0,0,0,98,0,0,0,18,0,0,0,76,1,0,0,36,0,0,0,204,0,0,0,152,0,0,0,226,0,0,0,146,0,0,0,98,0,0,0,18,0,0,0,0,0,0,0,36,0,0,0,204,0,0,0,152,0,0,0,0,0,0,0,146,0,0,0,98,0,0,0,18,0,0,0,0,0,0,0,36,0,0,0,204,0,0,0,152,0,0,0,0,0,0,0,146,0,0,0,98,0,0,0,18,0,0,0,0,0,0,0,36,0,0,0,204,0,0,0,152,0,0,0,0,0,0,0,146,0,0,0,98,0,0,0,18,0,0,0,0,0,0,0,36,0,0,0,204,0,0,0,152,0,0,0,0,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,16,0,0,0,22,0,0,0,22,0,0,0,22,0,0,0,22,0,0,0,22,0,0,0,22,0,0,0,22,0,0,0,22,0,0,0,28,0,0,0,28,0,0,0,28,0,0,0,28,0,0,0,28,0,0,0,28,0,0,0,28,0,0,0,28,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,44,0,0,0,26,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,52,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,10,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,42,0,0,0,40,0,0,0,64,0,0,0,66,0,0,0,18,0,0,0,46,0,0,0,46,0,0,0,46,0,0,0,8,0,0,0,228,0,0,0,190,0,0,0,86,0,0,0,184,0,0,0,128,0,0,0,70,0,0,0,16,0,0,0,28,0,0,0,104,0,0,0,14,1,0,0,18,1,0,0,184,0,0,0,128,0,0,0,70,0,0,0,16,0,0,0,12,0,0,0,48,0,0,0,98,0,0,0,180,0,0,0,184,0,0,0,128,0,0,0,70,0,0,0,16,0,0,0,144,0,0,0,100,0,0,0,250,0,0,0,108,0,0,0,184,0,0,0,128,0,0,0,70,0,0,0,16,0,0,0,94,0,0,0,38,0,0,0,178,0,0,0,10,1,0,0,184,0,0,0,128,0,0,0,70,0,0,0,16,0,0,0,234,0,0,0,194,0,0,0,138,0,0,0,108,0,0,0,184,0,0,0,128,0,0,0,70,0,0,0,16,0,0,0,10,0,0,0,52,1,0,0,90,0,0,0,108,0,0,0,184,0,0,0,128,0,0,0,70,0,0,0,16,0,0,0])
.concat([46,1,0,0,14,0,0,0,52,0,0,0,80,1,0,0,184,0,0,0,128,0,0,0,70,0,0,0,16,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,112,0,0,0,82,1,0,0,40,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,40,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,40,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,40,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,40,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,40,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,40,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,40,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,82,1,0,0,192,0,0,0,142,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,142,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,142,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,142,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,142,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,142,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,142,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,142,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,50,1,0,0,26,0,0,0,242,0,0,0,72,0,0,0,108,0,0,0,108,0,0,0,124,0,0,0,134,0,0,0,118,0,0,0,58,0,0,0,18,0,0,0,152,0,0,0,108,0,0,0,108,0,0,0,124,0,0,0,134,0,0,0,226,0,0,0,186,0,0,0,72,1,0,0,66,1,0,0,108,0,0,0,108,0,0,0,124,0,0,0,134,0,0,0,22,0,0,0,64,0,0,0,20,1,0,0,54,0,0,0,108,0,0,0,108,0,0,0,124,0,0,0,134,0,0,0,162,0,0,0,212,0,0,0,4,1,0,0,246,0,0,0,108,0,0,0,108,0,0,0,124,0,0,0,48,1,0,0,154,0,0,0,208,0,0,0,82,0,0,0,60,0,0,0,108,0,0,0,108,0,0,0,124,0,0,0,134,0,0,0,28,1,0,0,68,1,0,0,132,0,0,0,6,1,0,0,108,0,0,0,108,0,0,0,124,0,0,0,134,0,0,0,108,0,0,0,20,0,0,0,170,0,0,0,80,1,0,0,108,0,0,0,108,0,0,0,124,0,0,0,134,0,0,0,172,0,0,0,216,0,0,0,24,1,0,0,66,0,0,0,56,1,0,0,254,0,0,0,206,0,0,0,66,0,0,0,172,0,0,0,216,0,0,0,24,1,0,0,66,0,0,0,56,1,0,0,254,0,0,0,206,0,0,0,66,0,0,0,172,0,0,0,216,0,0,0,24,1,0,0,66,0,0,0,56,1,0,0,254,0,0,0,206,0,0,0,66,0,0,0,172,0,0,0,216,0,0,0,24,1,0,0,66,0,0,0,56,1,0,0,254,0,0,0,206,0,0,0,66,0,0,0,172,0,0,0,216,0,0,0,24,1,0,0,66,0,0,0,56,1,0,0,254,0,0,0,206,0,0,0,66,0,0,0,172,0,0,0,216,0,0,0,24,1,0,0,66,0,0,0,56,1,0,0,254,0,0,0,206,0,0,0,66,0,0,0,172,0,0,0,216,0,0,0,24,1,0,0,66,0,0,0,56,1,0,0,254,0,0,0,206,0,0,0,66,0,0,0,172,0,0,0,216,0,0,0,24,1,0,0,66,0,0,0,56,1,0,0,254,0,0,0,206,0,0,0,66,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,40,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,108,0,0,0,108,0,0,0,108,0,0,0,108,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,108,0,0,0,108,0,0,0,108,0,0,0,108,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,108,0,0,0,108,0,0,0,108,0,0,0,108,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,108,0,0,0,108,0,0,0,108,0,0,0,108,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,108,0,0,0,108,0,0,0,108,0,0,0,108,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,108,0,0,0,108,0,0,0,108,0,0,0,108,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,108,0,0,0,108,0,0,0,108,0,0,0,108,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,62,0,0,0,108,0,0,0,108,0,0,0,108,0,0,0,108,0,0,0,230,0,0,0,88,0,0,0,76,1,0,0,32,0,0,0,110,0,0,0,78,0,0,0,222,0,0,0,74,1,0,0,230,0,0,0,88,0,0,0,76,1,0,0,32,0,0,0,110,0,0,0,78,0,0,0,222,0,0,0,74,1,0,0,230,0,0,0,88,0,0,0,76,1,0,0,32,0,0,0,110,0,0,0,78,0,0,0,222,0,0,0,74,1,0,0,230,0,0,0,88,0,0,0,76,1,0,0,32,0,0,0,110,0,0,0,78,0,0,0,222,0,0,0,74,1,0,0,230,0,0,0,88,0,0,0,76,1,0,0,32,0,0,0,110,0,0,0,78,0,0,0,222,0,0,0,74,1,0,0,230,0,0,0,88,0,0,0,76,1,0,0,32,0,0,0,110,0,0,0,78,0,0,0,222,0,0,0,74,1,0,0,230,0,0,0,88,0,0,0,76,1,0,0,32,0,0,0,110,0,0,0,78,0,0,0,222,0,0,0,74,1,0,0,230,0,0,0,88,0,0,0,76,1,0,0,32,0,0,0,110,0,0,0,78,0,0,0,222,0,0,0,74,1,0,0,30,1,0,0,30,0,0,0,6,0,0,0,46,0,0,0,198,0,0,0,12,1,0,0,106,0,0,0,2,1,0,0,30,1,0,0,30,0,0,0,6,0,0,0,46,0,0,0,198,0,0,0,12,1,0,0,106,0,0,0,2,1,0,0,30,1,0,0,30,0,0,0,6,0,0,0,46,0,0,0,198,0,0,0,12,1,0,0,106,0,0,0,2,1,0,0,30,1,0,0,30,0,0,0,6,0,0,0,46,0,0,0,198,0,0,0,12,1,0,0,106,0,0,0,2,1,0,0,30,1,0,0,30,0,0,0,6,0,0,0,46,0,0,0,198,0,0,0,12,1,0,0,106,0,0,0,2,1,0,0,30,1,0,0,30,0,0,0,6,0,0,0,46,0,0,0,198,0,0,0,12,1,0,0,106,0,0,0,2,1,0,0,30,1,0,0,30,0,0,0,6,0,0,0,46,0,0,0,198,0,0,0,12,1,0,0,106,0,0,0,2,1,0,0,30,1,0,0,30,0,0,0,6,0,0,0,46,0,0,0,198,0,0,0,12,1,0,0,106,0,0,0,2,1,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,56,0,0,0,2,0,0,0,42,1,0,0,240,0,0,0,22,1,0,0,60,1,0,0,24,0,0,0,236,0,0,0,56,0,0,0,2,0,0,0,42,1,0,0,240,0,0,0,22,1,0,0,60,1,0,0,24,0,0,0,236,0,0,0,56,0,0,0,2,0,0,0,42,1,0,0,240,0,0,0,22,1,0,0,60,1,0,0,24,0,0,0,236,0,0,0,56,0,0,0,2,0,0,0,42,1,0,0,240,0,0,0,22,1,0,0,60,1,0,0,24,0,0,0,236,0,0,0,56,0,0,0,2,0,0,0,42,1,0,0,240,0,0,0,22,1,0,0,60,1,0,0,24,0,0,0,236,0,0,0,56,0,0,0,2,0,0,0,42,1,0,0,240,0,0,0,22,1,0,0,60,1,0,0,24,0,0,0,236,0,0,0,56,0,0,0,2,0,0,0,42,1,0,0,240,0,0,0,22,1,0,0,60,1,0,0,24,0,0,0,236,0,0,0,56,0,0,0,2,0,0,0,42,1,0,0,240,0,0,0,22,1,0,0,60,1,0,0,24,0,0,0,236,0,0,0,150,0,0,0,200,0,0,0,78,1,0,0,232,0,0,0,4,0,0,0,44,1,0,0,102,0,0,0,146,0,0,0,150,0,0,0,200,0,0,0,78,1,0,0,232,0,0,0,4,0,0,0,44,1,0,0,102,0,0,0,146,0,0,0,150,0,0,0,200,0,0,0,78,1,0,0,232,0,0,0,4,0,0,0,44,1,0,0,102,0,0,0,146,0,0,0,150,0,0,0,200,0,0,0,78,1,0,0,232,0,0,0,4,0,0,0,44,1,0,0,102,0,0,0,146,0,0,0,150,0,0,0,200,0,0,0,78,1,0,0,232,0,0,0,4,0,0,0,44,1,0,0,102,0,0,0,146,0,0,0,150,0,0,0,200,0,0,0,78,1,0,0,232,0,0,0,4,0,0,0,44,1,0,0,102,0,0,0,146,0,0,0,150,0,0,0,200,0,0,0,78,1,0,0,232,0,0,0,4,0,0,0,44,1,0,0,102,0,0,0,146,0,0,0,150,0,0,0,200,0,0,0,78,1,0,0,232,0,0,0,4,0,0,0,44,1,0,0,102,0,0,0,146,0,0,0,248,0,0,0,26,1,0,0,148,0,0,0,36,0,0,0,120,0,0,0,174,0,0,0,34,0,0,0,64,1,0,0,248,0,0,0,26,1,0,0,148,0,0,0,36,0,0,0,120,0,0,0,174,0,0,0,34,0,0,0,64,1,0,0,248,0,0,0,26,1,0,0,148,0,0,0,36,0,0,0,120,0,0,0,174,0,0,0,34,0,0,0,64,1,0,0,248,0,0,0,26,1,0,0,148,0,0,0,36,0,0,0,120,0,0,0,174,0,0,0,34,0,0,0,64,1,0,0,248,0,0,0,26,1,0,0,148,0,0,0,36,0,0,0,120,0,0,0,174,0,0,0,34,0,0,0,64,1,0,0,248,0,0,0,26,1,0,0,148,0,0,0,36,0,0,0,120,0,0,0,174,0,0,0,34,0,0,0,64,1,0,0,248,0,0,0,26,1,0,0,148,0,0,0,36,0,0,0,120,0,0,0,174,0,0,0,34,0,0,0,64,1,0,0,248,0,0,0,26,1,0,0,148,0,0,0,36,0,0,0,120,0,0,0,174,0,0,0,34,0,0,0,64,1,0,0,92,0,0,0,122,0,0,0,176,0,0,0,50,0,0,0,210,0,0,0,158,0,0,0,114,0,0,0,8,1,0,0,92,0,0,0,122,0,0,0,176,0,0,0,218,0,0,0,210,0,0,0,158,0,0,0,114,0,0,0,168,0,0,0,92,0,0,0,122,0,0,0,176,0,0,0,62,1,0,0,210,0,0,0,158,0,0,0,114,0,0,0,160,0,0,0,92,0,0,0,122,0,0,0,176,0,0,0,136,0,0,0,210,0,0,0,158,0,0,0,114,0,0,0,74,0,0,0,92,0,0,0,122,0,0,0,176,0,0,0,76,0,0,0,210,0,0,0,158,0,0,0,114,0,0,0,84,0,0,0,92,0,0,0,122,0,0,0,176,0,0,0,58,1,0,0,210,0,0,0,158,0,0,0,114,0,0,0,42,0,0,0,92,0,0,0,122,0,0,0,176,0,0,0,224,0,0,0,210,0,0,0,158,0,0,0,114,0,0,0,108,0,0,0,92,0,0,0,122,0,0,0,176,0,0,0,214,0,0,0,210,0,0,0,158,0,0,0,114,0,0,0,196,0,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,36,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,38,1,0,0,64,0,0,0,56,0,0,0,0,0,0,0,22,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,82,0,0,0,56,1,0,0,0,0,0,0,0,0,0,0,22,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,22,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,210,0,0,0,210,0,0,0,210,0,0,0,210,0,0,0,182,0,0,0,182,0,0,0,182,0,0,0,182,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,120,0,0,0,120,0,0,0,120,0,0,0,120,0,0,0,20,1,0,0,20,1,0,0,20,1,0,0,20,1,0,0,34,0,0,0,34,0,0,0,34,0,0,0,34,0,0,0,136,0,0,0,136,0,0,0,136,0,0,0,136,0,0,0,24,1,0,0,24,1,0,0,24,1,0,0,24,1,0,0,126,1,0,0,126,1,0,0,126,1,0,0,126,1,0,0,100,0,0,0,100,0,0,0,100,0,0,0,100,0,0,0,70,1,0,0,70,1,0,0,70,1,0,0,70,1,0,0,234,0,0,0,234,0,0,0,234,0,0,0,234,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,88,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,122,1,0,0,122,1,0,0,122,1,0,0,122,1,0,0,84,0,0,0,84,0,0,0,84,0,0,0,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,214,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,156,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,196,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,26,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,185,0,0,48,0,0,0,144,171,0,0,48,0,0,0,208,157,0,0,180,0,0,0,0,0,0,0,0,0,0,0,240,205,0,0,58,1,0,0,240,211,0,0,62,1,0,0,240,186,0,0,36,1,0,0,56,172,0,0,36,1,0,0,88,158,0,0,60,1,0,0,56,146,0,0,70,0,0,0,0,0,0,0,0,0,0,0,0,128,2,0,40,0,0,0,1,0,0,0,8,0,0,0,0,2,0,0,2,0,0,0,0,208,2,0,40,0,0,0,1,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,0,5,0,40,0,0,0,2,0,0,0,8,0,0,0,0,2,0,0,2,0,0,0,0,160,5,0,40,0,0,0,2,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,0,10,0,80,0,0,0,2,0,0,0,8,0,0,0,0,2,0,0,2,0,0,0,0,64,11,0,80,0,0,0,2,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,192,18,0,80,0,0,0,2,0,0,0,15,0,0,0,0,2,0,0,2,128,0,0,0,128,22,0,80,0,0,0,2,0,0,0,18,0,0,0,0,2,0,0,2,128,0,0,0,0,45,0,80,0,0,0,2,0,0,0,36,0,0,0,0,2,0,0,2,128,0,0,0,64,19,0,77,0,0,0,2,0,0,0,8,0,0,0,0,4,0,0,2,128,0,0,0,233,3,0,77,0,0,0,1,0,0,0,26,0,0,0,128,0,0,0,1,128,0,0,0,210,7,0,77,0,0,0,2,0,0,0,26,0,0,0,128,0,0,0,1,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,67,77,80,46,76,0,0,0,83,108,111,116,86,73,110,115,116,97,108,108,0,0,0,0,65,68,68,82,0,0,0,0,83,116,97,114,116,82,105,103,104,116,0,0,0,0,0,0,42,42,42,32,82,65,77,32,110,111,116,32,102,111,117,110,100,32,97,116,32,48,48,48,48,48,48,10,0,0,0,0,67,77,80,65,46,87,0,0,83,108,111,116,77,97,110,97,103,101,114,0,0,0,0,0,83,117,112,101,114,82,105,103,104,116,0,0,0,0,0,0,42,42,42,32,117,110,107,110,111,119,110,32,99,112,117,32,109,111,100,101,108,32,40,37,115,41,10,0,0,0,0,0,69,79,82,46,66,0,0,0,72,83,101,116,83,116,97,116,101,0,0,0,0,0,0,0,77,101,116,97,82,105,103,104,116,0,0,0,0,0,0,0,109,111,100,101,108,61,37,115,32,115,112,101,101,100,61,37,100,10,0,0,0,0,0,0,45,40,65,37,117,41,0,0,67,77,80,77,46,66,0,0,72,71,101,116,83,116,97,116,101,0,0,0,0,0,0,0,65,108,116,82,105,103,104,116,0,0,0,0,0,0,0,0,67,80,85,58,0,0,0,0,69,79,82,46,87,0,0,0,72,67,108,114,82,66,105,116,0,0,0,0,0,0,0,0,83,112,97,99,101,0,0,0,115,112,101,101,100,0,0,0,67,77,80,77,46,87,0,0,72,83,101,116,82,66,105,116,0,0,0,0,0,0,0,0,68,101,108,101,116,101,0,0,65,108,116,0,0,0,0,0,99,112,117,0,0,0,0,0,115,111,110,121,58,32,99,104,115,32,101,114,114,111,114,32,40,98,108,107,61,37,108,117,44,32,108,98,97,61,37,108,117,41,10,0,0,0,0,0,69,79,82,46,76,0,0,0,78,101,119,69,109,112,116,121,72,97,110,100,108,101,0,0,115,99,115,105,58,32,114,101,97,100,32,101,114,114,111,114,32,97,116,32,37,108,117,32,43,32,37,108,117,10,0,0,65,108,116,76,101,102,116,0,97,108,116,101,114,110,97,116,101,32,115,111,117,110,100,32,98,117,102,102,101,114,10,0,67,77,80,77,46,76,0,0,101,109,117,46,105,119,109,46,114,111,0,0,0,0,0,0,83,116,97,99,107,83,112,97,99,101,0,0,0,0,0,0,101,109,117,46,101,120,105,116,0,0,0,0,0,0,0,0,77,111,100,101,0,0,0,0,70,57,0,0,0,0,0,0,33,61,0,0,0,0,0,0,123,0,0,0,0,0,0,0,109,97,105,110,32,115,111,117,110,100,32,98,117,102,102,101,114,10,0,0,0,0,0,0,99,112,117,46,115,112,101,101,100,32,61,32,0,0,0,0,104,0,0,0,0,0,0,0,98,105,110,0,0,0,0,0,109,111,117,115,101,95,109,117,108,95,120,0,0,0,0,0,110,111,110,101,0,0,0,0,97,100,100,114,61,48,120,37,48,56,108,120,32,115,105,122,101,61,37,108,117,32,102,105,108,101,61,37,115,10,0,0,67,77,80,65,46,76,0,0,104,0,0,0,0,0,0,0,45,45,37,115,0,0,0,0,101,120,112,101,99,116,105,110,103,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,116,100,48,58,32,100,114,111,112,112,105,110,103,32,112,104,97,110,116,111,109,32,115,101,99,116,111,114,32,37,117,47,37,117,47,37,117,10,0,0,77,111,118,101,72,72,105,0,82,101,108,101,97,115,101,32,51,46,48,55,36,48,0,0,46,116,100,48,0,0,0,0,79,0,0,0,0,0,0,0,87,105,110,100,111,119,115,76,101,102,116,0,0,0,0,0,97,108,116,101,114,110,97,116,101,32,118,105,100,101,111,32,98,117,102,102,101,114,10,0,118,105,100,101,111,0,0,0,116,101,114,109,46,116,105,116,108,101,0,0,0,0,0,0,77,85,76,85,46,87,0,0,77,97,120,65,112,112,108,90,111,110,101,0,0,0,0,0,83,116,97,114,116,76,101,102,116,0,0,0,0,0,0,0,109,97,105,110,32,118,105,100,101,111,32,98,117,102,102,101,114,10,0,0,0,0,0,0,103,0,0,0,0,0,0,0,115,112,101,101,100,58,32,37,117,10,0,0,0,0,0,0,65,78,68,46,66,0,0,0,80,117,114,103,101,83,112,97,99,101,0,0,0,0,0,0,82,83,69,84,0,0,0,0,83,117,112,101,114,76,101,102,116,0,0,0,0,0,0,0,86,73,65,58,0,0,0,0,65,66,67,68,46,66,0,0,77,97,120,66,108,111,99,107,0,0,0,0,0,0,0,0,77,101,116,97,0,0,0,0,118,105,97,0,0,0,0,0,65,78,68,46,87,0,0,0,72,70,83,68,105,115,112,97,116,99,104,0,0,0,0,0,77,101,116,97,76,101,102,116,0,0,0,0,0,0,0,0,83,67,67,58,0,0,0,0,40,65,37,117,41,43,0,0,65,78,68,46,76,0,0,0,83,119,97,112,77,77,85,77,111,100,101,0,0,0,0,0,67,116,114,108,0,0,0,0,115,99,99,0,0,0,0,0,105,103,110,111,114,105,110,103,32,112,99,101,32,107,101,121,58,32,37,48,52,120,32,40,37,115,41,10,0,0,0,0,80,114,105,109,101,84,105,109,101,0,0,0,0,0,0,0,67,116,114,108,76,101,102,116,0,0,0,0,0,0,0,0,42,42,42,32,99,97,110,39,116,32,111,112,101,110,32,100,114,105,118,101,114,32,40,37,115,41,10,0,0,0,0,0,77,85,76,83,46,87,0,0,82,109,118,84,105,109,101,0,67,114,101,97,116,101,0,0,47,0,0,0,0,0,0,0,42,42,42,32,98,97,100,32,112,111,114,116,32,110,117,109,98,101,114,32,40,37,117,41,10,0,0,0,0,0,0,0,105,119,109,58,32,100,114,105,118,101,32,37,117,32,101,106,101,99,116,10,0,0,0,0,115,111,110,121,58,32,119,114,105,116,101,32,101,114,114,111,114,32,97,116,32,37,117,47,37,117,47,37,117,10,0,0,65,68,68,65,46,87,0,0,73,110,115,84,105,109,101,0,115,99,115,105,58,32,116,111,111,32,109,97,110,121,32,98,108,111,99,107,115,32,40,37,117,41,10,0,0,0,0,0,83,108,97,115,104,0,0,0,112,111,114,116,61,37,117,32,109,117,108,116,105,99,104,97,114,61,37,117,32,100,114,105,118,101,114,61,37,115,10,0,65,68,68,46,66,0,0,0,101,109,117,46,100,105,115,107,46,114,119,0,0,0,0,0,83,101,116,65,112,112,66,97,115,101,0,0,0,0,0,0,115,100,108,58,32,98,108,105,116,32,101,114,114,111,114,10,0,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,46,0,0,0,0,0,0,0,70,56,0,0,0,0,0,0,61,61,0,0,0,0,0,0,115,101,99,116,105,111,110,0,83,69,82,73,65,76,58,0,34,10,0,0,0,0,0,0,102,0,0,0,0,0,0,0,115,114,101,99,0,0,0,0,115,99,97,108,101,0,0,0,82,65,77,58,0,0,0,0,65,68,68,88,46,66,0,0,99,0,0,0,0,0,0,0,32,32,0,0,0,0,0,0,101,120,112,101,99,116,105,110,103,32,111,102,102,115,101,116,0,0,0,0,0,0,0,0,116,100,48,58,32,99,114,99,32,101,114,114,111,114,32,97,116,32,115,101,99,116,111,114,32,37,117,47,37,117,47,37,117,32,40,37,48,50,88,32,37,48,52,88,32,37,48,52,88,41,10,0,0,0,0,0,83,116,114,105,112,65,100,100,114,101,115,115,0,0,0,0,82,101,108,101,97,115,101,32,51,46,48,50,36,48,0,0,46,116,99,0,0,0,0,0,78,0,0,0,0,0,0,0,80,101,114,105,111,100,0,0,109,117,108,116,105,99,104,97,114,0,0,0,0,0,0,0,65,68,68,46,87,0,0,0,85,112,114,83,116,114,105,110,103,0,0,0,0,0,0,0,44,0,0,0,0,0,0,0,112,111,114,116,0,0,0,0,114,117,110,32,117,110,116,105,108,32,101,120,99,101,112,116,105,111,110,0,0,0,0,0,115,121,115,116,101,109,32,116,111,111,32,115,108,111,119,44])
.concat([32,115,107,105,112,112,105,110,103,32,49,32,115,101,99,111,110,100,10,0,0,0,0,0,65,68,68,88,46,87,0,0,82,101,108,83,116,114,105,110,103,0,0,0,0,0,0,0,115,115,112,0,0,0,0,0,67,111,109,109,97,0,0,0,115,101,114,105,97,108,0,0,65,68,68,46,76,0,0,0,82,68,114,118,114,73,110,115,116,97,108,108,0,0,0,0,109,0,0,0,0,0,0,0,99,111,112,121,32,109,101,109,111,114,121,0,0,0,0,0,42,42,42,32,114,101,97,100,105,110,103,32,114,116,99,32,102,105,108,101,32,102,97,105,108,101,100,10,0,0,0,0,105,119,109,58,32,108,111,97,100,105,110,103,32,100,114,105,118,101,32,37,117,32,40,112,98,105,116,41,10,0,0,0,65,68,68,88,46,76,0,0,65,100,100,68,114,105,118,101,0,0,0,0,0,0,0,0,110,0,0,0,0,0,0,0,115,114,99,32,100,115,116,32,99,110,116,0,0,0,0,0,60,110,111,119,62,0,0,0,32,68,51,61,37,48,56,108,88,32,32,68,55,61,37,48,56,108,88,32,32,65,51,61,37,48,56,108,88,32,32,65,55,61,37,48,56,108,88,32,32,83,83,80,61,37,48,56,108,88,10,0,0,0,0,0,68,0,0,0,0,0,0,0,65,68,68,65,46,76,0,0,80,117,114,103,101,77,101,109,0,0,0,0,0,0,0,0,98,0,0,0,0,0,0,0,101,118,97,108,117,97,116,101,32,101,120,112,114,101,115,115,105,111,110,115,0,0,0,0,102,105,108,101,61,37,115,32,114,101,97,108,116,105,109,101,61,37,100,32,115,116,97,114,116,61,37,115,32,114,111,109,100,105,115,107,61,37,100,10,0,0,0,0,0,0,0,0,117,110,104,97,110,100,108,101,100,32,109,97,103,105,99,32,107,101,121,32,40,37,117,41,10,0,0,0,0,0,0,0,32,68,50,61,37,48,56,108,88,32,32,68,54,61,37,48,56,108,88,32,32,65,50,61,37,48,56,108,88,32,32,65,54,61,37,48,56,108,88,32,32,85,83,80,61,37,48,56,108,88,10,0,0,0,0,0,82,79,82,46,66,0,0,0,67,111,109,112,97,99,116,77,101,109,0,0,0,0,0,0,118,0,0,0,0,0,0,0,91,101,120,112,114,46,46,46,93,0,0,0,0,0,0,0,82,84,67,58,0,0,0,0,32,68,49,61,37,48,56,108,88,32,32,68,53,61,37,48,56,108,88,32,32,65,49,61,37,48,56,108,88,32,32,65,53,61,37,48,56,108,88,32,32,76,80,67,61,37,48,56,108,88,10,0,0,0,0,0,82,79,88,82,46,66,0,0,83,101,116,71,114,111,119,90,111,110,101,0,0,0,0,0,71,101,116,86,111,108,73,110,102,111,0,0,0,0,0,0,99,0,0,0,0,0,0,0,110,97,109,101,32,91,102,93,32,91,97,32,110,46,46,46,93,0,0,0,0,0,0,0,115,116,97,114,116,0,0,0,32,68,48,61,37,48,56,108,88,32,32,68,52,61,37,48,56,108,88,32,32,65,48,61,37,48,56,108,88,32,32,65,52,61,37,48,56,108,88,32,32,32,80,67,61,37,48,56,108,88,10,0,0,0,0,0,115,111,110,121,58,32,99,111,110,116,114,111,108,58,32,117,110,107,110,111,119,110,32,40,111,112,99,111,100,101,61,48,120,37,48,52,120,41,10,0,76,83,82,46,66,0,0,0,72,78,111,80,117,114,103,101,0,0,0,0,0,0,0,0,115,99,115,105,58,32,119,114,105,116,101,32,101,114,114,111,114,10,0,0,0,0,0,0,120,0,0,0,0,0,0,0,113,117,105,116,0,0,0,0,114,111,109,100,105,115,107,0,32,83,82,61,37,48,52,88,91,37,99,37,99,93,32,32,67,67,61,37,48,50,88,91,37,99,37,99,37,99,37,99,37,99,93,32,69,88,61,37,48,50,88,40,37,45,52,115,41,32,84,82,80,61,37,48,52,88,32,73,77,76,61,37,88,32,73,80,76,61,37,88,10,0,0,0,0,0,0,0,65,83,82,46,66,0,0,0,101,109,117,46,100,105,115,107,46,114,111,0,0,0,0,0,72,80,117,114,103,101,0,0,115,100,108,58,32,107,101,121,32,61,32,48,120,37,48,52,120,10,0,0,0,0,0,0,116,101,114,109,46,102,117,108,108,115,99,114,101,101,110,0,122,0,0,0,0,0,0,0,115,101,110,100,32,97,32,109,101,115,115,97,103,101,32,116,111,32,116,104,101,32,101,109,117,108,97,116,111,114,32,99,111,114,101,0,0,0,0,0,70,55,0,0,0,0,0,0,114,101,97,108,116,105,109,101,0,0,0,0,0,0,0,0,38,0,0,0,0,0,0,0,67,76,75,61,37,108,108,120,32,32,79,80,61,37,108,108,120,32,32,68,76,89,61,37,108,117,32,32,67,80,73,61,37,46,52,102,10,0,0,0,99,112,117,46,109,111,100,101,108,32,61,32,34,0,0,0,101,0,0,0,0,0,0,0,105,104,120,0,0,0,0,0,109,105,110,95,104,0,0,0,100,101,102,97,117,108,116,0,82,79,82,46,76,0,0,0,111,102,102,115,101,116,0,0,44,32,0,0,0,0,0,0,115,121,110,116,97,120,32,101,114,114,111,114,0,0,0,0,58,0,0,0,0,0,0,0,116,100,48,58,32,115,101,99,116,111,114,32,99,114,99,32,111,118,101,114,32,104,101,97,100,101,114,43,100,97,116,97,10,0,0,0,0,0,0,0,80,116,114,90,111,110,101,0,99,112,50,58,32,119,97,114,110,105,110,103,58,32,117,110,107,110,111,119,110,32,67,80,50,32,118,101,114,115,105,111,110,10,0,0,0,0,0,0,46,114,97,119,0,0,0,0,108,111,103,0,0,0,0,0,60,0,0,0,0,0,0,0,109,115,103,32,91,118,97,108,93,0,0,0,0,0,0,0,112,114,97,109,46,100,97,116,0,0,0,0,0,0,0,0,54,56,48,48,48,0,0,0,82,79,88,82,46,76,0,0,83,101,116,84,114,97,112,65,100,100,114,101,115,115,0,0,76,101,115,115,0,0,0,0,114,101,97,100,32,97,32,102,105,108,101,32,105,110,116,111,32,109,101,109,111,114,121,0,114,116,99,0,0,0,0,0,77,69,77,0,0,0,0,0,91,101,120,99,101,112,116,105,111,110,93,0,0,0,0,0,76,83,82,46,76,0,0,0,109,97,99,58,32,114,101,115,101,116,10,0,0,0,0,0,71,101,116,84,114,97,112,65,100,100,114,101,115,115,0,0,117,115,112,0,0,0,0,0,83,104,105,102,116,0,0,0,110,97,109,101,32,91,102,93,32,91,97,32,91,110,93,93,0,0,0,0,0,0,0,0,109,111,100,101,108,61,37,117,32,105,110,116,101,114,110,97,116,105,111,110,97,108,61,37,100,32,107,101,121,112,97,100,61,37,115,10,0,0,0,0,87,82,37,48,50,117,65,61,37,48,50,88,32,32,82,82,37,48,50,117,65,61,37,48,50,88,32,32,87,82,37,48,50,117,66,61,37,48,50,88,32,32,82,82,37,48,50,117,66,61,37,48,50,88,10,0,65,83,82,46,76,0,0,0,70,108,117,115,104,70,105,108,101,0,0,0,0,0,0,0,37,48,52,88,0,0,0,0,77,101,110,117,67,104,111,105,99,101,0,0,0,0,0,0,83,104,105,102,116,76,101,102,116,0,0,0,0,0,0,0,83,101,116,77,67,69,110,116,114,105,101,115,0,0,0,0,112,114,105,110,116,32,104,101,108,112,0,0,0,0,0,0,75,69,89,66,79,65,82,68,58,0,0,0,0,0,0,0,71,101,116,77,67,69,110,116,114,121,0,0,0,0,0,0,68,105,115,112,77,67,69,110,116,114,105,101,115,0,0,0,32,32,73,82,81,61,37,117,10,0,0,0,0,0,0,0,83,101,116,77,67,73,110,102,111,0,0,0,0,0,0,0,71,101,116,77,67,73,110,102,111,0,0,0,0,0,0,0,65,83,82,46,87,0,0,0,68,101,108,77,67,69,110,116,114,105,101,115,0,0,0,0,83,101,101,100,67,70,105,108,108,0,0,0,0,0,0,0,83,101,116,70,80,111,115,0,67,97,108,99,67,77,97,115,107,0,0,0,0,0,0,0,68,101,108,67,111,109,112,0,68,101,108,83,101,97,114,99,104,0,0,0,0,0,0,0,92,0,0,0,0,0,0,0,78,101,119,67,68,105,97,108,111,103,0,0,0,0,0,0,102,105,110,100,32,98,121,116,101,115,32,105,110,32,109,101,109,111,114,121,0,0,0,0,105,110,116,108,0,0,0,0,82,101,115,116,111,114,101,69,110,116,114,105,101,115,0,0,83,97,118,101,69,110,116,114,105,101,115,0,0,0,0,0,56,53,51,48,45,83,67,67,0,0,0,0,0,0,0,0,65,0,0,0,0,0,0,0,71,101,116,67,87,77,103,114,80,111,114,116,0,0,0,0,83,101,116,68,101,115,107,67,80,97,116,0,0,0,0,0,82,79,76,46,66,0,0,0,71,101,116,78,101,119,67,87,105,110,100,111,119,0,0,0,78,101,119,67,87,105,110,100,111,119,0,0,0,0,0,0,83,101,116,70,105,108,84,121,112,101,0,0,0,0,0,0,71,101,116,65,117,120,67,116,108,0,0,0,0,0,0,0,83,101,116,67,116,108,67,111,108,111,114,0,0,0,0,0,71,101,116,65,117,120,87,105,110,0,0,0,0,0,0,0,66,97,99,107,115,108,97,115,104,0,0,0,0,0,0,0,83,101,116,87,105,110,67,111,108,111,114,0,0,0,0,0,97,100,100,114,32,99,110,116,32,91,118,97,108,46,46,46,93,0,0,0,0,0,0,0,109,111,100,101,108,0,0,0,81,68,69,114,114,111,114,0,83,101,116,69,110,116,114,105,101,115,0,0,0,0,0,0,32,32,80,65,61,37,48,50,88,32,32,32,80,66,61,37,48,50,88,32,32,67,66,50,61,37,88,32,32,37,99,84,50,86,61,37,48,52,88,10,0,0,0,0,0,0,0,0,82,101,115,101,114,118,101,69,110,116,114,121,0,0,0,0,107,101,121,112,97,100,32,109,111,100,101,58,32,107,101,121,112,97,100,10,0,0,0,0,80,114,111,116,101,99,116,69,110,116,114,121,0,0,0,0,82,79,88,76,46,66,0,0,83,101,116,67,108,105,101,110,116,73,68,0,0,0,0,0,65,100,100,67,111,109,112,0,65,100,100,83,101,97,114,99,104,0,0,0,0,0,0,0,82,115,116,70,105,108,76,111,99,107,0,0,0,0,0,0,77,97,107,101,73,84,97,98,108,101,0,0,0,0,0,0,71,101,116,83,117,98,84,97,98,108,101,0,0,0,0,0,39,0,0,0,0,0,0,0,82,101,97,108,67,111,108,111,114,0,0,0,0,0,0,0,101,110,116,101,114,32,98,121,116,101,115,32,105,110,116,111,32,109,101,109,111,114,121,0,107,101,121,112,97,100,0,0,73,110,118,101,114,116,67,111,108,111,114,0,0,0,0,0,73,110,100,101,120,50,67,111,108,111,114,0,0,0,0,0,32,79,82,65,61,37,48,50,88,32,32,79,82,66,61,37,48,50,88,32,32,67,66,49,61,37,88,32,32,32,84,50,76,61,37,48,52,88,10,0,67,111,108,111,114,50,73,110,100,101,120,0,0,0,0,0,71,101,116,71,68,101,118,105,99,101,0,0,0,0,0,0,76,83,76,46,66,0,0,0,83,101,116,71,68,101,118,105,99,101,0,0,0,0,0,0,68,105,115,112,111,115,71,68,101,118,105,99,101,0,0,0,78,101,119,71,68,101,118,105,99,101,0,0,0,0,0,0,83,101,116,70,105,108,76,111,99,107,0,0,0,0,0,0,75,105,108,108,73,79,0,0,73,110,105,116,71,68,101,118,105,99,101,0,0,0,0,0,83,101,116,68,101,118,105,99,101,65,116,116,114,105,98,117,116,101,0,0,0,0,0,0,65,112,111,115,116,114,111,112,104,101,0,0,0,0,0,0,84,101,115,116,68,101,118,105,99,101,65,116,116,114,105,98,117,116,101,0,0,0,0,0,97,100,100,114,32,91,118,97,108,124,115,116,114,105,110,103,46,46,46,93,0,0,0,0,109,111,116,105,111,110,0,0,71,101,116,78,101,120,116,68,101,118,105,99,101,0,0,0,71,101,116,77,97,105,110,68,101,118,105,99,101,0,0,0,32,73,82,65,61,37,48,50,88,32,32,73,82,66,61,37,48,50,88,32,32,67,65,50,61,37,88,32,32,37,99,84,49,86,61,37,48,52,88,10,0,0,0,0,0,0,0,0,71,101,116,68,101,118,105,99,101,76,105,115,116,0,0,0,115,111,110,121,58,32,115,116,97,116,117,115,58,32,117,110,107,110,111,119,110,32,40,99,115,61,48,120,37,48,52,120,41,10,0,0,0,0,0,0,71,101,116,77,97,120,68,101,118,105,99,101,0,0,0,0,65,83,76,46,66,0,0,0,68,105,115,112,111,115,67,67,117,114,115,111,114,0,0,0,68,105,115,112,111,115,67,73,99,111,110,0,0,0,0,0,68,105,115,112,111,115,67,84,97,98,108,101,0,0,0,0,82,101,115,114,118,77,101,109,0,0,0,0,0,0,0,0,67,104,97,114,69,120,116,114,97,0,0,0,0,0,0,0,115,99,115,105,58,32,119,114,105,116,101,32,115,105,122,101,32,109,105,115,109,97,116,99,104,32,40,37,117,32,47,32,37,117,41,10,0,0,0,0,72,105,108,105,116,101,67,111,108,111,114,0,0,0,0,0,81,117,111,116,101,0,0,0,79,112,67,111,108,111,114,0,100,117,109,112,32,109,101,109,111,114,121,0,0,0,0,0,107,101,121,98,111,97,114,100,32,107,101,121,112,97,100,95,109,111,100,101,61,37,115,10,0,0,0,0,0,0,0,0,80,108,111,116,67,73,99,111,110,0,0,0,0,0,0,0,71,101,116,67,73,99,111,110,0,0,0,0,0,0,0,0,68,68,82,65,61,37,48,50,88,32,68,68,82,66,61,37,48,50,88,32,32,67,65,49,61,37,88,32,32,32,84,49,76,61,37,48,52,88,32,83,72,70,84,61,37,48,50,88,47,37,117,10,0,0,0,0,65,108,108,111,99,67,117,114,115,111,114,0,0,0,0,0,83,101,116,67,67,117,114,115,111,114,0,0,0,0,0,0,68,87,0,0,0,0,0,0,71,101,116,67,67,117,114,115,111,114,0,0,0,0,0,0,101,109,117,46,100,105,115,107,46,105,110,115,101,114,116,0,71,101,116,66,97,99,107,67,111,108,111,114,0,0,0,0,71,101,116,70,111,114,101,67,111,108,111,114,0,0,0,0,73,110,105,116,85,116,105,108,0,0,0,0,0,0,0,0,71,101,116,67,84,97,98,108,101,0,0,0,0,0,0,0,101,109,117,46,115,116,111,112,0,0,0,0,0,0,0,0,71,101,116,67,80,105,120,101,108,0,0,0,0,0,0,0,59,0,0,0,0,0,0,0,83,101,116,67,80,105,120,101,108,0,0,0,0,0,0,0,91,97,100,100,114,32,91,99,110,116,93,93,0,0,0,0,70,54,0,0,0,0,0,0,109,111,117,115,101,10,0,0,94,0,0,0,0,0,0,0,82,71,66,66,97,99,107,67,111,108,111,114,0,0,0,0,60,110,108,62,0,0,0,0,82,71,66,70,111,114,101,67,111,108,111,114,0,0,0,0,32,80,67,82,61,37,48,50,88,32,32,65,67,82,61,37,48,50,88,32,32,73,70,82,61,37,48,50,88,32,32,73,69,82,61,37,48,50,88,32,32,73,82,81,61,37,117,10,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,70,105,108,108,67,80,111,108,121,0,0,0,0,0,0,0,100,0,0,0,0,0,0,0,105,104,101,120,0,0,0,0,109,105,110,95,119,0,0,0,70,105,108,108,67,82,103,110,0,0,0,0,0,0,0,0,115,105,122,101,0,0,0,0,97,117,116,111,0,0,0,0,82,79,76,46,76,0,0,0,32,32,45,37,99,0,0,0,70,105,108,108,67,65,114,99,0,0,0,0,0,0,0,0,115,116,114,105,110,103,32,116,111,111,32,108,111,110,103,0,101,120,112,101,99,116,105,110,103,32,97,100,100,114,101,115,115,0,0,0,0,0,0,0,70,105,108,108,67,82,111,117,110,100,82,101,99,116,0,0,116,100,48,58,32,117,110,107,110,111,119,110,32,99,111,109,112,114,101,115,115,105,111,110,32,40,37,117,47,37,117,47,37,117,32,37,117,41,10,0,70,105,108,108,67,79,118,97,108,0,0,0,0,0,0,0,68,114,118,114,82,101,109,111,118,101,0,0,0,0,0,0,99,112,50,58,32,110,111,116,32,97,32,67,80,50,32,102,105,108,101,10,0,0,0,0,46,105,109,103,0,0,0,0,70,105,108,108,67,82,101,99,116,0,0,0,0,0,0,0,121,100,105,118,0,0,0,0,119,0,0,0,0,0,0,0,77,97,107,101,82,71,66,80,97,116,0,0,0,0,0,0,83,101,109,105,99,111,108,111,110,0,0,0,0,0,0,0,71,101,116,80,105,120,80,97,116,0,0,0,0,0,0,0,115,101,116,32,97,110,32,101,120,112,114,101,115,115,105,111,110,32,98,114,101,97,107,112,111,105,110,116,32,91,112,97,115,115,61,49,32,114,101,115,101,116,61,48,93,0,0,0,42,42,42,32,99,97,110,39,116,32,99,114,101,97,116,101,32,97,100,98,10,0,0,0,66,97,99,107,80,105,120,80,97,116,0,0,0,0,0,0,80,101,110,80,105,120,80,97,116,0,0,0,0,0,0,0,54,53,50,50,45,86,73,65,0,0,0,0,0,0,0,0,67,111,112,121,80,105,120,80,97,116,0,0,0,0,0,0,68,105,115,112,111,115,80,105,120,80,97,116,0,0,0,0,82,79,88,76,46,76,0,0,78,101,119,80,105,120,80,97,116,0,0,0,0,0,0,0,83,101,116,67,80,111,114,116,80,105,120,0,0,0,0,0,67,111,112,121,80,105,120,77,97,112,0,0,0,0,0,0,68,114,118,114,73,110,115,116,97,108,108,0,0,0,0,0,68,105,115,112,111,115,80,105,120,77,97,112,0,0,0,0,78,101,119,80,105,120,77,97,112,0,0,0,0,0,0,0,108,0,0,0,0,0,0,0,73,110,105,116,67,112,111,114,116,0,0,0,0,0,0,0,101,120,112,114,32,91,112,97,115,115,32,91,114,101,115,101,116,93,93,0,0,0,0,0,101,110,97,98,108,101,100,10,0,0,0,0,0,0,0,0,79,112,101,110,67,112,111,114,116,0,0,0,0,0,0,0,80,117,116,83,99,114,97,112,0,0,0,0,0,0,0,0,101,120,99,101,112,116,105,111,110,32,37,48,50,88,32,40,37,115,41,10,0,0,0,0,103,101,0,0,0,0,0,0,71,101,116,83,99,114,97,112,0,0,0,0,0,0,0,0,90,101,114,111,83,99,114,97,112,0,0,0,0,0,0,0,76,83,76,46,76,0,0,0,76,111,100,101,83,99,114,97,112,0,0,0,0,0,0,0,85,110,108,111,100,101,83,99,114,97,112,0,0,0,0,0,54,56,48,50,48,0,0,0,73,110,102,111,83,99,114,97,112,0,0,0,0,0,0,0,67,109,112,83,116,114,105,110,103,0,0,0,0,0,0,0,83,101,116,82,101,115,70,105,108,101,65,116,116,114,115,0,71,101,116,82,101,115,70,105,108,101,65,116,116,114,115,0,99,99,114,0,0,0,0,0,107,0,0,0,0,0,0,0,71,101,116,65,112,112,80,97,114,109,115,0,0,0,0,0,98,115,120,0,0,0,0,0,65,68,66,58,0,0,0,0,69,120,105,116,84,111,83,104,101,108,108,0,0,0,0,0,67,104,97,105,110,0,0,0,101,0,0,0,0,0,0,0,76,97,117,110,99,104,0,0,85,110,108,111,97,100,83,101,103,0,0,0,0,0,0,0,65,83,76,46,76,0,0,0,76,111,97,100,83,101,103,0,80,116,114,65,110,100,72,97,110,100,0,0,0,0,0,0,80,97,99,107,55,0,0,0,68,101,108,97,121,0,0,0,80,97,99,107,54,0,0,0,80,97,99,107,53,0,0,0,105,119,109,58,32,115,97,118,105,110,103,32,100,114,105,118,101,32,37,117,32,102,97,105,108,101,100,32,40,100,105,115,107,41,10,0,0,0,0,0,106,0,0,0,0,0,0,0,69,108,101,109,115,54,56,75,0,0,0,0,0,0,0,0,115,101,116,32,97,110,32,97,100,100,114,101,115,115,32,98,114,101,97,107,112,111,105,110,116,32,91,112,97,115,115,61,49,32,114,101,115,101,116,61,48,93,0,0,0,0,0,0,107,101,121,112,97,100,95,109,111,116,105,111,110,0,0,0,80,97,99,107,52,0,0,0,70,80,54,56,75,0,0,0,109,105,115,115,105,110,103,32,118,97,108,117,101,10,0,0,80,97,99,107,51,0,0,0,80,97,99,107,50,0,0,0,65,83,76,46,87,0,0,0,80,97,99,107,49,0,0,0,80,97,99,107,48,0,0,0,73,110,105,116,65,108,108,80,97,99,107,115,0,0,0,0,83,101,116,68,97,116,101,84,105,109,101,0,0,0,0,0,73,110,105,116,80,97,99,107,0,0,0,0,0,0,0,0,72,97,110,100,65,110,100,72,97,110,100,0,0,0,0,0,104,0,0,0,0,0,0,0,80,116,114,84,111,72,97,110,100,0,0,0,0,0,0,0,97,100,100,114,32,91,112,97,115,115,32,91,114,101,115,101,116,93,93,0,0,0,0,0,107,101,121,98,111,97,114,100,0,0,0,0,0,0,0,0,80,116,114,84,111,88,72,97,110,100,0,0,0,0,0,0,72,97,110,100,84,111,72,97,110,100,0,0,0,0,0,0,37,48,56,108,88,10,0,0,77,117,110,103,101,114,0,0,37,115,37,117,0,0,0,0,84,69,83,101,116,74,117,115,116,0,0,0,0,0,0,0,76,83,82,46,87,0,0,0,84,69,73,110,115,101,114,116,0,0,0,0,0,0,0,0,84,69,83,99,114,111,108,108,0,0,0,0,0,0,0,0,84,69,75,101,121,0,0,0,82,101,97,100,68,97,116,101,84,105,109,101,0,0,0,0,84,69,80,97,115,116,101,0,84,69,73,100,108,101,0,0,103,0,0,0,0,0,0,0,84,69,68,101,97,99,116,105,118,97,116,101,0,0,0,0,98,115,0,0,0,0,0,0,109,111,117,115,101,0,0,0,84,69,65,99,116,105,118,97,116,101,0,0,0,0,0,0,84,69,68,101,108,101,116,101,0,0,0,0,0,0,0,0,98,97,100,32,114,101,103,105,115,116,101,114,32,40,37,115,41,10,0,0,0,0,0,0,84,69,67,117,116,0,0,0,84,69,67,111,112,121,0,0,107,101,121,112,97,100,32,109,111,100,101,58,32,109,111,116,105,111,110,10,0,0,0,0,76,83,76,46,87,0,0,0,84,69,67,108,105,99,107,0,84,69,85,112,100,97,116,101,0,0,0,0,0,0,0,0,84,69,78,101,119,0,0,0,87,114,105,116,101,80,97,114,97,109,0,0,0,0,0,0,84,69,83,101,116,83,101,108,101,99,116,0,0,0,0,0,84,69,67,97,108,84,101,120,116,0,0,0,0,0,0,0,80,114,105,110,116,32,118,101,114,115,105,111,110,32,105,110,102,111,114,109,97,116,105,111,110,0,0,0,0,0,0,0,102,0,0,0,0,0,0,0,84,69,83,101,116,84,101,120,116,0,0,0,0,0,0,0,108,105,115,116,32,98,114,101,97,107,112,111,105,110,116,115,0,0,0,0,0,0,0,0,97,100,98,0,0,0,0,0,84,101,120,116,66,111,120,0,84,69,68,105,115,112,111,115,101,0,0,0,0,0,0,0,109,105,115,115,105,110,103,32,114,101,103,105,115,116,101,114,10,0,0,0,0,0,0,0,84,69,73,110,105,116,0,0,84,69,71,101,116,84,101,120,116,0,0,0,0,0,0,0,82,79,88,82,46,87,0,0,83,121,115,69,114,114,111,114,0,0,0,0,0,0,0,0,83,121,115,66,101,101,112,0,68,97,116,101,50,83,101,99,0,0,0,0,0,0,0,0,77,111,114,101,77,97,115,116,101,114,115,0,0,0,0,0,83,101,99,115,50,68,97,116,101,0,0,0,0,0,0,0,83,116,97,116,117,115,0,0,82,115,114,99,77,97,112,69,110,116,114,121,0,0,0,0,118,101,114,115,105,111,110,0,100,0,0,0,0,0,0,0,79,112,101,110,82,70,80,101,114,109,0,0,0,0,0,0,98,108,0,0,0,0,0,0,100,114,105,118,101,61,37,117,32,115,105,122,101,61,37,117,75,32,108,111,99,107,101,100,61,37,100,32,114,111,116,97,116,101,61,37,100,32,100,105,115,107,61,37,117,32,102,105,108,101,61,37,115,10,0,0,75,101,121,84,114,97,110,115,0,0,0,0,0,0,0,0,83,121,115,69,100,105,116,0,59,32,0,0,0,0,0,0,85,110,105,113,117,101,73,68,0,0,0,0,0,0,0,0,105,110,115,101,114,116,32,100,114,105,118,101,32,37,117,10,0,0,0,0,0,0,0,0,71,101,116,78,101,119,77,66,97,114,0,0,0,0,0,0,82,79,88,76,46,87,0,0,71,101,116,82,77,101,110,117,0,0,0,0,0,0,0,0,71,101,116,78,101,119,67,111,110,116,114,111,108,0,0,0,71,101,116,78,101,119,87,105,110,100,111,119,0,0,0,0,79,102,102,108,105,110,101,0,71,101,116,80,105,99,116,117,114,101,0,0,0,0,0,0,115,99,115,105,58,32,119,114,105,116,101,32,98,108,111,99,107,32,99,111,117,110,116,32,37,117,10,0,0,0,0,0,71,101,116,73,99,111,110,0,83,101,116,32,116,104,101,32,108,111,103,32,108,101,118,101,108,32,116,111,32,100,101,98,117,103,32,91,110,111,93,0,115,0,0,0,0,0,0,0,71,101,116,83,116,114,105,110,103,0,0,0,0,0,0,0,99,108,101,97,114,32,97,32,98,114,101,97,107,112,111,105,110,116,32,111,114,32,97,108,108,0,0,0,0,0,0,0,97,117,116,111,95,114,111,116,97,116,101,0,0,0,0,0,71,101,116,67,117,114,115,111,114,0,0,0,0,0,0,0,71,101,116,80,97,116,116,101,114,110,0,0,0,0,0,0,109,97,99,46,105,110,115,101,114,116,0,0,0,0,0,0,67,108,111,115,101,68,101,115,107,65,99,99,0,0,0,0,79,112,101,110,68,101,115,107,65,99,99,0,0,0,0,0,82,79,82,46,87,0,0,0,83,121,115,116,101,109,77,101,110,117,0,0,0,0,0,0,101,109,117,46,100,105,115,107,46,101,106,101,99,116,0,0,83,121,115,116,101,109,84,97,115,107,0,0,0,0,0,0,83,121,115,116,101,109,67,108,105,99,107,0,0,0,0,0,86,82,101,109,111,118,101,0,83,121,115,116,101,109,69,118,101,110,116,0,0,0,0,0,49,0,0,0,0,0,0,0,116,101,114,109,46,114,101,108,101,97,115,101,0,0,0,0,67,114,101,97,116,101,82,101,115,70,105,108,101,0,0,0,118,101,114,98,111,115,101,0,97,0,0,0,0,0,0,0,87,114,105,116,101,82,101,115,111,117,114,99,101,0,0,0,91,105,110,100,101,120,93,0,70,53,0,0,0,0,0,0,105,110,115,101,114,116,101,100,0,0,0,0,0,0,0,0,94,94,0,0,0,0,0,0,70,114,97,109,101,82,111,117,110,100,82,101,99,116,0,0,60,101,111,102,62,0,0,0,82,101,115,69,114,114,111,114,0,0,0,0,0,0,0,0,37,45,56,115,32,37,115,44,32,37,115,44,32,37,115,0,37,115,58,32,101,114,114,111,114,32,112,97,114,115,105,110,103,32,105,110,105,32,115,116,114,105,110,103,32,40,37,115,41,10,0,0,0,0,0,0,82,109,118,101,82,101,102,101,114,101,110,99,101,0,0,0,115,97,118,101,0,0,0,0,97,117,116,111,0,0,0,0,97,115,112,101,99,116,95,121,0,0,0,0,0,0,0,0,82,109,118,101,82,101,115,111,117,114,99,101,0,0,0,0,115,105,122,101,107,0,0,0,116,121,112,101,0,0,0,0,82,79,76,46,87,0,0,0,37,115,58,32,109,105,115,115,105,110,103,32,111,112,116,105,111,110,32,97,114,103,117,109,101,110,116,32,40,45,37,99,41,10,0,0,0,0,0,0,65,100,100,82,101,102,101,114,101,110,99,101,0,0,0,0,105,100,101,110,116,105,102,105,101,114,32,116,111,111,32,108,111,110,103,0,0,0,0,0,120,0,0,0,0,0,0,0,110,111,0,0,0,0,0,0,65,100,100,82,101,115,111,117,114,99,101,0,0,0,0,0,116,100,48,58,32,122,101,114,111,32,100,97,116,97,32,108,101,110,103,116,104,32,40,37,117,47,37,117,47,37,117,41,10,0,0,0,0,0,0,0,67,104,97,110,103,101,100,82,101,115,111,117,114,99,101,0,86,73,110,115,116,97,108,108,0,0,0,0,0,0,0,0,46,105,109,100,0,0,0,0,83,101,116,82,101,115,73,110,102,111,0,0,0,0,0,0,115,101,114,99,111,110,0,0,121,109,117,108,0,0,0,0,115,116,100,105,111,0,0,0,71,101,116,82,101,115,73,110,102,111,0,0,0,0,0,0,83,101,116,32,116,104,101,32,116,101,114,109,105,110,97,108,32,100,101,118,105,99,101,0,67,97,112,115,76,111,99,107,0,0,0,0,0,0,0,0,100,105,115,107,32,37,117,58,32,119,114,105,116,105,110,103,32,98,97,99,107,32,102,97,105,108,101,100,10,0,0,0,83,101,116,82,101,115,65,116,116,114,115,0,0,0,0,0,98,99,0,0,0,0,0,0,108,111,99,107,101,100,0,0,71,101,116,82,101,115,65,116,116,114,115,0,0,0,0,0,83,105,122,101,82,115,114,99,0,0,0,0,0,0,0,0,114,117,110,32,119,105,116,104,32,98,114,101,97,107,112,111,105,110,116,115,32,97,116,32,97,100,100,114,0,0,0,0,37,45,56,115,32,37,115,44,32,37,115,0,0,0,0,0,72,111,109,101,82,101,115,70,105,108,101,0,0,0,0,0,82,101,108,101,97,115,101,82,101,115,111,117,114,99,101,0,66,70,84,83,84,0,0,0,76,111,97,100,82,101,115,111,117,114,99,101,0,0,0,0,71,101,116,78,97,109,101,100,82,101,115,111,117,114,99,101,0,0,0,0,0,0,0,0,71,101,116,82,101,115,111,117,114,99,101,0,0,0,0,0,70,108,117,115,104,69,118,101,110,116,115,0,0,0,0,0,71,101,116,73,110,100,84,121,112,101,0,0,0,0,0,0,67,111,117,110,116,84,121,112,101,115,0,0,0,0,0,0,116,101,114,109,105,110,97,108,0,0,0,0,0,0,0,0,82,101,116,117,114,110,0,0,71,101,116,73,110,100,82,101,115,111,117,114,99,101,0,0,115,105,110,103,108,101,95,115,105,100,101,100,0,0,0,0,67,111,117,110,116,82,101,115,111,117,114,99,101,115,0,0,83,101,116,82,101,115,76,111,97,100,0,0,0,0,0,0,37,45,56,115,32,37,115,0,99,0,0,0,0,0,0,0,67,108,111,115,101,82,101,115,70,105,108,101,0,0,0,0,85,112,100,97,116,101,82,101,115,70,105,108,101,0,0,0,66,70,69,88,84,85,0,0,85,115,101,82,101,115,70,105,108,101,0,0,0,0,0,0,79,112,101,110,82,101,115,70,105,108,101,0,0,0,0,0,82,115,114,99,90,111,110,101,73,110,105,116,0,0,0,0,54,56,48,49,48,0,0,0,71,101,116,79,83,69,118,101,110,116,0,0,0,0,0,0,73,110,105,116,82,101,115,111,117,114,99,101,115,0,0,0,67,117,114,82,101,115,70,105,108,101,0,0,0,0,0,0,83,101,116,32,116,104,101,32,67,80,85,32,115,112,101,101,100,0,0,0,0,0,0,0,93,0,0,0,0,0,0,0,115,112,0,0,0,0,0,0,83,101,116,82,101,115,80,117,114,103,101,0,0,0,0,0,102,105,108,101,0,0,0,0,68,101,116,97,99,104,82,101,115,111,117,114,99,101,0,0,77,111,100,97,108,68,105,97,108,111,103,0,0,0,0,0,91,97,100,100,114,46,46,93,0,0,0,0,0,0,0,0,71,101,116,73,84,101,120,116,0,0,0,0,0,0,0,0,83,101,116,73,84,101,120,116,0,0,0,0,0,0,0,0,66,70,67,72,71,0,0,0,83,101,116,68,73,116,101,109,0,0,0,0,0,0,0,0,71,101,116,68,73,116,101,109,0,0,0,0,0,0,0,0,69,114,114,111,114,83,111,117,110,100,0,0,0,0,0,0,79,83,69,118,101,110,116,65,118,97,105,108,0,0,0,0,80,97,114,97,109,84,101,120,116,0,0,0,0,0,0,0,70,114,101,101,65,108,101,114,116,0,0,0,0,0,0,0,67,111,117,108,100,65,108,101,114,116,0,0,0,0,0,0,105,110,116,0,0,0,0,0,82,105,103,104,116,66,114,97,99,107,101,116,0,0,0,0,105,119,109,58,32,115,97,118,105,110,103,32,100,114,105,118,101,32,37,117,32,102,97,105,108,101,100,32,40,112,98,105,116,41,10,0,0,0,0,0,67,97,117,116,105,111,110,65,108,101,114,116,0,0,0,0,78,111,116,101,65,108,101,114,116,0,0,0,0,0,0,0,100,105,115,107,0,0,0,0,83,116,111,112,65,108,101,114,116,0,0,0,0,0,0,0,65,108,101,114,116,0,0,0,66,70,69,88,84,83,0,0,70,105,110,100,68,73,116,101,109,0,0,0,0,0,0,0,68,105,115,112,111,115,68,105,97,108,111,103,0,0,0,0,67,108,111,115,101,68,105,97,108,111,103,0,0,0,0,0,80,111,115,116,69,118,101,110,116,0,0,0,0,0,0,0,68,114,97,119,68,105,97,108,111,103,0,0,0,0,0,0,68,105,97,108,111,103,83,101,108,101,99,116,0,0,0,0,115,112,101,101,100,0,0,0,91,0,0,0,0,0,0,0,73,115,68,105,97,108,111,103,69,118,101,110,116,0,0,0,83,101,108,73,84,101,120,116,0,0,0,0,0,0,0,0,78,101,119,68,105,97,108,111,103,0,0,0,0,0,0,0,97,100,100,114,61,48,120,37,48,54,108,120,10,0,0,0,71,101,116,78,101,119,68,105,97,108,111,103,0,0,0,0,65,37,117,0,0,0,0,0,73,110,105,116,68,105,97,108,111,103,115,0,0,0,0,0,66,70,67,76,82,0,0,0,70,114,101,101,68,105,97,108,111,103,0,0,0,0,0,0,67,111,117,108,100,68,105,97,108,111,103,0,0,0,0,0,85,112,100,116,68,105,97,108,111,103,0,0,0,0,0,0,66,108,111,99,107,77,111,118,101,0,0,0,0,0,0,0,87,97,105,116,77,111,117,115,101,85,112,0,0,0,0,0,71,101,116,75,101,121,115,0,78,101,118,101,114,32,115,116,111,112,32,114,117,110,110,105,110,103,32,91,110,111,93,0,76,101,102,116,66,114,97,99,107,101,116,0,0,0,0,0,84,105,99,107,67,111,117,110,116,0,0,0,0,0,0,0,98,108,111,99,107,95,99,111,117,110,116,0,0,0,0,0,66,117,116,116,111,110,0,0,83,116,105,108,108,68,111,119,110,0,0,0,0,0,0,0,73,87,77,58,0,0,0,0,71,101,116,77,111,117,115,101,0,0,0,0,0,0,0,0,69,118,101,110,116,65,118,97,105,108,0,0,0,0,0,0,71,101,116,78,101,120,116,69,118,101,110,116,0,0,0,0,66,70,83,69,84,0,0,0,52,0,0,0,0,0,0,0,69,110,113,117,101,117,101,0,68,101,113,117,101,117,101,0,83,101,116,65,112,112,108,76,105,109,105,116,0,0,0,0,68,114,97,119,49,67,111,110,116,114,111,108,0,0,0,0,70,105,110,100,67,111,110,116,114,111,108,0,0,0,0,0,110,111,45,109,111,110,105,116,111,114,0,0,0,0,0,0,112,0,0,0,0,0,0,0,83,101,116,67,116,108,65,99,116,105,111,110,0,0,0,0,98,108,111,99,107,95,115,116,97,114,116,0,0,0,0,0,105,119,109,0,0,0,0,0,71,101,116,67,116,108,65,99,116,105,111,110,0,0,0,0,68,114,97,119,67,111,110,116,114,111,108,115,0,0,0,0,101,109,117,46,115,116,111,112,0,0,0,0,0,0,0,0,84,114,97,99,107,67,111,110,116,114,111,108,0,0,0,0,117,110,104,97,110,100,108,101,100,32,104,111,111,107,32,40,37,48,52,88,41,10,0,0,68,114,97,103,67,111,110,116,114,111,108,0,0,0,0,0,36,0,0,0,0,0,0,0,84,101,115,116,67,111,110,116,114,111,108,0,0,0,0,0,83,101,116,77,97,120,67,116,108,0,0,0,0,0,0,0,83,101,116,77,105,110,67,116,108,0,0,0,0,0,0,0,73,110,105,116,65,112,112,108,90,111,110,101,0,0,0,0,83,101,116,67,116,108,86,97,108,117,101,0,0,0,0,0,67,111,110,116,114,111,108,0,117,110,107,110,111,119,110,32,67,80,85,32,109,111,100,101,108,32,40,37,115,41,10,0,71,101,116,77,97,120,67,116,108,0,0,0,0,0,0,0,83,116,97,114,116,32,114,117,110,110,105,110,103,32,105,109,109,101,100,105,97,116,101,108,121,32,91,110,111,93,0,0,111,0,0,0,0,0,0,0,71,101,116,77,105,110,67,116,108,0,0,0,0,0,0,0,100,114,105,118,101,61,37,117,32,118,99,104,115,61,37,108,117,47,37,108,117,47,37,108,117,10,0,0,0,0,0,0,105,100,61,37,117,32,100,114,105,118,101,61,37,117,32,118,101,110,100,111,114,61,34,37,115,34,32,112,114,111,100,117,99,116,61,34,37,115,34,10,0,0,0,0,0,0,0,0,71,101,116,67,116,108,86,97,108,117,101,0,0,0,0,0,83,101,116,67,84,105,116,108,101,0,0,0,0,0,0,0,32,32,32,32,32,0,0,0,71,101,116,67,84,105,116,108,101,0,0,0,0,0,0,0,115,111,110,121,32,100,114,105,118,101,114,32,97,116,32,48,120,37,48,54,108,120,10,0,72,105,108,105,116,101,67,111,110,116,114,111,108,0,0,0,40,91,37,115,44,32,37,115,44,32,37,115,37,115,93,44,32,37,115,41,0,0,0,0,83,105,122,101,67,111,110,116,114,111,108,0,0,0,0,0,83,101,116,67,82,101,102,67,111,110,0,0,0,0,0,0,71,101,116,67,82,101,102,67,111,110,0,0,0,0,0,0,69,109,112,116,121,72,97,110,100,108,101,0,0,0,0,0,77,111,118,101,67,111,110,116,114,111,108,0,0,0,0,0,79,112,101,110,0,0,0,0,115,99,115,105,58,32,117,110,107,110,111,119,110,32,99,111,109,109,97,110,100,32,40,37,48,50,88,41,10,0,0,0,42,42,42,32,99,111,109,109,105,116,32,101,114,114,111,114,32,102,111,114,32,100,114,105,118,101,32,37,117,10,0,0,72,105,100,101,67,111,110,116,114,111,108,0,0,0,0,0,114,117,110,0,0,0,0,0,73,0,0,0,0,0,0,0,83,104,111,119,67,111,110,116,114,111,108,0,0,0,0,0,118,105,115,105,98,108,101,95,115,0,0,0,0,0,0,0,80,67,69,68,73,83,75,0,75,105,108,108,67,111,110,116,114,111,108,115,0,0,0,0,68,105,115,112,111,115,67,111,110,116,114,111,108,0,0,0,37,48,52,88,32,0,0,0,78,101,119,67,111,110,116,114,111,108,0,0,0,0,0,0,85,112,100,116,67,111,110,116,114,111,108,0,0,0,0,0,40,91,37,115,44,32,37,115,93,44,32,37,115,37,115,44,32,37,115,41,0,0,0,0,68,101,108,77,101,110,117,73,116,101,109,0,0,0,0,0,101,109,117,46,100,105,115,107,46,99,111,109,109,105,116,0,73,110,115,101,114,116,82,101,115,77,101,110,117,0,0,0,67,111,117,110,116,77,73,116,101,109,115,0,0,0,0,0,72,85,110,108,111,99,107,0,68,101,108,116,97,80,111,105,110,116,0,0,0,0,0,0,101,109,117,46,101,120,105,116,0,0,0,0,0,0,0,0,116,101,114,109,46,115,99,114,101,101,110,115,104,111,116,0,80,105,110,82,101,99,116,0,99,111,109,109,105,116,0,0,83,101,116,32,116,104,101,32,108,111,103,32,108,101,118,101,108,32,116,111,32,101,114,114,111,114,32,91,110,111,93,0,117,0,0,0,0,0,0,0,65,100,100,82,101,115,77,101,110,117,0,0,0,0,0,0,118,105,115,105,98,108,101,95,104,0,0,0,0,0,0,0,70,52,0,0,0,0,0,0,112,114,111,100,117,99,116,0,124,0,0,0,0,0,0,0,70,108,97,115,104,77,101,110,117,66,97,114,0,0,0,0,58,32,0,0,0,0,0,0,80,108,111,116,73,99,111,110,0,0,0,0,0,0,0,0,37,48,56,108,88,32,32,37,115,10,0,0,0,0,0,0,37,115,58,32,98,97,100,32,100,114,105,118,101,32,110,117,109,98,101,114,32,40,37,117,41,10,0,0,0,0,0,0,83,101,116,77,70,108,97,115,104,0,0,0,0,0,0,0,108,111,97,100,0,0,0,0,102,105,108,101,61,37,115,32,102,111,114,109,97,116,61,98,105,110,97,114,121,32,97,100,100,114,61,48,120,37,48,56,108,120,10,0,0,0,0,0,97,115,112,101,99,116,95,120,0,0,0,0,0,0,0,0,71,101,116,77,72,97,110,100,108,101,0,0,0,0,0,0,115,105,122,101,109,0,0,0,100,114,105,118,101,0,0,0,37,115,58,32,117,110,107,110,111,119,110,32,111,112,116,105,111,110,32,40,45,37,99,41,10,0,0,0,0,0,0,0,37,115,37,115,37,48,56,88,0,0,0,0,0,0,0,0,67,97,108,99,77,101,110,117,83,105,122,101,0,0,0,0,42,42,42,32,37,115,32,91,37,115,93,10,0,0,0,0,98,58,32,117,110,107,110,111,119,110,32,99,111,109,109,97,110,100,0,0,0,0,0,0,102,97,108,115,101,0,0,0,115,100,108,0,0,0,0,0,83,101,116,73,116,101,109,0,116,100,48,58,32,99,114,99,32,101,114,114,111,114,32,97,116,32,115,101,99,116,111,114,32,37,117,47,37,117,47,37,117,32,40,110,111,32,100,97,116,97,41,10,0,0,0,0,71,101,116,73,116,101,109,0,32,37,48,50,88,0,0,0,72,76,111,99,107,0,0,0,46,105,109,97,0,0,0,0,67,104,101,99,107,73,116,101,109,0,0,0,0,0,0,0,46,116,99,0,0,0,0,0,45,45,0,0,0,0,0,0,120,100,105,118,0,0,0,0,112,116,121,0,0,0,0,0,83,101,116,73,116,109,77,97,114,107,0,0,0,0,0,0,99,111,109,109,105,116,105,110,103,32,100,114,105,118,101,32,37,117,10,0,0,0,0,0,113,101,100,58,32,117,110,107,110,111,119,110,32,102,101,97,116,117,114,101,115,32,40,48,120,37,48,56,108,108,120,41,10,0,0,0,0,0,0,0,113,117,105,101,116,0,0,0,121,0,0,0,0,0,0,0,100,105,115,107,32,37,117,58,32,119,114,105,116,105,110,103,32,98,97,99,107,32,102,100,99,32,105,109,97,103,101,10,0,0,0,0,0,0,0,0,71,101,116,73,116,109,77,97,114,107,0,0,0,0,0,0,118,105,115,105,98,108,101,95,99,0,0,0,0,0,0,0,80,67,69,0,0,0,0,0,83,101,116,73,116,109,83,116,121,108,101,0,0,0,0,0,71,101,116,73,116,109,83,116,121,108,101,0,0,0,0,0,45,0,0,0,0,0,0,0,83,101,116,73,116,109,73,99,111,110,0,0,0,0,0,0,71,101,116,73,116,109,73,99,111,110,0,0,0,0,0,0,42,37,117,0,0,0,0,0,77,101,110,117,75,101,121,0,77,101,110,117,83,101,108,101,99,116,0,0,0,0,0,0,83,101,116,77,101,110,117,66,97,114,0,0,0,0,0,0,82,101,99,111,118,101,114,72,97,110,100,108,101,0,0,0,71,101,116,77,101,110,117,66,97,114,0,0,0,0,0,0,68,105,115,97,98,108,101,73,116,101,109,0,0,0,0,0,42,42,42,32,99,111,109,109,105,116,32,101,114,114,111,114,58,32,98,97,100,32,100,114,105,118,101,32,40,37,115,41,10,0,0,0,0,0,0,0,83,101,116,32,116,104,101,32,67,80,85,32,109,111,100,101,108,0,0,0,0,0,0,0,116,0,0,0,0,0,0,0,69,110,97,98,108,101,73,116])
.concat([101,109,0,0,0,0,0,0,100,105,115,107,0,0,0,0,118,101,110,100,111,114,0,0,72,105,108,105,116,101,77,101,110,117,0,0,0,0,0,0,68,114,97,119,77,101,110,117,66,97,114,0,0,0,0,0,37,48,56,108,88,58,32,117,110,100,101,102,105,110,101,100,32,111,112,101,114,97,116,105,111,110,58,32,37,48,52,108,88,32,91,37,48,52,88,32,37,48,52,88,32,37,48,52,88,32,37,48,52,88,32,37,48,52,88,93,10,0,0,0,97,100,98,45,107,98,100,58,32,116,97,108,107,32,50,10,0,0,0,0,0,0,0,0,68,101,108,101,116,101,77,101,110,117,0,0,0,0,0,0,73,110,115,101,114,116,77,101,110,117,0,0,0,0,0,0,37,115,37,117,37,115,0,0,67,108,101,97,114,77,101,110,117,66,97,114,0,0,0,0,65,112,112,101,110,100,77,101,110,117,0,0,0,0,0,0,68,105,115,112,111,115,77,101,110,117,0,0,0,0,0,0,82,101,97,108,108,111,99,72,97,110,100,108,101,0,0,0,78,101,119,77,101,110,117,0,54,56,48,48,48,0,0,0,73,110,105,116,77,101,110,117,115,0,0,0,0,0,0,0,42,42,42,32,99,111,109,109,105,116,32,102,97,105,108,101,100,32,102,111,114,32,97,116,32,108,101,97,115,116,32,111,110,101,32,100,105,115,107,10,0,0,0,0,0,0,0,0,83,101,116,32,116,104,101,32,108,111,103,32,102,105,108,101,32,110,97,109,101,32,91,110,111,110,101,93,0,0,0,0,114,0,0,0,0,0,0,0,115,114,0,0,0,0,0,0,71,101,116,87,105,110,100,111,119,80,105,99,0,0,0,0,42,42,42,32,108,111,97,100,105,110,103,32,100,114,105,118,101,32,48,120,37,48,50,120,32,102,97,105,108,101,100,32,40,99,111,119,41,10,0,0,100,114,105,118,101,0,0,0,83,101,116,87,105,110,100,111,119,80,105,99,0,0,0,0,67,108,111,115,101,87,105,110,100,111,119,0,0,0,0,0,37,48,56,108,88,58,32,101,120,99,101,112,116,105,111,110,32,37,48,50,88,32,40,37,115,41,32,73,87,61,37,48,52,88,10,0,0,0,0,0,70,105,110,100,87,105,110,100,111,119,0,0,0,0,0,0,71,114,111,119,87,105,110,100,111,119,0,0,0,0,0,0,80,67,0,0,0,0,0,0,86,97,108,105,100,82,101,99,116,0,0,0,0,0,0,0,86,97,108,105,100,82,103,110,0,0,0,0,0,0,0,0,73,110,118,97,108,82,101,99,116,0,0,0,0,0,0,0,72,97,110,100,108,101,90,111,110,101,0,0,0,0,0,0,73,110,118,97,108,82,103,110,0,0,0,0,0,0,0,0,68,114,97,103,84,104,101,82,103,110,0,0,0,0,0,0,99,111,109,109,105,116,105,110,103,32,97,108,108,32,100,114,105,118,101,115,10,0,0,0,108,111,103,0,0,0,0,0,101,0,0,0,0,0,0,0,68,114,97,103,87,105,110,100,111,119,0,0,0,0,0,0,70,114,111,110,116,87,105,110,100,111,119,0,0,0,0,0,49,0,0,0,0,0,0,0,105,100,0,0,0,0,0,0,105,119,109,58,32,115,97,118,105,110,103,32,100,114,105,118,101,32,37,117,10,0,0,0,69,110,100,85,112,100,97,116,101,0,0,0,0,0,0,0,103,98,0,0,0,0,0,0,66,101,103,105,110,85,112,100,97,116,101,0,0,0,0,0,83,79,78,89,58,0,0,0,83,101,110,100,66,101,104,105,110,100,0,0,0,0,0,0,60,69,65,62,40,37,48,50,88,41,0,0,0,0,0,0,66,114,105,110,103,84,111,70,114,111,110,116,0,0,0,0,83,101,108,101,99,116,87,105,110,100,111,119,0,0,0,0,84,114,97,99,107,71,111,65,119,97,121,0,0,0,0,0,71,101,116,72,97,110,100,108,101,83,105,122,101,0,0,0,83,105,122,101,87,105,110,100,111,119,0,0,0,0,0,0,72,105,108,105,116,101,87,105,110,100,111,119,0,0,0,0,97,108,108,0,0,0,0,0,65,100,100,32,97,110,32,105,110,105,32,115,116,114,105,110,103,32,97,102,116,101,114,32,116,104,101,32,99,111,110,102,105,103,32,102,105,108,101,0,119,0,0,0,0,0,0,0,77,111,118,101,87,105,110,100,111,119,0,0,0,0,0,0,114,119,0,0,0,0,0,0,100,101,118,105,99,101,0,0,83,101,116,87,84,105,116,108,101,0,0,0,0,0,0,0,71,101,116,87,84,105,116,108,101,0,0,0,0,0,0,0,116,101,114,109,46,114,101,108,101,97,115,101,0,0,0,0,83,101,116,87,82,101,102,67,111,110,0,0,0,0,0,0,68,37,117,0,0,0,0,0,71,101,116,87,82,101,102,67,111,110,0,0,0,0,0,0,37,115,37,115,37,48,50,88,40,80,67,44,32,37,115,37,117,37,115,42,37,117,41,0,72,105,100,101,87,105,110,100,111,119,0,0,0,0,0,0,83,104,111,119,87,105,110,100,111,119,0,0,0,0,0,0,115,116,100,105,111,58,102,105,108,101,61,0,0,0,0,0,68,105,115,112,111,115,87,105,110,100,111,119,0,0,0,0,83,101,116,72,97,110,100,108,101,83,105,122,101,0,0,0,78,101,119,87,105,110,100,111,119,0,0,0,0,0,0,0,73,110,105,116,87,105,110,100,111,119,115,0,0,0,0,0,101,106,101,99,116,105,110,103,32,100,114,105,118,101,32,37,108,117,10,0,0,0,0,0,105,110,105,45,97,112,112,101,110,100,0,0,0,0,0,0,113,0,0,0,0,0,0,0,67,104,101,99,107,85,112,100,97,116,101,0,0,0,0,0,114,111,0,0,0,0,0,0,97,100,100,114,61,48,120,37,48,54,108,120,32,115,105,122,101,61,48,120,37,108,120,10,0,0,0,0,0,0,0,0,71,101,116,87,77,103,114,80,111,114,116,0,0,0,0,0,68,114,97,119,78,101,119,0,98,0,0,0,0,0,0,0,83,97,118,101,79,108,100,0,80,97,105,110,116,66,101,104,105,110,100,0,0,0,0,0,37,115,37,48,56,108,88,40,80,67,41,0,0,0,0,0,80,97,105,110,116,79,110,101,0,0,0,0,0,0,0,0,67,108,105,112,65,98,111,118,101,0,0,0,0,0,0,0,51,0,0,0,0,0,0,0,67,97,108,99,86,66,101,104,105,110,100,0,0,0,0,0,68,105,115,112,111,115,72,97,110,100,108,101,0,0,0,0,67,97,108,99,86,105,115,0,83,104,111,119,72,105,100,101,0,0,0,0,0,0,0,0,42,42,42,32,100,105,115,107,32,101,106,101,99,116,32,101,114,114,111,114,58,32,110,111,32,115,117,99,104,32,100,105,115,107,32,40,37,108,117,41,10,0,0,0,0,0,0,0,65,100,100,32,97,110,32,105,110,105,32,115,116,114,105,110,103,32,98,101,102,111,114,101,32,116,104,101,32,99,111,110,102,105,103,32,102,105,108,101,0,0,0,0,0,0,0,0,84,97,98,0,0,0,0,0,83,101,116,83,116,114,105,110,103,0,0,0,0,0,0,0,100,114,105,118,101,61,37,117,32,116,121,112,101,61,37,115,32,98,108,111,99,107,115,61,37,108,117,32,99,104,115,61,37,108,117,47,37,108,117,47,37,108,117,32,37,115,32,102,105,108,101,61,37,115,10,0,83,67,83,73,58,0,0,0,78,101,119,83,116,114,105,110,103,0,0,0,0,0,0,0,68,114,97,103,71,114,97,121,82,103,110,0,0,0,0,0,117,110,107,110,111,119,110,32,99,111,109,112,111,110,101,110,116,32,40,37,115,41,10,0,68,114,97,119,71,114,111,119,73,99,111,110,0,0,0,0,83,101,116,70,111,110,116,76,111,99,107,0,0,0,0,0,109,97,114,107,58,32,80,67,61,37,48,54,108,88,10,0,37,115,37,115,37,48,52,88,0,0,0,0,0,0,0,0,82,101,97,108,70,111,110,116,0,0,0,0,0,0,0,0,70,77,83,119,97,112,70,111,110,116,0,0,0,0,0,0,71,101,116,70,78,117,109,0,78,101,119,72,97,110,100,108,101,0,0,0,0,0,0,0,71,101,116,70,78,97,109,101,0,0,0,0,0,0,0,0,87,114,105,116,101,0,0,0,73,110,105,116,70,111,110,116,115,0,0,0,0,0,0,0,42,42,42,32,100,105,115,107,32,101,106,101,99,116,32,101,114,114,111,114,58,32,98,97,100,32,100,114,105,118,101,32,40,37,115,41,10,0,0,0,66,97,99,107,115,112,97,99,101,0,0,0,0,0,0,0,105,110,105,45,112,114,101,102,105,120,0,0,0,0,0,0,77,97,112,80,111,108,121,0,42,42,42,32,108,111,97,100,105,110,103,32,100,114,105,118,101,32,48,120,37,48,50,120,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,0,115,105,122,101,0,0,0,0,77,97,112,82,103,110,0,0,77,97,112,82,101,99,116,0,118,105,97,0,0,0,0,0,77,97,112,80,116,0,0,0,115,111,110,121,32,100,114,105,118,101,114,32,110,111,116,32,102,111,117,110,100,10,0,0,83,99,97,108,101,80,116,0,46,87,0,0,0,0,0,0,68,114,97,119,80,105,99,116,117,114,101,0,0,0,0,0,75,105,108,108,80,105,99,116,117,114,101,0,0,0,0,0,67,108,111,115,101,80,105,99,116,117,114,101,0,0,0,0,71,101,116,80,116,114,83,105,122,101,0,0,0,0,0,0,79,112,101,110,80,105,99,116,117,114,101,0,0,0,0,0,115,99,115,105,58,32,115,101,116,32,32,56,58,32,37,48,52,108,88,32,60,45,32,37,48,50,88,10,0,0,0,0,80,105,99,67,111,109,109,101,110,116,0,0,0,0,0,0,115,101,116,116,105,110,103,32,114,101,97,100,111,110,108,121,32,100,114,105,118,101,32,37,108,117,10,0,0,0,0,0,61,0,0,0,0,0,0,0,65,100,100,32,97,32,100,105,114,101,99,116,111,114,121,32,116,111,32,116,104,101,32,115,101,97,114,99,104,32,112,97,116,104,0,0,0,0,0,0,83,116,100,67,111,109,109,101,110,116,0,0,0,0,0,0,116,101,108,101,100,105,115,107,0,0,0,0,0,0,0,0,115,99,115,105,0,0,0,0,83,116,100,80,117,116,80,105,99,0,0,0,0,0,0,0,83,99,114,111,108,108,82,101,99,116,0,0,0,0,0,0,115,99,99,0,0,0,0,0,83,116,100,71,101,116,80,105,99,0,0,0,0,0,0,0,83,116,100,84,120,77,101,97,115,0,0,0,0,0,0,0,46,76,0,0,0,0,0,0,67,111,112,121,66,105,116,115,0,0,0,0,0,0,0,0,101,109,117,46,99,112,117,46,115,112,101,101,100,46,115,116,101,112,0,0,0,0,0,0,83,116,100,66,105,116,115,0,83,101,116,83,116,100,80,114,111,99,115,0,0,0,0,0,83,101,116,80,116,114,83,105,122,101,0,0,0,0,0,0,82,101,99,116,73,110,82,103,110,0,0,0,0,0,0,0,107,101,121,109,97,112,0,0,116,101,114,109,46,101,115,99,97,112,101,0,0,0,0,0,80,116,73,110,82,103,110,0,115,101,116,116,105,110,103,32,114,101,97,100,47,119,114,105,116,101,32,100,114,105,118,101,32,37,108,117,10,0,0,0,69,113,117,97,108,0,0,0,112,97,116,104,0,0,0,0,88,111,114,82,103,110,0,0,112,102,100,99,45,97,117,116,111,0,0,0,0,0,0,0,70,51,0,0,0,0,0,0,100,114,105,118,101,61,37,117,32,100,101,108,97,121,61,37,108,117,10,0,0,0,0,0,38,38,0,0,0,0,0,0,68,105,102,102,82,103,110,0,37,115,58,37,108,117,58,32,37,115,0,0,0,0,0,0,85,110,105,111,110,82,103,110,0,0,0,0,0,0,0,0,109,101,109,0,0,0,0,0,83,101,99,116,82,103,110,0,91,37,48,54,108,88,93,32,0,0,0,0,0,0,0,0,102,105,108,101,61,37,115,32,102,111,114,109,97,116,61,115,114,101,99,10,0,0,0,0,101,115,99,97,112,101,0,0,69,113,117,97,108,82,103,110,0,0,0,0,0,0,0,0,98,97,115,101,0,0,0,0,100,114,105,118,101,61,37,117,32,116,121,112,101,61,99,111,119,32,102,105,108,101,61,37,115,10,0,0,0,0,0,0,37,115,58,32,109,105,115,115,105,110,103,32,111,112,116,105,111,110,32,97,114,103,117,109,101,110,116,32,40,37,115,41,10,0,0,0,0,0,0,0,37,115,37,115,37,48,50,88,40,65,37,117,44,32,37,115,37,117,37,115,42,37,117,41,0,0,0,0,0,0,0,0,69,109,112,116,121,82,103,110,0,0,0,0,0,0,0,0,99,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,119,97,118,0,0,0,0,0,73,110,115,101,116,82,103,110,0,0,0,0,0,0,0,0,116,100,48,58,32,116,114,97,99,107,32,99,114,99,32,40,37,48,50,88,32,37,48,52,88,41,10,0,0,0,0,0,100,99,52,50,58,32,116,97,103,32,99,104,101,99,107,115,117,109,32,101,114,114,111,114,10,0,0,0,0,0,0,0,79,102,115,101,116,82,103,110,0,0,0,0,0,0,0,0,68,105,115,112,111,115,80,116,114,0,0,0,0,0,0,0,46,105,109,97,103,101,0,0,82,101,99,116,82,103,110,0,46,112,98,105,116,0,0,0,119,98,0,0,0,0,0,0,45,0,0,0,0,0,0,0,120,109,117,108,0,0,0,0,115,101,114,99,111,110,0,0,83,101,116,82,101,99,82,103,110,0,0,0,0,0,0,0,99,111,109,109,105,116,0,0,115,101,116,116,105,110,103,32,105,119,109,32,100,114,105,118,101,32,37,108,117,32,116,111,32,114,101,97,100,45,111,110,108,121,10,0,0,0,0,0,99,111,109,109,105,116,0,0,45,0,0,0,0,0,0,0,99,111,109,109,105,116,0,0,83,101,116,32,116,104,101,32,99,111,110,102,105,103,32,102,105,108,101,32,110,97,109,101,32,91,110,111,110,101,93,0,48,98,0,0,0,0,0,0,83,101,116,69,109,112,116,121,82,103,110,0,0,0,0,0,112,102,100,99,0,0,0,0,83,79,78,89,58,0,0,0,67,111,112,121,82,103,110,0,67,108,111,115,101,82,103,110,0,0,0,0,0,0,0,0,99,112,117,0,0,0,0,0,79,112,101,110,82,103,110,0,68,105,115,112,111,115,82,103,110,0,0,0,0,0,0,0,40,65,37,117,41,0,0,0,78,101,119,82,103,110,0,0,70,105,108,108,82,103,110,0,73,110,118,101,114,82,103,110,0,0,0,0,0,0,0,0,78,101,119,80,116,114,0,0,69,114,97,115,101,82,103,110,0,0,0,0,0,0,0,0,114,98,0,0,0,0,0,0,80,97,105,110,116,82,103,110,0,0,0,0,0,0,0,0,115,101,116,116,105,110,103,32,97,108,108,32,105,119,109,32,100,114,105,118,101,115,32,116,111,32,114,101,97,100,45,111,110,108,121,10,0,0,0,0,77,105,110,117,115,0,0,0,115,116,114,105,110,103,0,0,48,120,0,0,0,0,0,0,70,114,97,109,101,82,103,110,0,0,0,0,0,0,0,0,105,109,100,0,0,0,0,0,105,110,115,101,114,116,95,100,101,108,97,121,95,37,117,0,83,116,100,82,103,110,0,0,85,110,112,97,99,107,66,105,116,115,0,0,0,0,0,0,100,105,115,97,115,115,101,109,98,108,101,0,0,0,0,0,97,100,98,45,107,98,100,58,32,116,97,108,107,32,37,117,10,0,0,0,0,0,0,0,80,97,99,107,66,105,116,115,0,0,0,0,0,0,0,0,79,102,102,115,101,116,80,111,108,121,0,0,0,0,0,0,37,115,37,117,47,37,115,37,117,0,0,0,0,0,0,0,75,105,108,108,80,111,108,121,0,0,0,0,0,0,0,0,67,108,111,115,101,80,103,111,110,0,0,0,0,0,0,0,79,112,101,110,80,111,108,121,0,0,0,0,0,0,0,0,77,97,120,77,101,109,0,0,70,105,108,108,80,111,108,121,0,0,0,0,0,0,0,0,73,110,118,101,114,116,80,111,108,121,0,0,0,0,0,0,115,101,116,116,105,110,103,32,105,119,109,32,100,114,105,118,101,32,37,108,117,32,116,111,32,114,101,97,100,47,119,114,105,116,101,10,0,0,0,0,48,0,0,0,0,0,0,0,99,111,110,102,105,103,0,0,102,97,108,115,101,0,0,0,108,112,99,0,0,0,0,0,69,114,97,115,101,80,111,108,121,0,0,0,0,0,0,0,105,109,97,103,101,100,105,115,107,0,0,0,0,0,0,0,102,111,114,109,97,116,95,104,100,95,97,115,95,100,100,0,80,97,105,110,116,80,111,108,121,0,0,0,0,0,0,0,70,114,97,109,101,80,111,108,121,0,0,0,0,0,0,0,91,91,45,93,97,100,100,114,32,91,99,110,116,93,93,0,83,116,100,80,111,108,121,0,65,110,103,108,101,70,114,111,109,83,108,111,112,101,0,0,107,98,100,58,32,117,110,107,110,111,119,110,32,99,111,109,109,97,110,100,32,40,37,48,50,88,41,10,0,0,0,0,37,115,37,117,45,37,115,37,117,0,0,0,0,0,0,0,80,116,84,111,65,110,103,108,101,0,0,0,0,0,0,0,70,105,108,108,65,114,99,0,73,110,118,101,114,116,65,114,99,0,0,0,0,0,0,0,70,114,101,101,77,101,109,0,69,114,97,115,101,65,114,99,0,0,0,0,0,0,0,0,80,97,105,110,116,65,114,99,0,0,0,0,0,0,0,0,115,101,116,116,105,110,103,32,97,108,108,32,105,119,109,32,100,114,105,118,101,115,32,116,111,32,114,101,97,100,47,119,114,105,116,101,10,0,0,0,57,0,0,0,0,0,0,0,116,114,117,101,0,0,0,0,83,101,116,32,116,104,101,32,100,105,115,107,32,100,101,108,97,121,32,91,51,48,93,0,70,114,97,109,101,65,114,99,0,0,0,0,0,0,0,0,100,99,52,50,0,0,0,0,105,110,115,101,114,116,95,100,101,108,97,121,0,0,0,0,83,116,100,65,114,99,0,0,83,108,111,112,101,70,114,111,109,65,110,103,108,101,0,0,105,119,109,58,32,108,111,97,100,105,110,103,32,100,114,105,118,101,32,37,117,32,102,97,105,108,101,100,10,0,0,0,117,0,0,0,0,0,0,0,70,105,108,108,79,118,97,108,0,0,0,0,0,0,0,0,73,110,118,101,114,116,79,118,97,108,0,0,0,0,0,0,69,114,97,115,101,79,118,97,108,0,0,0,0,0,0,0,80,97,105,110,116,79,118,97,108,0,0,0,0,0,0,0,70,114,97,109,101,79,118,97,108,0,0,0,0,0,0,0,83,101,116,90,111,110,101,0,83,116,100,79,118,97,108,0,83,99,114,105,112,116,85,116,105,108,0,0,0,0,0,0,73,87,77,32,100,114,105,118,101,32,37,117,58,32,108,111,99,107,101,100,61,37,100,10,0,0,0,0,0,0,0,0,56,0,0,0,0,0,0,0,100,101,102,105,110,101,100,0,100,114,105,118,101,32,100,101,108,97,121,0,0,0,0,0,70,105,108,108,82,111,117,110,100,82,101,99,116,0,0,0,99,112,50,0,0,0,0,0,101,120,101,99,117,116,101,32,99,110,116,32,105,110,115,116,114,117,99,116,105,111,110,115,32,91,49,93,0,0,0,0,115,111,110,121,0,0,0,0,73,110,118,101,114,82,111,117,110,100,82,101,99,116,0,0,69,114,97,115,101,82,111,117,110,100,82,101,99,116,0,0,99,108,111,99,107,0,0,0,80,97,105,110,116,82,111,117,110,100,82,101,99,116,0,0,35,37,115,37,48,52,88,0,83,116,100,82,82,101,99,116,0,0,0,0,0,0,0,0,67,82,40,37,117,41,0,0,69,109,112,116,121,82,101,99,116,0,0,0,0,0,0,0,80,116,73,110,82,101,99,116,0,0,0,0,0,0,0,0,80,116,50,82,101,99,116,0,71,101,116,90,111,110,101,0,85,110,105,111,110,82,101,99,116,0,0,0,0,0,0,0,83,101,99,116,82,101,99,116,0,0,0,0,0,0,0,0,32,9,0,0,0,0,0,0,43,49,0,0,0,0,0,0,55,0,0,0,0,0,0,0,41,0,0,0,0,0,0,0,100,105,115,107,45,100,101,108,97,121,0,0,0,0,0,0,73,110,115,101,116,82,101,99,116,0,0,0,0,0,0,0,97,110,97,100,105,115,107,0,42,42,42,32,115,101,116,116,105,110,103,32,115,111,117,110,100,32,100,114,105,118,101,114,32,102,97,105,108,101,100,32,40,37,115,41,10,0,0,0,79,102,102,115,101,116,82,101,99,116,0,0,0,0,0,0,83,101,116,82,101,99,116,0,116,0,0,0,0,0,0,0,69,113,117,97,108,82,101,99,116,0,0,0,0,0,0,0,70,105,108,108,82,101,99,116,0,0,0,0,0,0,0,0,73,110,118,101,114,82,101,99,116,0,0,0,0,0,0,0,86,66,82,0,0,0,0,0,69,114,97,115,101,82,101,99,116,0,0,0,0,0,0,0,80,97,105,110,116,82,101,99,116,0,0,0,0,0,0,0,50,0,0,0,0,0,0,0,79,82,73,46,66,0,0,0,73,110,105,116,90,111,110,101,0,0,0,0,0,0,0,0,70,114,97,109,101,82,101,99,116,0,0,0,0,0,0,0,79,82,73,46,87,0,0,0,83,116,100,82,101,99,116,0,79,82,73,46,76,0,0,0,58,0,0,0,0,0,0,0,45,49,0,0,0,0,0,0,54,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,83,101,116,32,116,104,101,32,100,105,115,107,32,100,101,108,97,121,32,102,111,114,32,100,114,105,118,101,32,49,32,91,51,48,93,0,0,0,0,0,80,101,110,78,111,114,109,97,108,0,0,0,0,0,0,0,67,77,80,50,46,66,0,0,112,97,114,116,105,116,105,111,110,0,0,0,0,0,0,0,32,32,0,0,0,0,0,0,60,110,111,110,101,62,0,0,80,101,110,80,97,116,0,0,67,72,75,50,46,66,0,0,80,101,110,77,111,100,101,0,112,114,105,110,116,32,115,116,97,116,117,115,32,40,99,112,117,124,109,101,109,124,115,99,99,124,118,105,97,41,0,0,80,101,110,83,105,122,101,0,71,101,116,80,101,110,0,0,65,78,68,73,46,66,0,0,83,101,116,80,101,110,83,116,97,116,101,0,0,0,0,0,68,70,67,0,0,0,0,0,101,109,117,46,101,120,105,116,0,0,0,0,0,0,0,0,65,78,68,73,46,87,0,0,71,101,116,80,101,110,83,116,97,116,101,0,0,0,0,0,65,78,68,73,46,76,0,0,83,104,111,119,80,101,110,0,67,77,80,50,46,87,0,0,71,101,116,70,80,111,115,0,72,105,100,101,80,101,110,0,67,72,75,50,46,87,0,0,82,101,97,100,0,0,0,0,83,104,117,116,100,111,119,110,0,0,0,0,0,0,0,0,83,85,66,73,46,66,0,0,49,0,0,0,0,0,0,0,101,109,117,46,99,112,117,46,115,112,101,101,100,46,115,116,101,112,0,0,0,0,0,0,53,0,0,0,0,0,0,0,100,101,108,97,121,0,0,0,77,111,118,101,0,0,0,0,83,85,66,73,46,87,0,0,113,101,100,0,0,0,0,0,32,32,32,0,0,0,0,0,97,100,100,114,61,48,120,37,48,54,108,88,32,108,111,119,112,97,115,115,61,37,108,117,32,100,114,105,118,101,114,61,37,115,10,0,0,0,0,0,77,111,118,101,84,111,0,0,83,85,66,73,46,76,0,0,76,105,110,101,0,0,0,0,91,119,104,97,116,93,0,0,67,77,80,50,46,76,0,0,76,105,110,101,84,111,0,0,67,72,75,50,46,76,0,0,80,67,69,32,82,79,77,32,101,120,116,101,110,115,105,111,110,32,97,116,32,48,120,37,48,54,108,120,10,0,0,0,83,116,100,76,105,110,101,0,65,68,68,73,46,66,0,0,83,70,67,0,0,0,0,0,83,112,97,99,101,69,120,116,114,97,0,0,0,0,0,0,65,68,68,73,46,87,0,0,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,67,104,97,114,87,105,100,116,104,0,0,0,0,0,0,0,65,68,68,73,46,76,0,0,83,116,114,105,110,103,87,105,100,116,104,0,0,0,0,0,66,84,83,84,0,0,0,0,69,106,101,99,116,0,0,0,71,101,116,70,111,110,116,73,110,102,111,0,0,0,0,0,66,67,72,71,0,0,0,0,84,101,120,116,83,105,122,101,0,0,0,0,0,0,0,0,115,99,115,105,58,32,103,101,116,32,32,56,58,32,37,48,52,108,88,32,45,62,32,37,48,50,88,10,0,0,0,0,66,67,76,82,0,0,0,0,116,101,114,109,46,114,101,108,101,97,115,101,0,0,0,0,101,109,117,46,114,101,115,101,116,0,0,0,0,0,0,0,52,0,0,0,0,0,0,0,33,0,0,0,0,0,0,0,100,105,115,107,45,100,101,108,97,121,45,49,0,0,0,0,84,101,120,116,77,111,100,101,0,0,0,0,0,0,0,0,66,83,69,84,0,0,0,0,112,99,101,0,0,0,0,0,32,37,48,50,88,0,0,0,83,79,85,78,68,58,0,0,84,101,120,116,70,97,99,101,0,0,0,0,0,0,0,0,69,79,82,73,46,66,0,0,112,99,101,37,48,52,117,46,112,112,109,0,0,0,0,0,84,101,120,116,70,111,110,116,0,0,0,0,0,0,0,0,115,0,0,0,0,0,0,0,69,79,82,73,46,87,0,0,84,101,120,116,87,105,100,116,104,0,0,0,0,0,0,0,69,79,82,73,46,76,0,0,68,114,97,119,84,101,120,116,0,0,0,0,0,0,0,0,67,77,80,73,46,66,0,0,68,114,97,119,83,116,114,105,110,103,0,0,0,0,0,0,67,77,80,73,46,87,0,0,68,114,97,119,67,104,97,114,0,0,0,0,0,0,0,0,101,109,117,46,99,112,117,46,115,112,101,101,100,0,0,0,67,77,80,73,46,76,0,0,83,116,100,84,101,120,116,0,77,79,86,83,46,66,0,0,73,110,105,116,81,117,101,117,101,0,0,0,0,0,0,0,69,113,117,97,108,80,116,0,77,79,86,83,46,87,0,0,114,101,112,111,114,116,95,107,101,121,115,0,0,0,0,0,80,54,10,37,117,32,37,117,10,37,117,10,0,0,0,0,83,101,116,80,116,0,0,0,77,79,86,83,46,76,0,0,109,97,99,46,105,110,115,101,114,116,0,0,0,0,0,0,101,109,117,46,112,97,117,115,101,46,116,111,103,103,108,101,0,0,0,0,0,0,0,0,51,0,0,0,0,0,0,0,126,0,0,0,0,0,0,0,80,114,105,110,116,32,117,115,97,103,101,32,105,110,102,111,114,109,97,116,105,111,110,0,83,117,98,80,116,0,0,0,42,42,42,32,110,111,32,116,101,114,109,105,110,97,108,32,102,111,117,110,100,10,0,0,100,111,115,101,109,117,0,0,70,50,0,0,0,0,0,0,99,111,109,109,105,116,0,0,60,45,0,0,0,0,0,0,100,114,105,118,101,114,0,0,124,124,0,0,0,0,0,0,65,100,100,80,116,0,0,0,77,79,86,69,46,66,0,0,60,110,111,110,101,62,0,0,67,108,111,115,101,80,111,114,116,0,0,0,0,0,0,0,103,101,116,32,111,114,32,115,101,116,32,97,32,114,101,103,105,115,116,101,114,0,0,0,77,79,86,69,46,76,0,0,32,9,0,0,0,0,0,0,119,97,114,110,105,110,103,58,32,100,101,108,97,121,32,61,61,32,48,32,97,116,32,37,48,56,108,120,10,0,0,0,67,108,111,115,101,67,80,111,114,116,0,0,0,0,0,0,37,45,57,115,32,0,0,0,112,99,101,45,109,97,99,112,108,117,115,58,32,115,105,103,110,97,108,32,37,100,10,0,102,105,108,101,61,37,115,32,102,111,114,109,97,116,61,105,104,101,120,10,0,0,0,0,110,117,108,108,0,0,0,0,66,97,99,107,80,97,116,0,97,100,100,114,101,115,115,0,42,42,42,32,99,111,119,32,102,97,105,108,101,100,32,40,100,114,105,118,101,61,37,117,32,102,105,108,101,61,37,115,41,10,0,0,0,0,0,0,37,115,58,32,117,110,107,110,111,119,110,32,111,112,116,105,111,110,32,40,37,115,41,10,0,0,0,0,0,0,0,0,37,117,0,0,0,0,0,0,67,108,105,112,82,101,99,116,0,0,0,0,0,0,0,0,78,69,71,88,46,66,0,0,115,0,0,0,0,0,0,0,121,101,115,0,0,0,0,0,110,117,108,108,0,0,0,0,71,101,116,67,108,105,112,0,78,69,71,88,46,87,0,0,69,83,67,0,0,0,0,0,116,100,48,58,32,104,101,97,100,101,114,32,99,114,99,32,40,37,48,52,88,32,37,48,52,88,41,10,0,0,0,0,109,102,109,0,0,0,0,0,112,102,100,99,58,32,117,110,107,110,111,119,110,32,118,101,114,115,105,111,110,32,40,37,108,117,41,10,0,0,0,0,114,98,0,0,0,0,0,0,100,99,52,50,58,32,100,97,116,97,32,99,104,101,99,107,115,117,109,32,101,114,114,111,114,10,0,0,0,0,0,0,83,101,116,67,108,105,112,0,32,45,0,0,0,0,0,0,78,69,71,88,46,76,0,0,114,98,0,0,0,0,0,0,83,101,116,86,111,108,0,0,114,43,98,0,0,0,0,0,46,99,112,50,0,0,0,0,112,98,105,116,58,32,117,110,107,110,111,119,110,32,118,101,114,115,105,111,110,32,110,117,109,98,101,114,32,40,37,108,117,41,10,0,0,0,0,0,83,101,116,79,114,105,103,105,110,0,0,0,0,0,0,0,45,0,0,0,0,0,0,0,99,104,97,114,45,112,116,121,58,32,37,115,10,0,0,0,119,114,105,116,101,0,0,0,109,115,121,115,0,0,0,0,112,111,115,105,120,0,0,0,77,111,118,101,80,111,114,116,84,111,0,0,0,0,0,0,119,98,0,0,0,0,0,0,101,109,117,46,118,105,100,101,111,46,98,114,105,103,104,116,110,101,115,115,0,0,0,0,114,43,98,0,0,0,0,0,101,109,117,46,115,116,111,112,0,0,0,0,0,0,0,0,50,0,0,0,0,0,0,0,37,0,0,0,0,0,0,0,104,101,108,112,0,0,0,0,80,111,114,116,83,105,122,101,0,0,0,0,0,0,0,0,67,76,82,46,66,0,0,0,42,42,42,32,117,110,107,110,111,119,110,32,116,101,114,109,105,110,97,108,32,100,114,105,118,101,114,58,32,37,115,10,0,0,0,0,0,0,0,0,105,109,97,103,101,0,0,0,45,62,0,0,0,0,0,0,108,111,119,112,97,115,115,0,63,0,0,0,0,0,0,0,83,101,116,80,66,105,116,115,0,0,0,0,0,0,0,0,67,76,82,46,87,0,0,0,71,101,116,80,111,114,116,0,114,101,103,32,91,118,97,108,93,0,0,0,0,0,0,0,67,76,82,46,76,0,0,0,73,78,84,82,0,0,0,0,83,101,116,80,111,114,116,0,78,69,71,46,66,0,0,0,71,114,97,102,68,101,118,105,99,101,0,0,0,0,0,0,78,69,71,46,87,0,0,0,68,37,117,58,68,37,117,0,71,108,111,98,97,108,84,111,76,111,99,97,108,0,0,0,78,69,71,46,76,0,0,0,76,111,99,97,108,84,111,71,108,111,98,97,108,0,0,0,78,79,84,46,66,0,0,0,79,112,101,110,80,111,114,116,0,0,0,0,0,0,0,0,78,79,84,46,87,0,0,0,71,101,116,86,111,108,0,0,73,110,105,116,71,114,97,102,0,0,0,0,0,0,0,0,78,79,84,46,76,0,0,0,114,0,0,0,0,0,0,0,73,110,105,116,80,111,114,116,0,0,0,0,0,0,0,0,77,79,86,69,46,87,0,0,101,109,117,46,115,116,111,112,0,0,0,0,0,0,0,0,116,101,114,109,46,103,114,97,98,0,0,0,0,0,0,0,49,0,0,0,0,0,0,0,47,0,0,0,0,0,0,0,117,115,97,103,101,58,32,112,99,101,45,109,97,99,112,108,117,115,32,91,111,112,116,105,111,110,115,93,0,0,0,0,70,105,120,82,111,117,110,100,0,0,0,0,0,0,0,0,78,66,67,68,46,66,0,0,42,42,42,32,115,101,116,116,105,110,103,32,117,112,32,110,117,108,108,32,116,101,114,109,105,110,97,108,32,102,97,105,108,101,100,10,0,0,0,0,114,97,109,0,0,0,0,0,37,115,32,37,48,50,88,0,112,97,114,115,101,32,101,114,114,111,114,32,98,101,102,111,114,101,0,0,0,0,0,0,115,111,117,110,100,0,0,0,76,111,87,111,114,100,0,0,72,105,87,111,114,100,0,0,114,0,0,0,0,0,0,0,97,100,98,45,107,98,100,58,32,108,105,115,116,101,110,32,37,117,10,0,0,0,0,0,83,87,65,80,0,0,0,0,84,82,65,80,0,0,0,0,70,105,120,82,97,116,105,111,0,0,0,0,0,0,0,0,69,88,84,46,87,0,0,0,114,0,0,0,0,0,0,0,70,105,120,77,117,108,0,0,69,88,84,46,76,0,0,0,116,114,117,101,0,0,0,0,85,83,80,0,0,0,0,0,76,111,110,103,77,117,108,0,69,88,84,66,46,76,0,0,83,116,117,102,102,72,101,120,0,0,0,0,0,0,0,0,84,83,84,46,66,0,0,0,71,101,116,80,105,120,101,108,0,0,0,0,0,0,0,0,84,83,84,46,87,0,0,0,70,108,117,115,104,86,111,108,0,0,0,0,0,0,0,0,67,111,108,111,114,66,105,116,0,0,0,0,0,0,0,0,84,83,84,46,76,0,0,0,66,97,99,107,67,111,108,111,114,0,0,0,0,0,0,0,101,109,117,46,115,101,114,112,111,114,116,46,102,105,108,101,0,0,0,0,0,0,0,0,70,111,114,101,67,111,108,111,114,0,0,0,0,0,0,0,116,101,114,109,46,102,117,108,108,115,99,114,101,101,110,46,116,111,103,103,108,101,0,0,96,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,112,99,101,45,109,97,99,112,108,117,115,58,32,77,97,99,105,110,116,111,115,104,32,80,108,117,115,32,101,109,117,108,97,116,111,114,0,0,0,0,112,99,101,45,109,97,99,112,108,117,115,0,0,0,0,0,112,99,0,0,0,0,0,0,42,42,42,32,115,101,116,116,105,110,103,32,117,112,32,115,100,108,32,116,101,114,109,105,110,97,108,32,102,97,105,108,101,100,10,0,0,0,0,0,114,98,0,0,0,0,0,0,45,45,32,37,115,61,37,100,10,0,0,0,0,0,0,0,49,0,0,0,0,0,0,0,82,97,110,100,111,109,0,0,77,85,76,85,46,76,0,0,87,97,105,116,78,101,120,116,69,118,101,110,116,0,0,0,101,120,101,99,117,116,101,32,116,111,32,110,101,120,116,32,114,116,101,0,0,0,0,0,68,73,86,85,46,76,0,0,65,86,69,67,0,0,0,0,66,105,116,67,108,114,0,0,66,105,116,83,101,116,0,0,66,105,116,84,115,116,0,0,83,82,0,0,0,0,0,0,60,110,111,110,101,62,0,0,66,105,116,83,104,105,102,116,0,0,0,0,0,0,0,0,97,0,0,0,0,0,0,0,77,79,86,69,0,0,0,0,66,105,116,79,114,0,0,0,73,87,77,58,32,68,37,117,32,84,114,97,99,107,32,37,117,32,32,32,32,13,0,0,85,78,76,75,0,0,0,0,66,105,116,78,111,116,0,0,83,101,116,69,79,70,0,0,112,99,101,45,109,97,99,112,108,117,115,58,32,115,101,103,109,101,110,116,97,116,105,111,110,32,102,97,117,108,116,10,0,0,0,0,0,0,0,0,76,73,78,75,0,0,0,0,114,98,0,0,0,0,0,0,66,105,116,88,111,114,0,0,84,82,65,80,0,0,0,0,101,109,117,46,115,101,114,112,111,114,116,46,100,114,105,118,101,114,0,0,0,0,0,0,56,0,0,0,0,0,0,0,66,97,99,107,113,117,111,116,101,0,0,0,0,0,0,0,37,108,117,0,0,0,0,0,112,99,101,45,109,97,99,112,108,117,115,32,118,101,114,115,105,111,110,32,50,48,49,51,48,53,48,56,45,51,55,101,54,98,55,56,10,10,67,111,112,121,114,105,103,104,116,32,40,67,41,32,50,48,48,55,45,50,48,49,50,32,72,97,109,112,97,32,72,117,103,32,60,104,97,109,112,97,64,104,97,109,112,97,46,99,104,62,10,0,0,0,0,0,0,0,66,105,116,65,110,100,0,0,77,79,86,69,67,0,0,0,115,100,108,0,0,0,0,0,102,105,108,101,0,0,0,0,82,73,0,0,0,0,0,0,116,101,114,109,46,114,101,108,101,97,115,101,0,0,0,0,116,101,114,109,105,110,97,108,0,0,0,0,0,0,0,0,79,98,115,99,117,114,101,67,117,114,115,111,114,0,0,0,83,104,105,101,108,100,67,117,114,115,111,114,0,0,0,0,114,116,101,0,0,0,0,0,84,82,65,80,86,0,0,0,83,104,111,119,67,117,114,115,111,114,0,0,0,0,0,0,70,82,77,84,0,0,0,0,114,97,109,0,0,0,0,0,105,119,109,58,32,108,111,97,100,105,110,103,32,100,114,105,118,101,32,37,117,32,40,100,105,115,107,41,10,0,0,0,72,105,100,101,67,117,114,115,111,114,0,0,0,0,0,0,83,101,116,67,117,114,115,111,114,0,0,0,0,0,0,0,73,110,105,116,67,117,114,115,111,114,0,0,0,0,0,0,83,84,79,80,0,0,0,0,83,101,116,73,116,101,109,67,109,100,0,0,0,0,0,0,71,101,116,69,79,70,0,0,99,111,119,0,0,0,0,0,71,101,116,73,116,101,109,67,109,100,0,0,0,0,0,0,82,69,83,69,84,0,0,0,70,105,120,68,105,118,0,0,101,109,117,46,114,101,115,101,116,0,0,0,0,0,0,0,37,115,10,10,0,0,0,0,112,99,101,0,0,0,0,0,55,0,0,0,0,0,0,0,80,97,117,115,101,0,0,0,45,0,0,0,0,0,0,0,101,108,115,101,0,0,0,0,112,99,101,45,109,97,99,112,108,117,115,32,118,101,114,115,105,111,110,32,50,48,49,51,48,53,48,56,45,51,55,101,54,98,55,56,10,67,111,112,121,114,105,103,104,116,32,40,67,41,32,50,48,48,55,45,50,48,49,50,32,72,97,109,112,97,32,72,117,103,32,60,104,97,109,112,97,64,104,97,109,112,97,46,99,104,62,10,0,0,0,0,0,0,0,0,70,114,97,99,68,105,118,0,65,68,68,81,46,66,0,0,42,42,42,32,116,101,114,109,105,110,97,108,32,100,114,105,118,101,114,32,39,120,49,49,39,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,0,111,112,116,105,111,110,97,108,0,0,0,0,0,0,0,0,67,68,0,0,0,0,0,0,97,100,100,114,61,48,120,37,48,54,108,88,32,119,61,37,117,32,104,61,37,117,32,98,114,105,103,104,116,61,37,117,37,37,10,0,0,0,0,0,70,114,97,99,77,117,108,0,65,68,68,81,46,87,0,0,70,114,97,99,83,113,114,116,0,0,0,0,0,0,0,0,114,101,115,101,116,0,0,0,65,68,68,81,46,76,0,0,70,88,88,88,0,0,0,0,70,114,97,99,83,105,110,0,68,66,76,69,0,0,0,0,66,70,73,78,83,0,0,0,70,114,97,99,67,111,115,0,68,66,71,84,0,0,0,0,37,115,37,48,56,108,88,0,88,50,70,114,97,99,0,0,68,66,76,84,0,0,0,0,70,114,97,99,50,88,0,0,68,66,71,69,0,0,0,0,37,52,117,32,32,0,0,0,88,50,70,105,120,0,0,0,68,66,77,73,0,0,0,0,65,108,108,111,99,97,116,101,0,0,0,0,0,0,0,0,49,0,0,0,0,0,0,0,70,105,120,50,88,0,0,0,115,111,110,121,58,32,114,101,97,100,32,101,114,114,111,114,32,97,116,32,37,117,47,37,117,47,37,117,10,0,0,0,68,66,80,76,0,0,0,0,115,99,115,105,58,32,109,111,100,101,32,115,101,110,115,101,58,32,117,110,107,110,111,119,110,32,109,111,100,101,32,112,97,103,101,32,40,37,48,50,88,41,10,0,0,0,0,0,119,97,118,0,0,0,0,0,70,114,97,99,50,70,105,120,0,0,0,0,0,0,0,0,68,66,86,83,0,0,0,0,115,110,100,45,115,100,108,58,32,101,114,114,111,114,32,105,110,105,116,105,97,108,105,122,105,110,103,32,97,117,100,105,111,32,115,117,98,115,121,115,116,101,109,32,40,37,115,41,10,0,0,0,0,0,0,0,101,109,117,46,114,101,97,108,116,105,109,101,46,116,111,103,103,108,101,0,0,0,0,0,116,101,114,109,46,102,117,108,108,115,99,114,101,101,110,0,54,0,0,0,0,0,0,0,83,99,114,76,107,0,0,0,43,0,0,0,0,0,0,0,59,0,0,0,0,0,0,0,42,42,42,32,108,111,97,100,105,110,103,32,99,111,110,102,105,103,32,102,105,108,101,32,102,97,105,108,101,100,10,0,70,105,120,50,70,114,97,99,0,0,0,0,0,0,0,0,42,42,42,32,108,111,97,100,105,110,103,32,102,97,105,108,101,100,32,40,37,115,41,10,0,0,0,0,0,0,0,0,68,66,86,67,0,0,0,0,120,49,49,0,0,0,0,0,114,101,97,100,111,110,108,121,0,0,0,0,0,0,0,0,68,83,82,0,0,0,0,0,119,97,118,102,105,108,116,101,114,0,0,0,0,0,0,0,101,120,101,99,117,116,101,32,99,110,116,32,105,110,115,116,114,117,99,116,105,111,110,115,44,32,115,107,105,112,32,99,97,108,108,115,32,91,49,93,0,0,0,0,0,0,0,0,86,73,68,69,79,58,0,0,70,105,120,50,76,111,110,103,0,0,0,0,0,0,0,0,68,66,69,81,0,0,0,0,76,111,110,103,50,70,105,120,0,0,0,0,0,0,0,0,91,99,110,116,93,0,0,0,68,66,78,69,0,0,0,0,65,88,88,88,0,0,0,0,84,69,83,116,121,108,101,78,101,119,0,0,0,0,0,0,68,66,67,83,0,0,0,0,84,69,68,105,115,112,97,116,99,104,0,0,0,0,0,0,68,66,67,67,0,0,0,0,84,69,71,101,116,79,102,102,115,101,116,0,0,0,0,0,35,37,115,37,88,0,0,0,68,66,76,83,0,0,0,0,84,114,97,99,107,66,111,120,0,0,0,0,0,0,0,0,68,66,72,73,0,0,0,0,116,99,58,32,117,110,107,110,111,119,110,32,109,97,114,107,32,48,120,37,48,50,120,32,40,37,115,44,32,99,61,37,117,44,32,104,61,37,117,44,32,98,105,116,61,37,108,117,47,37,108,117,41,10,0,0,90,111,111,109,87,105,110,100,111,119,0,0,0,0,0,0,68,66,70,0,0,0,0,0,83,101,101,100,70,105,108,108,0,0,0,0,0,0,0,0,77,111,117,110,116,86,111,108,0,0,0,0,0,0,0,0,112,102,100,99,58,32,99,114,99,32,101,114,114,111,114,10,0,0,0,0,0,0,0,0,49,0,0,0,0,0,0,0,115,111,110,121,58,32,114,101,97,100,32,101,114,114,111,114,10,0,0,0,0,0,0,0,68,66,84,0,0,0,0,0,112,102,100,99,58,32,119,97,114,110,105,110,103,58,32,108,111,97,100,105,110,103,32,100,101,112,114,101,99,97,116,101,100,32,118,101,114,115,105,111,110,32,50,32,102,105,108,101,10,0,0,0,0,0,0,0,65,80,80,76,69,32,67,79,77,80,85,84,69,82,44,32,73,78,67,0,0,0,0,0,112,102,100,99,58,32,119,97,114,110,105,110,103,58,32,108,111,97,100,105,110,103,32,100,101,112,114,101,99,97,116,101,100,32,118,101,114,115,105,111,110,32,49,32,102,105,108,101,10,0,0,0,0,0,0,0,67,97,108,99,77,97,115,107,0,0,0,0,0,0,0,0,83,76,69,0,0,0,0,0,101,109,117,46,114,101,97,108,116,105,109,101,0,0,0,0,112,102,100,99,58,32,119,97,114,110,105,110,103,58,32,108,111,97,100,105,110,103,32,100,101,112,114,101,99,97,116,101,100,32,118,101,114,115,105,111,110,32,48,32,102,105,108,101,10,0,0,0,0,0,0,0,116,101,114,109,46,102,117,108,108,115,99,114,101,101,110,46,116,111,103,103,108,101,0,0])
.concat([53,0,0,0,0,0,0,0,83,99,114,111,108,108,76,111,99,107,0,0,0,0,0,0,62,62,0,0,0,0,0,0,99,97,110,39,116,32,111,112,101,110,32,105,110,99,108,117,100,101,32,102,105,108,101,58,0,0,0,0,0,0,0,0,102,105,108,101,61,34,37,115,34,10,0,0,0,0,0,0,77,101,97,115,117,114,101,84,101,120,116,0,0,0,0,0,98,97,115,101,0,0,0,0,83,71,84,0,0,0,0,0,69,83,67,0,0,0,0,0,42,42,42,32,108,111,97,100,105,110,103,32,114,111,109,32,102,97,105,108,101,100,32,40,37,115,41,10,0,0,0,0,115,105,122,101,103,0,0,0,82,84,83,0,0,0,0,0,98,114,105,103,104,116,110,101,115,115,0,0,0,0,0,0,70,111,110,116,77,101,116,114,105,99,115,0,0,0,0,0,83,76,84,0,0,0,0,0,83,101,116,70,83,99,97,108,101,68,105,115,97,98,108,101,0,0,0,0,0,0,0,0,112,0,0,0,0,0,0,0,83,71,69,0,0,0,0,0,80,82,73,86,0,0,0,0,80,97,99,107,49,53,0,0,83,77,73,0,0,0,0,0,99,112,50,58,32,37,117,47,37,117,47,37,117,58,32,115,101,99,116,111,114,32,100,97,116,97,32,116,111,111,32,98,105,103,32,40,37,117,41,10,0,0,0,0,0,0,0,0,80,97,99,107,49,52,0,0,83,80,76,0,0,0,0,0,80,97,99,107,49,51,0,0,35,37,115,37,48,56,108,88,0,0,0,0,0,0,0,0,83,86,83,0,0,0,0,0,80,97,99,107,49,50,0,0,49,0,0,0,0,0,0,0,83,86,67,0,0,0,0,0,69,120,116,114,97,49,54,0,80,97,99,107,49,49,0,0,83,69,81,0,0,0,0,0,85,110,109,111,117,110,116,86,111,108,0,0,0,0,0,0,69,120,116,114,97,49,53,0,80,97,99,107,49,48,0,0,115,111,110,121,58,32,110,111,110,45,97,108,105,103,110,101,100,32,114,101,97,100,10,0,83,78,69,0,0,0,0,0,67,108,111,115,101,0,0,0,115,99,115,105,58,32,115,116,97,114,116,47,115,116,111,112,32,117,110,105,116,32,37,117,32,40,37,115,41,10,0,0,69,120,116,114,97,49,52,0,80,97,99,107,57,0,0,0,83,67,83,0,0,0,0,0,101,109,117,46,112,97,117,115,101,46,116,111,103,103,108,101,0,0,0,0,0,0,0,0,116,101,114,109,46,115,101,116,95,98,111,114,100,101,114,95,121,0,0,0,0,0,0,0,52,0,0,0,0,0,0,0,69,120,116,114,97,49,51,0,80,114,116,83,99,110,0,0,60,60,0,0,0,0,0,0,105,110,99,108,117,100,101,0,83,104,111,119,68,73,116,101,109,0,0,0,0,0,0,0,67,79,78,70,73,71,58,0,97,100,100,114,101,115,115,0,100,114,105,118,101,114,61,37,115,32,69,83,67,61,37,115,32,97,115,112,101,99,116,61,37,117,47,37,117,32,109,105,110,95,115,105,122,101,61,37,117,42,37,117,32,115,99,97,108,101,61,37,117,32,109,111,117,115,101,61,91,37,117,47,37,117,32,37,117,47,37,117,93,10,0,0,0,0,0,0,83,67,67,0,0,0,0,0,82,79,77,58,0,0,0,0,115,105,122,101,109,0,0,0,68,84,82,0,0,0,0,0,69,120,116,114,97,49,50,0,99,111,108,111,114,49,0,0,72,105,100,101,68,73,116,101,109,0,0,0,0,0,0,0,83,76,83,0,0,0,0,0,69,120,116,114,97,49,49,0,73,110,115,77,101,110,117,73,116,101,109,0,0,0,0,0,115,101,116,32,104,97,108,116,32,115,116,97,116,101,32,91,50,93,0,0,0,0,0,0,83,72,73,0,0,0,0,0,79,70,76,87,0,0,0,0,69,120,116,114,97,49,48,0,77,97,120,83,105,122,101,82,115,114,99,0,0,0,0,0,83,70,0,0,0,0,0,0,69,120,116,114,97,57,0,0,80,67,69,32,82,79,77,32,101,120,116,101,110,115,105,111,110,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,71,101,116,49,78,97,109,101,100,82,101,115,111,117,114,99,101,0,0,0,0,0,0,0,83,84,0,0,0,0,0,0,114,98,0,0,0,0,0,0,69,120,116,114,97,56,0,0,71,101,116,49,82,101,115,111,117,114,99,101,0,0,0,0,35,37,115,37,48,50,88,0,83,85,66,81,46,66,0,0,103,99,114,58,32,100,97,116,97,32,99,114,99,32,101,114,114,111,114,32,40,37,117,47,37,117,47,37,117,41,10,0,69,120,116,114,97,55,0,0,102,105,108,101,0,0,0,0,67,111,117,110,116,49,84,121,112,101,115,0,0,0,0,0,83,85,66,81,46,87,0,0,115,121,109,108,105,110,107,0,69,120,116,114,97,54,0,0,70,105,120,65,116,97,110,50,0,0,0,0,0,0,0,0,102,105,108,101,0,0,0,0,83,85,66,81,46,76,0,0,83,101,116,70,105,108,101,73,110,102,111,0,0,0,0,0,69,120,116,114,97,53,0,0,67,111,112,121,77,97,115,107,0,0,0,0,0,0,0,0,115,111,110,121,58,32,119,114,105,116,101,32,101,114,114,111,114,10,0,0,0,0,0,0,66,76,69,0,0,0,0,0,112,114,111,116,111,99,111,108,0,0,0,0,0,0,0,0,108,111,97,100,32,109,101,100,105,97,0,0,0,0,0,0,69,120,116,114,97,52,0,0,80,97,99,107,56,0,0,0,66,71,84,0,0,0,0,0,80,67,69,68,73,83,75,32,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,101,109,117,46,112,97,117,115,101,0,0,0,0,0,0,0,116,101,114,109,46,115,101,116,95,98,111,114,100,101,114,95,120,0,0,0,0,0,0,0,51,0,0,0,0,0,0,0,69,120,116,114,97,51,0,0,80,114,105,110,116,83,99,114,101,101,110,0,0,0,0,0,62,0,0,0,0,0,0,0,105,102,0,0,0,0,0,0,83,67,83,73,68,105,115,112,97,116,99,104,0,0,0,0,121,0,0,0,0,0,0,0,102,105,108,101,0,0,0,0,84,69,82,77,58,0,0,0,66,76,84,0,0,0,0,0,114,111,109,0,0,0,0,0,115,105,122,101,107,0,0,0,67,84,83,0,0,0,0,0,69,120,116,114,97,50,0,0,99,111,108,111,114,48,0,0,84,69,65,117,116,111,86,105,101,119,0,0,0,0,0,0,66,71,69,0,0,0,0,0,69,120,116,114,97,49,0,0,109,111,117,115,101,0,0,0,84,69,80,105,110,83,99,114,111,108,108,0,0,0,0,0,91,118,97,108,93,0,0,0,66,77,73,0,0,0,0,0,114,98,0,0,0,0,0,0,67,72,75,0,0,0,0,0,82,105,103,104,116,0,0,0,84,69,83,101,108,86,105,101,119,0,0,0,0,0,0,0,66,80,76,0,0,0,0,0,114,98,0,0,0,0,0,0,68,111,119,110,0,0,0,0,85,110,105,113,117,101,49,73,68,0,0,0,0,0,0,0,66,86,83,0,0,0,0,0,114,98,0,0,0,0,0,0,76,101,102,116,0,0,0,0,68,79,83,69,77,85,0,0,71,101,116,49,73,120,84,121,112,101,0,0,0,0,0,0,66,86,67,0,0,0,0,0,85,112,0,0,0,0,0,0,71,101,116,49,73,120,82,101,115,111,117,114,99,101,0,0,66,69,81,0,0,0,0,0,101,109,117,46,99,112,117,46,109,111,100,101,108,0,0,0,80,97,103,101,68,111,119,110,0,0,0,0,0,0,0,0,67,111,117,110,116,49,82,101,115,111,117,114,99,101,115,0,66,78,69,0,0,0,0,0,71,101,116,70,105,108,101,73,110,102,111,0,0,0,0,0,69,110,100,0,0,0,0,0,82,71,101,116,82,101,115,111,117,114,99,101,0,0,0,0,115,111,110,121,58,32,110,111,110,45,97,108,105,103,110,101,100,32,119,114,105,116,101,10,0,0,0,0,0,0,0,0,66,67,83,0,0,0,0,0,98,111,114,100,101,114,0,0,99,111,109,109,105,116,0,0,101,106,101,99,116,32,109,101,100,105,97,0,0,0,0,0,68,101,108,101,116,101,0,0,119,98,0,0,0,0,0,0,80,111,112,85,112,77,101,110,117,83,101,108,101,99,116,0,66,67,67,0,0,0,0,0,101,109,117,46,101,120,105,116,0,0,0,0,0,0,0,0,116,101,114,109,46,116,105,116,108,101,0,0,0,0,0,0,50,0,0,0,0,0,0,0,80,97,103,101,85,112,0,0,70,49,50,0,0,0,0,0,60,0,0,0,0,0,0,0,61,0,0,0,0,0,0,0,71,101,116,87,86,97,114,105,97,110,116,0,0,0,0,0,109,97,99,112,108,117,115,0,118,0,0,0,0,0,0,0,102,111,114,109,97,116,0,0,109,111,117,115,101,95,100,105,118,95,121,0,0,0,0,0,42,42,42,32,108,111,97,100,105,110,103,32,114,97,109,32,102,97,105,108,101,100,32,40,37,115,41,10,0,0,0,0,66,76,83,0,0,0,0,0,115,105,122,101,0,0,0,0,65,32,32,37,48,56,108,88,32,32,37,48,52,88,32,32,37,48,52,88,10,0,0,0,70,49,0,0,0,0,0,0,82,101,108,101,97,115,101,32,54,46,48,10,36,48,0,0,114,43,98,0,0,0,0,0,119,43,98,0,0,0,0,0,119,98,0,0,0,0,0,0,114,98,0,0,0,0,0,0,45,45,32,37,108,117,32,37,117,37,115,37,117,10,0,0,72,111,109,101,0,0,0,0,58,0,0,0,0,0,0,0,104,97,108,116,0,0,0,0,104,101,105,103,104,116,0,0,71,101,116,67,86,97,114,105,97,110,116,0,0,0,0,0,66,72,73,0,0,0,0,0,73,110,115,101,114,116,0,0,114,98,0,0,0,0,0,0,73,110,105,116,80,114,111,99,77,101,110,117,0,0,0,0,60,110,111,110,101,62,0,0,112,97,116,104,0,0,0,0,66,83,82,0,0,0,0,0,102,97,108,115,101,0,0,0,68,73,86,90,0,0,0,0,75,80,95,80,101,114,105,111,100,0,0,0,0,0,0,0,83,121,115,69,110,118,105,114,111,110,115,0,0,0,0,0,66,82,65,0,0,0,0,0,99,112,117,0,0,0,0,0,76,111,97,100,58,0,0,0,75,80,95,48,0,0,0,0,100,114,105,118,101,114,0,0,71,101,116,79,83,68,101,102,97,117,108,116,0,0,0,0,102,105,108,101,0,0,0,0,46,83,0,0,0,0,0,0,68,73,83,75,58,0,0,0,75,80,95,69,110,116,101,114,0,0,0,0,0,0,0,0,83,101,116,79,83,68,101,102,97,117,108,116,0,0,0,0,45,0,0,0,0,0,0,0,77,79,86,69,81,0,0,0,108,0,0,0,0,0,0,0,116,114,117,101,0,0,0,0,119,98,0,0,0,0,0,0,115,110,100,45,115,100,108,58,32,101,114,114,111,114,32,111,112,101,110,105,110,103,32,111,117,116,112,117,116,32,40,37,115,41,10,0,0,0,0,0,75,80,95,51,0,0,0,0,108,111,119,112,97,115,115,0,66,76,75,32,37,48,52,88,58,32,65,49,61,37,48,56,108,88,32,65,50,61,37,48,56,108,88,32,83,61,37,48,56,108,88,32,82,79,61,37,100,10,0,0,0,0,0,0,68,84,73,110,115,116,97,108,108,0,0,0,0,0,0,0,68,73,86,85,46,87,0,0,116,100,48,58,32,97,100,118,97,110,99,101,100,32,99,111,109,112,114,101,115,115,105,111,110,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,0,102,109,0,0,0,0,0,0,112,102,100,99,58,32,111,114,112,104,97,110,101,100,32,97,108,116,101,114,110,97,116,101,32,115,101,99,116,111,114,10,0,0,0,0,0,0,0,0,75,80,95,50,0,0,0,0,73,77,68,32,49,46,49,55,58,32,37,50,100,47,37,50,100,47,37,52,100,32,37,48,50,100,58,37,48,50,100,58,37,48,50,100,0,0,0,0,6,78,111,110,97,109,101,0,83,101,116,86,105,100,101,111,68,101,102,97,117,108,116,0,99,112,50,58,32,37,117,47,37,117,47,37,117,58,0,0,79,82,46,66,0,0,0,0,82,101,110,97,109,101,0,0,75,80,95,49,0,0,0,0,46,97,110,97,0,0,0,0,112,98,105,116,58,32,99,114,99,32,101,114,114,111,114,10,0,0,0,0,0,0,0,0,71,101,116,86,105,100,101,111,68,101,102,97,117,108,116,0,115,111,110,121,58,32,112,114,105,109,101,58,32,117,110,107,110,111,119,110,32,40,116,114,97,112,61,48,120,37,48,52,120,41,10,0,0,0,0,0,83,66,67,68,46,66,0,0,119,98,0,0,0,0,0,0,102,108,117,115,104,0,0,0,42,42,42,32,101,114,114,111,114,32,99,114,101,97,116,105,110,103,32,115,121,109,108,105,110,107,32,37,115,32,45,62,32,37,115,10,0,0,0,0,114,101,97,100,0,0,0,0,109,105,99,114,111,115,111,102,116,0,0,0,0,0,0,0,115,116,97,114,116,32,109,111,116,111,114,0,0,0,0,0,75,80,95,54,0,0,0,0,110,117,108,108,0,0,0,0,73,110,116,101,114,110,97,108,87,97,105,116,0,0,0,0,114,43,98,0,0,0,0,0,114,43,98,0,0,0,0,0,79,82,46,87,0,0,0,0,114,43,98,0,0,0,0,0,114,98,0,0,0,0,0,0,101,109,117,46,105,119,109,46,115,116,97,116,117,115,0,0,116,101,114,109,46,114,101,108,101,97,115,101,0,0,0,0,101,109,117,46,99,112,117,46,115,112,101,101,100,0,0,0,75,80,95,53,0,0,0,0,70,49,49,0,0,0,0,0,114,43,98,0,0,0,0,0,62,61,0,0,0,0,0,0,63,61,0,0,0,0,0,0,83,101,116,68,101,102,97,117,108,116,83,116,97,114,116,117,112,0,0,0,0,0,0,0,114,111,109,115,47,112,99,101,45,99,111,110,102,105,103,46,99,102,103,0,0,0,0,0,113,0,0,0,0,0,0,0,108,111,97,100,0,0,0,0,109,111,117,115,101,95,109,117,108,95,121,0,0,0,0,0,42,42,42,32,109,101,109,111,114,121,32,98,108,111,99,107,32,99,114,101,97,116,105,111,110,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,79,82,46,76,0,0,0,0,98,108,111,99,107,115,0,0,83,32,32,37,48,52,88,58,37,48,52,108,88,32,32,37,48,52,88,32,32,37,48,52,88,10,0,0,0,0,0,0,116,100,48,58,32,99,111,109,109,101,110,116,32,99,114,99,32,40,37,48,52,88,32,37,48,52,88,41,10,0,0,0,82,101,108,101,97,115,101,32,53,46,48,49,36,48,0,0,114,98,0,0,0,0,0,0,63,0,0,0,0,0,0,0,75,80,95,52,0,0,0,0,119,105,100,116,104,0,0,0,71,101,116,68,101,102,97,117,108,116,83,116,97,114,116,117,112,0,0,0,0,0,0,0,68,73,86,83,46,87,0,0,65,68,66,79,112,0,0,0,75,80,95,80,108,117,115,0,42,42,42,32,117,110,107,110,111,119,110,32,109,111,100,101,108,32,40,37,115,41,10,0,114,117,110,0,0,0,0,0,83,85,66,65,46,87,0,0,65,68,66,82,101,73,110,105,116,0,0,0,0,0,0,0,73,76,76,71,0,0,0,0,75,80,95,57,0,0,0,0,109,97,99,45,99,108,97,115,115,105,99,0,0,0,0,0,83,85,66,46,66,0,0,0,83,101,116,65,68,66,73,110,102,111,0,0,0,0,0,0,75,80,95,56,0,0,0,0,109,97,99,45,115,101,0,0,83,85,66,88,46,66,0,0,71,101,116,65,68,66,73,110,102,111,0,0,0,0,0,0,75,80,95,55,0,0,0,0,109,111,100,101,108,61,37,115,10,0,0,0,0,0,0,0,37,115,37,115,37,48,52,88,40,65,37,117,41,0,0,0,83,85,66,46,87,0,0,0,71,101,116,73,110,100,65,68,66,0,0,0,0,0,0,0,75,80,95,77,105,110,117,115,0,0,0,0,0,0,0,0,83,89,83,84,69,77,58,0,83,85,66,88,46,87,0,0,67,111,117,110,116,65,68,66,115,0,0,0,0,0,0,0,75,80,95,83,116,97,114,0,109,97,99,45,112,108,117,115,0,0,0,0,0,0,0,0,83,85,66,46,76,0,0,0,83,73,110,116,82,101,109,111,118,101,0,0,0,0,0,0,79,112,101,110,82,70,0,0,75,80,95,83,108,97,115,104,0,0,0,0,0,0,0,0,115,121,115,116,101,109,0,0,115,111,110,121,58,32,102,111,114,109,97,116,116,101,100,32,100,105,115,107,32,40,37,108,117,32,98,108,111,99,107,115,41,10,0,0,0,0,0,0,83,85,66,88,46,76,0,0,83,73,110,116,73,110,115,116,97,108,108,0,0,0,0,0,115,116,111,112,32,109,111,116,111,114,0,0,0,0,0,0,78,117,109,76,111,99,107,0,100,105,115,97,98,108,105,110,103,32,109,101,109,111,114,121,32,116,101,115,116,10,0,0,83,85,66,65,46,76,0,0,101,109,117,46,105,119,109,46,114,119,0,0,0,0,0,0,68,111,86,66,76,84,97,115,107,0,0,0,0,0,0,0,116,101,114,109,46,103,114,97,98,0,0,0,0,0,0,0,49,0,0,0,0,0,0,0,67,116,114,108,82,105,103,104,116,0,0,0,0,0,0,0,70,49,48,0,0,0,0,0,60,61,0,0,0,0,0,0,125,0,0,0,0,0,0,0,82,65,77,58,0,0,0,0,37,115,58,32,117,110,107,110,111,119,110,32,111,112,116,105,111,110,32,40,37,115,41,10,0,0,0,0,0,0,0,0,109,0,0,0,0,0,0,0,98,105,110,97,114,121,0,0,109,111,117,115,101,95,100,105,118,95,120,0,0,0,0,0,60,110,111,110,101,62,0,0,67,77,80,46,66,0,0,0,115,0,0,0,0,0,0,0,32,37,115,0,0,0,0,0,69,32,32,34,37,115,34,10,0,0,0,0,0,0,0,0,116,100,48,58,32,114,101,97,100,32,101,114,114,111,114,10,0,0,0,0,0,0,0,0,65,116,116,97,99,104,86,66,76,0,0,0,0,0,0,0,82,101,108,101,97,115,101,32,52,46,48,48,36,48,0,0,46,120,100,102,0,0,0,0,69,0,0,0,0,0,0,0,77,101,110,117,0,0,0,0,97,100,100,114,101,115,115,0,109,101,109,116,101,115,116,0,67,77,80,46,87,0,0,0,83,108,111,116,86,82,101,109,111,118,101,0,0,0,0,0,87,105,110,100,111,119,115,82,105,103,104,116,0,0,0,0,42,42,42,32,82,79,77,32,110,111,116,32,102,111,117,110,100,32,97,116,32,52,48,48,48,48,48,10,0,0,0,0,105,103,110,111,114,105,110,103,32,112,99,101,32,107,101,121,58,32,48,120,37,48,52,120,32,40,37,115,41,10,0,0,97,100,98,58,32,117,110,107,110,111,119,110,32,99,109,100,32,40,37,48,50,88,41,10,0,0,0,0,0,0,0,0])
, "i8", ALLOC_NONE, Runtime.GLOBAL_BASE)
var tempDoublePtr = Runtime.alignMemory(allocate(12, "i8", ALLOC_STATIC), 8);
assert(tempDoublePtr % 8 == 0);
function copyTempFloat(ptr) { // functions, because inlining this code increases code size too much
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
}
function copyTempDouble(ptr) {
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];
  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];
  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];
  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];
}
  Module["_memset"] = _memset;var _llvm_memset_p0i8_i64=_memset;
  Module["_memcpy"] = _memcpy;var _llvm_memcpy_p0i8_p0i8_i32=_memcpy;
  function _emscripten_set_main_loop(func, fps, simulateInfiniteLoop) {
      Module['noExitRuntime'] = true;
      Browser.mainLoop.runner = function() {
        if (ABORT) return;
        if (Browser.mainLoop.queue.length > 0) {
          var start = Date.now();
          var blocker = Browser.mainLoop.queue.shift();
          blocker.func(blocker.arg);
          if (Browser.mainLoop.remainingBlockers) {
            var remaining = Browser.mainLoop.remainingBlockers;
            var next = remaining%1 == 0 ? remaining-1 : Math.floor(remaining);
            if (blocker.counted) {
              Browser.mainLoop.remainingBlockers = next;
            } else {
              // not counted, but move the progress along a tiny bit
              next = next + 0.5; // do not steal all the next one's progress
              Browser.mainLoop.remainingBlockers = (8*remaining + next)/9;
            }
          }
          console.log('main loop blocker "' + blocker.name + '" took ' + (Date.now() - start) + ' ms'); //, left: ' + Browser.mainLoop.remainingBlockers);
          Browser.mainLoop.updateStatus();
          setTimeout(Browser.mainLoop.runner, 0);
          return;
        }
        if (Browser.mainLoop.shouldPause) {
          // catch pauses from non-main loop sources
          Browser.mainLoop.paused = true;
          Browser.mainLoop.shouldPause = false;
          return;
        }
        if (Module['preMainLoop']) {
          Module['preMainLoop']();
        }
        Runtime.dynCall('v', func);
        if (Module['postMainLoop']) {
          Module['postMainLoop']();
        }
        if (Browser.mainLoop.shouldPause) {
          // catch pauses from the main loop itself
          Browser.mainLoop.paused = true;
          Browser.mainLoop.shouldPause = false;
          return;
        }
        Browser.mainLoop.scheduler();
      }
      if (fps && fps > 0) {
        Browser.mainLoop.scheduler = function() {
          setTimeout(Browser.mainLoop.runner, 1000/fps); // doing this each time means that on exception, we stop
        }
      } else {
        Browser.mainLoop.scheduler = function() {
          Browser.requestAnimationFrame(Browser.mainLoop.runner);
        }
      }
      Browser.mainLoop.scheduler();
      if (simulateInfiniteLoop) {
        throw 'SimulateInfiniteLoop';
      }
    }
  var ERRNO_CODES={EPERM:1,ENOENT:2,ESRCH:3,EINTR:4,EIO:5,ENXIO:6,E2BIG:7,ENOEXEC:8,EBADF:9,ECHILD:10,EAGAIN:11,EWOULDBLOCK:11,ENOMEM:12,EACCES:13,EFAULT:14,ENOTBLK:15,EBUSY:16,EEXIST:17,EXDEV:18,ENODEV:19,ENOTDIR:20,EISDIR:21,EINVAL:22,ENFILE:23,EMFILE:24,ENOTTY:25,ETXTBSY:26,EFBIG:27,ENOSPC:28,ESPIPE:29,EROFS:30,EMLINK:31,EPIPE:32,EDOM:33,ERANGE:34,ENOMSG:35,EIDRM:36,ECHRNG:37,EL2NSYNC:38,EL3HLT:39,EL3RST:40,ELNRNG:41,EUNATCH:42,ENOCSI:43,EL2HLT:44,EDEADLK:45,ENOLCK:46,EBADE:50,EBADR:51,EXFULL:52,ENOANO:53,EBADRQC:54,EBADSLT:55,EDEADLOCK:56,EBFONT:57,ENOSTR:60,ENODATA:61,ETIME:62,ENOSR:63,ENONET:64,ENOPKG:65,EREMOTE:66,ENOLINK:67,EADV:68,ESRMNT:69,ECOMM:70,EPROTO:71,EMULTIHOP:74,ELBIN:75,EDOTDOT:76,EBADMSG:77,EFTYPE:79,ENOTUNIQ:80,EBADFD:81,EREMCHG:82,ELIBACC:83,ELIBBAD:84,ELIBSCN:85,ELIBMAX:86,ELIBEXEC:87,ENOSYS:88,ENMFILE:89,ENOTEMPTY:90,ENAMETOOLONG:91,ELOOP:92,EOPNOTSUPP:95,EPFNOSUPPORT:96,ECONNRESET:104,ENOBUFS:105,EAFNOSUPPORT:106,EPROTOTYPE:107,ENOTSOCK:108,ENOPROTOOPT:109,ESHUTDOWN:110,ECONNREFUSED:111,EADDRINUSE:112,ECONNABORTED:113,ENETUNREACH:114,ENETDOWN:115,ETIMEDOUT:116,EHOSTDOWN:117,EHOSTUNREACH:118,EINPROGRESS:119,EALREADY:120,EDESTADDRREQ:121,EMSGSIZE:122,EPROTONOSUPPORT:123,ESOCKTNOSUPPORT:124,EADDRNOTAVAIL:125,ENETRESET:126,EISCONN:127,ENOTCONN:128,ETOOMANYREFS:129,EPROCLIM:130,EUSERS:131,EDQUOT:132,ESTALE:133,ENOTSUP:134,ENOMEDIUM:135,ENOSHARE:136,ECASECLASH:137,EILSEQ:138,EOVERFLOW:139,ECANCELED:140,ENOTRECOVERABLE:141,EOWNERDEAD:142,ESTRPIPE:143};
  var ___errno_state=0;function ___setErrNo(value) {
      // For convenient setting and returning of errno.
      HEAP32[((___errno_state)>>2)]=value
      return value;
    }
  var _stdin=allocate(1, "i32*", ALLOC_STATIC);
  var _stdout=allocate(1, "i32*", ALLOC_STATIC);
  var _stderr=allocate(1, "i32*", ALLOC_STATIC);
  var __impure_ptr=allocate(1, "i32*", ALLOC_STATIC);var FS={currentPath:"/",nextInode:2,streams:[null],ignorePermissions:true,createFileHandle:function (stream, fd) {
        if (typeof stream === 'undefined') {
          stream = null;
        }
        if (!fd) {
          if (stream && stream.socket) {
            for (var i = 1; i < 64; i++) {
              if (!FS.streams[i]) {
                fd = i;
                break;
              }
            }
            assert(fd, 'ran out of low fds for sockets');
          } else {
            fd = Math.max(FS.streams.length, 64);
            for (var i = FS.streams.length; i < fd; i++) {
              FS.streams[i] = null; // Keep dense
            }
          }
        }
        // Close WebSocket first if we are about to replace the fd (i.e. dup2)
        if (FS.streams[fd] && FS.streams[fd].socket && FS.streams[fd].socket.close) {
          FS.streams[fd].socket.close();
        }
        FS.streams[fd] = stream;
        return fd;
      },removeFileHandle:function (fd) {
        FS.streams[fd] = null;
      },joinPath:function (parts, forceRelative) {
        var ret = parts[0];
        for (var i = 1; i < parts.length; i++) {
          if (ret[ret.length-1] != '/') ret += '/';
          ret += parts[i];
        }
        if (forceRelative && ret[0] == '/') ret = ret.substr(1);
        return ret;
      },absolutePath:function (relative, base) {
        if (typeof relative !== 'string') return null;
        if (base === undefined) base = FS.currentPath;
        if (relative && relative[0] == '/') base = '';
        var full = base + '/' + relative;
        var parts = full.split('/').reverse();
        var absolute = [''];
        while (parts.length) {
          var part = parts.pop();
          if (part == '' || part == '.') {
            // Nothing.
          } else if (part == '..') {
            if (absolute.length > 1) absolute.pop();
          } else {
            absolute.push(part);
          }
        }
        return absolute.length == 1 ? '/' : absolute.join('/');
      },analyzePath:function (path, dontResolveLastLink, linksVisited) {
        var ret = {
          isRoot: false,
          exists: false,
          error: 0,
          name: null,
          path: null,
          object: null,
          parentExists: false,
          parentPath: null,
          parentObject: null
        };
        path = FS.absolutePath(path);
        if (path == '/') {
          ret.isRoot = true;
          ret.exists = ret.parentExists = true;
          ret.name = '/';
          ret.path = ret.parentPath = '/';
          ret.object = ret.parentObject = FS.root;
        } else if (path !== null) {
          linksVisited = linksVisited || 0;
          path = path.slice(1).split('/');
          var current = FS.root;
          var traversed = [''];
          while (path.length) {
            if (path.length == 1 && current.isFolder) {
              ret.parentExists = true;
              ret.parentPath = traversed.length == 1 ? '/' : traversed.join('/');
              ret.parentObject = current;
              ret.name = path[0];
            }
            var target = path.shift();
            if (!current.isFolder) {
              ret.error = ERRNO_CODES.ENOTDIR;
              break;
            } else if (!current.read) {
              ret.error = ERRNO_CODES.EACCES;
              break;
            } else if (!current.contents.hasOwnProperty(target)) {
              ret.error = ERRNO_CODES.ENOENT;
              break;
            }
            current = current.contents[target];
            if (current.link && !(dontResolveLastLink && path.length == 0)) {
              if (linksVisited > 40) { // Usual Linux SYMLOOP_MAX.
                ret.error = ERRNO_CODES.ELOOP;
                break;
              }
              var link = FS.absolutePath(current.link, traversed.join('/'));
              ret = FS.analyzePath([link].concat(path).join('/'),
                                   dontResolveLastLink, linksVisited + 1);
              return ret;
            }
            traversed.push(target);
            if (path.length == 0) {
              ret.exists = true;
              ret.path = traversed.join('/');
              ret.object = current;
            }
          }
        }
        return ret;
      },findObject:function (path, dontResolveLastLink) {
        FS.ensureRoot();
        var ret = FS.analyzePath(path, dontResolveLastLink);
        if (ret.exists) {
          return ret.object;
        } else {
          ___setErrNo(ret.error);
          return null;
        }
      },createObject:function (parent, name, properties, canRead, canWrite) {
        if (!parent) parent = '/';
        if (typeof parent === 'string') parent = FS.findObject(parent);
        if (!parent) {
          ___setErrNo(ERRNO_CODES.EACCES);
          throw new Error('Parent path must exist.');
        }
        if (!parent.isFolder) {
          ___setErrNo(ERRNO_CODES.ENOTDIR);
          throw new Error('Parent must be a folder.');
        }
        if (!parent.write && !FS.ignorePermissions) {
          ___setErrNo(ERRNO_CODES.EACCES);
          throw new Error('Parent folder must be writeable.');
        }
        if (!name || name == '.' || name == '..') {
          ___setErrNo(ERRNO_CODES.ENOENT);
          throw new Error('Name must not be empty.');
        }
        if (parent.contents.hasOwnProperty(name)) {
          ___setErrNo(ERRNO_CODES.EEXIST);
          throw new Error("Can't overwrite object.");
        }
        parent.contents[name] = {
          read: canRead === undefined ? true : canRead,
          write: canWrite === undefined ? false : canWrite,
          timestamp: Date.now(),
          inodeNumber: FS.nextInode++
        };
        for (var key in properties) {
          if (properties.hasOwnProperty(key)) {
            parent.contents[name][key] = properties[key];
          }
        }
        return parent.contents[name];
      },createFolder:function (parent, name, canRead, canWrite) {
        var properties = {isFolder: true, isDevice: false, contents: {}};
        return FS.createObject(parent, name, properties, canRead, canWrite);
      },createPath:function (parent, path, canRead, canWrite) {
        var current = FS.findObject(parent);
        if (current === null) throw new Error('Invalid parent.');
        path = path.split('/').reverse();
        while (path.length) {
          var part = path.pop();
          if (!part) continue;
          if (!current.contents.hasOwnProperty(part)) {
            FS.createFolder(current, part, canRead, canWrite);
          }
          current = current.contents[part];
        }
        return current;
      },createFile:function (parent, name, properties, canRead, canWrite) {
        properties.isFolder = false;
        return FS.createObject(parent, name, properties, canRead, canWrite);
      },createDataFile:function (parent, name, data, canRead, canWrite) {
        if (typeof data === 'string') {
          var dataArray = new Array(data.length);
          for (var i = 0, len = data.length; i < len; ++i) dataArray[i] = data.charCodeAt(i);
          data = dataArray;
        }
        var properties = {
          isDevice: false,
          contents: data.subarray ? data.subarray(0) : data // as an optimization, create a new array wrapper (not buffer) here, to help JS engines understand this object
        };
        return FS.createFile(parent, name, properties, canRead, canWrite);
      },createLazyFile:function (parent, name, url, canRead, canWrite) {
        if (typeof XMLHttpRequest !== 'undefined') {
          if (!ENVIRONMENT_IS_WORKER) throw 'Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc';
          // Lazy chunked Uint8Array (implements get and length from Uint8Array). Actual getting is abstracted away for eventual reuse.
          var LazyUint8Array = function() {
            this.lengthKnown = false;
            this.chunks = []; // Loaded chunks. Index is the chunk number
          }
          LazyUint8Array.prototype.get = function(idx) {
            if (idx > this.length-1 || idx < 0) {
              return undefined;
            }
            var chunkOffset = idx % this.chunkSize;
            var chunkNum = Math.floor(idx / this.chunkSize);
            return this.getter(chunkNum)[chunkOffset];
          }
          LazyUint8Array.prototype.setDataGetter = function(getter) {
            this.getter = getter;
          }
          LazyUint8Array.prototype.cacheLength = function() {
              // Find length
              var xhr = new XMLHttpRequest();
              xhr.open('HEAD', url, false);
              xhr.send(null);
              if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
              var datalength = Number(xhr.getResponseHeader("Content-length"));
              var header;
              var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
              var chunkSize = 1024*1024; // Chunk size in bytes
              if (!hasByteServing) chunkSize = datalength;
              // Function to get a range from the remote URL.
              var doXHR = (function(from, to) {
                if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
                if (to > datalength-1) throw new Error("only " + datalength + " bytes available! programmer error!");
                // TODO: Use mozResponseArrayBuffer, responseStream, etc. if available.
                var xhr = new XMLHttpRequest();
                xhr.open('GET', url, false);
                if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
                // Some hints to the browser that we want binary data.
                if (typeof Uint8Array != 'undefined') xhr.responseType = 'arraybuffer';
                if (xhr.overrideMimeType) {
                  xhr.overrideMimeType('text/plain; charset=x-user-defined');
                }
                xhr.send(null);
                if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
                if (xhr.response !== undefined) {
                  return new Uint8Array(xhr.response || []);
                } else {
                  return intArrayFromString(xhr.responseText || '', true);
                }
              });
              var lazyArray = this;
              lazyArray.setDataGetter(function(chunkNum) {
                var start = chunkNum * chunkSize;
                var end = (chunkNum+1) * chunkSize - 1; // including this byte
                end = Math.min(end, datalength-1); // if datalength-1 is selected, this is the last block
                if (typeof(lazyArray.chunks[chunkNum]) === "undefined") {
                  lazyArray.chunks[chunkNum] = doXHR(start, end);
                }
                if (typeof(lazyArray.chunks[chunkNum]) === "undefined") throw new Error("doXHR failed!");
                return lazyArray.chunks[chunkNum];
              });
              this._length = datalength;
              this._chunkSize = chunkSize;
              this.lengthKnown = true;
          }
          var lazyArray = new LazyUint8Array();
          Object.defineProperty(lazyArray, "length", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._length;
              }
          });
          Object.defineProperty(lazyArray, "chunkSize", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._chunkSize;
              }
          });
          var properties = { isDevice: false, contents: lazyArray };
        } else {
          var properties = { isDevice: false, url: url };
        }
        return FS.createFile(parent, name, properties, canRead, canWrite);
      },createPreloadedFile:function (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile) {
        Browser.init();
        var fullname = FS.joinPath([parent, name], true);
        function processData(byteArray) {
          function finish(byteArray) {
            if (!dontCreateFile) {
              FS.createDataFile(parent, name, byteArray, canRead, canWrite);
            }
            if (onload) onload();
            removeRunDependency('cp ' + fullname);
          }
          var handled = false;
          Module['preloadPlugins'].forEach(function(plugin) {
            if (handled) return;
            if (plugin['canHandle'](fullname)) {
              plugin['handle'](byteArray, fullname, finish, function() {
                if (onerror) onerror();
                removeRunDependency('cp ' + fullname);
              });
              handled = true;
            }
          });
          if (!handled) finish(byteArray);
        }
        addRunDependency('cp ' + fullname);
        if (typeof url == 'string') {
          Browser.asyncLoad(url, function(byteArray) {
            processData(byteArray);
          }, onerror);
        } else {
          processData(url);
        }
      },createLink:function (parent, name, target, canRead, canWrite) {
        var properties = {isDevice: false, link: target};
        return FS.createFile(parent, name, properties, canRead, canWrite);
      },createDevice:function (parent, name, input, output) {
        if (!(input || output)) {
          throw new Error('A device must have at least one callback defined.');
        }
        var ops = {isDevice: true, input: input, output: output};
        return FS.createFile(parent, name, ops, Boolean(input), Boolean(output));
      },forceLoadFile:function (obj) {
        if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
        var success = true;
        if (typeof XMLHttpRequest !== 'undefined') {
          throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
        } else if (Module['read']) {
          // Command-line.
          try {
            // WARNING: Can't read binary files in V8's d8 or tracemonkey's js, as
            //          read() will try to parse UTF8.
            obj.contents = intArrayFromString(Module['read'](obj.url), true);
          } catch (e) {
            success = false;
          }
        } else {
          throw new Error('Cannot load without read() or XMLHttpRequest.');
        }
        if (!success) ___setErrNo(ERRNO_CODES.EIO);
        return success;
      },ensureRoot:function () {
        if (FS.root) return;
        // The main file system tree. All the contents are inside this.
        FS.root = {
          read: true,
          write: true,
          isFolder: true,
          isDevice: false,
          timestamp: Date.now(),
          inodeNumber: 1,
          contents: {}
        };
      },init:function (input, output, error) {
        // Make sure we initialize only once.
        assert(!FS.init.initialized, 'FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)');
        FS.init.initialized = true;
        FS.ensureRoot();
        // Allow Module.stdin etc. to provide defaults, if none explicitly passed to us here
        input = input || Module['stdin'];
        output = output || Module['stdout'];
        error = error || Module['stderr'];
        // Default handlers.
        var stdinOverridden = true, stdoutOverridden = true, stderrOverridden = true;
        if (!input) {
          stdinOverridden = false;
          input = function() {
            if (!input.cache || !input.cache.length) {
              var result;
              if (typeof window != 'undefined' &&
                  typeof window.prompt == 'function') {
                // Browser.
                result = window.prompt('Input: ');
                if (result === null) result = String.fromCharCode(0); // cancel ==> EOF
              } else if (typeof readline == 'function') {
                // Command line.
                result = readline();
              }
              if (!result) result = '';
              input.cache = intArrayFromString(result + '\n', true);
            }
            return input.cache.shift();
          };
        }
        var utf8 = new Runtime.UTF8Processor();
        function simpleOutput(val) {
          if (val === null || val === 10) {
            output.printer(output.buffer.join(''));
            output.buffer = [];
          } else {
            output.buffer.push(utf8.processCChar(val));
          }
        }
        if (!output) {
          stdoutOverridden = false;
          output = simpleOutput;
        }
        if (!output.printer) output.printer = Module['print'];
        if (!output.buffer) output.buffer = [];
        if (!error) {
          stderrOverridden = false;
          error = simpleOutput;
        }
        if (!error.printer) error.printer = Module['print'];
        if (!error.buffer) error.buffer = [];
        // Create the temporary folder, if not already created
        try {
          FS.createFolder('/', 'tmp', true, true);
        } catch(e) {}
        // Create the I/O devices.
        var devFolder = FS.createFolder('/', 'dev', true, true);
        var stdin = FS.createDevice(devFolder, 'stdin', input);
        stdin.isTerminal = !stdinOverridden;
        var stdout = FS.createDevice(devFolder, 'stdout', null, output);
        stdout.isTerminal = !stdoutOverridden;
        var stderr = FS.createDevice(devFolder, 'stderr', null, error);
        stderr.isTerminal = !stderrOverridden;
        FS.createDevice(devFolder, 'tty', input, output);
        FS.createDevice(devFolder, 'null', function(){}, function(){});
        // Create default streams.
        FS.streams[1] = {
          path: '/dev/stdin',
          object: stdin,
          position: 0,
          isRead: true,
          isWrite: false,
          isAppend: false,
          error: false,
          eof: false,
          ungotten: []
        };
        FS.streams[2] = {
          path: '/dev/stdout',
          object: stdout,
          position: 0,
          isRead: false,
          isWrite: true,
          isAppend: false,
          error: false,
          eof: false,
          ungotten: []
        };
        FS.streams[3] = {
          path: '/dev/stderr',
          object: stderr,
          position: 0,
          isRead: false,
          isWrite: true,
          isAppend: false,
          error: false,
          eof: false,
          ungotten: []
        };
        // TODO: put these low in memory like we used to assert on: assert(Math.max(_stdin, _stdout, _stderr) < 15000); // make sure these are low, we flatten arrays with these
        HEAP32[((_stdin)>>2)]=1;
        HEAP32[((_stdout)>>2)]=2;
        HEAP32[((_stderr)>>2)]=3;
        // Other system paths
        FS.createPath('/', 'dev/shm/tmp', true, true); // temp files
        // Newlib initialization
        for (var i = FS.streams.length; i < Math.max(_stdin, _stdout, _stderr) + 4; i++) {
          FS.streams[i] = null; // Make sure to keep FS.streams dense
        }
        FS.streams[_stdin] = FS.streams[1];
        FS.streams[_stdout] = FS.streams[2];
        FS.streams[_stderr] = FS.streams[3];
        allocate([ allocate(
          [0, 0, 0, 0, _stdin, 0, 0, 0, _stdout, 0, 0, 0, _stderr, 0, 0, 0],
          'void*', ALLOC_NORMAL) ], 'void*', ALLOC_NONE, __impure_ptr);
      },quit:function () {
        if (!FS.init.initialized) return;
        // Flush any partially-printed lines in stdout and stderr. Careful, they may have been closed
        if (FS.streams[2] && FS.streams[2].object.output.buffer.length > 0) FS.streams[2].object.output(10);
        if (FS.streams[3] && FS.streams[3].object.output.buffer.length > 0) FS.streams[3].object.output(10);
      },standardizePath:function (path) {
        if (path.substr(0, 2) == './') path = path.substr(2);
        return path;
      },deleteFile:function (path) {
        path = FS.analyzePath(path);
        if (!path.parentExists || !path.exists) {
          throw 'Invalid path ' + path;
        }
        delete path.parentObject.contents[path.name];
      }};
  var Browser={mainLoop:{scheduler:null,shouldPause:false,paused:false,queue:[],pause:function () {
          Browser.mainLoop.shouldPause = true;
        },resume:function () {
          if (Browser.mainLoop.paused) {
            Browser.mainLoop.paused = false;
            Browser.mainLoop.scheduler();
          }
          Browser.mainLoop.shouldPause = false;
        },updateStatus:function () {
          if (Module['setStatus']) {
            var message = Module['statusMessage'] || 'Please wait...';
            var remaining = Browser.mainLoop.remainingBlockers;
            var expected = Browser.mainLoop.expectedBlockers;
            if (remaining) {
              if (remaining < expected) {
                Module['setStatus'](message + ' (' + (expected - remaining) + '/' + expected + ')');
              } else {
                Module['setStatus'](message);
              }
            } else {
              Module['setStatus']('');
            }
          }
        }},isFullScreen:false,pointerLock:false,moduleContextCreatedCallbacks:[],workers:[],init:function () {
        if (!Module["preloadPlugins"]) Module["preloadPlugins"] = []; // needs to exist even in workers
        if (Browser.initted || ENVIRONMENT_IS_WORKER) return;
        Browser.initted = true;
        try {
          new Blob();
          Browser.hasBlobConstructor = true;
        } catch(e) {
          Browser.hasBlobConstructor = false;
          console.log("warning: no blob constructor, cannot create blobs with mimetypes");
        }
        Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : (typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : (!Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null));
        Browser.URLObject = typeof window != "undefined" ? (window.URL ? window.URL : window.webkitURL) : console.log("warning: cannot create object URLs");
        // Support for plugins that can process preloaded files. You can add more of these to
        // your app by creating and appending to Module.preloadPlugins.
        //
        // Each plugin is asked if it can handle a file based on the file's name. If it can,
        // it is given the file's raw data. When it is done, it calls a callback with the file's
        // (possibly modified) data. For example, a plugin might decompress a file, or it
        // might create some side data structure for use later (like an Image element, etc.).
        function getMimetype(name) {
          return {
            'jpg': 'image/jpeg',
            'jpeg': 'image/jpeg',
            'png': 'image/png',
            'bmp': 'image/bmp',
            'ogg': 'audio/ogg',
            'wav': 'audio/wav',
            'mp3': 'audio/mpeg'
          }[name.substr(name.lastIndexOf('.')+1)];
        }
        var imagePlugin = {};
        imagePlugin['canHandle'] = function(name) {
          return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/i.test(name);
        };
        imagePlugin['handle'] = function(byteArray, name, onload, onerror) {
          var b = null;
          if (Browser.hasBlobConstructor) {
            try {
              b = new Blob([byteArray], { type: getMimetype(name) });
              if (b.size !== byteArray.length) { // Safari bug #118630
                // Safari's Blob can only take an ArrayBuffer
                b = new Blob([(new Uint8Array(byteArray)).buffer], { type: getMimetype(name) });
              }
            } catch(e) {
              Runtime.warnOnce('Blob constructor present but fails: ' + e + '; falling back to blob builder');
            }
          }
          if (!b) {
            var bb = new Browser.BlobBuilder();
            bb.append((new Uint8Array(byteArray)).buffer); // we need to pass a buffer, and must copy the array to get the right data range
            b = bb.getBlob();
          }
          var url = Browser.URLObject.createObjectURL(b);
          var img = new Image();
          img.onload = function() {
            assert(img.complete, 'Image ' + name + ' could not be decoded');
            var canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            Module["preloadedImages"][name] = canvas;
            Browser.URLObject.revokeObjectURL(url);
            if (onload) onload(byteArray);
          };
          img.onerror = function(event) {
            console.log('Image ' + url + ' could not be decoded');
            if (onerror) onerror();
          };
          img.src = url;
        };
        Module['preloadPlugins'].push(imagePlugin);
        var audioPlugin = {};
        audioPlugin['canHandle'] = function(name) {
          return !Module.noAudioDecoding && name.substr(-4) in { '.ogg': 1, '.wav': 1, '.mp3': 1 };
        };
        audioPlugin['handle'] = function(byteArray, name, onload, onerror) {
          var done = false;
          function finish(audio) {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = audio;
            if (onload) onload(byteArray);
          }
          function fail() {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = new Audio(); // empty shim
            if (onerror) onerror();
          }
          if (Browser.hasBlobConstructor) {
            try {
              var b = new Blob([byteArray], { type: getMimetype(name) });
            } catch(e) {
              return fail();
            }
            var url = Browser.URLObject.createObjectURL(b); // XXX we never revoke this!
            var audio = new Audio();
            audio.addEventListener('canplaythrough', function() { finish(audio) }, false); // use addEventListener due to chromium bug 124926
            audio.onerror = function(event) {
              if (done) return;
              console.log('warning: browser could not fully decode audio ' + name + ', trying slower base64 approach');
              function encode64(data) {
                var BASE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
                var PAD = '=';
                var ret = '';
                var leftchar = 0;
                var leftbits = 0;
                for (var i = 0; i < data.length; i++) {
                  leftchar = (leftchar << 8) | data[i];
                  leftbits += 8;
                  while (leftbits >= 6) {
                    var curr = (leftchar >> (leftbits-6)) & 0x3f;
                    leftbits -= 6;
                    ret += BASE[curr];
                  }
                }
                if (leftbits == 2) {
                  ret += BASE[(leftchar&3) << 4];
                  ret += PAD + PAD;
                } else if (leftbits == 4) {
                  ret += BASE[(leftchar&0xf) << 2];
                  ret += PAD;
                }
                return ret;
              }
              audio.src = 'data:audio/x-' + name.substr(-3) + ';base64,' + encode64(byteArray);
              finish(audio); // we don't wait for confirmation this worked - but it's worth trying
            };
            audio.src = url;
            // workaround for chrome bug 124926 - we do not always get oncanplaythrough or onerror
            Browser.safeSetTimeout(function() {
              finish(audio); // try to use it even though it is not necessarily ready to play
            }, 10000);
          } else {
            return fail();
          }
        };
        Module['preloadPlugins'].push(audioPlugin);
        // Canvas event setup
        var canvas = Module['canvas'];
        canvas.requestPointerLock = canvas['requestPointerLock'] ||
                                    canvas['mozRequestPointerLock'] ||
                                    canvas['webkitRequestPointerLock'];
        canvas.exitPointerLock = document['exitPointerLock'] ||
                                 document['mozExitPointerLock'] ||
                                 document['webkitExitPointerLock'] ||
                                 function(){}; // no-op if function does not exist
        canvas.exitPointerLock = canvas.exitPointerLock.bind(document);
        function pointerLockChange() {
          Browser.pointerLock = document['pointerLockElement'] === canvas ||
                                document['mozPointerLockElement'] === canvas ||
                                document['webkitPointerLockElement'] === canvas;
        }
        document.addEventListener('pointerlockchange', pointerLockChange, false);
        document.addEventListener('mozpointerlockchange', pointerLockChange, false);
        document.addEventListener('webkitpointerlockchange', pointerLockChange, false);
        if (Module['elementPointerLock']) {
          canvas.addEventListener("click", function(ev) {
            if (!Browser.pointerLock && canvas.requestPointerLock) {
              canvas.requestPointerLock();
              ev.preventDefault();
            }
          }, false);
        }
      },createContext:function (canvas, useWebGL, setInModule) {
        var ctx;
        try {
          if (useWebGL) {
            ctx = canvas.getContext('experimental-webgl', {
              alpha: false
            });
          } else {
            ctx = canvas.getContext('2d');
          }
          if (!ctx) throw ':(';
        } catch (e) {
          Module.print('Could not create canvas - ' + e);
          return null;
        }
        if (useWebGL) {
          // Set the background of the WebGL canvas to black
          canvas.style.backgroundColor = "black";
          // Warn on context loss
          canvas.addEventListener('webglcontextlost', function(event) {
            alert('WebGL context lost. You will need to reload the page.');
          }, false);
        }
        if (setInModule) {
          Module.ctx = ctx;
          Module.useWebGL = useWebGL;
          Browser.moduleContextCreatedCallbacks.forEach(function(callback) { callback() });
          Browser.init();
        }
        return ctx;
      },destroyContext:function (canvas, useWebGL, setInModule) {},fullScreenHandlersInstalled:false,lockPointer:undefined,resizeCanvas:undefined,requestFullScreen:function (lockPointer, resizeCanvas) {
        Browser.lockPointer = lockPointer;
        Browser.resizeCanvas = resizeCanvas;
        if (typeof Browser.lockPointer === 'undefined') Browser.lockPointer = true;
        if (typeof Browser.resizeCanvas === 'undefined') Browser.resizeCanvas = false;
        var canvas = Module['canvas'];
        function fullScreenChange() {
          Browser.isFullScreen = false;
          if ((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
               document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
               document['fullScreenElement'] || document['fullscreenElement']) === canvas) {
            canvas.cancelFullScreen = document['cancelFullScreen'] ||
                                      document['mozCancelFullScreen'] ||
                                      document['webkitCancelFullScreen'];
            canvas.cancelFullScreen = canvas.cancelFullScreen.bind(document);
            if (Browser.lockPointer) canvas.requestPointerLock();
            Browser.isFullScreen = true;
            if (Browser.resizeCanvas) Browser.setFullScreenCanvasSize();
          } else if (Browser.resizeCanvas){
            Browser.setWindowedCanvasSize();
          }
          if (Module['onFullScreen']) Module['onFullScreen'](Browser.isFullScreen);
        }
        if (!Browser.fullScreenHandlersInstalled) {
          Browser.fullScreenHandlersInstalled = true;
          document.addEventListener('fullscreenchange', fullScreenChange, false);
          document.addEventListener('mozfullscreenchange', fullScreenChange, false);
          document.addEventListener('webkitfullscreenchange', fullScreenChange, false);
        }
        canvas.requestFullScreen = canvas['requestFullScreen'] ||
                                   canvas['mozRequestFullScreen'] ||
                                   (canvas['webkitRequestFullScreen'] ? function() { canvas['webkitRequestFullScreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null);
        canvas.requestFullScreen();
      },requestAnimationFrame:function (func) {
        if (!window.requestAnimationFrame) {
          window.requestAnimationFrame = window['requestAnimationFrame'] ||
                                         window['mozRequestAnimationFrame'] ||
                                         window['webkitRequestAnimationFrame'] ||
                                         window['msRequestAnimationFrame'] ||
                                         window['oRequestAnimationFrame'] ||
                                         window['setTimeout'];
        }
        window.requestAnimationFrame(func);
      },safeCallback:function (func) {
        return function() {
          if (!ABORT) return func.apply(null, arguments);
        };
      },safeRequestAnimationFrame:function (func) {
        return Browser.requestAnimationFrame(function() {
          if (!ABORT) func();
        });
      },safeSetTimeout:function (func, timeout) {
        return setTimeout(function() {
          if (!ABORT) func();
        }, timeout);
      },safeSetInterval:function (func, timeout) {
        return setInterval(function() {
          if (!ABORT) func();
        }, timeout);
      },getUserMedia:function (func) {
        if(!window.getUserMedia) {
          window.getUserMedia = navigator['getUserMedia'] ||
                                navigator['mozGetUserMedia'];
        }
        window.getUserMedia(func);
      },getMovementX:function (event) {
        return event['movementX'] ||
               event['mozMovementX'] ||
               event['webkitMovementX'] ||
               0;
      },getMovementY:function (event) {
        return event['movementY'] ||
               event['mozMovementY'] ||
               event['webkitMovementY'] ||
               0;
      },mouseX:0,mouseY:0,mouseMovementX:0,mouseMovementY:0,calculateMouseEvent:function (event) { // event should be mousemove, mousedown or mouseup
        if (Browser.pointerLock) {
          // When the pointer is locked, calculate the coordinates
          // based on the movement of the mouse.
          // Workaround for Firefox bug 764498
          if (event.type != 'mousemove' &&
              ('mozMovementX' in event)) {
            Browser.mouseMovementX = Browser.mouseMovementY = 0;
          } else {
            Browser.mouseMovementX = Browser.getMovementX(event);
            Browser.mouseMovementY = Browser.getMovementY(event);
          }
          // check if SDL is available
          if (typeof SDL != "undefined") {
          	Browser.mouseX = SDL.mouseX + Browser.mouseMovementX;
          	Browser.mouseY = SDL.mouseY + Browser.mouseMovementY;
          } else {
          	// just add the mouse delta to the current absolut mouse position
          	// FIXME: ideally this should be clamped against the canvas size and zero
          	Browser.mouseX += Browser.mouseMovementX;
          	Browser.mouseY += Browser.mouseMovementY;
          }        
        } else {
          // Otherwise, calculate the movement based on the changes
          // in the coordinates.
          if (Module["canvasFront"]) {
            var rect = Module["canvasFront"].getBoundingClientRect();
          } else {
            var rect = Module["canvas"].getBoundingClientRect();
          }
          var x = event.pageX - (window.scrollX + rect.left);
          var y = event.pageY - (window.scrollY + rect.top);
          // the canvas might be CSS-scaled compared to its backbuffer;
          // SDL-using content will want mouse coordinates in terms
          // of backbuffer units.
          var cw = Module["canvas"].width;
          var ch = Module["canvas"].height;
          x = x * (cw / rect.width);
          y = y * (ch / rect.height);
          Browser.mouseMovementX = x - Browser.mouseX;
          Browser.mouseMovementY = y - Browser.mouseY;
          Browser.mouseX = x;
          Browser.mouseY = y;
        }
      },xhrLoad:function (url, onload, onerror) {
        var xhr = new XMLHttpRequest();
        xhr.open('GET', url, true);
        xhr.responseType = 'arraybuffer';
        xhr.onload = function() {
          if (xhr.status == 200 || (xhr.status == 0 && xhr.response)) { // file URLs can return 0
            onload(xhr.response);
          } else {
            onerror();
          }
        };
        xhr.onerror = onerror;
        xhr.send(null);
      },asyncLoad:function (url, onload, onerror, noRunDep) {
        Browser.xhrLoad(url, function(arrayBuffer) {
          assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
          onload(new Uint8Array(arrayBuffer));
          if (!noRunDep) removeRunDependency('al ' + url);
        }, function(event) {
          if (onerror) {
            onerror();
          } else {
            throw 'Loading data file "' + url + '" failed.';
          }
        });
        if (!noRunDep) addRunDependency('al ' + url);
      },resizeListeners:[],updateResizeListeners:function () {
        var canvas = Module['canvas'];
        Browser.resizeListeners.forEach(function(listener) {
          listener(canvas.width, canvas.height);
        });
      },setCanvasSize:function (width, height, noUpdates) {
        var canvas = Module['canvas'];
        canvas.width = width;
        canvas.height = height;
        if (!noUpdates) Browser.updateResizeListeners();
      },windowedWidth:0,windowedHeight:0,setFullScreenCanvasSize:function () {
        var canvas = Module['canvas'];
        this.windowedWidth = canvas.width;
        this.windowedHeight = canvas.height;
        canvas.width = screen.width;
        canvas.height = screen.height;
        // check if SDL is available   
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags | 0x00800000; // set SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },setWindowedCanvasSize:function () {
        var canvas = Module['canvas'];
        canvas.width = this.windowedWidth;
        canvas.height = this.windowedHeight;
        // check if SDL is available       
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags & ~0x00800000; // clear SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      }};var SDL={defaults:{width:320,height:200,copyOnLock:true},version:null,surfaces:{},canvasPool:[],events:[],fonts:[null],audios:[null],music:{audio:null,volume:1},mixerFrequency:22050,mixerFormat:32784,mixerNumChannels:2,mixerChunkSize:1024,channelMinimumNumber:0,GL:false,keyboardState:null,keyboardMap:{},textInput:false,startTime:null,buttonState:0,modState:0,DOMButtons:[0,0,0],DOMEventToSDLEvent:{},keyCodes:{16:1249,17:1248,18:1250,33:1099,34:1102,37:1104,38:1106,39:1103,40:1105,46:127,96:1112,97:1113,98:1114,99:1115,100:1116,101:1117,102:1118,103:1119,104:1120,105:1121,112:1082,113:1083,114:1084,115:1085,116:1086,117:1087,118:1088,119:1089,120:1090,121:1091,122:1092,123:1093,173:45,188:44,190:46,191:47,192:96},scanCodes:{9:43,13:40,27:41,32:44,44:54,46:55,47:56,48:39,49:30,50:31,51:32,52:33,53:34,54:35,55:36,56:37,57:38,92:49,97:4,98:5,99:6,100:7,101:8,102:9,103:10,104:11,105:12,106:13,107:14,108:15,109:16,110:17,111:18,112:19,113:20,114:21,115:22,116:23,117:24,118:25,119:26,120:27,121:28,122:29,305:224,308:226},structs:{Rect:{__size__:16,x:0,y:4,w:8,h:12},PixelFormat:{__size__:36,format:0,palette:4,BitsPerPixel:8,BytesPerPixel:9,padding1:10,padding2:11,Rmask:12,Gmask:16,Bmask:20,Amask:24,Rloss:28,Gloss:29,Bloss:30,Aloss:31,Rshift:32,Gshift:33,Bshift:34,Ashift:35},KeyboardEvent:{__size__:16,type:0,windowID:4,state:8,repeat:9,padding2:10,padding3:11,keysym:12},keysym:{__size__:16,scancode:0,sym:4,mod:8,unicode:12},TextInputEvent:{__size__:264,type:0,windowID:4,text:8},MouseMotionEvent:{__size__:28,type:0,windowID:4,state:8,padding1:9,padding2:10,padding3:11,x:12,y:16,xrel:20,yrel:24},MouseButtonEvent:{__size__:20,type:0,windowID:4,button:8,state:9,padding1:10,padding2:11,x:12,y:16},ResizeEvent:{__size__:12,type:0,w:4,h:8},AudioSpec:{__size__:24,freq:0,format:4,channels:6,silence:7,samples:8,size:12,callback:16,userdata:20},version:{__size__:3,major:0,minor:1,patch:2}},loadRect:function (rect) {
        return {
          x: HEAP32[((rect + SDL.structs.Rect.x)>>2)],
          y: HEAP32[((rect + SDL.structs.Rect.y)>>2)],
          w: HEAP32[((rect + SDL.structs.Rect.w)>>2)],
          h: HEAP32[((rect + SDL.structs.Rect.h)>>2)]
        };
      },loadColorToCSSRGB:function (color) {
        var rgba = HEAP32[((color)>>2)];
        return 'rgb(' + (rgba&255) + ',' + ((rgba >> 8)&255) + ',' + ((rgba >> 16)&255) + ')';
      },loadColorToCSSRGBA:function (color) {
        var rgba = HEAP32[((color)>>2)];
        return 'rgba(' + (rgba&255) + ',' + ((rgba >> 8)&255) + ',' + ((rgba >> 16)&255) + ',' + (((rgba >> 24)&255)/255) + ')';
      },translateColorToCSSRGBA:function (rgba) {
        return 'rgba(' + (rgba&0xff) + ',' + (rgba>>8 & 0xff) + ',' + (rgba>>16 & 0xff) + ',' + (rgba>>>24)/0xff + ')';
      },translateRGBAToCSSRGBA:function (r, g, b, a) {
        return 'rgba(' + (r&0xff) + ',' + (g&0xff) + ',' + (b&0xff) + ',' + (a&0xff)/255 + ')';
      },translateRGBAToColor:function (r, g, b, a) {
        return r | g << 8 | b << 16 | a << 24;
      },makeSurface:function (width, height, flags, usePageCanvas, source, rmask, gmask, bmask, amask) {
        flags = flags || 0;
        var surf = _malloc(14*Runtime.QUANTUM_SIZE);  // SDL_Surface has 14 fields of quantum size
        var buffer = _malloc(width*height*4); // TODO: only allocate when locked the first time
        var pixelFormat = _malloc(18*Runtime.QUANTUM_SIZE);
        flags |= 1; // SDL_HWSURFACE - this tells SDL_MUSTLOCK that this needs to be locked
        //surface with SDL_HWPALETTE flag is 8bpp surface (1 byte)
        var is_SDL_HWPALETTE = flags & 0x00200000;  
        var bpp = is_SDL_HWPALETTE ? 1 : 4;
        HEAP32[((surf+Runtime.QUANTUM_SIZE*0)>>2)]=flags         // SDL_Surface.flags
        HEAP32[((surf+Runtime.QUANTUM_SIZE*1)>>2)]=pixelFormat // SDL_Surface.format TODO
        HEAP32[((surf+Runtime.QUANTUM_SIZE*2)>>2)]=width         // SDL_Surface.w
        HEAP32[((surf+Runtime.QUANTUM_SIZE*3)>>2)]=height        // SDL_Surface.h
        HEAP32[((surf+Runtime.QUANTUM_SIZE*4)>>2)]=width * bpp       // SDL_Surface.pitch, assuming RGBA or indexed for now,
                                                                                 // since that is what ImageData gives us in browsers
        HEAP32[((surf+Runtime.QUANTUM_SIZE*5)>>2)]=buffer      // SDL_Surface.pixels
        HEAP32[((surf+Runtime.QUANTUM_SIZE*6)>>2)]=0      // SDL_Surface.offset
        HEAP32[((pixelFormat + SDL.structs.PixelFormat.format)>>2)]=-2042224636 // SDL_PIXELFORMAT_RGBA8888
        HEAP32[((pixelFormat + SDL.structs.PixelFormat.palette)>>2)]=0 // TODO
        HEAP8[((pixelFormat + SDL.structs.PixelFormat.BitsPerPixel)|0)]=bpp * 8
        HEAP8[((pixelFormat + SDL.structs.PixelFormat.BytesPerPixel)|0)]=bpp
        HEAP32[((pixelFormat + SDL.structs.PixelFormat.Rmask)>>2)]=rmask || 0x000000ff
        HEAP32[((pixelFormat + SDL.structs.PixelFormat.Gmask)>>2)]=gmask || 0x0000ff00
        HEAP32[((pixelFormat + SDL.structs.PixelFormat.Bmask)>>2)]=bmask || 0x00ff0000
        HEAP32[((pixelFormat + SDL.structs.PixelFormat.Amask)>>2)]=amask || 0xff000000
        // Decide if we want to use WebGL or not
        var useWebGL = (flags & 0x04000000) != 0; // SDL_OPENGL
        SDL.GL = SDL.GL || useWebGL;
        var canvas;
        if (!usePageCanvas) {
          if (SDL.canvasPool.length > 0) {
            canvas = SDL.canvasPool.pop();
          } else {
            canvas = document.createElement('canvas');
          }
          canvas.width = width;
          canvas.height = height;
        } else {
          canvas = Module['canvas'];
        }
        var ctx = Browser.createContext(canvas, useWebGL, usePageCanvas);
        SDL.surfaces[surf] = {
          width: width,
          height: height,
          canvas: canvas,
          ctx: ctx,
          surf: surf,
          buffer: buffer,
          pixelFormat: pixelFormat,
          alpha: 255,
          flags: flags,
          locked: 0,
          usePageCanvas: usePageCanvas,
          source: source,
          isFlagSet: function (flag) {
            return flags & flag;
          }
        };
        return surf;
      },copyIndexedColorData:function (surfData, rX, rY, rW, rH) {
        // HWPALETTE works with palette
        // setted by SDL_SetColors
        if (!surfData.colors) {
          return;
        }
        var fullWidth  = Module['canvas'].width;
        var fullHeight = Module['canvas'].height;
        var startX  = rX || 0;
        var startY  = rY || 0;
        var endX    = (rW || (fullWidth - startX)) + startX;
        var endY    = (rH || (fullHeight - startY)) + startY;
        var buffer  = surfData.buffer;
        var data    = surfData.image.data;
        var colors  = surfData.colors;
        for (var y = startY; y < endY; ++y) {
          var indexBase = y * fullWidth;
          var colorBase = indexBase * 4;
          for (var x = startX; x < endX; ++x) {
            // HWPALETTE have only 256 colors (not rgba)
            var index = HEAPU8[((buffer + indexBase + x)|0)] * 3;
            var colorOffset = colorBase + x * 4;
            data[colorOffset   ] = colors[index   ];
            data[colorOffset +1] = colors[index +1];
            data[colorOffset +2] = colors[index +2];
            //unused: data[colorOffset +3] = color[index +3];
          }
        }
      },freeSurface:function (surf) {
        var info = SDL.surfaces[surf];
        if (!info) return; // surface has already been freed
        if (!info.usePageCanvas && info.canvas) SDL.canvasPool.push(info.canvas);
        _free(info.buffer);
        _free(info.pixelFormat);
        _free(surf);
        SDL.surfaces[surf] = null;
      },touchX:0,touchY:0,receiveEvent:function (event) {
        switch(event.type) {
          case 'touchstart':
            event.preventDefault();
            var touch = event.touches[0];
            touchX = touch.pageX;
            touchY = touch.pageY;
            var event = {
              type: 'mousedown',
              button: 0,
              pageX: touchX,
              pageY: touchY
            };
            SDL.DOMButtons[0] = 1;
            SDL.events.push(event);
            break;
          case 'touchmove':
            event.preventDefault();
            var touch = event.touches[0];
            touchX = touch.pageX;
            touchY = touch.pageY;
            event = {
              type: 'mousemove',
              button: 0,
              pageX: touchX,
              pageY: touchY
            };
            SDL.events.push(event);
            break;
          case 'touchend':
            event.preventDefault();
            event = {
              type: 'mouseup',
              button: 0,
              pageX: touchX,
              pageY: touchY
            };
            SDL.DOMButtons[0] = 0;
            SDL.events.push(event);
            break;
          case 'mousemove':
            if (Browser.pointerLock) {
              // workaround for firefox bug 750111
              if ('mozMovementX' in event) {
                event['movementX'] = event['mozMovementX'];
                event['movementY'] = event['mozMovementY'];
              }
              // workaround for Firefox bug 782777
              if (event['movementX'] == 0 && event['movementY'] == 0) {
                // ignore a mousemove event if it doesn't contain any movement info
                // (without pointer lock, we infer movement from pageX/pageY, so this check is unnecessary)
                event.preventDefault();
                return;
              }
            }
            // fall through
          case 'keydown': case 'keyup': case 'keypress': case 'mousedown': case 'mouseup': case 'DOMMouseScroll': case 'mousewheel':
            if (event.type == 'DOMMouseScroll' || event.type == 'mousewheel') {
              var button = (event.type == 'DOMMouseScroll' ? event.detail : -event.wheelDelta) > 0 ? 4 : 3;
              var event2 = {
                type: 'mousedown',
                button: button,
                pageX: event.pageX,
                pageY: event.pageY
              };
              SDL.events.push(event2);
              event = {
                type: 'mouseup',
                button: button,
                pageX: event.pageX,
                pageY: event.pageY
              };
            } else if (event.type == 'mousedown') {
              SDL.DOMButtons[event.button] = 1;
            } else if (event.type == 'mouseup') {
              // ignore extra ups, can happen if we leave the canvas while pressing down, then return,
              // since we add a mouseup in that case
              if (!SDL.DOMButtons[event.button]) {
                event.preventDefault();
                return;
              }
              SDL.DOMButtons[event.button] = 0;
            }
            if (event.type == 'keypress' && !SDL.textInput) {
              break;
            }
            SDL.events.push(event);
            break;
          case 'mouseout':
            // Un-press all pressed mouse buttons, because we might miss the release outside of the canvas
            for (var i = 0; i < 3; i++) {
              if (SDL.DOMButtons[i]) {
                SDL.events.push({
                  type: 'mouseup',
                  button: i,
                  pageX: event.pageX,
                  pageY: event.pageY
                });
                SDL.DOMButtons[i] = 0;
              }
            }
            break;
          case 'blur':
          case 'visibilitychange': {
            // Un-press all pressed keys: TODO
            for (var code in SDL.keyboardMap) {
              SDL.events.push({
                type: 'keyup',
                keyCode: SDL.keyboardMap[code]
              });
            }
            break;
          }
          case 'unload':
            if (Browser.mainLoop.runner) {
              SDL.events.push(event);
              // Force-run a main event loop, since otherwise this event will never be caught!
              Browser.mainLoop.runner();
            }
            return;
          case 'resize':
            SDL.events.push(event);
            break;
        }
        if (SDL.events.length >= 10000) {
          Module.printErr('SDL event queue full, dropping events');
          SDL.events = SDL.events.slice(0, 10000);
        }
        // manually triggered resize event doesn't have a preventDefault member
        if (event.preventDefault) {
          event.preventDefault();
        }
        return;
      },makeCEvent:function (event, ptr) {
        if (typeof event === 'number') {
          // This is a pointer to a native C event that was SDL_PushEvent'ed
          _memcpy(ptr, event, SDL.structs.KeyboardEvent.__size__); // XXX
          return;
        }
        switch(event.type) {
          case 'keydown': case 'keyup': {
            var down = event.type === 'keydown';
            //Module.print('Received key event: ' + event.keyCode);
            var key = event.keyCode;
            if (key >= 65 && key <= 90) {
              key += 32; // make lowercase for SDL
            } else {
              key = SDL.keyCodes[event.keyCode] || event.keyCode;
            }
            var scan;
            if (key >= 1024) {
              scan = key - 1024;
            } else {
              scan = SDL.scanCodes[key] || key;
            }
            var code = SDL.keyCodes[event.keyCode] || event.keyCode;
            HEAP8[(((SDL.keyboardState)+(code))|0)]=down;
            if (down) {
              SDL.keyboardMap[code] = event.keyCode; // save the DOM input, which we can use to unpress it during blur
            } else {
              delete SDL.keyboardMap[code];
            }
            // TODO: lmeta, rmeta, numlock, capslock, KMOD_MODE, KMOD_RESERVED
            SDL.modState = (HEAP8[(((SDL.keyboardState)+(1248))|0)] ? 0x0040 | 0x0080 : 0) | // KMOD_LCTRL & KMOD_RCTRL
              (HEAP8[(((SDL.keyboardState)+(1249))|0)] ? 0x0001 | 0x0002 : 0) | // KMOD_LSHIFT & KMOD_RSHIFT
              (HEAP8[(((SDL.keyboardState)+(1250))|0)] ? 0x0100 | 0x0200 : 0); // KMOD_LALT & KMOD_RALT
            HEAP32[(((ptr)+(SDL.structs.KeyboardEvent.type))>>2)]=SDL.DOMEventToSDLEvent[event.type]
            HEAP8[(((ptr)+(SDL.structs.KeyboardEvent.state))|0)]=down ? 1 : 0
            HEAP8[(((ptr)+(SDL.structs.KeyboardEvent.repeat))|0)]=0 // TODO
            HEAP32[(((ptr)+(SDL.structs.KeyboardEvent.keysym + SDL.structs.keysym.scancode))>>2)]=scan
            HEAP32[(((ptr)+(SDL.structs.KeyboardEvent.keysym + SDL.structs.keysym.sym))>>2)]=key
            HEAP32[(((ptr)+(SDL.structs.KeyboardEvent.keysym + SDL.structs.keysym.mod))>>2)]=SDL.modState
            HEAP32[(((ptr)+(SDL.structs.KeyboardEvent.keysym + SDL.structs.keysym.unicode))>>2)]=key
            break;
          }
          case 'keypress': {
            HEAP32[(((ptr)+(SDL.structs.TextInputEvent.type))>>2)]=SDL.DOMEventToSDLEvent[event.type]
            // Not filling in windowID for now
            var cStr = intArrayFromString(String.fromCharCode(event.charCode));
            for (var i = 0; i < cStr.length; ++i) {
              HEAP8[(((ptr)+(SDL.structs.TextInputEvent.text + i))|0)]=cStr[i];
            }
            break;
          }
          case 'mousedown': case 'mouseup':
            if (event.type == 'mousedown') {
              // SDL_BUTTON(x) is defined as (1 << ((x)-1)).  SDL buttons are 1-3,
              // and DOM buttons are 0-2, so this means that the below formula is
              // correct.
              SDL.buttonState |= 1 << event.button;
            } else if (event.type == 'mouseup') {
              SDL.buttonState &= ~(1 << event.button);
            }
            // fall through
          case 'mousemove': {
            Browser.calculateMouseEvent(event);
            if (event.type != 'mousemove') {
              var down = event.type === 'mousedown';
              HEAP32[(((ptr)+(SDL.structs.MouseButtonEvent.type))>>2)]=SDL.DOMEventToSDLEvent[event.type];
              HEAP8[(((ptr)+(SDL.structs.MouseButtonEvent.button))|0)]=event.button+1; // DOM buttons are 0-2, SDL 1-3
              HEAP8[(((ptr)+(SDL.structs.MouseButtonEvent.state))|0)]=down ? 1 : 0;
              HEAP32[(((ptr)+(SDL.structs.MouseButtonEvent.x))>>2)]=Browser.mouseX;
              HEAP32[(((ptr)+(SDL.structs.MouseButtonEvent.y))>>2)]=Browser.mouseY;
            } else {
              HEAP32[(((ptr)+(SDL.structs.MouseMotionEvent.type))>>2)]=SDL.DOMEventToSDLEvent[event.type];
              HEAP8[(((ptr)+(SDL.structs.MouseMotionEvent.state))|0)]=SDL.buttonState;
              HEAP32[(((ptr)+(SDL.structs.MouseMotionEvent.x))>>2)]=Browser.mouseX;
              HEAP32[(((ptr)+(SDL.structs.MouseMotionEvent.y))>>2)]=Browser.mouseY;
              HEAP32[(((ptr)+(SDL.structs.MouseMotionEvent.xrel))>>2)]=Browser.mouseMovementX;
              HEAP32[(((ptr)+(SDL.structs.MouseMotionEvent.yrel))>>2)]=Browser.mouseMovementY;
            }
            break;
          }
          case 'unload': {
            HEAP32[(((ptr)+(SDL.structs.KeyboardEvent.type))>>2)]=SDL.DOMEventToSDLEvent[event.type];
            break;
          }
          case 'resize': {
            HEAP32[(((ptr)+(SDL.structs.KeyboardEvent.type))>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP32[(((ptr)+(SDL.structs.ResizeEvent.w))>>2)]=event.w;
            HEAP32[(((ptr)+(SDL.structs.ResizeEvent.h))>>2)]=event.h;
            break;
          }
          default: throw 'Unhandled SDL event: ' + event.type;
        }
      },estimateTextWidth:function (fontData, text) {
        var h = fontData.size;
        var fontString = h + 'px ' + fontData.name;
        var tempCtx = SDL.ttfContext;
        tempCtx.save();
        tempCtx.font = fontString;
        var ret = tempCtx.measureText(text).width | 0;
        tempCtx.restore();
        return ret;
      },allocateChannels:function (num) { // called from Mix_AllocateChannels and init
        if (SDL.numChannels && SDL.numChannels >= num) return;
        SDL.numChannels = num;
        SDL.channels = [];
        for (var i = 0; i < num; i++) {
          SDL.channels[i] = {
            audio: null,
            volume: 1.0
          };
        }
      },setGetVolume:function (info, volume) {
        if (!info) return 0;
        var ret = info.volume * 128; // MIX_MAX_VOLUME
        if (volume != -1) {
          info.volume = volume / 128;
          if (info.audio) info.audio.volume = info.volume;
        }
        return ret;
      },debugSurface:function (surfData) {
        console.log('dumping surface ' + [surfData.surf, surfData.source, surfData.width, surfData.height]);
        var image = surfData.ctx.getImageData(0, 0, surfData.width, surfData.height);
        var data = image.data;
        var num = Math.min(surfData.width, surfData.height);
        for (var i = 0; i < num; i++) {
          console.log('   diagonal ' + i + ':' + [data[i*surfData.width*4 + i*4 + 0], data[i*surfData.width*4 + i*4 + 1], data[i*surfData.width*4 + i*4 + 2], data[i*surfData.width*4 + i*4 + 3]]);
        }
      }};function _SDL_GetMouseState(x, y) {
      if (x) HEAP32[((x)>>2)]=Browser.mouseX;
      if (y) HEAP32[((y)>>2)]=Browser.mouseY;
      return SDL.buttonState;
    }
  function _emscripten_cancel_main_loop() {
      Browser.mainLoop.scheduler = null;
      Browser.mainLoop.shouldPause = true;
    }
  Module["_strlen"] = _strlen;
  function __reallyNegative(x) {
      return x < 0 || (x === 0 && (1/x) === -Infinity);
    }function __formatString(format, varargs) {
      var textIndex = format;
      var argIndex = 0;
      function getNextArg(type) {
        // NOTE: Explicitly ignoring type safety. Otherwise this fails:
        //       int x = 4; printf("%c\n", (char)x);
        var ret;
        if (type === 'double') {
          ret = HEAPF64[(((varargs)+(argIndex))>>3)];
        } else if (type == 'i64') {
          ret = [HEAP32[(((varargs)+(argIndex))>>2)],
                 HEAP32[(((varargs)+(argIndex+8))>>2)]];
          argIndex += 8; // each 32-bit chunk is in a 64-bit block
        } else {
          type = 'i32'; // varargs are always i32, i64, or double
          ret = HEAP32[(((varargs)+(argIndex))>>2)];
        }
        argIndex += Math.max(Runtime.getNativeFieldSize(type), Runtime.getAlignSize(type, null, true));
        return ret;
      }
      var ret = [];
      var curr, next, currArg;
      while(1) {
        var startTextIndex = textIndex;
        curr = HEAP8[(textIndex)];
        if (curr === 0) break;
        next = HEAP8[((textIndex+1)|0)];
        if (curr == 37) {
          // Handle flags.
          var flagAlwaysSigned = false;
          var flagLeftAlign = false;
          var flagAlternative = false;
          var flagZeroPad = false;
          flagsLoop: while (1) {
            switch (next) {
              case 43:
                flagAlwaysSigned = true;
                break;
              case 45:
                flagLeftAlign = true;
                break;
              case 35:
                flagAlternative = true;
                break;
              case 48:
                if (flagZeroPad) {
                  break flagsLoop;
                } else {
                  flagZeroPad = true;
                  break;
                }
              default:
                break flagsLoop;
            }
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          }
          // Handle width.
          var width = 0;
          if (next == 42) {
            width = getNextArg('i32');
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          } else {
            while (next >= 48 && next <= 57) {
              width = width * 10 + (next - 48);
              textIndex++;
              next = HEAP8[((textIndex+1)|0)];
            }
          }
          // Handle precision.
          var precisionSet = false;
          if (next == 46) {
            var precision = 0;
            precisionSet = true;
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
            if (next == 42) {
              precision = getNextArg('i32');
              textIndex++;
            } else {
              while(1) {
                var precisionChr = HEAP8[((textIndex+1)|0)];
                if (precisionChr < 48 ||
                    precisionChr > 57) break;
                precision = precision * 10 + (precisionChr - 48);
                textIndex++;
              }
            }
            next = HEAP8[((textIndex+1)|0)];
          } else {
            var precision = 6; // Standard default.
          }
          // Handle integer sizes. WARNING: These assume a 32-bit architecture!
          var argSize;
          switch (String.fromCharCode(next)) {
            case 'h':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 104) {
                textIndex++;
                argSize = 1; // char (actually i32 in varargs)
              } else {
                argSize = 2; // short (actually i32 in varargs)
              }
              break;
            case 'l':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 108) {
                textIndex++;
                argSize = 8; // long long
              } else {
                argSize = 4; // long
              }
              break;
            case 'L': // long long
            case 'q': // int64_t
            case 'j': // intmax_t
              argSize = 8;
              break;
            case 'z': // size_t
            case 't': // ptrdiff_t
            case 'I': // signed ptrdiff_t or unsigned size_t
              argSize = 4;
              break;
            default:
              argSize = null;
          }
          if (argSize) textIndex++;
          next = HEAP8[((textIndex+1)|0)];
          // Handle type specifier.
          switch (String.fromCharCode(next)) {
            case 'd': case 'i': case 'u': case 'o': case 'x': case 'X': case 'p': {
              // Integer.
              var signed = next == 100 || next == 105;
              argSize = argSize || 4;
              var currArg = getNextArg('i' + (argSize * 8));
              var origArg = currArg;
              var argText;
              // Flatten i64-1 [low, high] into a (slightly rounded) double
              if (argSize == 8) {
                currArg = Runtime.makeBigInt(currArg[0], currArg[1], next == 117);
              }
              // Truncate to requested size.
              if (argSize <= 4) {
                var limit = Math.pow(256, argSize) - 1;
                currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8);
              }
              // Format the number.
              var currAbsArg = Math.abs(currArg);
              var prefix = '';
              if (next == 100 || next == 105) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], null); else
                argText = reSign(currArg, 8 * argSize, 1).toString(10);
              } else if (next == 117) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], true); else
                argText = unSign(currArg, 8 * argSize, 1).toString(10);
                currArg = Math.abs(currArg);
              } else if (next == 111) {
                argText = (flagAlternative ? '0' : '') + currAbsArg.toString(8);
              } else if (next == 120 || next == 88) {
                prefix = (flagAlternative && currArg != 0) ? '0x' : '';
                if (argSize == 8 && i64Math) {
                  if (origArg[1]) {
                    argText = (origArg[1]>>>0).toString(16);
                    var lower = (origArg[0]>>>0).toString(16);
                    while (lower.length < 8) lower = '0' + lower;
                    argText += lower;
                  } else {
                    argText = (origArg[0]>>>0).toString(16);
                  }
                } else
                if (currArg < 0) {
                  // Represent negative numbers in hex as 2's complement.
                  currArg = -currArg;
                  argText = (currAbsArg - 1).toString(16);
                  var buffer = [];
                  for (var i = 0; i < argText.length; i++) {
                    buffer.push((0xF - parseInt(argText[i], 16)).toString(16));
                  }
                  argText = buffer.join('');
                  while (argText.length < argSize * 2) argText = 'f' + argText;
                } else {
                  argText = currAbsArg.toString(16);
                }
                if (next == 88) {
                  prefix = prefix.toUpperCase();
                  argText = argText.toUpperCase();
                }
              } else if (next == 112) {
                if (currAbsArg === 0) {
                  argText = '(nil)';
                } else {
                  prefix = '0x';
                  argText = currAbsArg.toString(16);
                }
              }
              if (precisionSet) {
                while (argText.length < precision) {
                  argText = '0' + argText;
                }
              }
              // Add sign if needed
              if (flagAlwaysSigned) {
                if (currArg < 0) {
                  prefix = '-' + prefix;
                } else {
                  prefix = '+' + prefix;
                }
              }
              // Add padding.
              while (prefix.length + argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad) {
                    argText = '0' + argText;
                  } else {
                    prefix = ' ' + prefix;
                  }
                }
              }
              // Insert the result into the buffer.
              argText = prefix + argText;
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 'f': case 'F': case 'e': case 'E': case 'g': case 'G': {
              // Float.
              var currArg = getNextArg('double');
              var argText;
              if (isNaN(currArg)) {
                argText = 'nan';
                flagZeroPad = false;
              } else if (!isFinite(currArg)) {
                argText = (currArg < 0 ? '-' : '') + 'inf';
                flagZeroPad = false;
              } else {
                var isGeneral = false;
                var effectivePrecision = Math.min(precision, 20);
                // Convert g/G to f/F or e/E, as per:
                // http://pubs.opengroup.org/onlinepubs/9699919799/functions/printf.html
                if (next == 103 || next == 71) {
                  isGeneral = true;
                  precision = precision || 1;
                  var exponent = parseInt(currArg.toExponential(effectivePrecision).split('e')[1], 10);
                  if (precision > exponent && exponent >= -4) {
                    next = ((next == 103) ? 'f' : 'F').charCodeAt(0);
                    precision -= exponent + 1;
                  } else {
                    next = ((next == 103) ? 'e' : 'E').charCodeAt(0);
                    precision--;
                  }
                  effectivePrecision = Math.min(precision, 20);
                }
                if (next == 101 || next == 69) {
                  argText = currArg.toExponential(effectivePrecision);
                  // Make sure the exponent has at least 2 digits.
                  if (/[eE][-+]\d$/.test(argText)) {
                    argText = argText.slice(0, -1) + '0' + argText.slice(-1);
                  }
                } else if (next == 102 || next == 70) {
                  argText = currArg.toFixed(effectivePrecision);
                  if (currArg === 0 && __reallyNegative(currArg)) {
                    argText = '-' + argText;
                  }
                }
                var parts = argText.split('e');
                if (isGeneral && !flagAlternative) {
                  // Discard trailing zeros and periods.
                  while (parts[0].length > 1 && parts[0].indexOf('.') != -1 &&
                         (parts[0].slice(-1) == '0' || parts[0].slice(-1) == '.')) {
                    parts[0] = parts[0].slice(0, -1);
                  }
                } else {
                  // Make sure we have a period in alternative mode.
                  if (flagAlternative && argText.indexOf('.') == -1) parts[0] += '.';
                  // Zero pad until required precision.
                  while (precision > effectivePrecision++) parts[0] += '0';
                }
                argText = parts[0] + (parts.length > 1 ? 'e' + parts[1] : '');
                // Capitalize 'E' if needed.
                if (next == 69) argText = argText.toUpperCase();
                // Add sign.
                if (flagAlwaysSigned && currArg >= 0) {
                  argText = '+' + argText;
                }
              }
              // Add padding.
              while (argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad && (argText[0] == '-' || argText[0] == '+')) {
                    argText = argText[0] + '0' + argText.slice(1);
                  } else {
                    argText = (flagZeroPad ? '0' : ' ') + argText;
                  }
                }
              }
              // Adjust case.
              if (next < 97) argText = argText.toUpperCase();
              // Insert the result into the buffer.
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 's': {
              // String.
              var arg = getNextArg('i8*');
              var argLength = arg ? _strlen(arg) : '(null)'.length;
              if (precisionSet) argLength = Math.min(argLength, precision);
              if (!flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              if (arg) {
                for (var i = 0; i < argLength; i++) {
                  ret.push(HEAPU8[((arg++)|0)]);
                }
              } else {
                ret = ret.concat(intArrayFromString('(null)'.substr(0, argLength), true));
              }
              if (flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              break;
            }
            case 'c': {
              // Character.
              if (flagLeftAlign) ret.push(getNextArg('i8'));
              while (--width > 0) {
                ret.push(32);
              }
              if (!flagLeftAlign) ret.push(getNextArg('i8'));
              break;
            }
            case 'n': {
              // Write the length written so far to the next parameter.
              var ptr = getNextArg('i32*');
              HEAP32[((ptr)>>2)]=ret.length
              break;
            }
            case '%': {
              // Literal percent sign.
              ret.push(curr);
              break;
            }
            default: {
              // Unknown specifiers remain untouched.
              for (var i = startTextIndex; i < textIndex + 2; i++) {
                ret.push(HEAP8[(i)]);
              }
            }
          }
          textIndex += 2;
          // TODO: Support a/A (hex float) and m (last error) specifiers.
          // TODO: Support %1${specifier} for arg selection.
        } else {
          ret.push(curr);
          textIndex += 1;
        }
      }
      return ret;
    }function _snprintf(s, n, format, varargs) {
      // int snprintf(char *restrict s, size_t n, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var limit = (n === undefined) ? result.length
                                    : Math.min(result.length, Math.max(n - 1, 0));
      if (s < 0) {
        s = -s;
        var buf = _malloc(limit+1);
        HEAP32[((s)>>2)]=buf;
        s = buf;
      }
      for (var i = 0; i < limit; i++) {
        HEAP8[(((s)+(i))|0)]=result[i];
      }
      if (limit < n || (n === undefined)) HEAP8[(((s)+(i))|0)]=0;
      return result.length;
    }function _sprintf(s, format, varargs) {
      // int sprintf(char *restrict s, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      return _snprintf(s, undefined, format, varargs);
    }
  Module["_strcat"] = _strcat;
  var _llvm_memset_p0i8_i32=_memset;
  function _llvm_lifetime_start() {}
  function _llvm_lifetime_end() {}
  function _strncmp(px, py, n) {
      var i = 0;
      while (i < n) {
        var x = HEAPU8[(((px)+(i))|0)];
        var y = HEAPU8[(((py)+(i))|0)];
        if (x == y && x == 0) return 0;
        if (x == 0) return -1;
        if (y == 0) return 1;
        if (x == y) {
          i ++;
          continue;
        } else {
          return x > y ? 1 : -1;
        }
      }
      return 0;
    }function _strcmp(px, py) {
      return _strncmp(px, py, TOTAL_MEMORY);
    }
  function _strdup(ptr) {
      var len = _strlen(ptr);
      var newStr = _malloc(len + 1);
      (_memcpy(newStr, ptr, len)|0);
      HEAP8[(((newStr)+(len))|0)]=0;
      return newStr;
    }
  function _send(fd, buf, len, flags) {
      var info = FS.streams[fd];
      if (!info) return -1;
      info.sender(HEAPU8.subarray(buf, buf+len));
      return len;
    }
  function _pwrite(fildes, buf, nbyte, offset) {
      // ssize_t pwrite(int fildes, const void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.streams[fildes];
      if (!stream || stream.object.isDevice) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      } else if (!stream.isWrite) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else if (stream.object.isFolder) {
        ___setErrNo(ERRNO_CODES.EISDIR);
        return -1;
      } else if (nbyte < 0 || offset < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        var contents = stream.object.contents;
        while (contents.length < offset) contents.push(0);
        for (var i = 0; i < nbyte; i++) {
          contents[offset + i] = HEAPU8[(((buf)+(i))|0)];
        }
        stream.object.timestamp = Date.now();
        return i;
      }
    }function _write(fildes, buf, nbyte) {
      // ssize_t write(int fildes, const void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.streams[fildes];
      if (stream && ('socket' in stream)) {
          return _send(fildes, buf, nbyte, 0);
      } else if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      } else if (!stream.isWrite) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else if (nbyte < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        if (stream.object.isDevice) {
          if (stream.object.output) {
            for (var i = 0; i < nbyte; i++) {
              try {
                stream.object.output(HEAP8[(((buf)+(i))|0)]);
              } catch (e) {
                ___setErrNo(ERRNO_CODES.EIO);
                return -1;
              }
            }
            stream.object.timestamp = Date.now();
            return i;
          } else {
            ___setErrNo(ERRNO_CODES.ENXIO);
            return -1;
          }
        } else {
          var bytesWritten = _pwrite(fildes, buf, nbyte, stream.position);
          if (bytesWritten != -1) stream.position += bytesWritten;
          return bytesWritten;
        }
      }
    }function _fwrite(ptr, size, nitems, stream) {
      // size_t fwrite(const void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fwrite.html
      var bytesToWrite = nitems * size;
      if (bytesToWrite == 0) return 0;
      var bytesWritten = _write(stream, ptr, bytesToWrite);
      if (bytesWritten == -1) {
        if (FS.streams[stream]) FS.streams[stream].error = true;
        return 0;
      } else {
        return Math.floor(bytesWritten / size);
      }
    }function _fprintf(stream, format, varargs) {
      // int fprintf(FILE *restrict stream, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var stack = Runtime.stackSave();
      var ret = _fwrite(allocate(result, 'i8', ALLOC_STACK), 1, result.length, stream);
      Runtime.stackRestore(stack);
      return ret;
    }
  function _fflush(stream) {
      // int fflush(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fflush.html
      var flush = function(filedes) {
        // Right now we write all data directly, except for output devices.
        if (FS.streams[filedes] && FS.streams[filedes].object.output) {
          if (!FS.streams[filedes].object.isTerminal) { // don't flush terminals, it would cause a \n to also appear
            FS.streams[filedes].object.output(null);
          }
        }
      };
      try {
        if (stream === 0) {
          for (var i = 0; i < FS.streams.length; i++) if (FS.streams[i]) flush(i);
        } else {
          flush(stream);
        }
        return 0;
      } catch (e) {
        ___setErrNo(ERRNO_CODES.EIO);
        return -1;
      }
    }
  function __exit(status) {
      // void _exit(int status);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/exit.html
      function ExitStatus() {
        this.name = "ExitStatus";
        this.message = "Program terminated with exit(" + status + ")";
        this.status = status;
        Module.print('Exit Status: ' + status);
      };
      ExitStatus.prototype = new Error();
      ExitStatus.prototype.constructor = ExitStatus;
      exitRuntime();
      ABORT = true;
      throw new ExitStatus();
    }function _exit(status) {
      __exit(status);
    }
  var _llvm_va_start=undefined;
  function _llvm_va_end() {}
  function _isspace(chr) {
      return chr in { 32: 0, 9: 0, 10: 0, 11: 0, 12: 0, 13: 0 };
    }function __parseInt(str, endptr, base, min, max, bits, unsign) {
      // Skip space.
      while (_isspace(HEAP8[(str)])) str++;
      // Check for a plus/minus sign.
      var multiplier = 1;
      if (HEAP8[(str)] == 45) {
        multiplier = -1;
        str++;
      } else if (HEAP8[(str)] == 43) {
        str++;
      }
      // Find base.
      var finalBase = base;
      if (!finalBase) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            finalBase = 16;
            str += 2;
          } else {
            finalBase = 8;
            str++;
          }
        }
      } else if (finalBase==16) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            str += 2;
          }
        }
      }
      if (!finalBase) finalBase = 10;
      // Get digits.
      var chr;
      var ret = 0;
      while ((chr = HEAP8[(str)]) != 0) {
        var digit = parseInt(String.fromCharCode(chr), finalBase);
        if (isNaN(digit)) {
          break;
        } else {
          ret = ret * finalBase + digit;
          str++;
        }
      }
      // Apply sign.
      ret *= multiplier;
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str
      }
      // Unsign if needed.
      if (unsign) {
        if (Math.abs(ret) > max) {
          ret = max;
          ___setErrNo(ERRNO_CODES.ERANGE);
        } else {
          ret = unSign(ret, bits);
        }
      }
      // Validate range.
      if (ret > max || ret < min) {
        ret = ret > max ? max : min;
        ___setErrNo(ERRNO_CODES.ERANGE);
      }
      if (bits == 64) {
        return ((asm["setTempRet0"](((Math.min((+(Math.floor((ret)/(+(4294967296))))), (+(4294967295))))|0)>>>0),ret>>>0)|0);
      }
      return ret;
    }function _strtoul(str, endptr, base) {
      return __parseInt(str, endptr, base, 0, 4294967295, 32, true);  // ULONG_MAX.
    }
  function _atexit(func, arg) {
      __ATEXIT__.unshift({ func: func, arg: arg });
    }
  function _SDL_Init(what) {
      SDL.startTime = Date.now();
      // capture all key events. we just keep down and up, but also capture press to prevent default actions
      if (!Module['doNotCaptureKeyboard']) {
        document.addEventListener("keydown", SDL.receiveEvent);
        document.addEventListener("keyup", SDL.receiveEvent);
        document.addEventListener("keypress", SDL.receiveEvent);
        document.addEventListener("blur", SDL.receiveEvent);
        document.addEventListener("visibilitychange", SDL.receiveEvent);
      }
      window.addEventListener("unload", SDL.receiveEvent);
      SDL.keyboardState = _malloc(0x10000); // Our SDL needs 512, but 64K is safe for older SDLs
      _memset(SDL.keyboardState, 0, 0x10000);
      // Initialize this structure carefully for closure
      SDL.DOMEventToSDLEvent['keydown'] = 0x300 /* SDL_KEYDOWN */;
      SDL.DOMEventToSDLEvent['keyup'] = 0x301 /* SDL_KEYUP */;
      SDL.DOMEventToSDLEvent['keypress'] = 0x303 /* SDL_TEXTINPUT */;
      SDL.DOMEventToSDLEvent['mousedown'] = 0x401 /* SDL_MOUSEBUTTONDOWN */;
      SDL.DOMEventToSDLEvent['mouseup'] = 0x402 /* SDL_MOUSEBUTTONUP */;
      SDL.DOMEventToSDLEvent['mousemove'] = 0x400 /* SDL_MOUSEMOTION */;
      SDL.DOMEventToSDLEvent['unload'] = 0x100 /* SDL_QUIT */;
      SDL.DOMEventToSDLEvent['resize'] = 0x7001 /* SDL_VIDEORESIZE/SDL_EVENT_COMPAT2 */;
      return 0; // success
    }
  function _signal(sig, func) {
      // TODO
      return 0;
    }
  var ___dirent_struct_layout={__size__:1040,d_ino:0,d_name:4,d_off:1028,d_reclen:1032,d_type:1036};function _open(path, oflag, varargs) {
      // int open(const char *path, int oflag, ...);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/open.html
      // NOTE: This implementation tries to mimic glibc rather than strictly
      // following the POSIX standard.
      var mode = HEAP32[((varargs)>>2)];
      // Simplify flags.
      var accessMode = oflag & 3;
      var isWrite = accessMode != 0;
      var isRead = accessMode != 1;
      var isCreate = Boolean(oflag & 512);
      var isExistCheck = Boolean(oflag & 2048);
      var isTruncate = Boolean(oflag & 1024);
      var isAppend = Boolean(oflag & 8);
      // Verify path.
      var origPath = path;
      path = FS.analyzePath(Pointer_stringify(path));
      if (!path.parentExists) {
        ___setErrNo(path.error);
        return -1;
      }
      var target = path.object || null;
      var finalPath;
      // Verify the file exists, create if needed and allowed.
      if (target) {
        if (isCreate && isExistCheck) {
          ___setErrNo(ERRNO_CODES.EEXIST);
          return -1;
        }
        if ((isWrite || isTruncate) && target.isFolder) {
          ___setErrNo(ERRNO_CODES.EISDIR);
          return -1;
        }
        if (isRead && !target.read || isWrite && !target.write) {
          ___setErrNo(ERRNO_CODES.EACCES);
          return -1;
        }
        if (isTruncate && !target.isDevice) {
          target.contents = [];
        } else {
          if (!FS.forceLoadFile(target)) {
            ___setErrNo(ERRNO_CODES.EIO);
            return -1;
          }
        }
        finalPath = path.path;
      } else {
        if (!isCreate) {
          ___setErrNo(ERRNO_CODES.ENOENT);
          return -1;
        }
        if (!path.parentObject.write) {
          ___setErrNo(ERRNO_CODES.EACCES);
          return -1;
        }
        target = FS.createDataFile(path.parentObject, path.name, [],
                                   mode & 0x100, mode & 0x80);  // S_IRUSR, S_IWUSR.
        finalPath = path.parentPath + '/' + path.name;
      }
      // Actually create an open stream.
      var id;
      if (target.isFolder) {
        var entryBuffer = 0;
        if (___dirent_struct_layout) {
          entryBuffer = _malloc(___dirent_struct_layout.__size__);
        }
        var contents = [];
        for (var key in target.contents) contents.push(key);
        id = FS.createFileHandle({
          path: finalPath,
          object: target,
          // An index into contents. Special values: -2 is ".", -1 is "..".
          position: -2,
          isRead: true,
          isWrite: false,
          isAppend: false,
          error: false,
          eof: false,
          ungotten: [],
          // Folder-specific properties:
          // Remember the contents at the time of opening in an array, so we can
          // seek between them relying on a single order.
          contents: contents,
          // Each stream has its own area for readdir() returns.
          currentEntry: entryBuffer
        });
      } else {
        id = FS.createFileHandle({
          path: finalPath,
          object: target,
          position: 0,
          isRead: isRead,
          isWrite: isWrite,
          isAppend: isAppend,
          error: false,
          eof: false,
          ungotten: []
        });
      }
      return id;
    }function _fopen(filename, mode) {
      // FILE *fopen(const char *restrict filename, const char *restrict mode);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fopen.html
      var flags;
      mode = Pointer_stringify(mode);
      if (mode[0] == 'r') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 0;
        }
      } else if (mode[0] == 'w') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 512;
        flags |= 1024;
      } else if (mode[0] == 'a') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 512;
        flags |= 8;
      } else {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return 0;
      }
      var ret = _open(filename, flags, allocate([0x1FF, 0, 0, 0], 'i32', ALLOC_STACK));  // All creation permissions.
      return (ret == -1) ? 0 : ret;
    }
  function _recv(fd, buf, len, flags) {
      var info = FS.streams[fd];
      if (!info) return -1;
      if (!info.hasData()) {
        ___setErrNo(ERRNO_CODES.EAGAIN); // no data, and all sockets are nonblocking, so this is the right behavior
        return -1;
      }
      var buffer = info.inQueue.shift();
      if (len < buffer.length) {
        if (info.stream) {
          // This is tcp (reliable), so if not all was read, keep it
          info.inQueue.unshift(buffer.subarray(len));
        }
        buffer = buffer.subarray(0, len);
      }
      HEAPU8.set(buffer, buf);
      return buffer.length;
    }
  function _pread(fildes, buf, nbyte, offset) {
      // ssize_t pread(int fildes, void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.streams[fildes];
      if (!stream || stream.object.isDevice) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      } else if (!stream.isRead) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else if (stream.object.isFolder) {
        ___setErrNo(ERRNO_CODES.EISDIR);
        return -1;
      } else if (nbyte < 0 || offset < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        var bytesRead = 0;
        while (stream.ungotten.length && nbyte > 0) {
          HEAP8[((buf++)|0)]=stream.ungotten.pop()
          nbyte--;
          bytesRead++;
        }
        var contents = stream.object.contents;
        var size = Math.min(contents.length - offset, nbyte);
        if (contents.subarray) { // typed array
          HEAPU8.set(contents.subarray(offset, offset+size), buf);
        } else
        if (contents.slice) { // normal array
          for (var i = 0; i < size; i++) {
            HEAP8[(((buf)+(i))|0)]=contents[offset + i]
          }
        } else {
          for (var i = 0; i < size; i++) { // LazyUint8Array from sync binary XHR
            HEAP8[(((buf)+(i))|0)]=contents.get(offset + i)
          }
        }
        bytesRead += size;
        return bytesRead;
      }
    }function _read(fildes, buf, nbyte) {
      // ssize_t read(int fildes, void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.streams[fildes];
      if (stream && ('socket' in stream)) {
        return _recv(fildes, buf, nbyte, 0);
      } else if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      } else if (!stream.isRead) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else if (nbyte < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        var bytesRead;
        if (stream.object.isDevice) {
          if (stream.object.input) {
            bytesRead = 0;
            while (stream.ungotten.length && nbyte > 0) {
              HEAP8[((buf++)|0)]=stream.ungotten.pop()
              nbyte--;
              bytesRead++;
            }
            for (var i = 0; i < nbyte; i++) {
              try {
                var result = stream.object.input();
              } catch (e) {
                ___setErrNo(ERRNO_CODES.EIO);
                return -1;
              }
              if (result === undefined && bytesRead === 0) {
                ___setErrNo(ERRNO_CODES.EAGAIN);
                return -1;
              }
              if (result === null || result === undefined) break;
              bytesRead++;
              HEAP8[(((buf)+(i))|0)]=result
            }
            return bytesRead;
          } else {
            ___setErrNo(ERRNO_CODES.ENXIO);
            return -1;
          }
        } else {
          var ungotSize = stream.ungotten.length;
          bytesRead = _pread(fildes, buf, nbyte, stream.position);
          if (bytesRead != -1) {
            stream.position += (stream.ungotten.length - ungotSize) + bytesRead;
          }
          return bytesRead;
        }
      }
    }function _fread(ptr, size, nitems, stream) {
      // size_t fread(void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fread.html
      var bytesToRead = nitems * size;
      if (bytesToRead == 0) return 0;
      var bytesRead = _read(stream, ptr, bytesToRead);
      var streamObj = FS.streams[stream];
      if (bytesRead == -1) {
        if (streamObj) streamObj.error = true;
        return 0;
      } else {
        if (bytesRead < bytesToRead) streamObj.eof = true;
        return Math.floor(bytesRead / size);
      }
    }
  function _close(fildes) {
      // int close(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/close.html
      if (FS.streams[fildes]) {
        if (FS.streams[fildes].currentEntry) {
          _free(FS.streams[fildes].currentEntry);
        }
        FS.streams[fildes] = null;
        return 0;
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }
  function _fsync(fildes) {
      // int fsync(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fsync.html
      if (FS.streams[fildes]) {
        // We write directly to the file system, so there's nothing to do here.
        return 0;
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }function _fclose(stream) {
      // int fclose(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fclose.html
      _fsync(stream);
      return _close(stream);
    }
  function _time(ptr) {
      var ret = Math.floor(Date.now()/1000);
      if (ptr) {
        HEAP32[((ptr)>>2)]=ret
      }
      return ret;
    }
  Module["_memcmp"] = _memcmp;
  Module["_strcpy"] = _strcpy;
  function _lseek(fildes, offset, whence) {
      // off_t lseek(int fildes, off_t offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/lseek.html
      if (FS.streams[fildes] && !FS.streams[fildes].object.isDevice) {
        var stream = FS.streams[fildes];
        var position = offset;
        if (whence === 1) {  // SEEK_CUR.
          position += stream.position;
        } else if (whence === 2) {  // SEEK_END.
          position += stream.object.contents.length;
        }
        if (position < 0) {
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
        } else {
          stream.ungotten = [];
          stream.position = position;
          return position;
        }
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }function _fseek(stream, offset, whence) {
      // int fseek(FILE *stream, long offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fseek.html
      var ret = _lseek(stream, offset, whence);
      if (ret == -1) {
        return -1;
      } else {
        FS.streams[stream].eof = false;
        return 0;
      }
    }
  function _ftell(stream) {
      // long ftell(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ftell.html
      if (FS.streams[stream]) {
        stream = FS.streams[stream];
        if (stream.object.isDevice) {
          ___setErrNo(ERRNO_CODES.ESPIPE);
          return -1;
        } else {
          return stream.position;
        }
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }
  function _truncate(path, length) {
      // int truncate(const char *path, off_t length);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/truncate.html
      // NOTE: The path argument may be a string, to simplify ftruncate().
      if (length < 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        if (typeof path !== 'string') path = Pointer_stringify(path);
        var target = FS.findObject(path);
        if (target === null) return -1;
        if (target.isFolder) {
          ___setErrNo(ERRNO_CODES.EISDIR);
          return -1;
        } else if (target.isDevice) {
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
        } else if (!target.write) {
          ___setErrNo(ERRNO_CODES.EACCES);
          return -1;
        } else {
          var contents = target.contents;
          if (length < contents.length) contents.length = length;
          else while (length > contents.length) contents.push(0);
          target.timestamp = Date.now();
          return 0;
        }
      }
    }function _ftruncate(fildes, length) {
      // int ftruncate(int fildes, off_t length);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ftruncate.html
      if (FS.streams[fildes] && FS.streams[fildes].isWrite) {
        return _truncate(FS.streams[fildes].path, length);
      } else if (FS.streams[fildes]) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }
  function _fileno(stream) {
      // int fileno(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fileno.html
      // We use file descriptor numbers and FILE* streams interchangeably.
      return stream;
    }
  function _fputc(c, stream) {
      // int fputc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputc.html
      var chr = unSign(c & 0xFF);
      HEAP8[((_fputc.ret)|0)]=chr
      var ret = _write(stream, _fputc.ret, 1);
      if (ret == -1) {
        if (FS.streams[stream]) FS.streams[stream].error = true;
        return -1;
      } else {
        return chr;
      }
    }
  var ___pollfd_struct_layout={__size__:8,fd:0,events:4,revents:6};function _poll(fds, nfds, timeout) {
      // int poll(struct pollfd fds[], nfds_t nfds, int timeout);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/poll.html
      // NOTE: This is pretty much a no-op mimicking glibc.
      var offsets = ___pollfd_struct_layout;
      var nonzero = 0;
      for (var i = 0; i < nfds; i++) {
        var pollfd = fds + ___pollfd_struct_layout.__size__ * i;
        var fd = HEAP32[(((pollfd)+(offsets.fd))>>2)];
        var events = HEAP16[(((pollfd)+(offsets.events))>>1)];
        var revents = 0;
        if (FS.streams[fd]) {
          var stream = FS.streams[fd];
          if (events & 1) revents |= 1;
          if (events & 2) revents |= 2;
        } else {
          if (events & 4) revents |= 4;
        }
        if (revents) nonzero++;
        HEAP16[(((pollfd)+(offsets.revents))>>1)]=revents
      }
      return nonzero;
    }
  function _unlink(path) {
      // int unlink(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/unlink.html
      path = FS.analyzePath(Pointer_stringify(path));
      if (!path.parentExists || !path.exists) {
        ___setErrNo(path.error);
        return -1;
      } else if (path.object.isFolder) {
        ___setErrNo(ERRNO_CODES.EISDIR);
        return -1;
      } else if (!path.object.write) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      } else {
        delete path.parentObject.contents[path.name];
        return 0;
      }
    }
  function _posix_openpt() {
  Module['printErr']('missing function: posix_openpt'); abort(-1);
  }
  function _symlink(path1, path2) {
      // int symlink(const char *path1, const char *path2);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/symlink.html
      var path = FS.analyzePath(Pointer_stringify(path2), true);
      if (!path.parentExists) {
        ___setErrNo(path.error);
        return -1;
      } else if (path.exists) {
        ___setErrNo(ERRNO_CODES.EEXIST);
        return -1;
      } else {
        FS.createLink(path.parentPath, path.name,
                      Pointer_stringify(path1), true, true);
        return 0;
      }
    }
  function _tcgetattr() {
  Module['printErr']('missing function: tcgetattr'); abort(-1);
  }
  function _tcsetattr() {
  Module['printErr']('missing function: tcsetattr'); abort(-1);
  }
  function _tcflush() {
  Module['printErr']('missing function: tcflush'); abort(-1);
  }
  var ___flock_struct_layout={__size__:16,l_type:0,l_whence:2,l_start:4,l_len:8,l_pid:12,l_xxx:14};function _fcntl(fildes, cmd, varargs, dup2) {
      // int fcntl(int fildes, int cmd, ...);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/fcntl.html
      if (!FS.streams[fildes]) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      var stream = FS.streams[fildes];
      switch (cmd) {
        case 0:
          var arg = HEAP32[((varargs)>>2)];
          if (arg < 0) {
            ___setErrNo(ERRNO_CODES.EINVAL);
            return -1;
          }
          var newStream = {};
          for (var member in stream) {
            newStream[member] = stream[member];
          }
          arg = dup2 ? arg : Math.max(arg, FS.streams.length); // dup2 wants exactly arg; fcntl wants a free descriptor >= arg
          FS.createFileHandle(newStream, arg);
          return arg;
        case 1:
        case 2:
          return 0;  // FD_CLOEXEC makes no sense for a single process.
        case 3:
          var flags = 0;
          if (stream.isRead && stream.isWrite) flags = 2;
          else if (!stream.isRead && stream.isWrite) flags = 1;
          else if (stream.isRead && !stream.isWrite) flags = 0;
          if (stream.isAppend) flags |= 8;
          // Synchronization and blocking flags are irrelevant to us.
          return flags;
        case 4:
          var arg = HEAP32[((varargs)>>2)];
          stream.isAppend = Boolean(arg | 8);
          // Synchronization and blocking flags are irrelevant to us.
          return 0;
        case 7:
        case 20:
          var arg = HEAP32[((varargs)>>2)];
          var offset = ___flock_struct_layout.l_type;
          // We're always unlocked.
          HEAP16[(((arg)+(offset))>>1)]=3
          return 0;
        case 8:
        case 9:
        case 21:
        case 22:
          // Pretend that the locking is successful.
          return 0;
        case 6:
        case 5:
          // These are for sockets. We don't have them fully implemented yet.
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
        default:
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
      }
      // Should never be reached. Only to silence strict warnings.
      return -1;
    }
  function _grantpt() {
  Module['printErr']('missing function: grantpt'); abort(-1);
  }
  function _unlockpt() {
  Module['printErr']('missing function: unlockpt'); abort(-1);
  }
  function _ptsname() {
  Module['printErr']('missing function: ptsname'); abort(-1);
  }
  Module["_tolower"] = _tolower; 
  Module["_strncasecmp"] = _strncasecmp; 
  Module["_strcasecmp"] = _strcasecmp;
  var ___tm_struct_layout={__size__:44,tm_sec:0,tm_min:4,tm_hour:8,tm_mday:12,tm_mon:16,tm_year:20,tm_wday:24,tm_yday:28,tm_isdst:32,tm_gmtoff:36,tm_zone:40};
  var ___tm_current=allocate(4*26, "i8", ALLOC_STATIC);
  var ___tm_timezones={};
  var __tzname=allocate(8, "i32*", ALLOC_STATIC);
  var __daylight=allocate(1, "i32*", ALLOC_STATIC);
  var __timezone=allocate(1, "i32*", ALLOC_STATIC);function _tzset() {
      // TODO: Use (malleable) environment variables instead of system settings.
      if (_tzset.called) return;
      _tzset.called = true;
      HEAP32[((__timezone)>>2)]=-(new Date()).getTimezoneOffset() * 60
      var winter = new Date(2000, 0, 1);
      var summer = new Date(2000, 6, 1);
      HEAP32[((__daylight)>>2)]=Number(winter.getTimezoneOffset() != summer.getTimezoneOffset())
      var winterName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | winter.toString().match(/\(([A-Z]+)\)/)[1];
      var summerName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | summer.toString().match(/\(([A-Z]+)\)/)[1];
      var winterNamePtr = allocate(intArrayFromString(winterName), 'i8', ALLOC_NORMAL);
      var summerNamePtr = allocate(intArrayFromString(summerName), 'i8', ALLOC_NORMAL);
      HEAP32[((__tzname)>>2)]=winterNamePtr
      HEAP32[(((__tzname)+(4))>>2)]=summerNamePtr
    }function _localtime_r(time, tmPtr) {
      _tzset();
      var offsets = ___tm_struct_layout;
      var date = new Date(HEAP32[((time)>>2)]*1000);
      HEAP32[(((tmPtr)+(offsets.tm_sec))>>2)]=date.getSeconds()
      HEAP32[(((tmPtr)+(offsets.tm_min))>>2)]=date.getMinutes()
      HEAP32[(((tmPtr)+(offsets.tm_hour))>>2)]=date.getHours()
      HEAP32[(((tmPtr)+(offsets.tm_mday))>>2)]=date.getDate()
      HEAP32[(((tmPtr)+(offsets.tm_mon))>>2)]=date.getMonth()
      HEAP32[(((tmPtr)+(offsets.tm_year))>>2)]=date.getFullYear()-1900
      HEAP32[(((tmPtr)+(offsets.tm_wday))>>2)]=date.getDay()
      var start = new Date(date.getFullYear(), 0, 1);
      var yday = Math.floor((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24));
      HEAP32[(((tmPtr)+(offsets.tm_yday))>>2)]=yday
      HEAP32[(((tmPtr)+(offsets.tm_gmtoff))>>2)]=start.getTimezoneOffset() * 60
      var dst = Number(start.getTimezoneOffset() != date.getTimezoneOffset());
      HEAP32[(((tmPtr)+(offsets.tm_isdst))>>2)]=dst
      var timezone = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | date.toString().match(/\(([A-Z]+)\)/)[1];
      if (!(timezone in ___tm_timezones)) {
        ___tm_timezones[timezone] = allocate(intArrayFromString(timezone), 'i8', ALLOC_NORMAL);
      }
      HEAP32[(((tmPtr)+(offsets.tm_zone))>>2)]=___tm_timezones[timezone]
      return tmPtr;
    }function _localtime(time) {
      return _localtime_r(time, ___tm_current);
    }
  function _fgetc(stream) {
      // int fgetc(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgetc.html
      if (!FS.streams[stream]) return -1;
      var streamObj = FS.streams[stream];
      if (streamObj.eof || streamObj.error) return -1;
      var ret = _read(stream, _fgetc.ret, 1);
      if (ret == 0) {
        streamObj.eof = true;
        return -1;
      } else if (ret == -1) {
        streamObj.error = true;
        return -1;
      } else {
        return HEAPU8[((_fgetc.ret)|0)];
      }
    }
  function _gmtime_r(time, tmPtr) {
      var date = new Date(HEAP32[((time)>>2)]*1000);
      var offsets = ___tm_struct_layout;
      HEAP32[(((tmPtr)+(offsets.tm_sec))>>2)]=date.getUTCSeconds()
      HEAP32[(((tmPtr)+(offsets.tm_min))>>2)]=date.getUTCMinutes()
      HEAP32[(((tmPtr)+(offsets.tm_hour))>>2)]=date.getUTCHours()
      HEAP32[(((tmPtr)+(offsets.tm_mday))>>2)]=date.getUTCDate()
      HEAP32[(((tmPtr)+(offsets.tm_mon))>>2)]=date.getUTCMonth()
      HEAP32[(((tmPtr)+(offsets.tm_year))>>2)]=date.getUTCFullYear()-1900
      HEAP32[(((tmPtr)+(offsets.tm_wday))>>2)]=date.getUTCDay()
      HEAP32[(((tmPtr)+(offsets.tm_gmtoff))>>2)]=0
      HEAP32[(((tmPtr)+(offsets.tm_isdst))>>2)]=0
      var start = new Date(date.getFullYear(), 0, 1);
      var yday = Math.round((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24));
      HEAP32[(((tmPtr)+(offsets.tm_yday))>>2)]=yday
      var timezone = "GMT";
      if (!(timezone in ___tm_timezones)) {
        ___tm_timezones[timezone] = allocate(intArrayFromString(timezone), 'i8', ALLOC_NORMAL);
      }
      HEAP32[(((tmPtr)+(offsets.tm_zone))>>2)]=___tm_timezones[timezone]
      return tmPtr;
    }function _gmtime(time) {
      return _gmtime_r(time, ___tm_current);
    }
  var _tan=Math.tan;
  function _SDL_PauseAudio(pauseOn) {
      if (SDL.audio.paused !== pauseOn) {
        SDL.audio.timer = pauseOn ? SDL.audio.timer && clearInterval(SDL.audio.timer) : Browser.safeSetInterval(SDL.audio.caller, 1/35);
      }
      SDL.audio.paused = pauseOn;
    }function _SDL_CloseAudio() {
      if (SDL.audio) {
        _SDL_PauseAudio(1);
        _free(SDL.audio.buffer);
        SDL.audio = null;
      }
    }
  function _SDL_WasInit() {
      if (SDL.startTime === null) {
        _SDL_Init();
      }
      return 1;
    }
  function _SDL_InitSubSystem(flags) { return 0 }
  function _SDL_GetError() {
      if (!SDL.errorMessage) {
        SDL.errorMessage = allocate(intArrayFromString("unknown SDL-emscripten error"), 'i8', ALLOC_NORMAL);
      }
      return SDL.errorMessage;
    }
  function _SDL_OpenAudio(desired, obtained) {
      SDL.allocateChannels(32);
      SDL.audio = {
        freq: HEAPU32[(((desired)+(SDL.structs.AudioSpec.freq))>>2)],
        format: HEAPU16[(((desired)+(SDL.structs.AudioSpec.format))>>1)],
        channels: HEAPU8[(((desired)+(SDL.structs.AudioSpec.channels))|0)],
        samples: HEAPU16[(((desired)+(SDL.structs.AudioSpec.samples))>>1)],
        callback: HEAPU32[(((desired)+(SDL.structs.AudioSpec.callback))>>2)],
        userdata: HEAPU32[(((desired)+(SDL.structs.AudioSpec.userdata))>>2)],
        paused: true,
        timer: null
      };
      if (obtained) {
        HEAP32[(((obtained)+(SDL.structs.AudioSpec.freq))>>2)]=SDL.audio.freq; // no good way for us to know if the browser can really handle this
        HEAP16[(((obtained)+(SDL.structs.AudioSpec.format))>>1)]=33040; // float, signed, 16-bit
        HEAP8[(((obtained)+(SDL.structs.AudioSpec.channels))|0)]=SDL.audio.channels;
        HEAP8[(((obtained)+(SDL.structs.AudioSpec.silence))|0)]=HEAPU8[(((desired)+(SDL.structs.AudioSpec.silence))|0)]; // unclear if browsers can provide this
        HEAP16[(((obtained)+(SDL.structs.AudioSpec.samples))>>1)]=SDL.audio.samples;
        HEAP32[(((obtained)+(SDL.structs.AudioSpec.callback))>>2)]=SDL.audio.callback;
        HEAP32[(((obtained)+(SDL.structs.AudioSpec.userdata))>>2)]=SDL.audio.userdata;
      }
      var totalSamples = SDL.audio.samples*SDL.audio.channels;
      SDL.audio.bufferSize = totalSamples*2; // hardcoded 16-bit audio
      SDL.audio.buffer = _malloc(SDL.audio.bufferSize);
      SDL.audio.caller = function() {
        Runtime.dynCall('viii', SDL.audio.callback, [SDL.audio.userdata, SDL.audio.buffer, SDL.audio.bufferSize]);
        SDL.audio.pushAudio(SDL.audio.buffer, SDL.audio.bufferSize);
      };
      // Mozilla Audio API. TODO: Other audio APIs
      try {
        SDL.audio.mozOutput = new Audio();
        SDL.audio.mozOutput['mozSetup'](SDL.audio.channels, SDL.audio.freq); // use string attributes on mozOutput for closure compiler
        SDL.audio.mozBuffer = new Float32Array(totalSamples);
        SDL.audio.pushAudio = function(ptr, size) {
          var mozBuffer = SDL.audio.mozBuffer;
          for (var i = 0; i < totalSamples; i++) {
            mozBuffer[i] = (HEAP16[(((ptr)+(i*2))>>1)]) / 0x8000; // hardcoded 16-bit audio, signed (TODO: reSign if not ta2?)
          }
          SDL.audio.mozOutput['mozWriteAudio'](mozBuffer);
        }
      } catch(e) {
        SDL.audio = null;
      }
      if (!SDL.audio) return -1;
      return 0;
    }
  function _SDL_LockAudio() {}
  function _SDL_UnlockAudio() {}
  function _strtol(str, endptr, base) {
      return __parseInt(str, endptr, base, -2147483648, 2147483647, 32);  // LONG_MIN, LONG_MAX.
    }
  function _printf(format, varargs) {
      // int printf(const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var stdout = HEAP32[((_stdout)>>2)];
      return _fprintf(stdout, format, varargs);
    }
  function _fputs(s, stream) {
      // int fputs(const char *restrict s, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputs.html
      return _write(stream, s, _strlen(s));
    }
  function _vfprintf(s, f, va_arg) {
      return _fprintf(s, f, HEAP32[((va_arg)>>2)]);
    }
  function _puts(s) {
      // int puts(const char *s);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/puts.html
      // NOTE: puts() always writes an extra newline.
      var stdout = HEAP32[((_stdout)>>2)];
      var ret = _fputs(s, stdout);
      if (ret < 0) {
        return ret;
      } else {
        var newlineRet = _fputc(10, stdout);
        return (newlineRet < 0) ? -1 : ret + 1;
      }
    }
  function _strchr(ptr, chr) {
      ptr--;
      do {
        ptr++;
        var val = HEAP8[(ptr)];
        if (val == chr) return ptr;
      } while (val);
      return 0;
    }
  function _usleep(useconds) {
      // int usleep(useconds_t useconds);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/usleep.html
      // We're single-threaded, so use a busy loop. Super-ugly.
      var msec = useconds / 1000;
      var start = Date.now();
      while (Date.now() - start < msec) {
        // Do nothing.
      }
      return 0;
    }
  var ___timespec_struct_layout={__size__:8,tv_sec:0,tv_nsec:4};function _nanosleep(rqtp, rmtp) {
      // int nanosleep(const struct timespec  *rqtp, struct timespec *rmtp);
      var seconds = HEAP32[(((rqtp)+(___timespec_struct_layout.tv_sec))>>2)];
      var nanoseconds = HEAP32[(((rqtp)+(___timespec_struct_layout.tv_nsec))>>2)];
      HEAP32[(((rmtp)+(___timespec_struct_layout.tv_sec))>>2)]=0
      HEAP32[(((rmtp)+(___timespec_struct_layout.tv_nsec))>>2)]=0
      return _usleep((seconds * 1e6) + (nanoseconds / 1000));
    }
  function _gettimeofday(ptr) {
      // %struct.timeval = type { i32, i32 }
      var now = Date.now();
      HEAP32[((ptr)>>2)]=Math.floor(now/1000); // seconds
      HEAP32[(((ptr)+(4))>>2)]=Math.floor((now-1000*Math.floor(now/1000))*1000); // microseconds
      return 0;
    }
  function _SDL_PollEvent(ptr) {
      if (SDL.events.length === 0) return 0;
      if (ptr) {
        SDL.makeCEvent(SDL.events.shift(), ptr);
      }
      return 1;
    }
  function _SDL_ShowCursor(toggle) {
      switch (toggle) {
        case 0: // SDL_DISABLE
          if (Browser.isFullScreen) { // only try to lock the pointer when in full screen mode
            Module['canvas'].requestPointerLock();
            return 0;
          } else { // else return SDL_ENABLE to indicate the failure
            return 1;
          }
          break;
        case 1: // SDL_ENABLE
          Module['canvas'].exitPointerLock();
          return 1;
          break;
        case -1: // SDL_QUERY
          return !Browser.pointerLock;
          break;
        default:
          console.log( "SDL_ShowCursor called with unknown toggle parameter value: " + toggle + "." );
          break;
      }
    }
  function _SDL_WM_GrabInput() {}
  function _SDL_WM_ToggleFullScreen(surf) {
      if (Browser.isFullScreen) {
        Module['canvas'].cancelFullScreen();
        return 1;
      } else {
        return 0;
      }
    }
  function _SDL_CreateRGBSurfaceFrom(pixels, width, height, depth, pitch, rmask, gmask, bmask, amask) {
      // TODO: Take into account depth and pitch parameters.
      var surface = SDL.makeSurface(width, height, 0, false, 'CreateRGBSurfaceFrom', rmask, gmask, bmask, amask);
      var surfaceData = SDL.surfaces[surface];
      var surfaceImageData = surfaceData.ctx.getImageData(0, 0, width, height);
      var surfacePixelData = surfaceImageData.data;
      // Fill pixel data to created surface.
      // Supports SDL_PIXELFORMAT_RGBA8888 and SDL_PIXELFORMAT_RGB888
      var channels = amask ? 4 : 3; // RGBA8888 or RGB888
      for (var pixelOffset = 0; pixelOffset < width*height; pixelOffset++) {
        surfacePixelData[pixelOffset*4+0] = HEAPU8[pixels + (pixelOffset*channels+0)]; // R
        surfacePixelData[pixelOffset*4+1] = HEAPU8[pixels + (pixelOffset*channels+1)]; // G
        surfacePixelData[pixelOffset*4+2] = HEAPU8[pixels + (pixelOffset*channels+2)]; // B
        surfacePixelData[pixelOffset*4+3] = amask ? HEAPU8[pixels + (pixelOffset*channels+3)] : 0xff; // A
      };
      surfaceData.ctx.putImageData(surfaceImageData, 0, 0);
      return surface;
    }
  function _SDL_UpperBlit(src, srcrect, dst, dstrect) {
      var srcData = SDL.surfaces[src];
      var dstData = SDL.surfaces[dst];
      var sr, dr;
      if (srcrect) {
        sr = SDL.loadRect(srcrect);
      } else {
        sr = { x: 0, y: 0, w: srcData.width, h: srcData.height };
      }
      if (dstrect) {
        dr = SDL.loadRect(dstrect);
      } else {
        dr = { x: 0, y: 0, w: -1, h: -1 };
      }
      dstData.ctx.drawImage(srcData.canvas, sr.x, sr.y, sr.w, sr.h, dr.x, dr.y, sr.w, sr.h);
      if (dst != SDL.screen) {
        // XXX As in IMG_Load, for compatibility we write out |pixels|
        console.log('WARNING: copying canvas data to memory for compatibility');
        _SDL_LockSurface(dst);
        dstData.locked--; // The surface is not actually locked in this hack
      }
      return 0;
    }
  function _SDL_FreeSurface(surf) {
      if (surf) SDL.freeSurface(surf);
    }
  function _SDL_Flip(surf) {
      // We actually do this in Unlock, since the screen surface has as its canvas
      // backing the page canvas element
    }
  function _SDL_SetVideoMode(width, height, depth, flags) {
      ['mousedown', 'mouseup', 'mousemove', 'DOMMouseScroll', 'mousewheel', 'mouseout'].forEach(function(event) {
        if (Module["canvasFront"]) {
          Module['canvasFront'].addEventListener(event, SDL.receiveEvent, true);
        } else {
          Module['canvas'].addEventListener(event, SDL.receiveEvent, true);
        }
      });
      Browser.setCanvasSize(width, height, true);
      // Free the old surface first.
      if (SDL.screen) {
        SDL.freeSurface(SDL.screen);
        SDL.screen = null;
      }
      SDL.screen = SDL.makeSurface(width, height, flags, true, 'screen');
      if (!SDL.addedResizeListener) {
        SDL.addedResizeListener = true;
        Browser.resizeListeners.push(function(w, h) {
          SDL.receiveEvent({
            type: 'resize',
            w: w,
            h: h
          });
        });
      }
      return SDL.screen;
    }
  function _SDL_WM_SetCaption(title, icon) {
      title = title && Pointer_stringify(title);
      icon = icon && Pointer_stringify(icon);
    }
  function _SDL_GetVideoInfo() {
      // %struct.SDL_VideoInfo = type { i32, i32, %struct.SDL_PixelFormat*, i32, i32 } - 5 fields of quantum size
      var ret = _malloc(5*Runtime.QUANTUM_SIZE);
      HEAP32[((ret+Runtime.QUANTUM_SIZE*0)>>2)]=0 // TODO
      HEAP32[((ret+Runtime.QUANTUM_SIZE*1)>>2)]=0 // TODO
      HEAP32[((ret+Runtime.QUANTUM_SIZE*2)>>2)]=0
      HEAP32[((ret+Runtime.QUANTUM_SIZE*3)>>2)]=Module["canvas"].width
      HEAP32[((ret+Runtime.QUANTUM_SIZE*4)>>2)]=Module["canvas"].height
      return ret;
    }
  function _SDL_EnableKeyRepeat(delay, interval) {
      // TODO
    }
  function _SDL_EventState() {}
  function _abort() {
      ABORT = true;
      throw 'abort() at ' + (new Error().stack);
    }
  function ___errno_location() {
      return ___errno_state;
    }var ___errno=___errno_location;
  function _sysconf(name) {
      // long sysconf(int name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/sysconf.html
      switch(name) {
        case 8: return PAGE_SIZE;
        case 54:
        case 56:
        case 21:
        case 61:
        case 63:
        case 22:
        case 67:
        case 23:
        case 24:
        case 25:
        case 26:
        case 27:
        case 69:
        case 28:
        case 101:
        case 70:
        case 71:
        case 29:
        case 30:
        case 199:
        case 75:
        case 76:
        case 32:
        case 43:
        case 44:
        case 80:
        case 46:
        case 47:
        case 45:
        case 48:
        case 49:
        case 42:
        case 82:
        case 33:
        case 7:
        case 108:
        case 109:
        case 107:
        case 112:
        case 119:
        case 121:
          return 200809;
        case 13:
        case 104:
        case 94:
        case 95:
        case 34:
        case 35:
        case 77:
        case 81:
        case 83:
        case 84:
        case 85:
        case 86:
        case 87:
        case 88:
        case 89:
        case 90:
        case 91:
        case 94:
        case 95:
        case 110:
        case 111:
        case 113:
        case 114:
        case 115:
        case 116:
        case 117:
        case 118:
        case 120:
        case 40:
        case 16:
        case 79:
        case 19:
          return -1;
        case 92:
        case 93:
        case 5:
        case 72:
        case 6:
        case 74:
        case 92:
        case 93:
        case 96:
        case 97:
        case 98:
        case 99:
        case 102:
        case 103:
        case 105:
          return 1;
        case 38:
        case 66:
        case 50:
        case 51:
        case 4:
          return 1024;
        case 15:
        case 64:
        case 41:
          return 32;
        case 55:
        case 37:
        case 17:
          return 2147483647;
        case 18:
        case 1:
          return 47839;
        case 59:
        case 57:
          return 99;
        case 68:
        case 58:
          return 2048;
        case 0: return 2097152;
        case 3: return 65536;
        case 14: return 32768;
        case 73: return 32767;
        case 39: return 16384;
        case 60: return 1000;
        case 106: return 700;
        case 52: return 256;
        case 62: return 255;
        case 2: return 100;
        case 65: return 64;
        case 36: return 20;
        case 100: return 16;
        case 20: return 6;
        case 53: return 4;
        case 10: return 1;
      }
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    }
  function _sbrk(bytes) {
      // Implement a Linux-like 'memory area' for our 'process'.
      // Changes the size of the memory area by |bytes|; returns the
      // address of the previous top ('break') of the memory area
      // We control the "dynamic" memory - DYNAMIC_BASE to DYNAMICTOP
      var self = _sbrk;
      if (!self.called) {
        DYNAMICTOP = alignMemoryPage(DYNAMICTOP); // make sure we start out aligned
        self.called = true;
        assert(Runtime.dynamicAlloc);
        self.alloc = Runtime.dynamicAlloc;
        Runtime.dynamicAlloc = function() { abort('cannot dynamically allocate, sbrk now has control') };
      }
      var ret = DYNAMICTOP;
      if (bytes != 0) self.alloc(bytes);
      return ret;  // Previous break location.
    }
__ATINIT__.unshift({ func: function() { if (!Module["noFSInit"] && !FS.init.initialized) FS.init() } });__ATMAIN__.push({ func: function() { FS.ignorePermissions = false } });__ATEXIT__.push({ func: function() { FS.quit() } });Module["FS_createFolder"] = FS.createFolder;Module["FS_createPath"] = FS.createPath;Module["FS_createDataFile"] = FS.createDataFile;Module["FS_createPreloadedFile"] = FS.createPreloadedFile;Module["FS_createLazyFile"] = FS.createLazyFile;Module["FS_createLink"] = FS.createLink;Module["FS_createDevice"] = FS.createDevice;
___errno_state = Runtime.staticAlloc(4); HEAP32[((___errno_state)>>2)]=0;
Module["requestFullScreen"] = function(lockPointer, resizeCanvas) { Browser.requestFullScreen(lockPointer, resizeCanvas) };
  Module["requestAnimationFrame"] = function(func) { Browser.requestAnimationFrame(func) };
  Module["pauseMainLoop"] = function() { Browser.mainLoop.pause() };
  Module["resumeMainLoop"] = function() { Browser.mainLoop.resume() };
  Module["getUserMedia"] = function() { Browser.getUserMedia() }
_fputc.ret = allocate([0], "i8", ALLOC_STATIC);
_fgetc.ret = allocate([0], "i8", ALLOC_STATIC);
STACK_BASE = STACKTOP = Runtime.alignMemory(STATICTOP);
staticSealed = true; // seal the static portion of memory
STACK_MAX = STACK_BASE + 5242880;
DYNAMIC_BASE = DYNAMICTOP = Runtime.alignMemory(STACK_MAX);
assert(DYNAMIC_BASE < TOTAL_MEMORY); // Stack must fit in TOTAL_MEMORY; allocations from here on may enlarge TOTAL_MEMORY
 var ctlz_i8 = allocate([8,7,6,6,5,5,5,5,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_DYNAMIC);
 var cttz_i8 = allocate([8,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,7,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0], "i8", ALLOC_DYNAMIC);
var Math_min = Math.min;
function invoke_ii(index,a1) {
  try {
    return Module["dynCall_ii"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiii(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vi(index,a1) {
  try {
    Module["dynCall_vi"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vii(index,a1,a2) {
  try {
    Module["dynCall_vii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiii(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viii(index,a1,a2,a3) {
  try {
    Module["dynCall_viii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_v(index) {
  try {
    Module["dynCall_v"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiii(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iiiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iii(index,a1,a2) {
  try {
    return Module["dynCall_iii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiiii(index,a1,a2,a3,a4,a5) {
  try {
    return Module["dynCall_iiiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiii(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function asmPrintInt(x, y) {
  Module.print('int ' + x + ',' + y);// + ' ' + new Error().stack);
}
function asmPrintFloat(x, y) {
  Module.print('float ' + x + ',' + y);// + ' ' + new Error().stack);
}
// EMSCRIPTEN_START_ASM
var asm=(function(global,env,buffer){"use asm";var a=new global.Int8Array(buffer);var b=new global.Int16Array(buffer);var c=new global.Int32Array(buffer);var d=new global.Uint8Array(buffer);var e=new global.Uint16Array(buffer);var f=new global.Uint32Array(buffer);var g=new global.Float32Array(buffer);var h=new global.Float64Array(buffer);var i=env.STACKTOP|0;var j=env.STACK_MAX|0;var k=env.tempDoublePtr|0;var l=env.ABORT|0;var m=env.cttz_i8|0;var n=env.ctlz_i8|0;var o=env._stdout|0;var p=env._stdin|0;var q=env._stderr|0;var r=+env.NaN;var s=+env.Infinity;var t=0;var u=0;var v=0;var w=0;var x=0,y=0,z=0,A=0,B=0.0,C=0,D=0,E=0,F=0.0;var G=0;var H=0;var I=0;var J=0;var K=0;var L=0;var M=0;var N=0;var O=0;var P=0;var Q=global.Math.floor;var R=global.Math.abs;var S=global.Math.sqrt;var T=global.Math.pow;var U=global.Math.cos;var V=global.Math.sin;var W=global.Math.tan;var X=global.Math.acos;var Y=global.Math.asin;var Z=global.Math.atan;var _=global.Math.atan2;var $=global.Math.exp;var aa=global.Math.log;var ab=global.Math.ceil;var ac=global.Math.imul;var ad=env.abort;var ae=env.assert;var af=env.asmPrintInt;var ag=env.asmPrintFloat;var ah=env.min;var ai=env.invoke_ii;var aj=env.invoke_viiiii;var ak=env.invoke_vi;var al=env.invoke_vii;var am=env.invoke_iiii;var an=env.invoke_viii;var ao=env.invoke_v;var ap=env.invoke_iiiii;var aq=env.invoke_iii;var ar=env.invoke_iiiiii;var as=env.invoke_viiii;var at=env._llvm_lifetime_end;var au=env._lseek;var av=env._fclose;var aw=env._SDL_EventState;var ax=env._strtoul;var ay=env._fflush;var az=env._SDL_GetMouseState;var aA=env._strtol;var aB=env._fputc;var aC=env._fwrite;var aD=env._ptsname;var aE=env._send;var aF=env._tcflush;var aG=env._fputs;var aH=env._emscripten_cancel_main_loop;var aI=env._SDL_UnlockAudio;var aJ=env._SDL_WasInit;var aK=env._read;var aL=env._fileno;var aM=env._fsync;var aN=env._signal;var aO=env._SDL_PauseAudio;var aP=env._SDL_LockAudio;var aQ=env._strcmp;var aR=env._strncmp;var aS=env._snprintf;var aT=env._fgetc;var aU=env._atexit;var aV=env._close;var aW=env._tcsetattr;var aX=env._strchr;var aY=env._tcgetattr;var aZ=env._fopen;var a_=env.___setErrNo;var a$=env._grantpt;var a0=env._ftell;var a1=env._exit;var a2=env._sprintf;var a3=env._fcntl;var a4=env._SDL_ShowCursor;var a5=env._gmtime;var a6=env._symlink;var a7=env._localtime_r;var a8=env._ftruncate;var a9=env._recv;var ba=env._SDL_PollEvent;var bb=env._SDL_Init;var bc=env.__exit;var bd=env._SDL_WM_GrabInput;var be=env._llvm_va_end;var bf=env._tzset;var bg=env._SDL_CreateRGBSurfaceFrom;var bh=env._printf;var bi=env._unlockpt;var bj=env._pread;var bk=env._SDL_SetVideoMode;var bl=env._poll;var bm=env._open;var bn=env._usleep;var bo=env._SDL_EnableKeyRepeat;var bp=env._puts;var bq=env._SDL_GetVideoInfo;var br=env._nanosleep;var bs=env._SDL_Flip;var bt=env._SDL_InitSubSystem;var bu=env._strdup;var bv=env._SDL_GetError;var bw=env.__formatString;var bx=env._gettimeofday;var by=env._vfprintf;var bz=env._SDL_WM_SetCaption;var bA=env._sbrk;var bB=env.___errno_location;var bC=env._SDL_CloseAudio;var bD=env._isspace;var bE=env._llvm_lifetime_start;var bF=env.__parseInt;var bG=env._SDL_OpenAudio;var bH=env._localtime;var bI=env._gmtime_r;var bJ=env._sysconf;var bK=env._fread;var bL=env._SDL_WM_ToggleFullScreen;var bM=env._abort;var bN=env._fprintf;var bO=env._tan;var bP=env.__reallyNegative;var bQ=env._posix_openpt;var bR=env._fseek;var bS=env._write;var bT=env._SDL_UpperBlit;var bU=env._truncate;var bV=env._emscripten_set_main_loop;var bW=env._unlink;var bX=env._pwrite;var bY=env._SDL_FreeSurface;var bZ=env._time;
// EMSCRIPTEN_START_FUNCS
function b9(a){a=a|0;var b=0;b=i;i=i+a|0;i=i+7>>3<<3;return b|0}function ca(){return i|0}function cb(a){a=a|0;i=a}function cc(a,b){a=a|0;b=b|0;if((t|0)==0){t=a;u=b}}function cd(b){b=b|0;a[k]=a[b];a[k+1|0]=a[b+1|0];a[k+2|0]=a[b+2|0];a[k+3|0]=a[b+3|0]}function ce(b){b=b|0;a[k]=a[b];a[k+1|0]=a[b+1|0];a[k+2|0]=a[b+2|0];a[k+3|0]=a[b+3|0];a[k+4|0]=a[b+4|0];a[k+5|0]=a[b+5|0];a[k+6|0]=a[b+6|0];a[k+7|0]=a[b+7|0]}function cf(a){a=a|0;G=a}function cg(a){a=a|0;H=a}function ch(a){a=a|0;I=a}function ci(a){a=a|0;J=a}function cj(a){a=a|0;K=a}function ck(a){a=a|0;L=a}function cl(a){a=a|0;M=a}function cm(a){a=a|0;N=a}function cn(a){a=a|0;O=a}function co(a){a=a|0;P=a}function cp(){}function cq(a,b){a=a|0;b=b|0;return}function cr(b){b=b|0;a[b+7|0]=0;return}function cs(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;if((d|0)!=3){f=0;return f|0}d=b+20|0;a[e+1|0]=c[d>>2]&255;a[e]=(c[d>>2]|0)>>>8&255;f=2;return f|0}function ct(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;if((d|0)!=3|f>>>0<2){return}if((a[e+1|0]|0)!=-2){return}f=a[e]&15;a[b+4|0]=f&255;e=b+20|0;c[e>>2]=f<<8|c[e>>2]&61695;return}function cu(a,b,d){a=a|0;b=b|0;d=d|0;c[a+92>>2]=b;c[a+96>>2]=d;return}function cv(a,b,d){a=a|0;b=b|0;d=d|0;c[a+100>>2]=b;c[a+104>>2]=d;return}function cw(a,b,d){a=a|0;b=b|0;d=d|0;c[a+112>>2]=b;c[a+116>>2]=d;return}function cx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=a+24|0;e=c[d>>2]|0;f=0;while(1){if(f>>>0>=e>>>0){break}if((c[a+28+(f<<2)>>2]|0)==(b|0)){g=1;h=26;break}else{f=f+1|0}}if((h|0)==26){return g|0}if(e>>>0>15){g=1;return g|0}c[d>>2]=e+1;c[a+28+(e<<2)>>2]=b;g=0;return g|0}function cy(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c[b+320>>2]|0;if((d|0)==0){d=c[2126]|0;if((d|0)!=0){f=e|0;g=8504;h=d;do{d=c[f>>2]|0;L52:do{if((d|0)!=0){i=g;j=e;k=d;l=h;while(1){if((k|0)==(l|0)){m=j;n=c[i+4>>2]|0;c[m>>2]=c[i>>2];c[m+4>>2]=n}n=j+8|0;m=c[n>>2]|0;if((m|0)==0){break L52}j=n;k=m;l=c[g>>2]|0}}}while(0);g=g+8|0;h=c[g>>2]|0;}while((h|0)!=0)}a[b+316|0]=0;return}else{h=c[2100]|0;if((h|0)!=0){g=e|0;f=8400;d=h;do{h=c[g>>2]|0;L36:do{if((h|0)!=0){l=f;k=e;j=h;i=d;while(1){if((j|0)==(i|0)){m=k;n=c[l+4>>2]|0;c[m>>2]=c[l>>2];c[m+4>>2]=n}n=k+8|0;m=c[n>>2]|0;if((m|0)==0){break L36}k=n;j=m;i=c[f>>2]|0}}}while(0);f=f+8|0;d=c[f>>2]|0;}while((d|0)!=0)}a[b+316|0]=1;return}}function cz(b){b=b|0;return a[b+316|0]|0}function cA(b){b=b|0;var e=0;e=a[b+5|0]|0;a[b+4|0]=e;u6(b+7|0,0,13);c[b+20>>2]=(e&255)<<8&3840|(d[b+6|0]|0)|24576;return}function cB(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;c[b>>2]=0;f=d&255;a[b+4|0]=f;a[b+5|0]=f;a[b+6|0]=e&255;u6(b+7|0,0,13);c[b+20>>2]=d<<8&3840|e&255|24576;c[b+24>>2]=0;c[b+28>>2]=34;c[b+32>>2]=14;c[b+36>>2]=94;c[b+40>>2]=130;c[b+44>>2]=2;return}function cC(){var b=0,d=0;b=u0(120)|0;if((b|0)==0){d=0;return d|0}a[b]=3;c[b+112>>2]=0;c[b+116>>2]=0;u6(b+1|0,0,5);u6(b+14|0,0,14);u6(b+92|0,0,17);d=b;return d|0}function cD(b){b=b|0;var d=0,e=0,f=0;d=b+24|0;if((c[d>>2]|0)!=0){e=0;do{f=c[b+28+(e<<2)>>2]|0;b0[c[f+28>>2]&127](f);e=e+1|0;}while(e>>>0<(c[d>>2]|0)>>>0)}a[b|0]=3;a[b+1|0]=1;d=b+108|0;e=b+2|0;y=0;a[e]=y&255;y=y>>8;a[e+1|0]=y&255;y=y>>8;a[e+2|0]=y&255;y=y>>8;a[e+3|0]=y&255;u6(b+14|0,0,10);if((a[d]|0)==0){return}a[d]=0;d=c[b+116>>2]|0;if((d|0)==0){return}b1[d&511](c[b+112>>2]|0,0);return}function cE(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=e&3;e=b|0;if((a[e]|0)==f<<24>>24){return}g=b+16|0;c[g>>2]=(c[g>>2]|0)+783;L87:do{if((f<<24>>24|0)==3|(f<<24>>24|0)==0){g=a[b+5|0]|0;if((d[b+4|0]|0)>=(g&255)){break}h=a[b+2|0]|0;if((h&12)!=8){break}a[b+1|0]=0;i=h&255;h=i>>>4;j=c[b+24>>2]|0;k=0;while(1){if(k>>>0>=j>>>0){break L87}l=c[b+28+(k<<2)>>2]|0;if((d[l+4|0]|0)==(h|0)){break}else{k=k+1|0}}if((l|0)==0){break}b8[c[l+44>>2]&7](l,i&3,b+6|0,g&255)}}while(0);a[e]=f;e=b+108|0;do{if((a[e]|0)!=0){a[e]=0;l=c[b+116>>2]|0;if((l|0)==0){break}b1[l&511](c[b+112>>2]|0,0)}}while(0);if((f<<24>>24|0)==0){a[b+1|0]=0;a[b+4|0]=0;a[b+5|0]=0;a[b+14|0]=8;a[b+15|0]=0;return}else if((f<<24>>24|0)==1|(f<<24>>24|0)==2){if((a[b+1|0]|0)==0){a[b+14|0]=8;a[b+15|0]=0;return}l=b+4|0;k=a[l]|0;h=a[b+5|0]|0;a[b+14|0]=8;if((k&255)>=(h&255)){a[b+15|0]=-86;if((a[e]|0)==1){return}a[e]=1;e=c[b+116>>2]|0;if((e|0)==0){return}b1[e&511](c[b+112>>2]|0,1);return}e=k+1&255;a[l]=e;a[b+15|0]=a[(k&255)+(b+6)|0]|0;if((e&255)<(h&255)){return}h=d[b+2|0]|0;e=h>>>4;k=c[b+24>>2]|0;l=0;while(1){if(l>>>0>=k>>>0){m=102;break}n=c[b+28+(l<<2)>>2]|0;if((d[n+4|0]|0)==(e|0)){break}else{l=l+1|0}}if((m|0)==102){return}if((n|0)==0){return}b1[c[n+40>>2]&511](n,h&3);return}else if((f<<24>>24|0)==3){a[b+1|0]=1;a[b+4|0]=0;a[b+5|0]=0;a[b+14|0]=0;a[b+15|0]=0;c[b+20>>2]=0;return}else{return}}function cF(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b+14|0;g=a[f]|0;if(g<<24>>24==0){if((a[b|0]|0)!=3){return}h=b+20|0;i=(c[h>>2]|0)+e|0;c[h>>2]=i;if(i>>>0<86170){return}c[h>>2]=0;h=a[b+3|0]|0;if(h<<24>>24==0){return}cG(b,h,1);if((d[b+4|0]|0)<(d[b+5|0]|0)){a[f]=8;a[b+15|0]=-86;return}if((a[b+108|0]|0)==0){return}a[f]=8;a[b+15|0]=-86;return}c[b+20>>2]=0;h=b+16|0;i=c[h>>2]|0;if(i>>>0>e>>>0){c[h>>2]=i-e;return}c[h>>2]=0;do{if((a[b+1|0]|0)==0){e=b+15|0;a[e]=a[e]<<1;i=g-1&255;a[f]=i;j=c[b+104>>2]|0;if((j|0)==0){k=i}else{if((b_[j&511](c[b+100>>2]|0)|0)<<24>>24!=0){a[e]=a[e]|1}k=a[f]|0}if(k<<24>>24!=0){break}if((a[b|0]|0)==0){cG(b,a[e]|0,0);break}j=b+5|0;i=a[j]|0;if((i&255)>=8){break}l=a[e]|0;a[j]=i+1&255;a[(i&255)+(b+6)|0]=l}else{l=c[b+96>>2]|0;if((l|0)==0){m=g;n=b+15|0}else{i=b+15|0;b1[l&511](c[b+92>>2]|0,(d[i]|0)>>>7);m=a[f]|0;n=i}a[n]=a[n]<<1;a[f]=m-1&255}}while(0);c[h>>2]=(c[h>>2]|0)+783;return}function cG(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;h=b+108|0;do{if((a[h]|0)!=0){a[h]=0;j=c[b+116>>2]|0;if((j|0)==0){break}b1[j&511](c[b+112>>2]|0,0)}}while(0);j=b+2|0;a[j]=e;a[b+4|0]=0;k=b+5|0;a[k]=0;l=e&255;m=l&15;L185:do{if((m|0)==0){n=b+24|0;if((c[n>>2]|0)!=0){o=0;do{p=c[b+28+(o<<2)>>2]|0;b0[c[p+28>>2]&127](p);o=o+1|0;}while(o>>>0<(c[n>>2]|0)>>>0)}a[b|0]=3;n=b+1|0;a[n]=1;o=j;y=0;a[o]=y&255;y=y>>8;a[o+1|0]=y&255;y=y>>8;a[o+2|0]=y&255;y=y>>8;a[o+3|0]=y&255;u6(b+14|0,0,10);do{if((a[h]|0)!=0){a[h]=0;o=c[b+116>>2]|0;if((o|0)==0){break}b1[o&511](c[b+112>>2]|0,0)}}while(0);a[n]=1}else{o=l&12;if((o|0)==8){break}else if((o|0)==12){a[b+1|0]=1;o=l>>>4;p=c[b+24>>2]|0;q=0;while(1){if(q>>>0>=p>>>0){break L185}r=c[b+28+(q<<2)>>2]|0;if((d[r+4|0]|0)==(o|0)){break}else{q=q+1|0}}if((r|0)==0){break}a[k]=(b2[c[r+36>>2]&127](r,l&3,b+6|0)|0)&255;a[b+3|0]=e;break}if((m|0)!=1){d$(55584,(x=i,i=i+8|0,c[x>>2]=l,x)|0);break}a[b+1|0]=1;q=l>>>4;o=c[b+24>>2]|0;p=0;while(1){if(p>>>0>=o>>>0){break L185}s=c[b+28+(p<<2)>>2]|0;if((d[s+4|0]|0)==(q|0)){break}else{p=p+1|0}}if((s|0)==0){break}b0[c[s+32>>2]&127](s)}}while(0);if((f|0)==0){i=g;return}f=l>>>4;l=b+24|0;s=c[l>>2]|0;if((s|0)==0){i=g;return}m=b+116|0;e=b+112|0;r=0;k=s;while(1){s=c[b+28+(r<<2)>>2]|0;do{if((a[s+7|0]|0)==0){t=k}else{if((d[s+4|0]|0)==(f|0)){t=k;break}if((c[s+20>>2]&8192|0)==0){t=k;break}if((a[h]|0)==1){t=k;break}a[h]=1;j=c[m>>2]|0;if((j|0)==0){t=k;break}b1[j&511](c[e>>2]|0,1);t=c[l>>2]|0}}while(0);s=r+1|0;if(s>>>0<t>>>0){r=s;k=t}else{break}}i=g;return}function cH(b,d){b=b|0;d=d|0;var e=0;e=c[b>>2]|0;if((d|0)!=0){return}a[e+48|0]=0;a[e+7|0]=(c[e+52>>2]|0)!=(c[e+56>>2]|0)|0;return}function cI(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;g=b+56|0;if(((c[g>>2]^d)&1|0)!=0){c[b+52>>2]=1}c[g>>2]=d;d=b+60|0;g=(c[d>>2]|0)+e|0;c[d>>2]=g;d=b+64|0;e=(c[d>>2]|0)+f|0;c[d>>2]=e;d=b+52|0;if((g|e|0)==0){h=c[d>>2]&255;i=b+7|0;a[i]=h;return}else{c[d>>2]=1;h=1;i=b+7|0;a[i]=h;return}}function cJ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[b>>2]|0;if((d|0)!=0){return}d=e+48|0;if((a[d]|0)==0){return}a[d]=0;d=e+52|0;c[d>>2]=0;if((c[e+68>>2]|0)==(c[e+56>>2]|0)){f=0}else{c[d>>2]=1;f=1}g=c[e+72>>2]|0;h=e+60|0;i=c[h>>2]|0;c[h>>2]=i-g;h=c[e+76>>2]|0;j=e+64|0;e=c[j>>2]|0;c[j>>2]=e-h;if((i|0)==(g|0)&(e|0)==(h|0)){k=f}else{c[d>>2]=1;k=1}a[b+7|0]=k;return}function cK(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;g=c[b+320>>2]|0;while(1){h=c[g>>2]|0;j=(h|0)==0;if(j|(h|0)==(e|0)){break}else{g=g+8|0}}if(j){j=uq(e)|0;sL(2,55552,(x=i,i=i+16|0,c[x>>2]=e,c[x+8>>2]=(j|0)!=0?j:53496,x)|0);i=f;return}do{if((d|0)==1){j=b+56|0;e=c[j>>2]|0;h=e+1&255;k=b+52|0;if((h|0)==(c[k>>2]|0)){l=k;m=j;break}a[b+60+e|0]=a[g+4|0]|0;c[j>>2]=h;l=k;m=j}else if((d|0)==2){j=b+56|0;k=c[j>>2]|0;h=k+1&255;e=b+52|0;if((h|0)==(c[e>>2]|0)){l=e;m=j;break}a[b+60+k|0]=a[g+4|0]|-128;c[j>>2]=h;l=e;m=j}else{l=b+52|0;m=b+56|0}}while(0);a[b+7|0]=(c[l>>2]|0)!=(c[m>>2]|0)|0;i=f;return}function cL(a){a=a|0;var b=0;b=c[a>>2]|0;u1(c[b+320>>2]|0);u1(b);return}function cM(b){b=b|0;var d=0;d=c[b>>2]|0;cA(b);a[d+48|0]=0;c[d+52>>2]=0;c[d+56>>2]=0;return}function cN(b){b=b|0;var d=0;d=c[b>>2]|0;cr(b);a[d+48|0]=0;c[d+52>>2]=0;c[d+56>>2]=0;return}function cO(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;if((d|0)==0){g=c[b>>2]|0;h=g;j=g+48|0;if((a[j]|0)==0){k=g+52|0;l=c[k>>2]|0;m=c[g+56>>2]|0;if((l|0)==(m|0)){n=0;i=f;return n|0}g=a[h+60+l|0]|0;o=l+1&255;c[k>>2]=o;if((o|0)==(m|0)){p=255}else{m=a[h+60+o|0]|0;c[k>>2]=l+2&255;p=m&255}m=b+8|0;c[m>>2]=p|(g&255)<<8;q=m}else{q=b+8|0}a[j]=1;a[e]=(c[q>>2]|0)>>>8&255;a[e+1|0]=c[q>>2]&255;n=2;i=f;return n|0}else if((d|0)==2){a[e]=-1;a[e+1|0]=-1;d$(41088,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);n=2;i=f;return n|0}else if((d|0)!=3){d$(44544,(x=i,i=i+8|0,c[x>>2]=d,x)|0)}n=cs(b,d,e)|0;i=f;return n|0}function cP(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0;g=i;do{if((b|0)!=3){d$(48520,(x=i,i=i+8|0,c[x>>2]=b,x)|0);if(!((b|0)==2&(f|0)==2)){break}c[a+16>>2]=(d[e]|0)<<8|(d[e+1|0]|0);i=g;return}}while(0);ct(a,b,e,f);i=g;return}function cQ(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=u0(324)|0;d=b;if((b|0)==0){e=0;return e|0}cB(b,2,2);c[b>>2]=b;c[b+24>>2]=2;c[b+28>>2]=26;c[b+32>>2]=4;c[b+36>>2]=72;c[b+40>>2]=126;c[b+44>>2]=6;c[b+52>>2]=0;c[b+56>>2]=0;a[b+316|0]=0;f=0;while(1){g=f+1|0;if((c[8608+(f<<3)>>2]|0)==0){break}else{f=g}}f=g<<3;g=u0(f)|0;if((g|0)==0){h=0}else{i=g;u7(g|0,8608,f)|0;h=i}c[b+320>>2]=h;e=d;return e|0}function cR(a){a=a|0;u1(c[a>>2]|0);return}function cS(a){a=a|0;var b=0;b=c[a>>2]|0;cA(a);u6(b+52|0,0,28);c[a+8>>2]=32896;return}function cT(a){a=a|0;var b=0;b=c[a>>2]|0;cr(a);u6(b+52|0,0,28);return}function cU(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((d|0)!=0){f=cs(b,d,e)|0;return f|0}d=c[b>>2]|0;if((c[d+52>>2]|0)==0){f=0;return f|0}a[d+48|0]=1;g=d+68|0;c[g>>2]=c[d+56>>2];h=d+72|0;c[h>>2]=c[d+60>>2];i=d+76|0;c[i>>2]=c[d+64>>2];d=b+8|0;c[d>>2]=32896;if((c[g>>2]&1|0)==0){j=32896}else{c[d>>2]=128;j=128}g=c[h>>2]|0;if((g|0)<0){k=(g|0)<-63?65:g&127}else{k=(g|0)>63?63:g}g=k|j;c[d>>2]=g;j=c[i>>2]|0;if((j|0)<0){l=(j|0)<-63?65:j&127}else{l=(j|0)>63?63:j}j=l<<8|g&33023;c[d>>2]=j;a[e]=j>>>8&255;a[e+1|0]=c[d>>2]&255;f=2;return f|0}function cV(){var a=0,b=0;a=u0(80)|0;if((a|0)==0){b=0;return b|0}cB(a,3,1);c[a>>2]=a;c[a+24>>2]=54;c[a+28>>2]=44;c[a+32>>2]=56;c[a+36>>2]=90;c[a+40>>2]=80;u6(a+52|0,0,28);b=a;return b|0}function cW(a,b){a=a|0;b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=i;i=i+264|0;g=f|0;rV(g,b);if((sa(g)|0)!=0){i=f;return}if((sa(g)|0)!=0){i=f;return}b=a+49|0;h=a+48|0;j=a+50|0;k=a+51|0;l=a+124|0;m=a+44|0;n=a+45|0;p=a+68|0;q=a+52|0;r=a+46|0;s=a+47|0;t=a+42|0;u=a+43|0;v=a+69|0;w=a+56|0;y=a+54|0;z=a+40|0;A=a+41|0;B=a+60|0;C=a+4624|0;D=a+4625|0;E=a+64|0;F=a+62|0;G=a+1424|0;H=a+8|0;I=a+4|0;L348:while(1){do{if((sb(g,44280)|0)==0){if((sb(g,43696)|0)!=0){sq(32168);nC(c[H>>2]|0,c[o>>2]|0);break}if((sb(g,43368)|0)==0){if((sb(g,43032)|0)==0){break L348}sq(34768);J=d[h]|0;K=d[j]|0;L=d[k]|0;M=d[l]|0;sp(34256,(x=i,i=i+40|0,c[x>>2]=d[b]|0,c[x+8>>2]=J,c[x+16>>2]=K,c[x+24>>2]=L,c[x+32>>2]=M,x)|0);M=d[n]|0;L=d[p]|0;K=e[q>>1]|0;J=d[r]|0;N=d[s]|0;sp(33928,(x=i,i=i+48|0,c[x>>2]=d[m]|0,c[x+8>>2]=M,c[x+16>>2]=L,c[x+24>>2]=K,c[x+32>>2]=J,c[x+40>>2]=N,x)|0);N=d[u]|0;J=d[v]|0;K=(c[w>>2]|0)!=0?42:32;L=e[y>>1]|0;sp(33568,(x=i,i=i+40|0,c[x>>2]=d[t]|0,c[x+8>>2]=N,c[x+16>>2]=J,c[x+24>>2]=K,c[x+32>>2]=L,x)|0);L=d[A]|0;K=e[B>>1]|0;sp(33272,(x=i,i=i+32|0,c[x>>2]=d[z]|0,c[x+8>>2]=L,c[x+16>>2]=0,c[x+24>>2]=K,x)|0);K=d[D]|0;L=(c[E>>2]|0)!=0?42:32;J=e[F>>1]|0;sp(32984,(x=i,i=i+40|0,c[x>>2]=d[C]|0,c[x+8>>2]=K,c[x+16>>2]=0,c[x+24>>2]=L,c[x+32>>2]=J,x)|0);break}else{sq(32736);sp(32512,(x=i,i=i+8|0,c[x>>2]=d[G]|0,x)|0);J=0;do{L=d[a+132+J|0]|0;K=d[a+148+J|0]|0;N=d[a+772+J|0]|0;M=d[a+788+J|0]|0;sp(32312,(x=i,i=i+64|0,c[x>>2]=J,c[x+8>>2]=L,c[x+16>>2]=J,c[x+24>>2]=K,c[x+32>>2]=J,c[x+40>>2]=N,c[x+48>>2]=J,c[x+56>>2]=M,x)|0);J=J+1|0;}while(J>>>0<16)}}else{cX(c[I>>2]|0)}}while(0);if((sa(g)|0)!=0){O=292;break}}if((O|0)==292){i=f;return}O=rW(g)|0;sp(42704,(x=i,i=i+8|0,c[x>>2]=O,x)|0);i=f;return}function cX(b){b=b|0;var d=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0.0,p=0,q=0,r=0,s=0,t=0,u=0;d=i;i=i+608|0;f=d|0;g=d+352|0;sq(32096);j=ia(b)|0;k=G;l=ib(b)|0;m=G;n=ic(b)|0;if((j|0)==0&(k|0)==0){o=1.0}else{p=vf(n,0,l,m)|0;o=(+(p>>>0)+ +(G>>>0)*4294967296.0)/(+(j>>>0)+ +(k>>>0)*4294967296.0)}sp(31816,(x=i,i=i+48|0,c[x>>2]=l,c[x+8>>2]=m,c[x+16>>2]=j,c[x+24>>2]=k,c[x+32>>2]=n,h[x+40>>3]=o,x)|0);n=b+148|0;k=e[n>>1]|0;j=ig(b)|0;m=ih(b)|0;l=(ij(b)|0)&65535;p=(e[n>>1]|0)>>>8&7;n=c[b+252>>2]|0;sp(31584,(x=i,i=i+112|0,c[x>>2]=k,c[x+8>>2]=(k&32768|0)!=0?84:45,c[x+16>>2]=(k&8192|0)!=0?83:45,c[x+24>>2]=k&255,c[x+32>>2]=(k&1|0)!=0?67:45,c[x+40>>2]=(k&2|0)!=0?86:45,c[x+48>>2]=(k&4|0)!=0?90:45,c[x+56>>2]=(k&8|0)!=0?78:45,c[x+64>>2]=(k&16|0)!=0?88:45,c[x+72>>2]=j,c[x+80>>2]=m,c[x+88>>2]=l,c[x+96>>2]=p,c[x+104>>2]=n,x)|0);n=c[b+96>>2]|0;p=c[b+112>>2]|0;l=c[b+128>>2]|0;m=b+144|0;j=c[m>>2]|0;sp(31416,(x=i,i=i+40|0,c[x>>2]=c[b+80>>2],c[x+8>>2]=n,c[x+16>>2]=p,c[x+24>>2]=l,c[x+32>>2]=j,x)|0);j=c[b+84>>2]|0;l=c[b+100>>2]|0;p=c[b+116>>2]|0;n=c[b+132>>2]|0;k=ii(b)|0;sp(31280,(x=i,i=i+40|0,c[x>>2]=j,c[x+8>>2]=l,c[x+16>>2]=p,c[x+24>>2]=n,c[x+32>>2]=k,x)|0);k=c[b+104>>2]|0;n=c[b+120>>2]|0;p=c[b+136>>2]|0;l=b+188|0;j=b+140|0;q=c[((a[l]|0)==0?j:b+152|0)>>2]|0;sp(31168,(x=i,i=i+40|0,c[x>>2]=c[b+88>>2],c[x+8>>2]=k,c[x+16>>2]=n,c[x+24>>2]=p,c[x+32>>2]=q,x)|0);q=c[b+92>>2]|0;p=c[b+108>>2]|0;n=c[b+124>>2]|0;k=c[j>>2]|0;if((a[l]|0)!=0){r=k;sp(30968,(x=i,i=i+40|0,c[x>>2]=q,c[x+8>>2]=p,c[x+16>>2]=n,c[x+24>>2]=k,c[x+32>>2]=r,x)|0);s=c[m>>2]|0;fP(b,f,s);t=g|0;c4(t,f);u=c[m>>2]|0;sp(40128,(x=i,i=i+16|0,c[x>>2]=u,c[x+8>>2]=t,x)|0);i=d;return}r=c[b+156>>2]|0;sp(30968,(x=i,i=i+40|0,c[x>>2]=q,c[x+8>>2]=p,c[x+16>>2]=n,c[x+24>>2]=k,c[x+32>>2]=r,x)|0);s=c[m>>2]|0;fP(b,f,s);t=g|0;c4(t,f);u=c[m>>2]|0;sp(40128,(x=i,i=i+16|0,c[x>>2]=u,c[x+8>>2]=t,x)|0);i=d;return}function cY(b){b=b|0;var d=0,e=0,f=0;d=b+4680|0;td(d);dE(b);dL(c[14426]|0,0);dL(c[14426]|0,0);if((c[d>>2]|0)!=0){tc();return}e=b+4676|0;f=b+3480|0;do{if((a[e]|0)!=0){do{s9(5e4)|0;uN(c[f>>2]|0);}while((a[e]|0)!=0)}dL(c[14426]|0,0);dL(c[14426]|0,0);}while((c[d>>2]|0)==0);tc();return}function cZ(a){a=a|0;c[14530]=a;td(a+4680|0);dE(a);bV(4,100,1)|0;return}function c_(a,b,c){a=a|0;b=b|0;c=c|0;return}function c$(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=0;while(1){do{if(((f|0)%100|0|0)==0){az(d|0,e|0)|0;g=c[(c[14530]|0)+4>>2]|0;h=c[e>>2]|0;j=h&65535;if((c[g+36>>2]|0)>>>0>2089){k=g+32|0;a[(c[k>>2]|0)+2088|0]=(j&65535)>>>8&255;a[(c[k>>2]|0)+2089|0]=h&255}else{b3[c[g+24>>2]&63](c[g+4>>2]|0,2088,j)}j=c[(c[14530]|0)+4>>2]|0;g=c[e>>2]|0;h=g&65535;if((c[j+36>>2]|0)>>>0>2093){k=j+32|0;a[(c[k>>2]|0)+2092|0]=(h&65535)>>>8&255;a[(c[k>>2]|0)+2093|0]=g&255}else{b3[c[j+24>>2]&63](c[j+4>>2]|0,2092,h)}h=c[(c[14530]|0)+4>>2]|0;j=c[e>>2]|0;g=j&65535;if((c[h+36>>2]|0)>>>0>2097){k=h+32|0;a[(c[k>>2]|0)+2096|0]=(g&65535)>>>8&255;a[(c[k>>2]|0)+2097|0]=j&255}else{b3[c[h+24>>2]&63](c[h+4>>2]|0,2096,g)}g=c[(c[14530]|0)+4>>2]|0;h=c[d>>2]|0;j=h&65535;if((c[g+36>>2]|0)>>>0>2091){k=g+32|0;a[(c[k>>2]|0)+2090|0]=(j&65535)>>>8&255;a[(c[k>>2]|0)+2091|0]=h&255}else{b3[c[g+24>>2]&63](c[g+4>>2]|0,2090,j)}j=c[(c[14530]|0)+4>>2]|0;g=c[d>>2]|0;h=g&65535;if((c[j+36>>2]|0)>>>0>2095){k=j+32|0;a[(c[k>>2]|0)+2094|0]=(h&65535)>>>8&255;a[(c[k>>2]|0)+2095|0]=g&255}else{b3[c[j+24>>2]&63](c[j+4>>2]|0,2094,h)}h=c[(c[14530]|0)+4>>2]|0;j=c[d>>2]|0;g=j&65535;if((c[h+36>>2]|0)>>>0>2099){k=h+32|0;a[(c[k>>2]|0)+2098|0]=(g&65535)>>>8&255;a[(c[k>>2]|0)+2099|0]=j&255;break}else{b3[c[h+24>>2]&63](c[h+4>>2]|0,2098,g);break}}}while(0);dL(c[14426]|0,0);dL(c[14426]|0,0);g=c[14530]|0;if((c[g+4680>>2]|0)!=0){break}if((a[g+4676|0]|0)!=0){do{s9(5e4)|0;uN(c[(c[14530]|0)+3480>>2]|0);}while((a[(c[14530]|0)+4676|0]|0)!=0)}g=f+1|0;if((g|0)<1e4){f=g}else{l=339;break}}if((l|0)==339){i=b;return}tc();aH()|0;i=b;return}function c0(d,f){d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;g=i;i=i+3032|0;h=g|0;j=g+8|0;k=g+16|0;l=g+1040|0;m=g+1392|0;n=g+1400|0;p=g+1408|0;q=g+1760|0;r=g+2016|0;s=g+2024|0;t=g+2032|0;u=g+2288|0;v=g+2640|0;w=g+2648|0;y=g+3e3|0;z=g+3008|0;A=g+3016|0;B=g+3024|0;C=d+3480|0;D=c[C>>2]|0;if((D|0)!=0){uN(D)}do{if((sb(f,42344)|0)==0){if((sb(f,37880)|0)!=0){c[B>>2]=1;si(f,B)|0;if((se(f)|0)==0){break}if((c[B>>2]|0)!=0){do{dL(d,1);D=(c[B>>2]|0)-1|0;c[B>>2]=D;}while((D|0)!=0)}cX(c[d+4>>2]|0);break}if((sb(f,29800)|0)!=0){if((sb(f,42344)|0)!=0){if((si(f,A)|0)!=0){D=d+28|0;do{r5(D,rZ(c[A>>2]|0)|0)|0;}while((si(f,A)|0)!=0)}if((se(f)|0)==0){break}D=d+4680|0;td(D);dE(d);E=d+4|0;F=d+28|0;do{H=ia(c[E>>2]|0)|0;I=G;do{J=ia(c[E>>2]|0)|0;if(!((J|0)==(H|0)&(G|0)==(I|0))){break}dL(d,0);}while((id(c[E>>2]|0)|0)==0);if((r6(F,0,c[(c[E>>2]|0)+144>>2]&16777215,c[o>>2]|0)|0)!=0){break}}while((c[D>>2]|0)==0);tc();break}if((sb(f,35264)|0)==0){if((se(f)|0)==0){break}cY(d);break}if((sh(f,z)|0)==0){b[z>>1]=-1}if((se(f)|0)==0){break}D=d+4|0;c[(c[D>>2]|0)+272>>2]=256;E=d+4680|0;td(E);dE(d);F=d+28|0;while(1){I=ia(c[D>>2]|0)|0;H=G;do{J=ia(c[D>>2]|0)|0;if(!((J|0)==(I|0)&(G|0)==(H|0))){break}dL(d,0);}while((id(c[D>>2]|0)|0)==0);if((r6(F,0,c[(c[D>>2]|0)+144>>2]&16777215,c[o>>2]|0)|0)!=0){break}if((c[E>>2]|0)!=0){break}H=(b[z>>1]|0)==-1;I=ig(c[D>>2]|0)|0;if(H){if((I|0)==256){continue}else{K=374;break}}else{if((I|0)==(e[z>>1]|0)){K=376;break}else{continue}}}if((K|0)==374){E=ig(c[D>>2]|0)|0;F=ih(c[D>>2]|0)|0;sp(35016,(x=i,i=i+16|0,c[x>>2]=E,c[x+8>>2]=F,x)|0)}else if((K|0)==376){F=ig(c[D>>2]|0)|0;E=ih(c[D>>2]|0)|0;sp(35016,(x=i,i=i+16|0,c[x>>2]=F,c[x+8>>2]=E,x)|0)}tc();break}if((sb(f,53424)|0)!=0){if((sh(f,y)|0)==0){b[y>>1]=2}if((se(f)|0)==0){break}E=d+4|0;ie(c[E>>2]|0,e[y>>1]|0);cX(c[E>>2]|0);break}if((sb(f,51440)|0)!=0){c[v>>2]=1;do{if((sb(f,51440)|0)!=0){c[v>>2]=2;if((sb(f,51440)|0)==0){break}do{c[v>>2]=(c[v>>2]|0)+1;}while((sb(f,51440)|0)!=0)}}while(0);si(f,v)|0;if((se(f)|0)==0){break}D=d+4680|0;td(D);E=d+4|0;L499:do{if((c[v>>2]|0)!=0){F=w|0;I=w+8|0;H=c[E>>2]|0;while(1){fP(H,w,c[H+144>>2]|0);J=c[E>>2]|0;L=c[J+144>>2]|0;do{if((c[F>>2]&4|0)==0){while(1){dL(d,0);if((c[D>>2]|0)!=0){break L499}M=c[E>>2]|0;if((c[M+144>>2]|0)!=(L|0)){N=M;break}}}else{M=c[I>>2]<<1;O=M+L|0;if((M|0)==0){N=J;break}while(1){dL(d,0);if((c[D>>2]|0)!=0){break L499}M=c[E>>2]|0;if((c[M+144>>2]|0)==(O|0)){N=M;break}}}}while(0);J=(c[v>>2]|0)-1|0;c[v>>2]=J;if((J|0)==0){break}else{H=N}}}}while(0);tc();cX(c[E>>2]|0);break}if((sb(f,50008)|0)!=0){if((se(f)|0)==0){break}dK(d);cX(c[d+4>>2]|0);break}if((sb(f,49488)|0)!=0){if((se(f)|0)==0){break}D=d+4680|0;td(D);H=d+4|0;I=d+28|0;F=u|0;while(1){J=ia(c[H>>2]|0)|0;L=G;do{O=ia(c[H>>2]|0)|0;if(!((O|0)==(J|0)&(G|0)==(L|0))){break}dL(d,0);}while((id(c[H>>2]|0)|0)==0);if((r6(I,0,c[(c[H>>2]|0)+144>>2]&16777215,c[o>>2]|0)|0)!=0){break}if((c[D>>2]|0)!=0){break}L=c[H>>2]|0;fP(L,u,c[L+144>>2]|0);if((c[F>>2]&8|0)!=0){K=412;break}}if((K|0)==412){cX(c[H>>2]|0)}tc();break}if((sb(f,48512)|0)!=0){F=t|0;if((sa(f)|0)!=0){cX(c[d+4>>2]|0);break}if((sc(f,F,256)|0)==0){r9(f,36176);break}D=d+4|0;if((it(c[D>>2]|0,F,s)|0)!=0){sp(35912,(x=i,i=i+8|0,c[x>>2]=F,x)|0);break}if((sa(f)|0)!=0){sp(35720,(x=i,i=i+8|0,c[x>>2]=c[s>>2],x)|0);break}if((si(f,s)|0)==0){r9(f,35504);break}if((se(f)|0)==0){break}I=c[D>>2]|0;E=c[s>>2]|0;iu(I,F,E)|0;cX(c[D>>2]|0);break}if((sb(f,46848)|0)!=0){if((sa(f)|0)==0){cW(d,rW(f)|0);break}else{cX(c[d+4>>2]|0);break}}if((sb(f,45752)|0)!=0){c[r>>2]=1;do{if((sb(f,45752)|0)!=0){c[r>>2]=2;if((sb(f,45752)|0)==0){break}do{c[r>>2]=(c[r>>2]|0)+1;}while((sb(f,45752)|0)!=0)}}while(0);si(f,r)|0;if((se(f)|0)==0){break}td(d+4680|0);H=d+4|0;if((c[r>>2]|0)!=0){D=0;do{E=ia(c[H>>2]|0)|0;F=G;do{I=ia(c[H>>2]|0)|0;if(!((I|0)==(E|0)&(G|0)==(F|0))){break}dL(d,0);}while((id(c[H>>2]|0)|0)==0);D=D+1|0;}while(D>>>0<(c[r>>2]|0)>>>0)}tc();cX(c[H>>2]|0);break}if((sb(f,45200)|0)==0){P=1;i=g;return P|0}D=q|0;if(a[7216]|0){Q=c[14532]|0}else{a[7216]=1;F=c[(c[d+4>>2]|0)+144>>2]|0;c[14532]=F;Q=F}c[m>>2]=Q;c[n>>2]=16;if((sb(f,40752)|0)==0){if((si(f,m)|0)!=0){si(f,n)|0}if((se(f)|0)==0){break}if((c[n>>2]|0)==0){R=c[m>>2]|0}else{F=d+4|0;E=p+8|0;I=0;L=c[m>>2]|0;while(1){fP(c[F>>2]|0,p,L);c4(D,p);sp(40128,(x=i,i=i+16|0,c[x>>2]=c[m>>2],c[x+8>>2]=D,x)|0);J=(c[m>>2]|0)+(c[E>>2]<<1)|0;c[m>>2]=J;O=I+1|0;if(O>>>0<(c[n>>2]|0)>>>0){I=O;L=J}else{R=J;break}}}c[14532]=R;break}L=t|0;c[h>>2]=Q;c[j>>2]=16;if((si(f,h)|0)!=0){si(f,j)|0}if((se(f)|0)==0){break}I=c[j>>2]|0;if(I>>>0>256){c[j>>2]=256;S=256}else{S=I}I=c[h>>2]|0;E=(S*-12|0)+I&-2;if(E>>>0>I>>>0){break}I=d+4|0;D=l+8|0;F=0;H=0;J=0;O=5;M=E;while(1){do{if((O|0)==0){c[k+(H<<2)>>2]=M;E=H+1&255;if((E|0)==(F|0)){T=0;U=J;V=F;W=F+1&255;break}else{T=0;U=J+1|0;V=E;W=F;break}}else{T=O-1|0;U=J;V=H;W=F}}while(0);fP(c[I>>2]|0,l,M);E=(c[D>>2]<<1)+M|0;if(E>>>0>(c[h>>2]|0)>>>0){break}else{F=W;H=V;J=U;O=T;M=E}}M=c[j>>2]|0;if(U>>>0>M>>>0){X=U+W-M&255}else{X=W}if((X|0)==(V|0)){break}else{Y=X}do{M=c[k+(Y<<2)>>2]|0;fP(c[I>>2]|0,l,M);c4(L,l);sp(40128,(x=i,i=i+16|0,c[x>>2]=M,c[x+8>>2]=L,x)|0);Y=Y+1&255;}while((Y|0)!=(V|0))}else{r7(f,d+28|0)}}while(0);d=c[C>>2]|0;if((d|0)==0){P=0;i=g;return P|0}uI(d,42024,41688)|0;P=0;i=g;return P|0}function c1(a,b){a=a|0;b=b|0;sV(b,6448,12)|0;sW(b)|0;b=a+4|0;c[(c[b>>2]|0)+60>>2]=a;c[(c[b>>2]|0)+64>>2]=0;c[(c[b>>2]|0)+68>>2]=68;c[(c[b>>2]|0)+72>>2]=326;c[(c[b>>2]|0)+76>>2]=16;return}function c2(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0;e=i;f=a+4|0;a=c[f>>2]|0;g=c[a+144>>2]|0;h=g&16777215;j=h+1|0;k=c[a+36>>2]|0;if(j>>>0<k>>>0){l=c[a+32>>2]|0;m=(d[l+h|0]|0)<<8|(d[l+j|0]|0);n=a;o=k}else{k=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0;h=c[f>>2]|0;m=k;n=h;o=c[h+36>>2]|0}h=m&65535;m=g+2&16777215;k=m+1|0;if(k>>>0<o>>>0){a=c[n+32>>2]|0;p=(d[a+m|0]|0)<<8|(d[a+k|0]|0);q=n;r=o}else{o=b6[c[n+12>>2]&63](c[n+4>>2]|0,m)|0;m=c[f>>2]|0;p=o;q=m;r=c[m+36>>2]|0}m=p&65535;p=g+4&16777215;o=p+1|0;if(o>>>0<r>>>0){n=c[q+32>>2]|0;s=(d[n+p|0]|0)<<8|(d[n+o|0]|0);t=q;u=r}else{r=b6[c[q+12>>2]&63](c[q+4>>2]|0,p)|0;p=c[f>>2]|0;s=r;t=p;u=c[p+36>>2]|0}p=s&65535;s=g+6&16777215;r=s+1|0;if(r>>>0<u>>>0){q=c[t+32>>2]|0;v=(d[q+s|0]|0)<<8|(d[q+r|0]|0);w=t;y=u}else{u=b6[c[t+12>>2]&63](c[t+4>>2]|0,s)|0;s=c[f>>2]|0;v=u;w=s;y=c[s+36>>2]|0}s=v&65535;v=g+8&16777215;u=v+1|0;if(u>>>0<y>>>0){y=c[w+32>>2]|0;z=(d[y+v|0]|0)<<8|(d[y+u|0]|0);A=z&65535;sL(3,41024,(x=i,i=i+56|0,c[x>>2]=g,c[x+8>>2]=b,c[x+16>>2]=h,c[x+24>>2]=m,c[x+32>>2]=p,c[x+40>>2]=s,c[x+48>>2]=A,x)|0);i=e;return}else{z=b6[c[w+12>>2]&63](c[w+4>>2]|0,v)|0;A=z&65535;sL(3,41024,(x=i,i=i+56|0,c[x>>2]=g,c[x+8>>2]=b,c[x+16>>2]=h,c[x+24>>2]=m,c[x+32>>2]=p,c[x+40>>2]=s,c[x+48>>2]=A,x)|0);i=e;return}}function c3(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=a+4|0;g=c[f>>2]|0;h=c[g+144>>2]&16777215;j=h+1|0;if(j>>>0<(c[g+36>>2]|0)>>>0){k=c[g+32>>2]|0;l=(d[k+h|0]|0)<<8|(d[k+j|0]|0)}else{l=b6[c[g+12>>2]&63](c[g+4>>2]|0,h)|0}if((b|0)==10){fp(a+2424|0);i=e;return}else if((b|0)==0){dK(a);i=e;return}else if((b|0)==25|(b|0)==26|(b|0)==32|(b|0)==39|(b|0)==40|(b|0)==41|(b|0)==42|(b|0)==43|(b|0)==44|(b|0)==46){i=e;return}else{a=c[f>>2]|0;f=c[a+144>>2]|0;h=ih(a)|0;sL(3,41440,(x=i,i=i+32|0,c[x>>2]=f,c[x+8>>2]=b,c[x+16>>2]=h,c[x+24>>2]=l&65535,x)|0);i=e;return}}function c4(b,d){b=b|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+256|0;g=f|0;h=g|0;a[b]=0;j=d+8|0;if((c[j>>2]|0)==0){k=0;l=513}else{m=g;n=0;do{a2(m|0,39792,(x=i,i=i+8|0,c[x>>2]=e[d+12+(n<<1)>>1]|0,x)|0)|0;u9(b|0,m|0)|0;n=n+1|0;o=c[j>>2]|0;}while(n>>>0<o>>>0);if(o>>>0<4){k=o;l=513}}if((l|0)==513){while(1){l=0;o=b+(u8(b|0)|0)|0;a[o]=a[39448]|0;a[o+1|0]=a[39449|0]|0;a[o+2|0]=a[39450|0]|0;a[o+3|0]=a[39451|0]|0;a[o+4|0]=a[39452|0]|0;a[o+5|0]=a[39453|0]|0;o=k+1|0;if(o>>>0<4){k=o;l=513}else{break}}}l=c[d>>2]|0;do{if((l&1|0)==0){if((l&4|0)!=0){k=b+(u8(b|0)|0)|0;y=62;a[k]=y&255;y=y>>8;a[k+1|0]=y&255;break}k=b+(u8(b|0)|0)|0;if((l&16|0)==0){y=32;a[k]=y&255;y=y>>8;a[k+1|0]=y&255;break}else{y=60;a[k]=y&255;y=y>>8;a[k+1|0]=y&255;break}}else{k=b+(u8(b|0)|0)|0;y=42;a[k]=y&255;y=y>>8;a[k+1|0]=y&255}}while(0);l=fx(e[d+12>>1]|0)|0;k=(l|0)==0?d+32|0:l;l=c[d+28>>2]|0;if((l|0)==3){o=g;n=d+96|0;j=d+160|0;m=d+224|0;a2(o|0,37064,(x=i,i=i+32|0,c[x>>2]=k,c[x+8>>2]=n,c[x+16>>2]=j,c[x+24>>2]=m,x)|0)|0;p=o}else if((l|0)==0){o=g;m=(u8(k|0)|0)+1|0;u7(o|0,k|0,m)|0;p=o}else if((l|0)==1){o=g;a2(o|0,37872,(x=i,i=i+16|0,c[x>>2]=k,c[x+8>>2]=d+96,x)|0)|0;p=o}else if((l|0)==2){l=g;a2(l|0,37624,(x=i,i=i+24|0,c[x>>2]=k,c[x+8>>2]=d+96,c[x+16>>2]=d+160,x)|0)|0;p=l}else{c[h>>2]=2960685;p=g}u9(b|0,p|0)|0;p=d+288|0;if((a[p]|0)==0){i=f;return}d=u8(b|0)|0;g=b+d|0;if(d>>>0<50){u6(g|0,32,50-d|0);q=b+50|0}else{q=g}a[q]=a[36448]|0;a[q+1|0]=a[36449|0]|0;a[q+2|0]=a[36450|0]|0;u9(q|0,p|0)|0;i=f;return}function c5(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=a;f=a+4|0;g=(c[f>>2]|0)+144|0;c[g>>2]=(c[g>>2]|0)+4;if((b|0)==2){eh(e,46152,51584)|0;h=0;i=d;return h|0}else if((b|0)==4){sL(2,42760,(x=i,i=i+8|0,c[x>>2]=c[(c[f>>2]|0)+144>>2],x)|0);h=0;i=d;return h|0}else if((b|0)==0){h=0;i=d;return h|0}else if((b|0)==3){g=a+2424|0;fq(g,1);fq(g,2);fq(g,3);fq(g,4);h=0;i=d;return h|0}else if((b|0)==1){eh(e,39072,51584)|0;h=0;i=d;return h|0}else{e=c[f>>2]|0;g=a+2628|0;c[g>>2]=c[e+80>>2];j=a+2632|0;c[j>>2]=c[e+112>>2];k=a+2636|0;c[k>>2]=c[e+116>>2];l=a+2640|0;c[l>>2]=c[e+144>>2];if((fs(a+2424|0,b)|0)==0){c[(c[f>>2]|0)+80>>2]=c[g>>2];c[(c[f>>2]|0)+112>>2]=c[j>>2];c[(c[f>>2]|0)+116>>2]=c[k>>2];c[(c[f>>2]|0)+144>>2]=c[l>>2];h=0;i=d;return h|0}else{d$(39104,(x=i,i=i+8|0,c[x>>2]=b,x)|0);h=1;i=d;return h|0}}return 0}function c6(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=i;if((d|0)==2){eh(b,36768,50912)|0;i=e;return 0}else if((d|0)==39){dB(b,7,1);dB(b,7,0);i=e;return 0}else if((d|0)==4){eh(b,36768,42424)|0;i=e;return 0}else if((d|0)==5){eh(b,36768,38904)|0;i=e;return 0}else if((d|0)==3){eh(b,36768,45848)|0;i=e;return 0}else if((d|0)==53|(d|0)==91){f=b+1744|0;g=c[f>>2]|0;do{if((g|0)!=0){if((a[g+280|0]|0)==0){d$(33048,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);dw(c[f>>2]|0,0);break}else{d$(35952,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);dw(c[f>>2]|0,1);break}}}while(0);f=b+1752|0;b=c[f>>2]|0;if((b|0)==0){i=e;return 0}if((cz(b)|0)==0){d$(35952,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);cy(c[f>>2]|0,1);i=e;return 0}else{d$(33048,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);cy(c[f>>2]|0,0);i=e;return 0}}else{sL(2,31136,(x=i,i=i+8|0,c[x>>2]=d,x)|0);i=e;return 0}return 0}function c7(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=i;e=b+20|0;a[e]=0;f=c[b+4>>2]|0;do{if((f|0)==0){g=578}else{h=pM(f,0)|0;if((h|0)==0){g=578;break}a[e]=1;d$(30880,(x=i,i=i+8|0,c[x>>2]=(c[b>>2]|0)+1,x)|0);j=h}}while(0);L743:do{if((g|0)==578){e=ol(c[b+8>>2]|0,c[b+12>>2]|0)|0;L745:do{if((e|0)!=0){L747:do{if((n1(e)|0)==6){k=0;l=c[(c[e+64>>2]|0)+68>>2]|0}else{f=n8(e)|0;if((f|0)==1600){m=2}else if((f|0)==800){m=1}else{break L745}f=qs()|0;if((f|0)==0){break L745}else{n=0;o=0}L753:while(1){h=o>>>4;p=12-h|0;if((h|0)==12){q=n}else{h=0;r=n;while(1){s=0;t=r;do{u=qh(o,h,s,512)|0;if((u|0)==0){g=590;break L753}qw(f,u,o,h)|0;if((oo(e,c[u+24>>2]|0,t,1)|0)!=0){g=591;break L753}t=t+1|0;s=s+1|0;}while(s>>>0<p>>>0);s=h+1|0;if(s>>>0<m>>>0){h=s;r=t}else{q=t;break}}}r=o+1|0;if(r>>>0<80){n=q;o=r}else{k=f;l=f;break L747}}if((g|0)==590){qt(f);break L745}else if((g|0)==591){qt(f);break L745}}}while(0);if((l|0)==0){break}r=pI(l)|0;qt(k);if((r|0)==0){break}d$(49536,(x=i,i=i+8|0,c[x>>2]=(c[b>>2]|0)+1,x)|0);j=r;break L743}}while(0);d$(45168,(x=i,i=i+8|0,c[x>>2]=(c[b>>2]|0)+1,x)|0);v=1;i=d;return v|0}}while(0);k=b+16|0;pS(c[k>>2]|0);c[k>>2]=j;a[b+92|0]=0;c[b+48>>2]=0;v=0;i=d;return v|0}function c8(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;e=i;i=i+512|0;f=e|0;g=d+16|0;if((c[g>>2]|0)==0){h=1;i=e;return h|0}j=d|0;d$(41704,(x=i,i=i+8|0,c[x>>2]=(c[j>>2]|0)+1,x)|0);L778:do{if((a[d+20|0]|0)==0){k=ol(c[d+8>>2]|0,c[d+12>>2]|0)|0;do{if((k|0)!=0){l=px(c[g>>2]|0)|0;if((l|0)==0){break}if((n1(k)|0)==6){m=c[k+64>>2]|0;n=m+68|0;qt(c[n>>2]|0);c[n>>2]=l;a[m+72|0]=1;break L778}m=f|0;n=n8(k)|0;if((n|0)==1600){o=2}else if((n|0)==800){o=1}else{qt(l);break}n=0;p=0;L790:while(1){q=12-(n>>>4)|0;r=0;s=p;do{t=0;while(1){if(t>>>0>=q>>>0){break}u=qp(l,n,r,t,0)|0;if((u|0)==0){u6(m|0,0,512)}else{v=b[u+10>>1]|0;w=v&65535;if((v&65535)<512){u6(f+w|0,0,512-w|0);y=w}else{y=512}w=c[u+24>>2]|0;u7(m|0,w|0,y)|0}if((op(k,m,t+s|0,1)|0)==0){t=t+1|0}else{z=626;break L790}}s=s+q|0;r=r+1|0;}while(r>>>0<o>>>0);r=n+1|0;if(r>>>0<80){n=r;p=s}else{z=624;break}}if((z|0)==624){qt(l);break L778}else if((z|0)==626){qt(l);break}}}while(0);d$(35360,(x=i,i=i+8|0,c[x>>2]=(c[j>>2]|0)+1,x)|0);h=1;i=e;return h|0}else{k=c[d+4>>2]|0;if((k|0)!=0){if((pN(k,c[g>>2]|0,0)|0)==0){break}}d$(38320,(x=i,i=i+8|0,c[x>>2]=(c[j>>2]|0)+1,x)|0);h=1;i=e;return h|0}}while(0);a[d+92|0]=0;h=0;i=e;return h|0}function c9(a,b,d){a=a|0;b=b|0;d=d|0;c[a+320>>2]=b;c[a+324>>2]=d;return}function da(a,b){a=a|0;b=b|0;c[a+32>>2]=b;c[a+128>>2]=b;c[a+224>>2]=b;return}function db(a,b,d){a=a|0;b=b|0;d=d|0;if(b>>>0>=3){return}c[a+24+(b*96|0)+12>>2]=d;return}function dc(b,c){b=b|0;c=c|0;var d=0;if(c>>>0>2){d=1;return d|0}d=(a[b+24+(c*96|0)+21|0]|0)!=0|0;return d|0}function dd(b,c,d){b=b|0;c=c|0;d=d|0;if(c>>>0>2){return}a[b+24+(c*96|0)+21|0]=(d|0)!=0|0;return}function de(b,c,d){b=b|0;c=c|0;d=d|0;if(c>>>0>2){return}a[b+24+(c*96|0)+22|0]=(d|0)!=0|0;return}function df(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=b+20|0;h=c[g>>2]|0;if((f|0)==0){i=h}else{j=f;f=h;h=e;while(1){e=(((d[6128+(a[h]&63)|0]|0)<<10)+(f*31|0)|0)>>>5;k=j-1|0;if((k|0)==0){i=e;break}else{j=k;f=e;h=h+1|0}}}c[g>>2]=i;c[(c[b+312>>2]|0)+88>>2]=i;return}function dg(b){b=b|0;a[b|0]=0;a[b+1|0]=0;a[b+3|0]=0;a[b+4|0]=0;a[b+5|0]=127;a[b+6|0]=0;u6(b+8|0,0,39);c[b+48>>2]=80;c[b+52>>2]=1;u6(b+56|0,0,5);u6(b+64|0,0,24);c[b+88>>2]=65e3;c[b+92>>2]=0;c[b+96>>2]=0;c[b+100>>2]=0;c[b+104>>2]=783360;c[b+108>>2]=0;a[b+116|0]=0;c[b+120>>2]=1;c[b+124>>2]=0;c[b+128>>2]=0;c[b+132>>2]=1;u6(b+136|0,0,7);c[b+144>>2]=80;c[b+148>>2]=1;u6(b+152|0,0,5);u6(b+160|0,0,24);c[b+184>>2]=65e3;c[b+188>>2]=0;c[b+192>>2]=0;c[b+196>>2]=0;c[b+200>>2]=783360;c[b+204>>2]=0;a[b+212|0]=0;c[b+216>>2]=2;c[b+220>>2]=0;c[b+224>>2]=0;c[b+228>>2]=2;u6(b+232|0,0,7);c[b+240>>2]=80;c[b+244>>2]=1;u6(b+248|0,0,5);u6(b+256|0,0,24);c[b+280>>2]=65e3;c[b+284>>2]=0;c[b+288>>2]=0;c[b+292>>2]=0;c[b+296>>2]=783360;c[b+300>>2]=0;a[b+308|0]=0;c[b+312>>2]=b+24;a[b+316|0]=0;c[b+320>>2]=0;c[b+324>>2]=0;return}function dh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if(b>>>0>2|d>>>0>2){e=1;return e|0}c[a+24+(b*96|0)+28>>2]=d;if((c[a+24+(b*96|0)+44>>2]|0)>>>0<d>>>0){e=0;return e|0}di(a+24+(b*96|0)|0,c[a+24+(b*96|0)+40>>2]|0,0);e=0;return e|0}function di(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;if((c[a+24>>2]|0)>>>0<=b>>>0){return}if((c[a+28>>2]|0)>>>0<=d>>>0){return}e=a+16|0;f=c[e>>2]|0;if((f|0)==0){g=pR()|0;c[e>>2]=g;h=g}else{h=f}f=pV(h,b,d,1)|0;if((f|0)==0){return}h=f+4|0;do{if((c[h>>2]|0)==0){if((pO(f,c[15544+((b>>>0>79?4:b>>>4)<<2)>>2]|0)|0)==0){break}return}}while(0);if((c[f>>2]|0)==0){pC(f,5e5)}c[a+40>>2]=b;c[a+44>>2]=d;c[a+48>>2]=f;f=c[h>>2]|0;c[a+56>>2]=f;h=a+52|0;if((c[h>>2]|0)>>>0<f>>>0){return}c[h>>2]=0;return}function dj(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;if(d>>>0>2){return}f=b+24+(d*96|0)+4|0;u1(c[f>>2]|0);c[f>>2]=0;a[b+24+(d*96|0)+20|0]=0;if((e|0)==0){return}d=(u8(e|0)|0)+1|0;b=u0(d)|0;if((b|0)==0){return}u7(b|0,e|0,d)|0;c[f>>2]=b;return}function dk(b,e){b=b|0;e=e|0;var f=0;f=e<<24>>24!=0;e=b+2|0;if((d[e]|0|0)==(f&1|0)){return}a[e]=f&1;if((a[b|0]&32)!=0){return}e=f?2:0;f=b+24+(e*96|0)|0;c[b+312>>2]=f;di(f,c[b+24+(e*96|0)+40>>2]|0,d[b+1|0]|0);return}function dl(b,e){b=b|0;e=e|0;var f=0,g=0;f=e<<24>>24!=0;e=b+1|0;g=f&1;if((d[e]|0|0)==(g|0)){return}a[e]=f&1;f=c[b+312>>2]|0;if((c[f+44>>2]|0)==(g|0)){return}di(f,c[f+40>>2]|0,g);return}function dm(b,d){b=b|0;d=d|0;var e=0,f=0;if(d>>>0>2){return}e=b+24+(d*96|0)|0;f=b+24+(d*96|0)+34|0;if((a[f]|0)!=0){return}if((c7(e)|0)!=0){return}a[f]=1;di(e,c[b+24+(d*96|0)+40>>2]|0,c[b+24+(d*96|0)+44>>2]|0);return}function dn(b,f){b=b|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((f&1|0)==0){g=0;return g|0}ds(b,f>>>9&15);f=d[b|0]|0;h=f&192;if((h|0)==0){if((f&16|0)==0){g=-1;return g|0}i=b+13|0;j=a[i]|0;a[i]=0;g=j;return g|0}else if((h|0)==64){j=a[b+4|0]&31|a[b+3|0]&96;i=c[b+312>>2]|0;k=((a[b+1|0]|0)!=0?8:0)|f&7;if((k|0)==1){f=i+33|0;l=a[f]|0;a[f]=0;m=l<<24>>24==0|0;n=737}else if((k|0)==3){m=(a[i+35|0]|0)!=0|0;n=737}else if((k|0)==6){m=(c[i+28>>2]|0)>>>0>1|0;n=737}else if((k|0)==0){m=(a[i+32|0]|0)==0|0;n=737}else if((k|0)==2){m=(a[i+36|0]|0)==0|0;n=737}else if((k|0)==8){m=(a[i+34|0]|0)==0|0;n=737}else if((k|0)==9){l=a[i+21|0]|0;do{if((a[i+20|0]|0)==0){f=ol(c[i+8>>2]|0,c[i+12>>2]|0)|0;if((f|0)==0){o=l;break}o=(n3(f)|0)==0?l:1}else{o=l}}while(0);m=(o|0)==0|0;n=737}else if((k|0)==10){m=(c[i+40>>2]|0)!=0|0;n=737}else if((k|0)==11){if((c[i+28>>2]|0)==1){o=ac(((65536-(c[i+88>>2]|0)|0)*120|0)>>>15,c[i+60>>2]|0)|0;p=(o>>>0)/((c[i+64>>2]|0)>>>0)|0}else{p=(((c[i+52>>2]|0)*120|0)>>>0)/((c[i+56>>2]|0)>>>0)|0}m=p&1^1;n=737}else if((k|0)==4|(k|0)==5|(k|0)==7|(k|0)==12|(k|0)==14){g=j;return g|0}do{if((n|0)==737){if((m|0)==0){g=j}else{break}return g|0}}while(0);g=j|-128;return g|0}else if((h|0)==128){h=a[b+5|0]|0;return((e[b+14>>1]|0)<256?h|-128:h&127)|0}else{g=0;return g|0}return 0}function dp(a,b,d){a=a|0;b=b|0;d=d|0;c[a+288>>2]=b;c[a+292>>2]=d;return}function dq(a,b,d){a=a|0;b=b|0;d=d|0;c[a+296>>2]=b;c[a+300>>2]=d;return}function dr(a,b,d){a=a|0;b=b|0;d=d|0;c[a+276>>2]=b;c[a+284>>2]=(d|0)==0?10288:12352;return 0}function ds(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;g=e&15;if((g|0)==3){e=b|0;a[e]=a[e]|2;h=e}else if((g|0)==2){e=b|0;a[e]=a[e]&-3;h=e}else if((g|0)==4){e=b|0;a[e]=a[e]&-5;h=e}else if((g|0)==0){e=b|0;a[e]=a[e]&-2;h=e}else if((g|0)==1){e=b|0;a[e]=a[e]|1;h=e}else if((g|0)==5){e=b|0;a[e]=a[e]|4;h=e}else if((g|0)==6){e=b|0;a[e]=a[e]&-9;h=e}else if((g|0)==7){e=b|0;a[e]=a[e]|8;h=e}else if((g|0)==8){e=b|0;a[e]=a[e]&-17;j=b+3|0;a[j]=a[j]&-33;h=e}else if((g|0)==9){e=b|0;a[e]=a[e]|16;j=b+3|0;a[j]=a[j]|32;h=e}else if((g|0)==10){e=b|0;a[e]=a[e]&-33;j=(a[b+2|0]|0)!=0?2:0;k=b+24+(j*96|0)|0;c[b+312>>2]=k;di(k,c[b+24+(j*96|0)+40>>2]|0,d[b+1|0]|0);h=e}else if((g|0)==11){e=b|0;a[e]=a[e]|32;j=b+120|0;c[b+312>>2]=j;di(j,c[b+160>>2]|0,d[b+1|0]|0);h=e}else if((g|0)==12){e=b|0;a[e]=a[e]&-65;h=e}else if((g|0)==13){e=b|0;a[e]=a[e]|64;h=e}else if((g|0)==14){e=b|0;a[e]=a[e]&127;h=e}else if((g|0)==15){g=b|0;a[g]=a[g]|-128;h=g}else{h=b|0}g=a[h]|0;if((g&8)==0){l=g}else{e=g&255;g=((a[b+1|0]|0)!=0?4:0)|e&3;j=e&4;e=(j|0)!=0;k=j>>>2;j=c[b+312>>2]|0;do{if((g|0)==0){a[j+32|0]=(k^1)&255}else if((g|0)==1){if((k|0)!=0){break}m=j+40|0;n=c[m>>2]|0;do{if((a[j+32|0]|0)==0){if((n|0)==0){o=0;break}p=n-1|0;c[m>>2]=p;o=p}else{p=n+1|0;if(p>>>0>=(c[j+24>>2]|0)>>>0){o=n;break}c[m>>2]=p;o=p}}while(0);a[j+33|0]=1;di(j,o,c[j+44>>2]|0);n=c[m>>2]|0;sp(49112,(x=i,i=i+16|0,c[x>>2]=(c[j>>2]|0)+1,c[x+8>>2]=n,x)|0)}else if((g|0)==2){n=j+36|0;p=k^1;if((a[n]|0)==(p|0)){q=0}else{a[n]=p&255;q=0}while(1){if(q>>>0>=3){r=0;break}if((a[b+24+(q*96|0)+36|0]|0)==0){q=q+1|0}else{r=1;break}}m=b+316|0;if((a[m]|0)==r<<24>>24){break}a[m]=r;m=c[b+324>>2]|0;if((m|0)==0){break}b1[m&511](c[b+320>>2]|0,r)}else if((g|0)==3){if(!e){break}a[j+34|0]=0;d$(30176,(x=i,i=i+8|0,c[x>>2]=(c[j>>2]|0)+1,x)|0);if((a[j+92|0]|0)==0){break}c8(j)|0}else if((g|0)==4){if(!e){break}a[j+35|0]=0}}while(0);l=a[h]|0}if(l<<24>>24<=-1){i=f;return}l=b+5|0;a[l]=a[l]|64;l=b+6|0;if((a[l]|0)==0){i=f;return}a[l]=0;l=c[b+312>>2]|0;b=l+76|0;do{if((c[b>>2]|0)>>>0>(c[l+56>>2]|0)>>>0){if((a[l+22|0]|0)==0){break}h=c[l+48>>2]|0;j=l+52|0;e=c[j>>2]|0;pP(h,e)|0;c[j>>2]=0}}while(0);c[b>>2]=0;i=f;return}function dt(e,f,g){e=e|0;f=f|0;g=g|0;if((f&1|0)==0){return}ds(e,f>>>9&15);f=d[e|0]|0;if((f&192|0)!=192){return}if((f&16|0)==0){a[e+4|0]=g;return}f=e+6|0;if((a[f]|0)==0){a[f]=1;c[e+8>>2]=0;c[(c[e+312>>2]|0)+76>>2]=0}b[e+14>>1]=g&255|-256;return}function du(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=c[e+312>>2]|0;if((a[g+36|0]|0)==0){return}h=g+84|0;i=(c[h>>2]|0)+(f*5e5|0)|0;f=c[g+80>>2]|0;j=(i>>>0)/(f>>>0)|0;c[h>>2]=(i>>>0)%(f>>>0)|0;f=g+56|0;i=c[f>>2]|0;if((i|0)==0){k=0}else{h=g+52|0;l=(c[h>>2]|0)+j|0;while(1){if(l>>>0<i>>>0){break}else{l=l-i|0}}c[h>>2]=l;k=i}i=c[g+64>>2]|0;do{if((i|0)!=0){l=g+60|0;h=(c[l>>2]|0)+j|0;c[l>>2]=h;if(h>>>0<i>>>0){break}c[l>>2]=h-i}}while(0);i=e+6|0;L1044:do{if((a[i]|0)==0){if((d[e|0]|0)>=64){break}j=c[g+48>>2]|0;if((j|0)==0|(k|0)==0){break}h=g+68|0;l=c[h>>2]|0;m=c[j+8>>2]|0;j=g+52|0;if((l|0)==(c[j>>2]|0)){break}n=e+12|0;o=e+16|0;p=e+13|0;q=128>>>((l&7)>>>0)&255;r=l>>>3;l=a[n]|0;while(1){s=l<<1;t=(a[m+r|0]&q)<<24>>24!=0;a[n]=t&1|s;do{if(t){c[o>>2]=0}else{u=(c[o>>2]|0)+1|0;c[o>>2]=u;if(u>>>0<=7){break}c[o>>2]=0;a[n]=s|1}}while(0);s=(c[h>>2]|0)+1|0;c[h>>2]=s;do{if(s>>>0<(c[f>>2]|0)>>>0){if(q<<24>>24==1){v=r+1|0;w=-128;x=s;break}else{v=r;w=(q&255)>>>1;x=s;break}}else{c[h>>2]=0;v=0;w=-128;x=0}}while(0);s=a[n]|0;if(s<<24>>24<0){a[p]=s;a[n]=0;y=0;z=c[h>>2]|0}else{y=s;z=x}if((z|0)==(c[j>>2]|0)){break}else{q=w;r=v;l=y}}}else{l=g+48|0;r=c[l>>2]|0;if((r|0)==0|(k|0)==0){break}q=g+72|0;j=c[q>>2]|0;h=c[r+8>>2]|0;r=g+52|0;n=e+8|0;p=e+14|0;o=e+12|0;m=g+92|0;s=g+76|0;t=j>>>3;u=128>>>((j&7)>>>0)&255;A=j;L1047:while(1){j=h+t|0;B=u;C=A;while(1){if((C|0)==(c[r>>2]|0)){break L1044}if((c[n>>2]|0)==0){D=b[p>>1]|0;if((D&65535)<256){break L1047}E=D&255;a[o]=E;c[n>>2]=8;b[p>>1]=0;F=E}else{F=a[o]|0}if(F<<24>>24<0){G=a[j]|B}else{G=a[j]&~B}a[j]=G;a[m]=1;a[o]=a[o]<<1;c[n>>2]=(c[n>>2]|0)-1;H=(c[q>>2]|0)+1|0;c[q>>2]=H;c[s>>2]=(c[s>>2]|0)+1;if(H>>>0>=(c[f>>2]|0)>>>0){I=839;break}if(B<<24>>24==1){I=842;break}B=(B&255)>>>1;C=H}if((I|0)==842){I=0;t=t+1|0;u=-128;A=H;continue}else if((I|0)==839){I=0;c[q>>2]=0;t=0;u=-128;A=0;continue}}A=e+5|0;a[A]=a[A]&-65;c[n>>2]=0;a[i]=0;do{if((c[s>>2]|0)>>>0>(c[f>>2]|0)>>>0){if((a[g+22|0]|0)==0){break}A=c[l>>2]|0;u=c[r>>2]|0;pP(A,u)|0;c[r>>2]=0}}while(0);c[s>>2]=0}}while(0);f=c[g+52>>2]|0;c[g+68>>2]=f;c[g+72>>2]=f;return}function dv(){var b=0,d=0;b=u0(304)|0;if((b|0)==0){d=0;return d|0}a[b+264|0]=0;c[b>>2]=0;c[b+4>>2]=0;u6(b+268|0,0,13);u6(b+288|0,0,16);c[b+284>>2]=10288;d=b;return d|0}function dw(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c[b+284>>2]|0;if((d|0)==0){d=c[3610]|0;if((d|0)!=0){f=14440;g=d;do{d=e;while(1){h=c[d>>2]|0;if((h|0)==0){break}if((h|0)==(g|0)){i=880;break}else{d=d+24|0}}if((i|0)==880){i=0;h=d;j=f;c[h>>2]=c[j>>2];c[h+4>>2]=c[j+4>>2];c[h+8>>2]=c[j+8>>2];c[h+12>>2]=c[j+12>>2];c[h+16>>2]=c[j+16>>2];c[h+20>>2]=c[j+20>>2]}f=f+24|0;g=c[f>>2]|0;}while((g|0)!=0)}a[b+280|0]=1;return}else{g=c[3748]|0;if((g|0)!=0){f=14992;j=g;do{g=e;while(1){h=c[g>>2]|0;if((h|0)==0){break}if((h|0)==(j|0)){i=873;break}else{g=g+24|0}}if((i|0)==873){i=0;d=g;h=f;c[d>>2]=c[h>>2];c[d+4>>2]=c[h+4>>2];c[d+8>>2]=c[h+8>>2];c[d+12>>2]=c[h+12>>2];c[d+16>>2]=c[h+16>>2];c[d+20>>2]=c[h+20>>2]}f=f+24|0;j=c[f>>2]|0;}while((j|0)!=0)}a[b+280|0]=0;return}}function dx(b,c){b=b|0;c=c|0;a[b+264|0]=c;return}function dy(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;if((f|0)==2){h=71}else{h=(f|0)==3?75:f}f=c[d+284>>2]|0;while(1){j=c[f>>2]|0;k=(j|0)==0;if(k|(j|0)==(h|0)){break}else{f=f+24|0}}if(k){k=uq(h)|0;sL(2,30016,(x=i,i=i+16|0,c[x>>2]=h,c[x+8>>2]=(k|0)!=0?k:49064,x)|0);i=g;return}if((e|0)==1){k=b[f+4>>1]|0;h=k&65535;if(k<<16>>16==0){i=g;return}k=d+4|0;j=d|0;l=0;m=c[k>>2]|0;while(1){if(m>>>0>255){n=m}else{a[((c[j>>2]|0)+m&255)+(d+8)|0]=a[f+6+l|0]|0;o=(c[k>>2]|0)+1|0;c[k>>2]=o;n=o}o=l+1|0;if(o>>>0<h>>>0){l=o;m=n}else{break}}i=g;return}else if((e|0)==2){e=b[f+14>>1]|0;n=e&65535;if(e<<16>>16==0){i=g;return}e=d+4|0;m=d|0;l=0;h=c[e>>2]|0;while(1){if(h>>>0>255){p=h}else{a[((c[m>>2]|0)+h&255)+(d+8)|0]=a[f+16+l|0]|0;k=(c[e>>2]|0)+1|0;c[e>>2]=k;p=k}k=l+1|0;if(k>>>0<n>>>0){l=k;h=p}else{break}}i=g;return}else{i=g;return}}function dz(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=d&255;if((f|0)==20){c[b+268>>2]=0;c[b+272>>2]=1;i=e;return}else if((f|0)==16){c[b+268>>2]=1958400;c[b+272>>2]=1;i=e;return}else if((f|0)==22){c[b>>2]=0;c[b+4>>2]=1;a[b+8|0]=(c[b+276>>2]<<1&14|1)&255;c[b+268>>2]=0;c[b+272>>2]=1;i=e;return}else{d$(44896,(x=i,i=i+8|0,c[x>>2]=f,x)|0);i=e;return}}function dA(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;if((a[b+264|0]|0)==0){return}e=b+272|0;if((c[e>>2]|0)==0){return}f=b+4|0;g=c[f>>2]|0;if((g|0)!=0){h=b|0;i=c[b+292>>2]|0;if((i|0)==0){j=g}else{b1[i&511](c[b+288>>2]|0,a[(c[h>>2]|0)+(b+8)|0]|0);j=c[f>>2]|0}c[h>>2]=(c[h>>2]|0)+1&255;c[f>>2]=j-1;c[e>>2]=0;c[b+268>>2]=0;return}j=b+268|0;f=c[j>>2]|0;if(f>>>0>d>>>0){c[j>>2]=f-d;return}d=c[b+292>>2]|0;if((d|0)!=0){b1[d&511](c[b+288>>2]|0,123)}c[e>>2]=0;return}function dB(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0;g=1<<e;if((f|0)==0){f=b+4652|0;e=(d[f]|0)&(g^255)&255;a[f]=e;h=e}else{e=b+4652|0;f=(d[e]|0|g)&255;a[e]=f;h=f}f=h&255;h=0;while(1){e=f>>>1;if((e|0)==0){break}else{f=e;h=h+1|0}}ix(c[b+4>>2]|0,h,0,1);return}function dC(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;if(e<<24>>24==0){return}do{if((fr(d+2424|0)|0)!=0){e=d+4|0;f=c[e>>2]|0;if((b[f+148>>1]&1792)==1792){break}g=(c[f+140>>2]|0)-4|0;h=c[f+144>>2]|0;i=g&16777215;j=i+3|0;if(j>>>0<(c[f+36>>2]|0)>>>0){k=f+32|0;a[(c[k>>2]|0)+i|0]=h>>>24&255;a[(c[k>>2]|0)+(i+1)|0]=h>>>16&255;a[(c[k>>2]|0)+(i+2)|0]=h>>>8&255;a[(c[k>>2]|0)+j|0]=h&255}else{b3[c[f+28>>2]&63](c[f+4>>2]|0,i,h)}c[(c[e>>2]|0)+140>>2]=g;c[(c[e>>2]|0)+144>>2]=c[d+2468>>2]}}while(0);e=d+36|0;mC(e,0);mC(e,1);return}function dD(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0;e=i;i=i+400|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+32|0;l=e+40|0;m=e+48|0;n=e+56|0;o=e+64|0;p=e+72|0;q=e+80|0;r=e+112|0;s=e+120|0;t=e+128|0;u=e+136|0;v=e+144|0;w=e+152|0;y=e+160|0;z=e+168|0;A=e+176|0;B=e+184|0;C=e+192|0;D=e+200|0;E=e+208|0;F=e+216|0;G=e+224|0;H=e+232|0;I=e+240|0;J=e+248|0;K=e+256|0;L=e+264|0;M=e+272|0;N=e+280|0;O=e+288|0;P=e+296|0;Q=e+304|0;R=e+312|0;S=e+320|0;T=e+328|0;U=e+336|0;V=e+344|0;W=e+352|0;X=e+360|0;Y=e+368|0;Z=e+376|0;_=e+384|0;$=e+392|0;aa=b+3480|0;c[aa>>2]=0;ab=b+3476|0;c[ab>>2]=0;c[b+4632>>2]=0;a[b+4652|0]=0;a[b+4676|0]=0;c[b+4680>>2]=0;ad=b+4684|0;u6(b+4656|0,0,14);c[ad>>2]=1;ae=b+4688|0;c[ae>>2]=1;af=b+4696|0;c[af>>2]=0;c[b+4692>>2]=0;u6(b+4712|0,0,24);rU(b+28|0);ag=tz(d,0,55040)|0;tK((ag|0)==0?d:ag,32952,$,54976)|0;sN(2,54936,54864,(x=i,i=i+8|0,c[x>>2]=c[$>>2],x)|0);ag=c[$>>2]|0;do{if((aQ(ag|0,54976)|0)==0){c[b>>2]=1}else{if((aQ(ag|0,54824)|0)==0){c[b>>2]=2;break}if((aQ(ag|0,54776)|0)==0){c[b>>2]=4;break}else{sL(0,54704,(x=i,i=i+8|0,c[x>>2]=ag,x)|0);c[b>>2]=1;break}}}while(0);ag=nB()|0;$=b+8|0;c[$>>2]=ag;ah=b;nx(ag,ah,26,2,18,4,38,12);ag=b+12|0;sx(c[$>>2]|0,d,ag)|0;sy(c[$>>2]|0,d)|0;c[ag>>2]=ny(c[$>>2]|0,0)|0;ai=ny(c[$>>2]|0,4194304)|0;aj=b+16|0;c[aj>>2]=ai;ak=b+20|0;c[ak>>2]=0;al=b+24|0;c[al>>2]=0;am=c[ag>>2]|0;do{if((am|0)==0){sL(0,28904,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0)}else{if((ai|0)==0){sL(0,55520,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);break}an=nz(am)|0;c[ak>>2]=an;nr(an,6291456);if((ns(c[ak>>2]|0)|0)>>>0>2097152){nt(c[ak>>2]|0,2097152)}an=nz(c[aj>>2]|0)|0;c[al>>2]=an;nr(an,0);c[b+4628>>2]=0;tJ(d,55472,_,1)|0;if((c[_>>2]|0)!=0){break}sN(2,55264,55136,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);an=c[b>>2]|0;if((an&1|0)!=0){nM(c[$>>2]|0,686,4194304);break}if((an&6|0)==0){break}nM(c[$>>2]|0,3324,1464619843)}}while(0);_=tz(d,0,29208)|0;tK(_,32952,Y,41224)|0;tH(_,29160,Z,0)|0;_=c[Z>>2]|0;sN(2,29120,29048,(x=i,i=i+16|0,c[x>>2]=c[Y>>2],c[x+8>>2]=_,x)|0);_=io()|0;al=b+4|0;c[al>>2]=_;if((_|0)!=0){if((dJ(b,c[Y>>2]|0)|0)!=0){sL(0,28976,(x=i,i=i+8|0,c[x>>2]=c[Y>>2],x)|0)}h5(c[al>>2]|0,c[$>>2]|0,28,12,24,14,26,18);h7(c[al>>2]|0,ah,182);h8(c[al>>2]|0,ah,38);h9(c[al>>2]|0,0);al=c[Z>>2]|0;c[ad>>2]=al;c[ae>>2]=al}al=tz(d,0,29912)|0;tG(al,55464,W,15720448)|0;tG(al,43008,X,8192)|0;al=c[X>>2]|0;sN(2,29872,42288,(x=i,i=i+16|0,c[x>>2]=c[W>>2],c[x+8>>2]=al,x)|0);al=b+36|0;my(al,9);mw(al,ah,238);ms(al,ah,288);mt(al,ah,290);ae=ng(c[W>>2]|0,c[X>>2]|0,0)|0;if((ae|0)!=0){nn(ae,al,4,32,10,28,2,22);nD(c[$>>2]|0,ae,1)}ae=tz(d,0,30008)|0;tG(ae,55464,U,8388608)|0;tG(ae,43008,V,4194304)|0;ae=c[V>>2]|0;sN(2,29960,42288,(x=i,i=i+16|0,c[x>>2]=c[U>>2],c[x+8>>2]=ae,x)|0);ae=b+128|0;mV(ae);mM(ae,ah,44);mS(ae,3672e3,3672e3,3672e3);X=ng(c[U>>2]|0,c[V>>2]|0,0)|0;if((X|0)!=0){nn(X,ah,34,0,0,30,0,0);nD(c[$>>2]|0,X,1)}X=b+3488|0;fc(X);ff(X,ae,0);X=b+4056|0;fc(X);ff(X,ae,1);X=tz(d,0,30792)|0;if((X|0)!=0){V=X;do{tH(V,30680,R,0)|0;tH(V,30632,S,1)|0;tK(V,47216,T,0)|0;X=c[S>>2]|0;U=c[T>>2]|0;sN(2,30424,30288,(x=i,i=i+24|0,c[x>>2]=c[R>>2],c[x+8>>2]=X,c[x+16>>2]=(U|0)!=0?U:46040,x)|0);V=tz(d,V,30792)|0;U=c[R>>2]|0;do{if(U>>>0>1){sL(0,30144,(x=i,i=i+8|0,c[x>>2]=U,x)|0)}else{X=c[S>>2]|0;mR(ae,U,X,X);X=c[T>>2]|0;if((X|0)==0){break}if((fd(b+3488+((c[R>>2]|0)*568|0)|0,X)|0)==0){break}sL(0,30080,(x=i,i=i+8|0,c[x>>2]=c[T>>2],x)|0)}}while(0);}while((V|0)!=0)}V=tz(d,0,32160)|0;tK(V,38088,N,32080)|0;tJ(V,31792,P,1)|0;tJ(V,31576,Q,0)|0;tK(V,31408,O,0)|0;V=c[P>>2]|0;T=c[O>>2]|0;R=c[Q>>2]|0;sN(2,31272,31088,(x=i,i=i+32|0,c[x>>2]=c[N>>2],c[x+8>>2]=V,c[x+16>>2]=(T|0)!=0?T:30960,c[x+24>>2]=R,x)|0);c[b+4672>>2]=bu(c[N>>2]|0)|0;R=b+1428|0;eE(R);ed(R,ah,96);ee(R,ah,116);ef(R,c[P>>2]|0);if((eF(R,c[N>>2]|0)|0)!=0){sL(0,30848,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0)}if((c[Q>>2]|0)!=0){a[b+1548|0]=0;a[b+1549|0]=6;a[b+1550|0]=-1;a[b+1551|0]=-53}Q=c[O>>2]|0;if((Q|0)==0){eG(R,0,1)}else{eL(R,Q)}Q=b+1744|0;c[Q>>2]=0;R=b|0;do{if((c[R>>2]&1|0)!=0){O=tz(d,0,35672)|0;tH(O,32952,K,1)|0;tJ(O,32696,L,0)|0;tJ(O,35472,M,0)|0;O=c[L>>2]|0;N=(c[M>>2]|0)!=0?33528:33232;sN(2,32464,32272,(x=i,i=i+24|0,c[x>>2]=c[K>>2],c[x+8>>2]=O,c[x+16>>2]=N,x)|0);N=dv()|0;c[Q>>2]=N;if((N|0)==0){break}O=c[K>>2]|0;P=c[L>>2]|0;dr(N,O,P)|0;dw(c[Q>>2]|0,c[M>>2]|0);dp(c[Q>>2]|0,al,166);dq(c[Q>>2]|0,ah,24);mv(al,c[Q>>2]|0,140);mu(al,c[Q>>2]|0,164)}}while(0);Q=b+1748|0;c[Q>>2]=0;M=b+1756|0;c[M>>2]=0;L=b+1752|0;c[L>>2]=0;do{if((c[R>>2]&6|0)!=0){K=tz(d,0,36144)|0;tJ(K,35872,H,1)|0;tJ(K,35672,I,1)|0;tJ(K,35472,J,0)|0;sN(2,35232,34968,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);K=cC()|0;c[Q>>2]=K;if((K|0)==0){sL(0,34712,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);break}P=al;cu(K,P,252);cv(c[Q>>2]|0,P,350);cw(c[Q>>2]|0,ah,202);do{if((c[H>>2]|0)!=0){sN(2,35232,34200,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);P=cV()|0;c[M>>2]=P;if((P|0)==0){break}K=c[Q>>2]|0;O=P|0;cx(K,O)|0}}while(0);if((c[I>>2]|0)==0){break}sN(2,35232,33864,(x=i,i=i+8|0,c[x>>2]=(c[J>>2]|0)!=0?33528:33232,x)|0);O=cQ()|0;c[L>>2]=O;if((O|0)==0){break}cy(O,c[J>>2]|0);O=c[Q>>2]|0;K=c[L>>2]|0;cx(O,K)|0}}while(0);L=b+3484|0;c[L>>2]=sw(d)|0;Q=tz(d,0,39032)|0;J=b+1760|0;dg(J);c9(J,ah,220);da(J,c[L>>2]|0);sN(2,38840,38592,(x=i,i=i+8|0,c[x>>2]=13631488,x)|0);I=tz(Q,0,41400)|0;if((I|0)!=0){M=0;H=I;do{tH(H,41400,E,M)|0;tH(H,38392,F,c[E>>2]|0)|0;tK(H,38088,G,0)|0;tJ(H,37824,A,0)|0;tJ(H,37552,B,0)|0;tJ(H,37e3,D,0)|0;tJ(H,36720,C,0)|0;I=(c[A>>2]|0)!=0?400:800;al=c[B>>2]|0;R=c[C>>2]|0;K=c[F>>2]|0;O=c[G>>2]|0;sN(2,38840,36368,(x=i,i=i+48|0,c[x>>2]=c[E>>2],c[x+8>>2]=I,c[x+16>>2]=al,c[x+24>>2]=R,c[x+32>>2]=K,c[x+40>>2]=(O|0)!=0?O:46040,x)|0);dh(J,(c[E>>2]|0)-1|0,(c[A>>2]|0)!=0?1:2)|0;db(J,(c[E>>2]|0)-1|0,c[F>>2]|0);dj(J,(c[E>>2]|0)-1|0,c[G>>2]|0);dd(J,(c[E>>2]|0)-1|0,c[B>>2]|0);de(J,(c[E>>2]|0)-1|0,c[C>>2]|0);if((c[D>>2]|0)!=0){dm(J,(c[E>>2]|0)-1|0)}M=(c[E>>2]|0)+1|0;H=tz(Q,H,41400)|0;}while((H|0)!=0)}H=tz(d,0,43328)|0;do{if((H|0)!=0){tG(H,55464,t,5767168)|0;tG(H,43008,u,524288)|0;Q=c[u>>2]|0;sN(2,42664,42288,(x=i,i=i+16|0,c[x>>2]=c[t>>2],c[x+8>>2]=Q,x)|0);Q=b+2088|0;eO(Q);eI(Q,c[L>>2]|0);E=ng(c[t>>2]|0,c[u>>2]|0,0)|0;if((E|0)==0){break}nn(E,Q,30,8,0,36,32,0);nD(c[$>>2]|0,E,1);E=tz(H,0,41984)|0;if((E|0)==0){break}else{ao=E}do{tH(ao,41696,v,0)|0;tH(ao,41400,w,0)|0;tK(ao,40984,y,40712)|0;tK(ao,40072,z,39752)|0;E=c[w>>2]|0;M=c[y>>2]|0;J=c[z>>2]|0;sN(2,42664,39368,(x=i,i=i+32|0,c[x>>2]=c[v>>2],c[x+8>>2]=E,c[x+16>>2]=M,c[x+24>>2]=J,x)|0);eP(Q,c[v>>2]|0,c[w>>2]|0);eJ(Q,c[v>>2]|0,c[y>>2]|0);eK(Q,c[v>>2]|0,c[z>>2]|0);ao=tz(H,ao,41984)|0;}while((ao|0)!=0)}}while(0);ao=q|0;q=tz(d,0,45440)|0;tH(q,45128,r,30)|0;tJ(q,44808,p,0)|0;H=b+2424|0;fn(H,(q|0)!=0|0);e$(H,c[$>>2]|0);e0(H,c[L>>2]|0);a[b+2484|0]=c[p>>2]&255;if((q|0)!=0){if((c[14506]&1|0)==0){a2(ao|0,44488,(x=i,i=i+8|0,c[x>>2]=1,x)|0)|0;p=c[r>>2]|0;tH(q,ao,s,p)|0;ap=c[s>>2]|0}else{p=c[14508]|0;c[s>>2]=p;ap=p}fo(H,0,ap);ap=c[s>>2]|0;sN(2,44248,43624,(x=i,i=i+16|0,c[x>>2]=1,c[x+8>>2]=ap,x)|0);if((c[14506]&2|0)==0){a2(ao|0,44488,(x=i,i=i+8|0,c[x>>2]=2,x)|0)|0;ap=c[r>>2]|0;tH(q,ao,s,ap)|0;aq=c[s>>2]|0}else{ap=c[14509]|0;c[s>>2]=ap;aq=ap}fo(H,1,aq);aq=c[s>>2]|0;sN(2,44248,43624,(x=i,i=i+16|0,c[x>>2]=2,c[x+8>>2]=aq,x)|0);if((c[14506]&4|0)==0){a2(ao|0,44488,(x=i,i=i+8|0,c[x>>2]=3,x)|0)|0;aq=c[r>>2]|0;tH(q,ao,s,aq)|0;ar=c[s>>2]|0}else{aq=c[14510]|0;c[s>>2]=aq;ar=aq}fo(H,2,ar);ar=c[s>>2]|0;sN(2,44248,43624,(x=i,i=i+16|0,c[x>>2]=3,c[x+8>>2]=ar,x)|0);if((c[14506]&8|0)==0){a2(ao|0,44488,(x=i,i=i+8|0,c[x>>2]=4,x)|0)|0;ar=c[r>>2]|0;tH(q,ao,s,ar)|0;as=c[s>>2]|0}else{ar=c[14511]|0;c[s>>2]=ar;as=ar}fo(H,3,as);as=c[s>>2]|0;sN(2,44248,43624,(x=i,i=i+16|0,c[x>>2]=4,c[x+8>>2]=as,x)|0)}as=b+2644|0;fD(as);do{if((c[ag>>2]|0)!=0){s=tz(d,0,48488)|0;H=ns(c[ag>>2]|0)|0;ar=H>>>0<768?0:H-768|0;c[m>>2]=ar;tG(s,55464,m,ar)|0;tG(s,48040,n,6e3)|0;tK(s,47216,o,0)|0;s=c[n>>2]|0;ar=c[o>>2]|0;sN(2,46784,46352,(x=i,i=i+24|0,c[x>>2]=c[m>>2],c[x+8>>2]=s,c[x+16>>2]=(ar|0)!=0?ar:46040,x)|0);ar=c[m>>2]|0;s=b+4644|0;c[s>>2]=ar;c[b+4648>>2]=ar-23552;ar=no(c[ag>>2]|0)|0;ft(as,ar+(c[s>>2]|0)|0);fE(as,c[n>>2]|0);s=c[o>>2]|0;if((s|0)==0){break}if((fF(as,s)|0)==0){break}sL(0,45688,(x=i,i=i+8|0,c[x>>2]=c[o>>2],x)|0)}}while(0);o=sz(d,c[14424]|0)|0;c[aa>>2]=o;if((o|0)!=0){ur(o,ah,74);us(c[aa>>2]|0,ah,34);ut(c[aa>>2]|0,ah,4)}if((c[ag>>2]|0)==0){at=c[$>>2]|0;au=sI(at,d)|0;av=c[aa>>2]|0;aw=uI(av,29720,48864)|0;ax=b+4700|0;c[ax>>2]=0;ay=b+4704|0;c[ay>>2]=0;az=ta(ay)|0;c[af>>2]=0;i=e;return}o=tz(d,0,29712)|0;as=ns(c[ag>>2]|0)|0;ag=as>>>0<22784?0:as-22784|0;tG(o,55464,f,ag)|0;tH(o,54648,g,512)|0;tH(o,53432,h,342)|0;tG(o,52680,k,0)|0;tG(o,51992,l,16777215)|0;tH(o,51376,j,1e3)|0;o=c[g>>2]|0;as=c[h>>2]|0;n=((c[j>>2]|0)>>>0)/10|0;sN(2,50600,49936,(x=i,i=i+32|0,c[x>>2]=c[f>>2],c[x+8>>2]=o,c[x+16>>2]=as,c[x+24>>2]=n,x)|0);n=c[f>>2]|0;f=b+4636|0;c[f>>2]=n;if((ag|0)==(n|0)&n>>>0>32767){c[b+4640>>2]=ag-32768}else{c[b+4640>>2]=n}n=fL(c[g>>2]|0,c[h>>2]|0)|0;c[ab>>2]=n;if((n|0)==0){at=c[$>>2]|0;au=sI(at,d)|0;av=c[aa>>2]|0;aw=uI(av,29720,48864)|0;ax=b+4700|0;c[ax>>2]=0;ay=b+4704|0;c[ay>>2]=0;az=ta(ay)|0;c[af>>2]=0;i=e;return}fH(n,ah,244);dN(b,c[f>>2]|0);ah=c[aa>>2]|0;if((ah|0)!=0){fM(c[ab>>2]|0,ah);ah=c[aa>>2]|0;uG(ah,512,342)|0}fJ(c[ab>>2]|0,c[k>>2]|0,c[l>>2]|0);fK(c[ab>>2]|0,((((c[j>>2]|0)*255|0)+500|0)>>>0)/1e3|0);if((ac((c[g>>2]|0)>>>3,c[h>>2]|0)|0)==0){at=c[$>>2]|0;au=sI(at,d)|0;av=c[aa>>2]|0;aw=uI(av,29720,48864)|0;ax=b+4700|0;c[ax>>2]=0;ay=b+4704|0;c[ay>>2]=0;az=ta(ay)|0;c[af>>2]=0;i=e;return}else{aA=0}do{nK(c[$>>2]|0,(c[f>>2]|0)+aA|0,-1);aA=aA+1|0;}while(aA>>>0<(ac((c[g>>2]|0)>>>3,c[h>>2]|0)|0)>>>0);at=c[$>>2]|0;au=sI(at,d)|0;av=c[aa>>2]|0;aw=uI(av,29720,48864)|0;ax=b+4700|0;c[ax>>2]=0;ay=b+4704|0;c[ay>>2]=0;az=ta(ay)|0;c[af>>2]=0;i=e;return}function dE(a){a=a|0;var b=0;c[a+4700>>2]=0;b=a+4704|0;c[b>>2]=0;ta(b)|0;c[a+4696>>2]=0;return}function dF(a){a=a|0;var b=0,c=0,d=0;b=u0(4736)|0;c=b;if((b|0)==0){d=0}else{dD(c,a);d=c}return d|0}function dG(b,d){b=b|0;d=d|0;var e=0;e=(d|0)!=0;a[b+4676|0]=e&1;if(e){return}c[b+4700>>2]=0;e=b+4704|0;c[e>>2]=0;ta(e)|0;c[b+4696>>2]=0;return}function dH(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;if(b>>>0>1){i=e;return}c[a+4688+(b<<2)>>2]=d;d=c[a+4688>>2]|0;b=c[a+4692>>2]|0;if((b|0)==0){f=d}else{f=(d|0)==0|b>>>0<d>>>0?b:d}d=a+4684|0;if((f|0)==(c[d>>2]|0)){i=e;return}d$(29808,(x=i,i=i+8|0,c[x>>2]=f,x)|0);ef(a+1428|0,(f|0)!=1|0);c[d>>2]=f;f=a+4696|0;c[f>>2]=0;c[a+4700>>2]=0;d=a+4704|0;c[d>>2]=0;ta(d)|0;c[f>>2]=0;i=e;return}function dI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=c[a+3480>>2]|0;if((e|0)==0){f=1;return f|0}f=uI(e,b,d)|0;return f|0}function dJ(a,b){a=a|0;b=b|0;var d=0;if((aQ(b|0,41224)|0)==0){ip(c[a+4>>2]|0);d=0;return d|0}if((aQ(b|0,37976)|0)==0){iq(c[a+4>>2]|0);d=0;return d|0}if((aQ(b|0,35120)|0)!=0){d=1;return d|0}ir(c[a+4>>2]|0);d=0;return d|0}function dK(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=b+4632|0;if((c[e>>2]|0)!=0){i=d;return}c[e>>2]=1;d$(32200,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);a[b+4652|0]=0;u6(b+4656|0,0,14);do{if((c[b>>2]&1|0)==0){d3(b,0);f=b+16|0;g=c[f>>2]|0;if((g|0)==0){break}if((c[g+40>>2]|0)>>>0<=7){break}h=b+4|0;j=c[h>>2]|0;k=nw(g,0)|0;if((c[j+36>>2]|0)>>>0>3){g=j+32|0;a[c[g>>2]|0]=k>>>24&255;a[(c[g>>2]|0)+1|0]=k>>>16&255;a[(c[g>>2]|0)+2|0]=k>>>8&255;a[(c[g>>2]|0)+3|0]=k&255}else{b3[c[j+28>>2]&63](c[j+4>>2]|0,0,k)}k=c[h>>2]|0;h=nw(c[f>>2]|0,4)|0;if((c[k+36>>2]|0)>>>0>7){f=k+32|0;a[(c[f>>2]|0)+4|0]=h>>>24&255;a[(c[f>>2]|0)+5|0]=h>>>16&255;a[(c[f>>2]|0)+6|0]=h>>>8&255;a[(c[f>>2]|0)+7|0]=h&255;break}else{b3[c[k+28>>2]&63](c[k+4>>2]|0,4,h);break}}else{d3(b,1)}}while(0);h=b+36|0;mT(h);a[b+4624|0]=-9;k=b+4625|0;a[k]=-1;mD(h,-9);mE(h,a[k]|0);fy(b+2424|0);eS(b+2088|0);nb(b+128|0);k=c[b+1748>>2]|0;if((k|0)!=0){cD(k)}iJ(c[b+4>>2]|0);c[b+4700>>2]=0;k=b+4704|0;c[k>>2]=0;ta(k)|0;c[b+4696>>2]=0;c[e>>2]=0;i=d;return}function dL(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;if((d|0)==0){f=c[(c[b+4>>2]|0)+268>>2]|0;g=(f|0)==0?1:f}else{g=d}d=c[b+4684>>2]|0;if((d|0)==0){h=(c[b+4696>>2]|0)+g|0;j=1}else{h=g;j=d}iL(c[b+4>>2]|0,h);fw(b+2644|0,h);h=b+4712|0;d=vf(c[h>>2]|0,c[h+4>>2]|0,g,0)|0;c[h>>2]=d;c[h+4>>2]=G;h=b+4720|0;d=(c[h>>2]|0)+g|0;c[h>>2]=d;g=b+4724|0;f=c[g>>2]|0;if(d>>>0<j>>>0){k=f}else{l=f;f=d;do{l=l+1|0;f=f-j|0;}while(f>>>0>=j>>>0);c[g>>2]=l;c[h>>2]=f;k=l}if(k>>>0<10){i=e;return}l=(k>>>0)/10|0;k=b+36|0;mU(k,l);f=b+1748|0;h=c[f>>2]|0;j=l*10|0;if((h|0)!=0){cF(h,j)}du(b+1760|0,l);c[g>>2]=(c[g>>2]|0)-j;g=b+4728|0;l=(c[g>>2]|0)+j|0;c[g>>2]=l;if(l>>>0<256){i=e;return}fO(c[b+3476>>2]|0,l);fk(b+3488|0,c[g>>2]|0);fk(b+4056|0,c[g>>2]|0);l=c[b+1744>>2]|0;if((l|0)!=0){dA(l,c[g>>2]|0)}l=b+4732|0;j=(c[l>>2]|0)+(c[g>>2]|0)|0;c[l>>2]=j;c[g>>2]=0;if(j>>>0<8192){i=e;return}j=c[b+3480>>2]|0;if((j|0)!=0){uN(j)}do{if((c[f>>2]|0)==0){j=b+4656|0;g=c[j>>2]|0;if((g+1|0)>>>0>2){h=b+4668|0;d=b+4625|0;m=a[d]|0;n=(a[h]|0)==0?m|16:m&-17;a[d]=n;if((g|0)>0){m=n^16;a[d]=m;o=g-2|0;p=m}else{o=g+2|0;p=n}c[j>>2]=o;mE(k,p);m8(b+128|0,a[h]|0);a[h]=(a[h]|0)==0|0}h=b+4660|0;j=c[h>>2]|0;if((j+1|0)>>>0<=2){break}n=b+4669|0;g=b+4625|0;m=a[g]|0;d=(a[n]|0)==0?m|32:m&-33;a[g]=d;if((j|0)>0){q=j-2|0;r=d}else{m=d^32;a[g]=m;q=j+2|0;r=m}c[h>>2]=q;mE(k,r);m9(b+128|0,a[n]|0);a[n]=(a[n]|0)==0|0}}while(0);eN(b+1428|0,c[l>>2]|0);r=b+4700|0;k=(c[r>>2]|0)+(c[l>>2]|0)|0;c[r>>2]=k;do{if(k>>>0>31333){c[r>>2]=k-31334;q=ta(b+4704|0)|0;do{if(q>>>0<4e3){p=b+4708|0;o=(c[p>>2]|0)+(4e3-q)|0;c[p>>2]=o;if((o|0)<=0){s=o;t=p;break}p=b+4696|0;c[p>>2]=(c[p>>2]|0)+1;u=o;v=1134}else{o=b+4708|0;p=(c[o>>2]|0)+(4e3-q)|0;c[o>>2]=p;if((p|0)>=0){u=p;v=1134;break}o=b+4696|0;f=c[o>>2]|0;if((f|0)==0){u=p;v=1134;break}c[o>>2]=f-1;u=p;v=1134}}while(0);do{if((v|0)==1134){q=b+4708|0;if((u|0)<=9999){s=u;t=q;break}s9(u)|0;s=c[q>>2]|0;t=q}}while(0);if((s|0)>=-1e6){break}d$(30712,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);c[t>>2]=(c[t>>2]|0)+1e6}}while(0);c[l>>2]=0;i=e;return}function dM(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+376|0;g=f|0;if(e<<24>>24==0){i=f;return}e=b+36|0;mB(e,0);mB(e,1);fG(b+2644|0);e=b+8|0;h=b+4644|0;j=0;while(1){k=j+1|0;a[g+j|0]=nF(c[e>>2]|0,k+(c[h>>2]|0)|0)|0;if(k>>>0<370){j=k}else{break}}if((c[b>>2]&4|0)==0){df(b+1760|0,g|0,370);i=f;return}j=(d[6592+(a[g|0]&63)|0]|0)*370|0;if(j>>>0<370){l=1}else{l=j>>>0>11839?31:(j>>>0)/370|0}j=(((((31-l|0)*223|0)+15|0)>>>0)/30|0)+32|0;l=c[b+3476>>2]|0;if((l|0)==0){i=f;return}if((c[l+28>>2]|0)==(j|0)){i=f;return}fK(l,j);i=f;return}function dN(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=a+12|0;do{if((ns(c[d>>2]|0)|0)>>>0>b>>>0){e=(no(c[d>>2]|0)|0)+b|0}else{f=ny(c[a+8>>2]|0,b)|0;if((f|0)!=0){g=no(f)|0;h=nq(f)|0;e=g+(h-(c[a+4636>>2]|0))|0;break}fI(c[a+3476>>2]|0,0);return}}while(0);fI(c[a+3476>>2]|0,e);return}function dO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;if((b|0)==3){e=a;c6(e,d)|0;return}e=c[a+1744>>2]|0;if((e|0)!=0){dy(e,b,d)}e=c[a+1752>>2]|0;if((e|0)==0){return}cK(e,b,d);return}function dP(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=b+4676|0;if((a[g]|0)!=0){if((f|0)==0){return}a[g]=0;c[b+4700>>2]=0;g=b+4704|0;c[g>>2]=0;ta(g)|0;c[b+4696>>2]=0;return}g=c[b+1756>>2]|0;if((g|0)!=0){cI(g,f,d,e);return}g=b+4664|0;if(((f&2^2)&(c[g>>2]^f)|0)!=0){h=c[b+3480>>2]|0;uI(h,49424,48952)|0}h=b+4625|0;i=a[h]|0;j=(f&1|0)==0?i|8:i&-9;a[h]=j;if(j<<24>>24!=i<<24>>24){mE(b+36|0,j)}j=b+4656|0;c[j>>2]=(c[j>>2]|0)+d;d=b+4660|0;c[d>>2]=(c[d>>2]|0)+e;c[g>>2]=f;return}function dQ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;e=b<<24>>24!=0;b=e?4:0;c[a+4692>>2]=b;f=c[a+4688>>2]|0;if(e){g=(f|0)==0|b>>>0<f>>>0?b:f}else{g=f}f=a+4684|0;if((g|0)==(c[f>>2]|0)){i=d;return}d$(29808,(x=i,i=i+8|0,c[x>>2]=g,x)|0);ef(a+1428|0,(g|0)!=1|0);c[f>>2]=g;g=a+4696|0;c[g>>2]=0;c[a+4700>>2]=0;f=a+4704|0;c[f>>2]=0;ta(f)|0;c[g>>2]=0;i=d;return}function dR(b,c){b=b|0;c=c|0;var d=0,e=0,f=0;d=b+4625|0;e=a[d]|0;f=c<<24>>24==0?e|8:e&-9;a[d]=f;mE(b+36|0,f);return}function dS(b,c){b=b|0;c=c|0;var d=0,e=0,f=0;d=b+4625|0;e=a[d]|0;f=c<<24>>24==0?e&-2:e|1;a[d]=f;mE(b+36|0,f);return}function dT(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b+4652|0;f=a[e]|0;g=d<<24>>24==0?f&-5:f|4;a[e]=g;e=g&255;g=0;while(1){f=e>>>1;if((f|0)==0){break}else{e=f;g=g+1|0}}ix(c[b+4>>2]|0,g,0,1);return}function dU(a){a=a|0;c[14428]=1;return}function dV(a,b){a=a|0;b=b|0;var c=0;if((b|0)==2097150){c=m4(a+128|0)|0}else if((b|0)==2097144){c=m1(a+128|0)|0}else if((b|0)==2097146){c=m0(a+128|0)|0}else if((b|0)==2097148){c=m5(a+128|0)|0}else{c=-1}return c|0}function dW(a,b,c){a=a|0;b=b|0;c=c|0;if((b|0)==4194297){m3(a+128|0,c);return}else if((b|0)==4194303){m6(a+128|0,c);return}else if((b|0)==4194301){m7(a+128|0,c);return}else if((b|0)==4194299){m2(a+128|0,c);return}else{return}}function dX(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b+4652|0;f=a[e]|0;g=d<<24>>24==0?f&-3:f|2;a[e]=g;e=g&255;g=0;while(1){f=e>>>1;if((f|0)==0){break}else{e=f;g=g+1|0}}ix(c[b+4>>2]|0,g,0,1);return}function dY(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=b;g=b+4624|0;h=a[g]|0;j=d&255;if(h<<24>>24==d<<24>>24){i=e;return}a[g]=d;g=(h^d)&255;do{if((g&16|0)!=0){h=c[b>>2]|0;if((h&1|0)!=0){d3(f,j>>>4&1);break}if((h&6|0)==0){break}dk(b+1760|0,(d&255)>>>4&1)}}while(0);if((g&32|0)!=0){dl(b+1760|0,(d&255)>>>5&1)}if((g&64|0)!=0){if((j&64|0)==0){d$(29688,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);k=b+4640|0}else{d$(29776,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);k=b+4636|0}dN(f,c[k>>2]|0)}do{if((g&8|0)!=0){if((c[b>>2]&1|0)==0){break}k=no(c[b+12>>2]|0)|0;if((j&8|0)==0){d$(29320,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);l=b+4648|0}else{d$(29432,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);l=b+4644|0}ft(b+2644|0,k+(c[l>>2]|0)|0)}}while(0);if((g&7|0)==0){i=e;return}fu(b+2644|0,j&7);i=e;return}function dZ(b,d){b=b|0;d=d|0;var e=0,f=0;e=b+4625|0;f=a[e]|0;if(f<<24>>24==d<<24>>24){return}a[e]=d;eM(b+1428|0,d);if((f^d)<<24>>24<0){fv(b+2644|0,(d&255)>>>7&255^1)}f=c[b+1748>>2]|0;if((f|0)==0){return}cE(f,(d&255)>>>4&3);return}function d_(a,b){a=a|0;b=b|0;if(b<<24>>24==0){return}dK(a);return}function d$(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+16|0;e=d|0;f=c[14426]|0;if((f|0)==0){g=0}else{g=c[(c[f+4>>2]|0)+144>>2]&16777215}sL(3,43712,(x=i,i=i+8|0,c[x>>2]=g,x)|0);g=e;c[g>>2]=b;c[g+4>>2]=0;sM(3,a,e|0);i=d;return}function d0(){tb(0,1);return}function d1(a,b,d){a=a|0;b=b|0;d=d|0;return(it(c[a+4>>2]|0,b,d)|0)!=0|0}function d2(a,b,d){a=a|0;b=b|0;d=d|0;return(iu(c[a+4>>2]|0,b,d)|0)!=0|0}function d3(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=a+4628|0;e=(b|0)!=0;if((c[d>>2]|0)==(e&1|0)){return}b=a+8|0;f=c[b>>2]|0;if(e){nE(f,c[a+12>>2]|0);nD(c[b>>2]|0,c[a+24>>2]|0,0);nD(c[b>>2]|0,c[a+20>>2]|0,0);h6(c[a+4>>2]|0,0,0);c[d>>2]=1;return}else{nE(f,c[a+24>>2]|0);nE(c[b>>2]|0,c[a+20>>2]|0);f=a+12|0;nD(c[b>>2]|0,c[f>>2]|0,0);b=c[a+4>>2]|0;a=no(c[f>>2]|0)|0;h6(b,a,ns(c[f>>2]|0)|0);c[d>>2]=0;return}}function d4(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;do{if(b>>>0<4194304){d=c[a+12>>2]|0;if((d|0)==0){break}e=ns(d)|0;if((e|0)==0){break}d=(b>>>0)%(e>>>0)|0;if((d|0)!=(b|0)){f=d;g=1288}}else{if(b>>>0>=5767168){break}d=c[a+16>>2]|0;if((d|0)==0){break}e=ns(d)|0;if((e|0)==0){break}d=((b>>>0)%(e>>>0)|0)+4194304|0;if((d|0)!=(b|0)){f=d;g=1288}}}while(0);if((g|0)==1288){h=nF(c[a+8>>2]|0,f)|0;return h|0}if((b-5767168|0)>>>0<524288){h=0;return h|0}f=b-12582912|0;if(f>>>0<2097152){h=dn(a+1760|0,f)|0;return h|0}else{h=(b&15728640|0)==13631488?-86:0;return h|0}return 0}function d5(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;do{if(b>>>0<4194304){d=c[a+12>>2]|0;if((d|0)==0){e=0;break}f=ns(d)|0;if((f|0)==0){e=0;break}d=(b>>>0)%(f>>>0)|0;if((d|0)==(b|0)){e=0}else{g=d;h=1306}}else{if(b>>>0>=5767168){e=0;break}d=c[a+16>>2]|0;if((d|0)==0){e=0;break}f=ns(d)|0;if((f|0)==0){e=0;break}d=((b>>>0)%(f>>>0)|0)+4194304|0;if((d|0)==(b|0)){e=0}else{g=d;h=1306}}}while(0);if((h|0)==1306){e=nG(c[a+8>>2]|0,g)|0}return e|0}function d6(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;do{if(b>>>0<4194304){d=c[a+12>>2]|0;if((d|0)==0){e=0;break}f=ns(d)|0;if((f|0)==0){e=0;break}d=(b>>>0)%(f>>>0)|0;if((d|0)==(b|0)){e=0}else{g=d;h=1316}}else{if(b>>>0>=5767168){e=0;break}d=c[a+16>>2]|0;if((d|0)==0){e=0;break}f=ns(d)|0;if((f|0)==0){e=0;break}d=((b>>>0)%(f>>>0)|0)+4194304|0;if((d|0)==(b|0)){e=0}else{g=d;h=1316}}}while(0);if((h|0)==1316){e=nH(c[a+8>>2]|0,g)|0}return e|0}function d7(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;do{if(b>>>0<4194304){e=c[a+12>>2]|0;if((e|0)==0){return}f=ns(e)|0;if((f|0)==0){return}e=(b>>>0)%(f>>>0)|0;if((e|0)!=(b|0)){g=e;h=1326;break}return}else{if(b>>>0>=5767168){i=b;break}e=c[a+16>>2]|0;if((e|0)==0){i=b;break}f=ns(e)|0;if((f|0)==0){i=b;break}e=((b>>>0)%(f>>>0)|0)+4194304|0;if((e|0)==(b|0)){i=b}else{g=e;h=1326}}}while(0);if((h|0)==1326){nK(c[a+8>>2]|0,g,d);i=g}if(!((i-5767168|0)>>>0>524287&i>>>0>12582911&i>>>0<14680064)){return}dt(a+1760|0,i-12582912|0,d);return}function d8(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0<4194304){e=c[a+12>>2]|0;if((e|0)==0){return}f=ns(e)|0;if((f|0)==0){return}e=(b>>>0)%(f>>>0)|0;if((e|0)!=(b|0)){g=e;break}return}else{if(b>>>0>=5767168){return}e=c[a+16>>2]|0;if((e|0)==0){return}f=ns(e)|0;if((f|0)==0){return}e=((b>>>0)%(f>>>0)|0)+4194304|0;if((e|0)!=(b|0)){g=e;break}return}}while(0);nL(c[a+8>>2]|0,g,d);return}function d9(a){a=a|0;tb(0,1);aC(49160,32,1,c[q>>2]|0)|0;ay(c[q>>2]|0)|0;a=c[14426]|0;if((a|0)==0){a1(1)}if((c[a+4>>2]|0)==0){a1(1)}cW(a,53576);a1(1)}function ea(a){a=a|0;tb(0,1);bN(c[q>>2]|0,47368,(x=i,i=i+8|0,c[x>>2]=a,x)|0)|0;ay(c[q>>2]|0)|0;a1(1)}function eb(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+8|0;e=d|0;sA();sB(c[q>>2]|0,0,2)|0;f=tx(0)|0;c[14512]=f;if((f|0)==0){g=1;i=d;return g|0}tC(58e3);f=ss(a,b,e,6656)|0;L1730:do{if((f|0)!=-1){h=f;while(1){if((h|0)<0){g=1;j=1391;break}if((h|0)==86){j=1366;break}else if((h|0)==73){tL(58e3,c[c[e>>2]>>2]|0,34312,0)|0}else if((h|0)==63){j=1365;break}else if((h|0)==100){s2(c[c[e>>2]>>2]|0)|0}else if((h|0)==0){j=1382;break}else if((h|0)==98){c[14506]=c[14506]|1;c[14508]=ax(c[c[e>>2]>>2]|0,0,0)|0}else if((h|0)==116){c[14424]=c[c[e>>2]>>2]}else if((h|0)==66){k=ax(c[c[e>>2]>>2]|0,0,0)|0;if((k|0)==0|k>>>0>3){j=1369;break}l=k-1|0;c[14506]=c[14506]|1<<l;c[58032+(l<<2)>>2]=ax(c[(c[e>>2]|0)+4>>2]|0,0,0)|0}else if((h|0)==113){sK(c[q>>2]|0,0)}else if((h|0)==105){if((tg(c[14512]|0,c[c[e>>2]>>2]|0)|0)!=0){j=1373;break}}else if((h|0)==115){tL(58e3,29456,c[c[e>>2]>>2]|0,34312)|0}else if((h|0)==118){sK(c[q>>2]|0,3)}else if((h|0)==108){sJ(c[c[e>>2]>>2]|0,3)|0}else if((h|0)==112){tL(58e3,31856,c[c[e>>2]>>2]|0,30432)|0}else if(!((h|0)==99|(h|0)==114|(h|0)==82)){g=1;j=1390;break}h=ss(a,b,e,6656)|0;if((h|0)==-1){break L1730}}if((j|0)==1369){h=c[q>>2]|0;l=c[b>>2]|0;bN(h|0,40144,(x=i,i=i+16|0,c[x>>2]=l,c[x+8>>2]=k,x)|0)|0;g=1;i=d;return g|0}else if((j|0)==1366){aC(49288,89,1,c[o>>2]|0)|0;ay(c[o>>2]|0)|0;g=0;i=d;return g|0}else if((j|0)==1390){i=d;return g|0}else if((j|0)==1391){i=d;return g|0}else if((j|0)==1365){sr(48824,48352,6656);ay(c[o>>2]|0)|0;g=0;i=d;return g|0}else if((j|0)==1382){l=c[c[e>>2]>>2]|0;bN(c[q>>2]|0,55272,(x=i,i=i+16|0,c[x>>2]=c[b>>2],c[x+8>>2]=l,x)|0)|0;g=1;i=d;return g|0}else if((j|0)==1373){l=c[c[e>>2]>>2]|0;bN(c[q>>2]|0,37080,(x=i,i=i+16|0,c[x>>2]=c[b>>2],c[x+8>>2]=l,x)|0)|0;g=1;i=d;return g|0}}}while(0);sK(c[q>>2]|0,3);sL(2,49752,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);sN(2,51856,51272,(x=i,i=i+8|0,c[x>>2]=54432,x)|0);if((tk(c[14512]|0,54432)|0)!=0){sL(0,50416,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);g=1;i=d;return g|0}b=tz(c[14512]|0,0,53224)|0;e=(b|0)==0?c[14512]|0:b;if((tM(58e3,e,1)|0)==0){aU(2)|0;bb(0)|0;s4(e)|0;aN(2,40)|0;aN(11,86)|0;aN(15,84)|0;sn(c[p>>2]|0,c[o>>2]|0);c[14426]=dF(e)|0;sO(57736);sP(57736,14,c[14426]|0);sQ(57736,74,c[14426]|0);sR(57736,c[(c[14426]|0)+8>>2]|0,28);sS(57736,c[(c[14426]|0)+8>>2]|0,14);sT(57736,0);sf(c[14426]|0,14,30);c1(c[14426]|0,57736);dK(c[14426]|0);cZ(c[14426]|0);a1(1);return 0}else{g=1;i=d;return g|0}return 0}function ec(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;d=b;while(1){b=a[d]|0;if((b-48&255)<=9){e=d;f=0;g=b;h=1401;break}if(b<<24>>24==0){i=0;j=d;break}else{d=d+1|0}}if((h|0)==1401){while(1){h=0;d=(g<<24>>24)-48+(f*10|0)|0;b=e+1|0;k=a[b]|0;if((k-48&255)<10){e=b;f=d;g=k;h=1401}else{i=d;j=b;break}}}g=j;while(1){j=a[g]|0;if((j-48&255)<=9){l=g;m=0;n=j;h=1411;break}if(j<<24>>24==0){o=0;p=g;break}else{g=g+1|0}}if((h|0)==1411){while(1){h=0;g=(n<<24>>24)-48+(m*10|0)|0;j=l+1|0;f=a[j]|0;if((f-48&255)<10){l=j;m=g;n=f;h=1411}else{o=g;p=j;break}}}n=p;while(1){p=a[n]|0;if((p-48&255)<=9){q=n;r=0;s=p;h=1415;break}if(p<<24>>24==0){t=0;u=n;break}else{n=n+1|0}}if((h|0)==1415){while(1){h=0;n=(s<<24>>24)-48+(r*10|0)|0;p=q+1|0;m=a[p]|0;if((m-48&255)<10){q=p;r=n;s=m;h=1415}else{t=n;u=p;break}}}s=u;while(1){u=a[s]|0;if((u-48&255)<=9){v=s;w=0;x=u;h=1419;break}if(u<<24>>24==0){y=0;z=s;break}else{s=s+1|0}}if((h|0)==1419){while(1){h=0;s=(x<<24>>24)-48+(w*10|0)|0;u=v+1|0;r=a[u]|0;if((r-48&255)<10){v=u;w=s;x=r;h=1419}else{y=s;z=u;break}}}x=z;while(1){z=a[x]|0;if((z-48&255)<=9){A=x;B=0;C=z;h=1423;break}if(z<<24>>24==0){D=0;E=x;break}else{x=x+1|0}}if((h|0)==1423){while(1){h=0;x=(C<<24>>24)-48+(B*10|0)|0;z=A+1|0;w=a[z]|0;if((w-48&255)<10){A=z;B=x;C=w;h=1423}else{D=x;E=z;break}}}C=E;while(1){E=a[C]|0;if((E-48&255)<=9){F=C;G=0;H=E;h=1427;break}if(E<<24>>24==0){I=0;break}else{C=C+1|0}}if((h|0)==1427){while(1){h=0;C=(H<<24>>24)-48+(G*10|0)|0;E=F+1|0;B=a[E]|0;if((B-48&255)<10){F=E;G=C;H=B;h=1427}else{I=C;break}}}h=(o|0)==0?0:o-1|0;o=(t|0)==0?0:t-1|0;do{if(i>>>0<1904|h>>>0>11){J=0}else{t=i-1904|0;H=t&3;G=((t>>>2)*1461|0)+(H*365|0)+((H|0)!=0)|0;t=(H|0)==0?7168:7120;if((h|0)==0){K=G}else{H=G;G=0;while(1){F=(c[t+(G<<2)>>2]|0)+H|0;C=G+1|0;if(C>>>0<h>>>0){H=F;G=C}else{K=F;break}}}if((c[t+(h<<2)>>2]|0)>>>0<=o>>>0){J=0;break}J=(K+o|0)*86400|0}}while(0);if(y>>>0>23|D>>>0>59|I>>>0>59){L=0;M=L+J|0;return M|0}L=(((y*60|0)+D|0)*60|0)+I|0;M=L+J|0;return M|0}function ed(a,b,d){a=a|0;b=b|0;d=d|0;c[a+292>>2]=b;c[a+296>>2]=d;return}function ee(a,b,d){a=a|0;b=b|0;d=d|0;c[a+304>>2]=b;c[a+308>>2]=d;return}function ef(a,b){a=a|0;b=b|0;c[a+284>>2]=(b|0)!=0;return}function eg(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;do{if(b>>>0<4194304){e=c[a+12>>2]|0;if((e|0)==0){return}f=ns(e)|0;if((f|0)==0){return}e=(b>>>0)%(f>>>0)|0;if((e|0)!=(b|0)){g=e;break}return}else{if(b>>>0>=5767168){return}e=c[a+16>>2]|0;if((e|0)==0){return}f=ns(e)|0;if((f|0)==0){return}e=((b>>>0)%(f>>>0)|0)+4194304|0;if((e|0)!=(b|0)){g=e;break}return}}while(0);nM(c[a+8>>2]|0,g,d);return}function eh(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=(a|0)==0?c[14426]|0:a;if((b|0)==0){f=1;return f|0}a=(d|0)==0?58208:d;d=5944;while(1){g=c[d>>2]|0;if((g|0)==0){break}if((sX(g,b)|0)==0){d=d+8|0}else{h=1457;break}}if((h|0)==1457){f=b2[c[d+4>>2]&127](e,b,a)|0;return f|0}d=c[e+3480>>2]|0;do{if((d|0)!=0){e=uI(d,b,a)|0;if((e|0)>-1){f=e}else{break}return f|0}}while(0);f=1;return f|0}function ei(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=i;if((dJ(a,d)|0)==0){e=0;i=b;return e|0}sL(0,39240,(x=i,i=i+8|0,c[x>>2]=d,x)|0);e=1;i=b;return e|0}function ej(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;b=i;i=i+8|0;e=b|0;if((sY(d,e)|0)==0){dH(a,0,c[e>>2]|0);f=0}else{f=1}i=b;return f|0}function ek(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;i=i+8|0;e=b|0;if((sZ(d,e)|0)!=0){f=1;i=b;return f|0}d=(c[e>>2]|0)+(c[a+4684>>2]|0)|0;g=(d|0)<1?1:d;c[e>>2]=g;dH(a,0,g);f=0;i=b;return f|0}function el(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;d=i;i=i+16|0;f=d|0;g=d+8|0;c[f>>2]=e;if((aQ(e|0,41904)|0)==0){sL(2,41616,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);if((os(c[b+3484>>2]|0)|0)==0){h=0;i=d;return h|0}sL(0,41248,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);h=1;i=d;return h|0}e=b+3484|0;b=0;L1888:while(1){do{if((a[c[f>>2]|0]|0)==0){h=b;j=1491;break L1888}if((s0(f,g,45920,45616)|0)!=0){break L1888}sL(2,40560,(x=i,i=i+8|0,c[x>>2]=c[g>>2],x)|0);}while((ot(c[e>>2]|0,c[g>>2]|0,39984,0)|0)==0);sL(0,39656,(x=i,i=i+8|0,c[x>>2]=c[g>>2],x)|0);b=1}if((j|0)==1491){i=d;return h|0}sL(0,40888,(x=i,i=i+8|0,c[x>>2]=c[f>>2],x)|0);h=1;i=d;return h|0}function em(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;d=i;i=i+16|0;f=d|0;g=d+8|0;c[f>>2]=e;if((a[e]|0)==0){h=0;i=d;return h|0}e=b+3484|0;while(1){if((s0(f,g,45920,45616)|0)!=0){break}b=ol(c[e>>2]|0,c[g>>2]|0)|0;j=c[g>>2]|0;if((b|0)==0){sL(0,42488,(x=i,i=i+8|0,c[x>>2]=j,x)|0)}else{sL(2,42216,(x=i,i=i+8|0,c[x>>2]=j,x)|0);j=c[e>>2]|0;ok(j,b)|0;oi(b)}if((a[c[f>>2]|0]|0)==0){h=0;k=1505;break}}if((k|0)==1505){i=d;return h|0}sL(0,42888,(x=i,i=i+8|0,c[x>>2]=c[f>>2],x)|0);h=1;i=d;return h|0}function en(a,b,d){a=a|0;b=b|0;d=d|0;return(st(c[a+3484>>2]|0,d,1)|0)!=0|0}function eo(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;b=i;i=i+8|0;e=b|0;if((sY(d,e)|0)!=0){f=1;i=b;return f|0}d=ol(c[a+3484>>2]|0,c[e>>2]|0)|0;if((d|0)==0){f=0;i=b;return f|0}sL(2,43216,(x=i,i=i+8|0,c[x>>2]=c[e>>2],x)|0);n4(d,1);f=0;i=b;return f|0}function ep(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;b=i;i=i+8|0;e=b|0;if((sY(d,e)|0)!=0){f=1;i=b;return f|0}d=ol(c[a+3484>>2]|0,c[e>>2]|0)|0;if((d|0)==0){f=0;i=b;return f|0}sL(2,43544,(x=i,i=i+8|0,c[x>>2]=c[e>>2],x)|0);n4(d,0);f=0;i=b;return f|0}function eq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;i=i+8|0;e=b|0;if((sY(d,e)|0)!=0){f=1;i=b;return f|0}d=c[e>>2]|0;if((d|0)==0){sL(2,44400,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);g=a+1760|0;dd(g,0,1);dd(g,1,1);dd(g,2,1);f=0;i=b;return f|0}else{sL(2,44120,(x=i,i=i+8|0,c[x>>2]=d,x)|0);dd(a+1760|0,(c[e>>2]|0)-1|0,1);f=0;i=b;return f|0}return 0}function er(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;i=i+8|0;e=b|0;if((sY(d,e)|0)!=0){f=1;i=b;return f|0}d=c[e>>2]|0;if((d|0)==0){sL(2,45024,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);g=a+1760|0;dd(g,0,0);dd(g,1,0);dd(g,2,0);f=0;i=b;return f|0}else{sL(2,44704,(x=i,i=i+8|0,c[x>>2]=d,x)|0);dd(a+1760|0,(c[e>>2]|0)-1|0,0);f=0;i=b;return f|0}return 0}function es(a,b,d){a=a|0;b=b|0;d=d|0;d=i;b=a+1760|0;a=dc(b,0)|0;sp(45320,(x=i,i=i+16|0,c[x>>2]=1,c[x+8>>2]=a,x)|0);a=dc(b,1)|0;sp(45320,(x=i,i=i+16|0,c[x>>2]=2,c[x+8>>2]=a,x)|0);a=dc(b,2)|0;sp(45320,(x=i,i=i+16|0,c[x>>2]=3,c[x+8>>2]=a,x)|0);i=d;return 0}function et(a,b,d){a=a|0;b=b|0;d=d|0;c[a+4680>>2]=2;sU(57736,1);return 0}function eu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;b=i;i=i+8|0;e=b|0;if((s_(d,e)|0)==0){dG(a,c[e>>2]|0);f=0}else{f=1}i=b;return f|0}function ev(b,c,d){b=b|0;c=c|0;d=d|0;dG(b,(a[b+4676|0]|0)==0|0);return 0}function ew(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;b=i;i=i+8|0;e=b|0;if((s_(d,e)|0)!=0){f=1;i=b;return f|0}dH(a,0,(c[e>>2]|0)!=0|0);f=0;i=b;return f|0}function ex(a,b,d){a=a|0;b=b|0;d=d|0;if((c[a+4688>>2]|0)==0){dH(a,0,1);return 0}else{dH(a,0,0);return 0}return 0}function ey(a,b,c){a=a|0;b=b|0;c=c|0;dK(a);return 0}function ez(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;i=i+16|0;e=b|0;f=b+8|0;c[e>>2]=d;if((s0(e,f,45920,45616)|0)!=0){g=1;i=b;return g|0}d=c[f>>2]|0;if(d>>>0>1){g=1;i=b;return g|0}g=(fd(a+3488+(d*568|0)|0,c[e>>2]|0)|0)!=0|0;i=b;return g|0}function eA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;i=i+16|0;e=b|0;f=b+8|0;c[e>>2]=d;if((s0(e,f,45920,45616)|0)!=0){g=1;i=b;return g|0}d=c[f>>2]|0;if(d>>>0>1){g=1;i=b;return g|0}g=(fe(a+3488+(d*568|0)|0,c[e>>2]|0)|0)!=0|0;i=b;return g|0}function eB(a,b,d){a=a|0;b=b|0;d=d|0;dI(a,46680,46272)|0;c[a+4680>>2]=1;return 0}function eC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;i=i+8|0;e=b|0;if((sY(d,e)|0)!=0){f=1;i=b;return f|0}d=c[e>>2]|0;if(d>>>0>999){g=255}else{g=(d<<8>>>0)/1e3|0}c[e>>2]=g;fK(c[a+3476>>2]|0,g);f=0;i=b;return f|0}function eD(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;d=i;i=i+8|0;f=d|0;do{if((a[e]|0)==0){g=b+2424|0;if((a[b+2426|0]|0)==0){h=0;break}fq(g,1);fq(g,2);fq(g,3);h=0}else{if((sY(e,f)|0)!=0){h=1;break}if((a[b+2426|0]|0)==0){g=c[f>>2]|0;dm(b+1760|0,(g|0)==0?0:g-1|0);h=0;break}else{fq(b+2424|0,c[f>>2]|0);h=0;break}}}while(0);i=d;return h|0}function eE(b){b=b|0;c[b+304>>2]=0;c[b+308>>2]=0;a[b+312|0]=0;u6(b|0,0,258);u6(b+260|0,0,20);u6(b+283|0,0,18);a[b+16|0]=-88;a[b+19|0]=34;a[b+30|0]=100;a[b+8|0]=24;a[b+9|0]=-120;a[b+11|0]=32;return}function eF(b,c){b=b|0;c=c|0;var d=0,e=0;d=aZ(c|0,44376)|0;if((d|0)==0){e=1;return e|0}c=(bK(b|0,1,256,d|0)|0)==256;av(d|0)|0;if(!c){e=1;return e|0}a[b+256|0]=-128;a[b+257|0]=0;e=0;return e|0}function eG(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0;f=bZ(0)|0;c[a+260>>2]=f+2082844800;if((e|0)==0){e=((d[a+237|0]|0)<<8|(d[a+238|0]|0))<<8;g=e|(d[a+239|0]|0);c[a+264>>2]=-2082844800-f+b-((e&8388608|0)==0?g:g|-16777216);return}else{c[a+264>>2]=b;return}}function eH(a,b){a=a|0;b=b|0;return 0}function eI(a,b){a=a|0;b=b|0;c[a+332>>2]=b;return}function eJ(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=c&7;c=a[d]|0;if(c<<24>>24==0){a[b+76+(e<<5)+8|0]=32;f=d}else{a[b+76+(e<<5)+8|0]=c;f=d+1|0}d=a[f]|0;if(d<<24>>24==0){a[b+76+(e<<5)+9|0]=32;g=f}else{a[b+76+(e<<5)+9|0]=d;g=f+1|0}f=a[g]|0;if(f<<24>>24==0){a[b+76+(e<<5)+10|0]=32;h=g}else{a[b+76+(e<<5)+10|0]=f;h=g+1|0}g=a[h]|0;if(g<<24>>24==0){a[b+76+(e<<5)+11|0]=32;i=h}else{a[b+76+(e<<5)+11|0]=g;i=h+1|0}h=a[i]|0;if(h<<24>>24==0){a[b+76+(e<<5)+12|0]=32;j=i}else{a[b+76+(e<<5)+12|0]=h;j=i+1|0}i=a[j]|0;if(i<<24>>24==0){a[b+76+(e<<5)+13|0]=32;k=j}else{a[b+76+(e<<5)+13|0]=i;k=j+1|0}j=a[k]|0;if(j<<24>>24==0){a[b+76+(e<<5)+14|0]=32;l=k}else{a[b+76+(e<<5)+14|0]=j;l=k+1|0}k=a[l]|0;l=b+76+(e<<5)+15|0;if(k<<24>>24==0){m=32;a[l]=m;return}else{m=k;a[l]=m;return}}function eK(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=c&7;c=0;f=d;while(1){d=a[f]|0;if(d<<24>>24==0){a[b+76+(e<<5)+16+c|0]=32;g=f}else{a[b+76+(e<<5)+16+c|0]=d;g=f+1|0}d=c+1|0;if(d>>>0<16){c=d;f=g}else{break}}return}function eL(a,b){a=a|0;b=b|0;var e=0,f=0,g=0;if((b|0)==0){c[a+260>>2]=(bZ(0)|0)+2082844800;c[a+264>>2]=0;return}else{e=ec(b)|0;b=bZ(0)|0;c[a+260>>2]=b+2082844800;f=((d[a+237|0]|0)<<8|(d[a+238|0]|0))<<8;g=f|(d[a+239|0]|0);c[a+264>>2]=e-2082844800-b-((f&8388608|0)==0?g:g|-16777216);return}}function eM(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=b+283|0;g=a[f]|0;h=e&255;a[f]=e;if((h&4|0)!=0){c[b+272>>2]=0;c[b+268>>2]=0;c[b+276>>2]=0;return}if(((h&2^2)&((g^e)&255)|0)==0){return}g=b+268|0;h=b+282|0;f=a[h]|0;if((c[g>>2]|0)!=0){i=(f&255)>>>7;a[b+300|0]=i;j=c[b+296>>2]|0;if((j|0)==0){k=f}else{b1[j&511](c[b+292>>2]|0,i);k=a[h]|0}a[h]=k<<1|(k&255)>>>7;k=b+276|0;i=(c[k>>2]|0)+1|0;c[k>>2]=i;if(i>>>0<=7){return}c[k>>2]=0;c[g>>2]=0;c[b+272>>2]=0;return}k=f<<1;f=k|e&1;a[h]=f;e=b+276|0;i=(c[e>>2]|0)+1|0;c[e>>2]=i;if(i>>>0<=7){return}i=b+272|0;j=c[i>>2]|0;do{if((j|0)==3){if((a[b+256|0]|0)>=0){a[b+(d[b+280|0]<<5&224|(d[b+281|0]|0)>>>2&31)|0]=f}c[i>>2]=0}else if((j|0)==1){l=a[b+280|0]|0;m=l&255;do{if(l<<24>>24==53){a[b+256|0]=k&-128}else{if((a[b+256|0]|0)<0){break}if((m&227|0)==1){n=m>>>2<<3&24;o=b+260|0;c[o>>2]=c[o>>2]&~(255<<n)|(f&255)<<n;break}if((m&243|0)==33){a[b+(m>>>2&3|8)|0]=f;break}if(l<<24>>24==49){a[b+257|0]=f;break}if((m&195|0)!=65){break}a[b+(m>>>2&15|16)|0]=f}}while(0);c[i>>2]=0}else if((j|0)==2){a[b+281|0]=f;m=a[b+280|0]|0;if(m<<24>>24<0){a[h]=a[b+((m&255)<<5&224|(k&255)>>>2&31)|0]|0;c[i>>2]=0;c[g>>2]=1;break}else{c[i>>2]=3;break}}else if((j|0)==0){a[b+280|0]=f;m=f&255;if((m&120|0)==56){c[i>>2]=2;break}if((m&128|0)==0){c[i>>2]=1;break}l=m>>>2;do{if((m&227|0)==129){a[h]=(c[b+260>>2]|0)>>>((l<<3&24)>>>0)&255}else{if((m&243|0)==161){a[h]=a[b+(l&3|8)|0]|0;break}if((m&195|0)==193){a[h]=a[b+(l&15|16)|0]|0;break}else{a[h]=0;break}}}while(0);c[i>>2]=0;c[g>>2]=1}}while(0);c[e>>2]=0;return}function eN(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=b+260|0;g=c[f>>2]|0;if((c[b+284>>2]|0)==0){h=b+288|0;i=(c[h>>2]|0)+e|0;c[h>>2]=i;if(i>>>0>7833600){c[h>>2]=i-7833600;i=g+1|0;c[f>>2]=i;j=i}else{j=g}i=b+264|0;h=j+(c[i>>2]|0)|0;c[f>>2]=h;c[i>>2]=0;k=h}else{h=(bZ(0)|0)+2082844800|0;i=(d[b+237|0]<<8|d[b+238|0])<<8;j=i|d[b+239|0];e=((i&8388608|0)==0?j:j|-16777216)+h+(c[b+264>>2]|0)|0;c[f>>2]=e;k=e}if((k|0)==(g|0)){return}g=b+312|0;do{if((a[g]|0)!=1){a[g]=1;k=c[b+308>>2]|0;if((k|0)==0){break}b1[k&511](c[b+304>>2]|0,1);if((a[g]|0)!=0){break}return}}while(0);a[g]=0;g=c[b+308>>2]|0;if((g|0)==0){return}b1[g&511](c[b+304>>2]|0,0);return}function eO(b){b=b|0;var d=0;a[b+9|0]=0;a[b+10|0]=0;a[b+11|0]=0;c[b+16>>2]=0;c[b+20>>2]=0;c[b+40>>2]=0;c[b+44>>2]=0;d=b;c[d>>2]=0;c[d+4>>2]=0;c[b+48>>2]=4096;c[b+52>>2]=u0(4096)|0;c[b+60>>2]=4080;c[b+64>>2]=4;c[b+68>>2]=0;c[b+72>>2]=0;c[b+76>>2]=0;c[b+108>>2]=0;c[b+140>>2]=0;c[b+172>>2]=0;c[b+204>>2]=0;c[b+236>>2]=0;c[b+268>>2]=0;c[b+300>>2]=0;c[b+332>>2]=0;return}function eP(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=d&7;c[b+76+(f<<5)>>2]=1;c[b+76+(f<<5)+4>>2]=e;e=b+76+(f<<5)+8|0;d=e|0;y=541410128;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;d=e+4|0;y=538976288;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;d=b+76+(f<<5)+16|0;u7(d|0,52488,16)|0;return}function eQ(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;g=(c[b+60>>2]&e)>>>((c[b+64>>2]|0)>>>0);do{if((g|0)==32){e=b;if((c[e>>2]|0)!=5){h=0;break}j=b+40|0;k=c[j>>2]|0;l=c[b+44>>2]|0;if(k>>>0>=l>>>0){h=0;break}m=a[(c[b+52>>2]|0)+k|0]|0;n=k+1|0;c[j>>2]=n;if(n>>>0<l>>>0){h=m;break}c[e>>2]=7;e=b+9|0;a[e]=a[e]&-125|108;a[b+5|0]=0;h=m}else if((g|0)==2){h=a[b+7|0]|0}else if((g|0)==3){h=a[b+8|0]&15}else if((g|0)==1){h=a[b+6|0]|0}else if((g|0)==7){h=-1}else if((g|0)==0){h=a[b+5|0]|0}else if((g|0)==4){h=a[b+9|0]|0}else if((g|0)==6|(g|0)==38){m=b;if((c[m>>2]|0)!=5){h=0;break}e=b+40|0;l=c[e>>2]|0;n=c[b+44>>2]|0;if(l>>>0>=n>>>0){h=0;break}j=a[(c[b+52>>2]|0)+l|0]|0;k=l+1|0;c[e>>2]=k;if(k>>>0<n>>>0){h=j;break}c[m>>2]=7;m=b+9|0;a[m]=a[m]&-125|108;a[b+5|0]=0;h=j}else if((g|0)==5){j=b+11|0;m=a[j]|0;n=(((d[b+9|0]|0)>>>2^a[b+8|0])&7)==0?m|8:m&-9;a[j]=n;h=n}else{d$(46640,(x=i,i=i+16|0,c[x>>2]=g,c[x+8>>2]=255,x)|0);h=-1}}while(0);i=f;return h|0}function eR(a,b,c){a=a|0;b=b|0;c=c|0;return}function eS(b){b=b|0;var d=0;a[b+9|0]=0;a[b+10|0]=0;d=b;c[d>>2]=0;c[d+4>>2]=0;a[b+11|0]=8;a[b+12|0]=0;c[b+16>>2]=0;c[b+20>>2]=0;c[b+40>>2]=0;c[b+44>>2]=0;c[b+68>>2]=0;c[b+72>>2]=0;return}function eT(b){b=b|0;var d=0;c[b>>2]=7;d=b+9|0;a[d]=a[d]&-125|108;a[b+5|0]=0;return}function eU(b){b=b|0;var d=0;c[b>>2]=7;d=b+9|0;a[d]=a[d]&-125|108;a[b+5|0]=0;return}function eV(b){b=b|0;var d=0;c[b+40>>2]=0;c[b+44>>2]=0;c[b>>2]=6;d=b+9|0;a[d]=a[d]&-125|96;return}function eW(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;g=b;h=(c[b+60>>2]&d)>>>((c[b+64>>2]|0)>>>0);if((h|0)==1){d=e&-97;j=b+6|0;k=d&255;l=a[j]^d;a[j]=d;d=b;j=c[d>>2]|0;if((j|0)==4){m=l&255;if((e&16&l)<<24>>24!=0){n=b+16|0;o=c[n>>2]|0;p=b+20|0;if(o>>>0<(c[p>>2]|0)>>>0){a[g+24+o|0]=a[b+4|0]|0;q=(c[n>>2]|0)+1|0;c[n>>2]=q;r=q}else{r=o}do{if((r|0)==1){o=a[b+24|0]|0;q=b+68|0;c[q>>2]=0;c[b+72>>2]=0;n=o&255;if((n|0)==60){c[p>>2]=6;c[q>>2]=70;break}else if((n|0)==21){c[p>>2]=6;c[q>>2]=6;break}else if((n|0)==3){c[p>>2]=6;c[q>>2]=66;break}else if((n|0)==4){c[p>>2]=6;c[q>>2]=36;break}else if((n|0)==26){c[p>>2]=6;c[q>>2]=64;break}else if((n|0)==27){c[p>>2]=6;c[q>>2]=88;break}else if((n|0)==47){c[p>>2]=10;c[q>>2]=52;break}else if((n|0)==8){c[p>>2]=6;c[q>>2]=42;break}else if((n|0)==10){c[p>>2]=6;c[q>>2]=98;break}else if((n|0)==18){c[p>>2]=6;c[q>>2]=90;break}else if((n|0)==0){c[p>>2]=6;c[q>>2]=80;break}else if((n|0)==37){c[p>>2]=10;c[q>>2]=38;break}else if((n|0)==40){c[p>>2]=10;c[q>>2]=30;break}else if((n|0)==42){c[p>>2]=10;c[q>>2]=100;break}else{d$(39624,(x=i,i=i+8|0,c[x>>2]=n,x)|0);c[d>>2]=7;n=b+9|0;a[n]=a[n]&-125|108;a[b+5|0]=2;break}}}while(0);p=b+9|0;a[p]=a[p]&-33}if((m&(k&16^16)|0)==0){i=f;return}if((c[b+16>>2]|0)>>>0<(c[b+20>>2]|0)>>>0){m=b+9|0;a[m]=a[m]|32;i=f;return}m=c[b+68>>2]|0;if((m|0)==0){c[d>>2]=7;p=b+9|0;a[p]=a[p]&-125|108;a[b+5|0]=2;i=f;return}else{b0[m&127](g);i=f;return}}else if((j|0)==1){if((e&4&l)<<24>>24==0){i=f;return}c[d>>2]=2;i=f;return}else if((j|0)==7){if((e&16&l)<<24>>24!=0){m=b+9|0;a[m]=a[m]&-33}if((l&255&(k&16^16)|0)==0){i=f;return}c[d>>2]=8;m=b+9|0;a[m]=a[m]|124;a[b+5|0]=0;i=f;return}else if((j|0)==6){m=l&255;if((e&16&l)<<24>>24!=0){p=b+40|0;r=c[p>>2]|0;if(r>>>0<(c[b+44>>2]|0)>>>0){a[(c[b+52>>2]|0)+r|0]=a[b+4|0]|0;c[p>>2]=(c[p>>2]|0)+1}p=b+9|0;a[p]=a[p]&-33}if((m&(k&16^16)|0)==0){i=f;return}if((c[b+40>>2]|0)>>>0<(c[b+44>>2]|0)>>>0){m=b+9|0;a[m]=a[m]|32;i=f;return}else{c[d>>2]=7;m=b+9|0;a[m]=a[m]&-125|108;a[b+5|0]=2;i=f;return}}else if((j|0)==8){if((e&16&l)<<24>>24!=0){m=b+9|0;a[m]=a[m]&-33}if((l&255&(k&16^16)|0)==0){i=f;return}c[d>>2]=0;m=b+9|0;a[m]=a[m]&-125;i=f;return}else if((j|0)==5){if((e&16&l)<<24>>24!=0){j=b+9|0;a[j]=a[j]&-33}if((l&255&(k&16^16)|0)==0){i=f;return}k=b+40|0;l=(c[k>>2]|0)+1|0;c[k>>2]=l;if(l>>>0<(c[b+44>>2]|0)>>>0){a[b+5|0]=a[(c[b+52>>2]|0)+l|0]|0;l=b+9|0;a[l]=a[l]|32;i=f;return}else{c[d>>2]=7;d=b+9|0;a[d]=a[d]&-125|108;a[b+5|0]=0;i=f;return}}else{i=f;return}}else if((h|0)==0){a[b+4|0]=e;i=f;return}else if((h|0)==2){d=b+7|0;l=e&255;k=a[d]^e;a[d]=e;d=b;j=c[d>>2]|0;L2272:do{if((j|0)==0){if((e&1&k)<<24>>24==0){break}c[d>>2]=1;a[b+5|0]=a[b+4|0]|0;m=b+6|0;a[m]=a[m]|64}else if((j|0)==2){if((k&255&(l&1^1)|0)==0){break}m=a[b+4|0]|0;p=m&127;if(p<<24>>24!=0&(m&1)==0){m=p;p=0;while(1){r=p+1|0;n=(m&255)>>>1;if(n<<24>>24!=0&(n&1)==0){m=n;p=r}else{s=r;break}}}else{s=0}c[b+56>>2]=s;p=b+6|0;a[p]=a[p]&-9;p=s&7;do{if((c[g+76+(p<<5)>>2]|0)!=0){m=c[g+76+(p<<5)+4>>2]|0;if((m|0)==65535){break}if((ol(c[b+332>>2]|0,m)|0)==0){break}c[d>>2]=4;m=b+9|0;a[m]=a[m]&-125|104;c[b+16>>2]=0;c[b+20>>2]=16;break L2272}}while(0);c[d>>2]=0;p=b+9|0;a[p]=a[p]&-125}else if((j|0)==5){if((e&2&k)<<24>>24==0){break}if((c[b+40>>2]|0)>>>0>=(c[b+44>>2]|0)>>>0){break}p=b+11|0;a[p]=a[p]|64}else if((j|0)==6){if((e&2&k)<<24>>24==0){break}if((c[b+40>>2]|0)>>>0>=(c[b+44>>2]|0)>>>0){break}p=b+11|0;a[p]=a[p]|64}}while(0);if((k&255&(l&2^2)|0)==0){i=f;return}l=b+11|0;a[l]=a[l]&-65;i=f;return}else if((h|0)==3){l=b+8|0;k=a[l]|0;a[l]=e;if((e&2&(k^2))<<24>>24==0){i=f;return}k=b;l=c[k>>2]|0;if((l|0)==5){c[k>>2]=7;j=b+9|0;a[j]=a[j]&-125|108;a[b+5|0]=0;i=f;return}else if((l|0)==6){c[k>>2]=7;k=b+9|0;a[k]=a[k]&-125|108;a[b+5|0]=0;i=f;return}else{i=f;return}}else if((h|0)==4){a[b+10|0]=e;i=f;return}else if((h|0)==5){k=b+11|0;a[k]=a[k]|64;i=f;return}else if((h|0)==32){k=b;if((c[k>>2]|0)!=6){i=f;return}l=b+40|0;j=c[l>>2]|0;d=b+44|0;if(j>>>0>=(c[d>>2]|0)>>>0){i=f;return}a[(c[b+52>>2]|0)+j|0]=e;j=(c[l>>2]|0)+1|0;c[l>>2]=j;if(j>>>0<(c[d>>2]|0)>>>0){i=f;return}d=c[b+72>>2]|0;if((d|0)==0){c[k>>2]=7;k=b+9|0;a[k]=a[k]&-125|108;a[b+5|0]=2;i=f;return}else{b0[d&127](g);i=f;return}}else if((h|0)==6|(h|0)==7){i=f;return}else{d$(43168,(x=i,i=i+16|0,c[x>>2]=h,c[x+8>>2]=e&255,x)|0);i=f;return}}function eX(b){b=b|0;var d=0,e=0;d=b+52|0;u6(c[d>>2]|0,0,13);a[c[d>>2]|0]=-16;c[b+40>>2]=0;c[b+44>>2]=13;c[b>>2]=5;e=b+9|0;a[e]=a[e]&-125|100;a[b+5|0]=a[c[d>>2]|0]|0;return}function eY(b){b=b|0;var c=0;c=a[b+28|0]|0;fa(b,((d[b+25|0]|0)<<8&7936|(d[b+26|0]|0))<<8|(d[b+27|0]|0),c<<24>>24==0?256:c&255);return}function eZ(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;e=a[b+28|0]|0;f=e<<24>>24==0?256:e&255;e=f<<9;g=b+48|0;do{if((c[g>>2]|0)>>>0<e>>>0){h=b+52|0;j=u2(c[h>>2]|0,e)|0;if((j|0)!=0){c[h>>2]=j;c[g>>2]=e;break}d$(36592,(x=i,i=i+8|0,c[x>>2]=f,x)|0);c[b>>2]=7;j=b+9|0;a[j]=a[j]&-125|108;a[b+5|0]=2;i=d;return}}while(0);c[b+40>>2]=0;c[b+44>>2]=e;c[b+72>>2]=72;c[b>>2]=6;e=b+9|0;a[e]=a[e]&-125|96;i=d;return}function e_(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b+76+((c[b+56>>2]&7)<<5)|0;f=(c[e>>2]|0)==0?0:e;e=b+52|0;u6(c[e>>2]|0,0,256);if((f|0)!=0){g=f+8|0;h=(c[e>>2]|0)+8|0;i=g|0;j=g+4|0;g=d[j]|d[j+1|0]<<8|d[j+2|0]<<16|d[j+3|0]<<24|0;j=h|0;y=d[i]|d[i+1|0]<<8|d[i+2|0]<<16|d[i+3|0]<<24|0;a[j]=y&255;y=y>>8;a[j+1|0]=y&255;y=y>>8;a[j+2|0]=y&255;y=y>>8;a[j+3|0]=y&255;j=h+4|0;y=g;a[j]=y&255;y=y>>8;a[j+1|0]=y&255;y=y>>8;a[j+2|0]=y&255;y=y>>8;a[j+3|0]=y&255;j=(c[e>>2]|0)+16|0;g=f+16|0;u7(j|0,g|0,16)|0}a[(c[e>>2]|0)+4|0]=32;c[b+40>>2]=0;g=a[b+28|0]|0;c[b+44>>2]=(g&255)<36?g&255:36;c[b>>2]=5;g=b+9|0;a[g]=a[g]&-125|100;a[b+5|0]=a[c[e>>2]|0]|0;return}function e$(a,b){a=a|0;b=b|0;c[a+4>>2]=b;return}function e0(a,b){a=a|0;b=b|0;c[a+8>>2]=b;return}function e1(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=c[b+56>>2]&7;do{if((c[b+76+(f<<5)>>2]|0)!=0){g=c[b+76+(f<<5)+4>>2]|0;if((g|0)==65535){break}h=ol(c[b+332>>2]|0,g)|0;if((h|0)==0){break}g=b+52|0;u6(c[g>>2]|0,0,512);j=b+40|0;c[j>>2]=0;k=b+44|0;c[k>>2]=0;l=d[b+26|0]|0;m=l&63;do{if((m|0)==1){a[c[g>>2]|0]=1;a[(c[g>>2]|0)+1|0]=10;c[k>>2]=12}else if((m|0)==48){a[c[g>>2]|0]=48;a[(c[g>>2]|0)+1|0]=33;n=(c[g>>2]|0)+14|0;u7(n|0,51008,20)|0;c[k>>2]=34}else if((m|0)==3){a[c[g>>2]|0]=3;a[(c[g>>2]|0)+1|0]=22;c[k>>2]=24}else if((m|0)==4){a[c[g>>2]|0]=4;a[(c[g>>2]|0)+1|0]=22;a[(c[g>>2]|0)+2|0]=0;nu(c[g>>2]|0,3,c[h+32>>2]&65535);a[(c[g>>2]|0)+5|0]=c[h+36>>2]&255;nu(c[g>>2]|0,20,3600);c[k>>2]=32}else{d$(50208,(x=i,i=i+8|0,c[x>>2]=l,x)|0);if((c[k>>2]|0)!=0){break}c[b>>2]=7;n=b+9|0;a[n]=a[n]&-125|108;a[b+5|0]=2;i=e;return}}while(0);c[b>>2]=5;k=b+9|0;a[k]=a[k]&-125|100;a[b+5|0]=a[(c[g>>2]|0)+(c[j>>2]|0)|0]|0;i=e;return}}while(0);c[b>>2]=7;f=b+9|0;a[f]=a[f]&-125|108;a[b+5|0]=2;i=e;return}function e2(b){b=b|0;var d=0,e=0,f=0;d=i;e=a[b+28|0]&3;if((e|0)==3){f=52448}else if((e|0)==1){f=54232}else if((e|0)==0){f=55112}else if((e|0)==2){f=53080}else{f=0}d$(51696,(x=i,i=i+16|0,c[x>>2]=c[b+56>>2],c[x+8>>2]=f,x)|0);c[b>>2]=7;f=b+9|0;a[f]=a[f]&-125|108;a[b+5|0]=0;i=d;return}function e3(b){b=b|0;var d=0,e=0,f=0;d=c[b+56>>2]&7;do{if((c[b+76+(d<<5)>>2]|0)!=0){e=c[b+76+(d<<5)+4>>2]|0;if((e|0)==65535){break}f=ol(c[b+332>>2]|0,e)|0;if((f|0)==0){break}e=n8(f)|0;f=b+52|0;nv(c[f>>2]|0,0,e-1|0);nv(c[f>>2]|0,4,512);c[b+40>>2]=0;c[b+44>>2]=8;c[b>>2]=5;e=b+9|0;a[e]=a[e]&-125|100;a[b+5|0]=a[c[f>>2]|0]|0;return}}while(0);c[b>>2]=7;d=b+9|0;a[d]=a[d]&-125|108;a[b+5|0]=2;return}function e4(a){a=a|0;fa(a,(((d[a+26|0]|0)<<8|(d[a+27|0]|0))<<8|(d[a+28|0]|0))<<8|(d[a+29|0]|0),(d[a+31|0]|0)<<8|(d[a+32|0]|0));return}function e5(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=(d[b+31|0]|0)<<8|(d[b+32|0]|0);g=f<<9;h=b+48|0;do{if((c[h>>2]|0)>>>0<g>>>0){j=b+52|0;k=u2(c[j>>2]|0,g)|0;if((k|0)!=0){c[j>>2]=k;c[h>>2]=g;break}d$(36592,(x=i,i=i+8|0,c[x>>2]=f,x)|0);c[b>>2]=7;k=b+9|0;a[k]=a[k]&-125|108;a[b+5|0]=2;i=e;return}}while(0);c[b+40>>2]=0;c[b+44>>2]=g;c[b+72>>2]=102;c[b>>2]=6;g=b+9|0;a[g]=a[g]&-125|96;i=e;return}function e6(b){b=b|0;var d=0,e=0;d=c[b+56>>2]&7;do{if((c[b+76+(d<<5)>>2]|0)!=0){e=c[b+76+(d<<5)+4>>2]|0;if((e|0)==65535){break}if((ol(c[b+332>>2]|0,e)|0)==0){break}c[b+40>>2]=0;c[b+44>>2]=0;c[b>>2]=7;e=b+9|0;a[e]=a[e]&-125|108;a[b+5|0]=0;return}}while(0);c[b>>2]=7;d=b+9|0;a[d]=a[d]&-125|108;a[b+5|0]=2;return}function e7(b){b=b|0;var d=0,e=0;d=b+52|0;u6(c[d>>2]|0,0,512);c[b+40>>2]=0;c[b+44>>2]=4;c[b>>2]=5;e=b+9|0;a[e]=a[e]&-125|100;a[b+5|0]=a[c[d>>2]|0]|0;return}function e8(a){a=a|0;e9(a,(((d[a+26|0]|0)<<8|(d[a+27|0]|0))<<8|(d[a+28|0]|0))<<8|(d[a+29|0]|0),(d[a+31|0]|0)<<8|(d[a+32|0]|0));return}function e9(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;g=c[b+56>>2]&7;do{if((c[b+76+(g<<5)>>2]|0)!=0){h=c[b+76+(g<<5)+4>>2]|0;if((h|0)==65535){break}j=ol(c[b+332>>2]|0,h)|0;if((j|0)==0){break}h=e<<9;k=b+40|0;l=c[k>>2]|0;if((h|0)!=(l|0)){d$(33776,(x=i,i=i+16|0,c[x>>2]=h,c[x+8>>2]=l,x)|0);c[b>>2]=7;l=b+9|0;a[l]=a[l]&-125|108;a[b+5|0]=2;i=f;return}if((op(j,c[b+52>>2]|0,d,e)|0)==0){c[k>>2]=0;c[b+44>>2]=0;c[b+72>>2]=0;c[b>>2]=7;k=b+9|0;a[k]=a[k]&-125|108;a[b+5|0]=0;i=f;return}else{d$(31536,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);c[b>>2]=7;k=b+9|0;a[k]=a[k]&-125|108;a[b+5|0]=2;i=f;return}}}while(0);c[b>>2]=7;e=b+9|0;a[e]=a[e]&-125|108;a[b+5|0]=2;i=f;return}function fa(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;g=c[b+56>>2]&7;do{if((c[b+76+(g<<5)>>2]|0)!=0){h=c[b+76+(g<<5)+4>>2]|0;if((h|0)==65535){break}j=ol(c[b+332>>2]|0,h)|0;if((j|0)==0){break}h=e<<9;k=b+48|0;l=b+52|0;m=c[l>>2]|0;do{if((c[k>>2]|0)>>>0<h>>>0){n=u2(m,h)|0;if((n|0)!=0){c[l>>2]=n;c[k>>2]=h;o=n;break}d$(30248,(x=i,i=i+8|0,c[x>>2]=e,x)|0);c[b>>2]=7;n=b+9|0;a[n]=a[n]&-125|108;a[b+5|0]=2;i=f;return}else{o=m}}while(0);if((oo(j,o,d,e)|0)==0){c[b+40>>2]=0;c[b+44>>2]=h;c[b>>2]=5;m=b+9|0;a[m]=a[m]&-125|100;a[b+5|0]=a[c[b+52>>2]|0]|0;i=f;return}else{d$(29280,(x=i,i=i+16|0,c[x>>2]=d,c[x+8>>2]=e,x)|0);c[b>>2]=7;m=b+9|0;a[m]=a[m]&-125|108;a[b+5|0]=2;i=f;return}}}while(0);c[b>>2]=7;e=b+9|0;a[e]=a[e]&-125|108;a[b+5|0]=2;i=f;return}function fb(b){b=b|0;var c=0;c=a[b+28|0]|0;e9(b,((d[b+25|0]|0)<<8&7936|(d[b+26|0]|0))<<8|(d[b+27|0]|0),c<<24>>24==0?256:c&255);return}function fc(a){a=a|0;c[a+300>>2]=0;c[a+304>>2]=0;c[a+564>>2]=0;u6(a|0,0,44);return}function fd(a,b){a=a|0;b=b|0;var d=0;d=a+564|0;a=c[d>>2]|0;if((a|0)!=0){o2(a)}a=o8(b)|0;c[d>>2]=a;return(a|0)==0|0}function fe(a,b){a=a|0;b=b|0;var d=0;d=s5(42136,b)|0;b=a+564|0;a=c[b>>2]|0;if((a|0)!=0){o2(a)}a=o8(d)|0;c[b>>2]=a;u1(d);return(a|0)==0|0}function ff(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=a|0;c[e>>2]=b;f=a+4|0;c[f>>2]=d;g=a;mN(b,d,g,272);mO(b,d,g,256);mP(b,d,g,310);mQ(b,d,g,2);na(c[e>>2]|0,c[f>>2]|0,1);return}function fg(a,b){a=a|0;b=b|0;fm(a);return}function fh(a,b){a=a|0;b=b|0;fl(a);return}function fi(a,b){a=a|0;b=b|0;var d=0,e=0;d=a+32|0;e=b&255;if((c[d>>2]|0)==(e|0)){return}c[d>>2]=b<<24>>24!=0;o6(c[a+564>>2]|0,e)|0;return}function fj(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0;g=f>>>1;c[a+12>>2]=b;c[a+16>>2]=d;c[a+20>>2]=e;c[a+24>>2]=g;o7(c[a+564>>2]|0,b,e,d,g)|0;return}function fk(a,b){a=a|0;b=b|0;var d=0,e=0;fl(a);fm(a);d=a|0;na(c[d>>2]|0,c[a+4>>2]|0,1);e=a+8|0;a=(c[e>>2]|0)+(b*15|0)|0;c[e>>2]=a;nc(c[d>>2]|0,a>>>5);c[e>>2]=c[e>>2]&31;return}function fl(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b+304|0;e=c[d>>2]|0;do{if((e|0)!=0){f=b+300|0;g=o4(c[b+564>>2]|0,(c[f>>2]|0)+(b+308)|0,e)|0;c[f>>2]=(c[f>>2]|0)+g;h=c[d>>2]|0;c[d>>2]=h-g;if((h|0)==(g|0)){c[f>>2]=0}if((h|0)==(g|0)){break}return}}while(0);e=b|0;g=b+4|0;L2461:do{if((m_(c[e>>2]|0,c[g>>2]|0)|0)==0){h=b+300|0;f=b+564|0;while(1){i=mY(c[e>>2]|0,c[g>>2]|0)|0;a[(c[d>>2]|0)+(c[h>>2]|0)+(b+308)|0]=i;i=(c[d>>2]|0)+1|0;c[d>>2]=i;j=c[h>>2]|0;if(!((j+i|0)>>>0<256|(i|0)==0)){k=o4(c[f>>2]|0,b+308+j|0,i)|0;c[h>>2]=(c[h>>2]|0)+k;i=c[d>>2]|0;c[d>>2]=i-k;if((i|0)==(k|0)){c[h>>2]=0}if((i|0)!=(k|0)){break}}if((m_(c[e>>2]|0,c[g>>2]|0)|0)!=0){break L2461}}return}}while(0);g=c[d>>2]|0;if((g|0)==0){return}e=b+300|0;h=o4(c[b+564>>2]|0,(c[e>>2]|0)+(b+308)|0,g)|0;c[e>>2]=(c[e>>2]|0)+h;g=c[d>>2]|0;c[d>>2]=g-h;if((g|0)!=(h|0)){return}c[e>>2]=0;return}function fm(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b+36|0;e=b|0;f=b+4|0;if((mZ(c[e>>2]|0,c[f>>2]|0)|0)!=0){return}g=b+40|0;h=b+564|0;while(1){if((c[g>>2]|0)==0){c[d>>2]=0;i=o3(c[h>>2]|0,b+44|0,256)|0;j=(c[g>>2]|0)+i|0;c[g>>2]=j;if((j|0)==0){k=1988;break}}mX(c[e>>2]|0,c[f>>2]|0,a[(c[d>>2]|0)+(b+44)|0]|0);c[d>>2]=(c[d>>2]|0)+1;c[g>>2]=(c[g>>2]|0)-1;if((mZ(c[e>>2]|0,c[f>>2]|0)|0)!=0){k=1987;break}}if((k|0)==1988){return}else if((k|0)==1987){return}}function fn(b,d){b=b|0;d=d|0;a[b|0]=0;a[b+1|0]=0;a[b+2|0]=(d|0)!=0|0;c[b+64>>2]=0;u6(b+4|0,0,57);return}function fo(a,b,d){a=a|0;b=b|0;d=d|0;if(b>>>0>=4){return}c[a+12+(b<<2)>>2]=d;c[a+28+(b<<2)>>2]=d;return}function fp(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0;d=i;if((a[b+2|0]|0)==0){i=d;return}e=b+1|0;if((a[e]|0)!=0){i=d;return}a[e]=1;e=b+132|0;c[e>>2]=0;f=b+136|0;c[f>>2]=0;g=b+4|0;do{if((nH(c[g>>2]|0,16252928)|0)==1346585944){if((nH(c[g>>2]|0,16252936)|0)>>>0<4){h=1999;break}c[b+44>>2]=(nH(c[g>>2]|0,16252944)|0)+16252928;c[b+48>>2]=(nH(c[g>>2]|0,16252948)|0)+16252928;c[b+52>>2]=(nH(c[g>>2]|0,16252952)|0)+16252928;j=(nH(c[g>>2]|0,16252940)|0)+16252928|0;c[e>>2]=j;if((j|0)==0){break}sN(2,41768,46448,(x=i,i=i+8|0,c[x>>2]=j,x)|0);j=4194304;k=1048576;L2509:while(1){l=j+1|0;m=k-1|0;do{if((nG(c[g>>2]|0,j)|0)<<16>>16==1326){if((nH(c[g>>2]|0,j+2|0)|0)!=1399811705){break}n=j-18|0;if((nG(c[g>>2]|0,n)|0)<<16>>16==20224){h=2008;break L2509}}}while(0);if((m|0)==0){h=2005;break}else{j=l;k=m}}do{if((h|0)==2008){c[f>>2]=n;if((n|0)==0){break}sN(2,41768,39472,(x=i,i=i+8|0,c[x>>2]=n,x)|0);k=c[f>>2]|0;if((k|0)==0){i=d;return}if((c[e>>2]|0)==0){i=d;return}j=0;o=b+140|0;p=k;while(1){k=(j<<1)+8|0;q=(nG(c[g>>2]|0,k+p|0)|0)&65535;r=(c[f>>2]|0)+q|0;q=nG(c[g>>2]|0,(c[e>>2]|0)+k|0)|0;k=c[e>>2]|0;a[o]=nF(c[g>>2]|0,r)|0;s=r+1|0;a[o+1|0]=nF(c[g>>2]|0,s)|0;t=r+2|0;a[o+2|0]=nF(c[g>>2]|0,t)|0;u=r+3|0;a[o+3|0]=nF(c[g>>2]|0,u)|0;v=r+4|0;a[o+4|0]=nF(c[g>>2]|0,v)|0;w=r+5|0;a[o+5|0]=nF(c[g>>2]|0,w)|0;y=k+(q&65535)|0;nI(c[g>>2]|0,r,78);nI(c[g>>2]|0,s,-7);nI(c[g>>2]|0,t,y>>>24&255);nI(c[g>>2]|0,u,y>>>16&255);nI(c[g>>2]|0,v,y>>>8&255);nI(c[g>>2]|0,w,y&255);y=j+1|0;if(y>>>0>=5){break}j=y;o=o+6|0;p=c[f>>2]|0}i=d;return}else if((h|0)==2005){c[f>>2]=0}}while(0);sN(0,41768,43048,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);i=d;return}else{h=1999}}while(0);if((h|0)==1999){c[e>>2]=0}sN(0,41768,52128,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);i=d;return}function fq(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;if((a[b|0]|0)==0){i=e;return}if((d|0)==0|d>>>0>4){i=e;return}f=ol(c[b+8>>2]|0,d)|0;if((f|0)==0){i=e;return}g=b+4|0;b=nH(c[g>>2]|0,308)|0;if(d>>>0<5){h=(d*66|0)+8+b|0}else{h=b}b=h+3|0;if((nF(c[g>>2]|0,b)|0)<<24>>24!=0){i=e;return}sN(2,41768,36472,(x=i,i=i+8|0,c[x>>2]=d,x)|0);nK(c[g>>2]|0,b,1);b=(n8(f)|0)>>>0<1600;d=c[g>>2]|0;j=h+18|0;if(b){nK(d,j,0)}else{nK(d,j,-1)}nK(c[g>>2]|0,h+19|0,-1);j=(n3(f)|0)==0;f=c[g>>2]|0;g=h+2|0;if(j){nK(f,g,0);i=e;return}else{nK(f,g,-1);i=e;return}}function fr(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[b|0]|0)==0){d=0;return d|0}e=b+8|0;f=b+4|0;g=0;h=0;L2564:while(1){i=h;do{if(i>>>0>=4){d=g;break L2564}j=b+28+(i<<2)|0;k=c[j>>2]|0;do{if((k|0)!=0){l=k-1|0;c[j>>2]=l;if((l|0)!=0){break}fq(b,i+1|0)}}while(0);i=i+1|0;}while((ol(c[e>>2]|0,i)|0)==0);j=nH(c[f>>2]|0,308)|0;if((i|0)!=0&i>>>0<5){m=(i*66|0)+8+j|0}else{m=j}g=(nF(c[f>>2]|0,m+3|0)|0)<<24>>24==1?1:g;h=i}return d|0}function fs(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0;e=i;i=i+560|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+32|0;l=e+544|0;if((d|0)==16){a[b|0]=1;if((fr(b)|0)==0){m=0;i=e;return m|0}c[b+216>>2]=c[b+44>>2];m=0;i=e;return m|0}else if((d|0)==17){n=b+4|0;o=b+208|0;p=(nG(c[n>>2]|0,(c[o>>2]|0)+6|0)|0)&65535;q=nG(c[n>>2]|0,(c[o>>2]|0)+22|0)|0;r=q&65535;if(q<<16>>16==0|(q&65535)>4){c[b+204>>2]=-56;s=nG(c[n>>2]|0,(c[o>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[o>>2]|0)+16|0,-56);if((s&512)!=0){m=0;i=e;return m|0}s=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,s)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}s=nH(c[n>>2]|0,308)|0;t=(q&65535)<5;if(t){u=(r*66|0)+8+s|0}else{u=s}s=u+3|0;if((nF(c[n>>2]|0,s)|0)<<24>>24==0){c[b+204>>2]=-65;u=nG(c[n>>2]|0,(c[o>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[o>>2]|0)+16|0,-65);if((u&512)!=0){m=0;i=e;return m|0}u=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,u)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}nK(c[n>>2]|0,s,2);s=p&255;if((s|0)==3){u=k|0;q=l|0;v=(nG(c[n>>2]|0,(c[o>>2]|0)+44|0)|0)&15;if((v|0)==0){w=nH(c[n>>2]|0,(c[b+212>>2]|0)+16|0)|0}else if((v|0)==1){w=nH(c[n>>2]|0,(c[o>>2]|0)+46|0)|0}else if((v|0)==3){v=nH(c[n>>2]|0,(c[o>>2]|0)+46|0)|0;w=(nH(c[n>>2]|0,(c[b+212>>2]|0)+16|0)|0)+v|0}else{w=0}v=nH(c[n>>2]|0,(c[o>>2]|0)+36|0)|0;y=(nH(c[n>>2]|0,(c[o>>2]|0)+32|0)|0)&16777215;z=ol(c[b+8>>2]|0,r)|0;if((z|0)==0){c[b+204>>2]=-65;A=nG(c[n>>2]|0,(c[o>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[o>>2]|0)+16|0,-65);if((A&512)!=0){m=0;i=e;return m|0}A=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,A)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}if((n3(z)|0)!=0){c[b+204>>2]=-44;A=nG(c[n>>2]|0,(c[o>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[o>>2]|0)+16|0,-44);if((A&512)!=0){m=0;i=e;return m|0}A=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,A)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}do{if((v&511|0)==0){if((w&511|0)!=0){break}u6(q|0,0,12);A=(nG(c[n>>2]|0,770)|0)&65535;B=v>>>9;C=b+56|0;D=w>>>9;E=l+1|0;F=l+2|0;G=l+3|0;H=l+4|0;I=l+5|0;J=l+6|0;K=l+7|0;L=l+8|0;M=l+9|0;N=l+10|0;O=l+11|0;P=0;while(1){if(P>>>0>=B>>>0){Q=2126;break}R=(P<<9)+y|0;S=0;do{a[k+S|0]=nF(c[n>>2]|0,R+S|0)|0;S=S+1|0;}while(S>>>0<512);S=c[C>>2]|0;L2633:do{if((S|0)==0){nL(c[n>>2]|0,770,P+A&65535);a[q]=nF(c[n>>2]|0,764)|0;a[E]=nF(c[n>>2]|0,765)|0;a[F]=nF(c[n>>2]|0,766)|0;a[G]=nF(c[n>>2]|0,767)|0;a[H]=nF(c[n>>2]|0,768)|0;a[I]=nF(c[n>>2]|0,769)|0;a[J]=nF(c[n>>2]|0,770)|0;a[K]=nF(c[n>>2]|0,771)|0;a[L]=nF(c[n>>2]|0,772)|0;a[M]=nF(c[n>>2]|0,773)|0;a[N]=nF(c[n>>2]|0,774)|0;a[O]=nF(c[n>>2]|0,775)|0}else{R=P*12|0;T=0;U=S;while(1){V=nF(c[n>>2]|0,U+R+T|0)|0;a[l+T|0]=V;nK(c[n>>2]|0,T+764|0,V);V=T+1|0;if(V>>>0>=12){break L2633}T=V;U=c[C>>2]|0}}}while(0);if((fB(z,u,q,P+D|0)|0)==0){P=P+1|0}else{Q=2124;break}}if((Q|0)==2124){d$(52400,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);c[b+204>>2]=-1;P=nG(c[n>>2]|0,(c[o>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[o>>2]|0)+16|0,-1);if((P&512)!=0){m=0;i=e;return m|0}P=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,P)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}else if((Q|0)==2126){nM(c[n>>2]|0,(c[o>>2]|0)+40|0,v);P=b+212|0;D=(nH(c[n>>2]|0,(c[P>>2]|0)+16|0)|0)+v|0;nM(c[n>>2]|0,(c[P>>2]|0)+16|0,D);c[b+204>>2]=0;D=nG(c[n>>2]|0,(c[o>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[o>>2]|0)+16|0,0);if((D&512)!=0){m=0;i=e;return m|0}D=nH(c[n>>2]|0,308)|0;c[P>>2]=nH(c[n>>2]|0,D)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}}}while(0);d$(53024,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);c[b+204>>2]=-50;v=nG(c[n>>2]|0,(c[o>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[o>>2]|0)+16|0,-50);if((v&512)!=0){m=0;i=e;return m|0}v=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,v)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}else if((s|0)==2){s=k|0;v=l|0;q=(nG(c[n>>2]|0,(c[o>>2]|0)+44|0)|0)&15;if((q|0)==1){W=nH(c[n>>2]|0,(c[o>>2]|0)+46|0)|0}else if((q|0)==3){u=nH(c[n>>2]|0,(c[o>>2]|0)+46|0)|0;W=(nH(c[n>>2]|0,(c[b+212>>2]|0)+16|0)|0)+u|0}else if((q|0)==0){W=nH(c[n>>2]|0,(c[b+212>>2]|0)+16|0)|0}else{W=0}q=nH(c[n>>2]|0,(c[o>>2]|0)+36|0)|0;u=(nH(c[n>>2]|0,(c[o>>2]|0)+32|0)|0)&16777215;z=nG(c[n>>2]|0,(c[o>>2]|0)+44|0)|0;y=ol(c[b+8>>2]|0,r)|0;if((y|0)==0){c[b+204>>2]=-65;w=nG(c[n>>2]|0,(c[o>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[o>>2]|0)+16|0,-65);if((w&512)!=0){m=0;i=e;return m|0}w=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,w)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}if((z&64)!=0){c[b+204>>2]=0;z=nG(c[n>>2]|0,(c[o>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[o>>2]|0)+16|0,0);if((z&512)!=0){m=0;i=e;return m|0}z=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,z)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}do{if((W&511|0)==0){if((q&511|0)!=0){break}z=q>>>9;L2684:do{if((z|0)!=0){w=W>>>9;D=y+64|0;P=b+56|0;C=l+1|0;O=l+2|0;N=l+3|0;M=l+4|0;L=l+5|0;K=l+6|0;J=l+7|0;I=l+8|0;H=l+9|0;G=l+10|0;F=l+11|0;E=0;while(1){A=E+w|0;if((n1(y)|0)==6){if((fC(n8(y)|0,A,f,g,h)|0)!=0){break}B=c[D>>2]|0;X=c[f>>2]|0;Y=c[g>>2]|0;Z=c[h>>2]|0;nO(B,v,12,X,Y,Z,0)|0;c[j>>2]=512;if((nN(c[D>>2]|0,s,j,X,Y,Z,0)|0)!=0){Q=2089;break}}else{u6(v|0,0,12);if((oo(y,s,A,1)|0)!=0){break}}A=(E<<9)+u|0;B=0;do{nK(c[n>>2]|0,A+B|0,a[k+B|0]|0);B=B+1|0;}while(B>>>0<512);nK(c[n>>2]|0,764,a[v]|0);nK(c[n>>2]|0,765,a[C]|0);nK(c[n>>2]|0,766,a[O]|0);nK(c[n>>2]|0,767,a[N]|0);nK(c[n>>2]|0,768,a[M]|0);nK(c[n>>2]|0,769,a[L]|0);nK(c[n>>2]|0,770,a[K]|0);nK(c[n>>2]|0,771,a[J]|0);nK(c[n>>2]|0,772,a[I]|0);nK(c[n>>2]|0,773,a[H]|0);nK(c[n>>2]|0,774,a[G]|0);nK(c[n>>2]|0,775,a[F]|0);B=c[P>>2]|0;if((B|0)!=0){A=E*12|0;nK(c[n>>2]|0,B+A|0,a[v]|0);nK(c[n>>2]|0,(A|1)+(c[P>>2]|0)|0,a[C]|0);nK(c[n>>2]|0,(A|2)+(c[P>>2]|0)|0,a[O]|0);nK(c[n>>2]|0,(A|3)+(c[P>>2]|0)|0,a[N]|0);nK(c[n>>2]|0,A+4+(c[P>>2]|0)|0,a[M]|0);nK(c[n>>2]|0,A+5+(c[P>>2]|0)|0,a[L]|0);nK(c[n>>2]|0,A+6+(c[P>>2]|0)|0,a[K]|0);nK(c[n>>2]|0,A+7+(c[P>>2]|0)|0,a[J]|0);nK(c[n>>2]|0,A+8+(c[P>>2]|0)|0,a[I]|0);nK(c[n>>2]|0,A+9+(c[P>>2]|0)|0,a[H]|0);nK(c[n>>2]|0,A+10+(c[P>>2]|0)|0,a[G]|0);nK(c[n>>2]|0,A+11+(c[P>>2]|0)|0,a[F]|0)}E=E+1|0;if(E>>>0>=z>>>0){break L2684}}if((Q|0)==2089){d$(50168,(x=i,i=i+24|0,c[x>>2]=X,c[x+8>>2]=Y,c[x+16>>2]=Z,x)|0)}d$(50920,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);c[b+204>>2]=-1;E=nG(c[n>>2]|0,(c[o>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[o>>2]|0)+16|0,-1);if((E&512)!=0){m=0;i=e;return m|0}E=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,E)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}}while(0);z=nH(c[n>>2]|0,308)|0;if(t){_=(r*66|0)+8+z|0}else{_=z}nK(c[n>>2]|0,_+3|0,2);nM(c[n>>2]|0,(c[o>>2]|0)+40|0,q);z=b+212|0;E=(nH(c[n>>2]|0,(c[z>>2]|0)+16|0)|0)+q|0;nM(c[n>>2]|0,(c[z>>2]|0)+16|0,E);c[b+204>>2]=0;E=nG(c[n>>2]|0,(c[o>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[o>>2]|0)+16|0,0);if((E&512)!=0){m=0;i=e;return m|0}E=nH(c[n>>2]|0,308)|0;c[z>>2]=nH(c[n>>2]|0,E)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}}while(0);d$(51656,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);c[b+204>>2]=-50;q=nG(c[n>>2]|0,(c[o>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[o>>2]|0)+16|0,-50);if((q&512)!=0){m=0;i=e;return m|0}q=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,q)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}else{d$(54104,(x=i,i=i+8|0,c[x>>2]=p,x)|0);c[b+204>>2]=-17;p=nG(c[n>>2]|0,(c[o>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[o>>2]|0)+16|0,-17);if((p&512)!=0){m=0;i=e;return m|0}p=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,p)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}}else if((d|0)==18){n=b+4|0;p=b+208|0;o=(nG(c[n>>2]|0,(c[p>>2]|0)+26|0)|0)&65535;if((o|0)==1){c[b+204>>2]=-27;q=c[n>>2]|0;_=(c[p>>2]|0)+6|0;nG(q,_)|0;nL(c[n>>2]|0,(c[p>>2]|0)+16|0,-27);m=0;i=e;return m|0}else if((o|0)==5){_=nG(c[n>>2]|0,(c[p>>2]|0)+22|0)|0;if(_<<16>>16==0|(_&65535)>4){c[b+204>>2]=-56;q=nG(c[n>>2]|0,(c[p>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[p>>2]|0)+16|0,-56);if((q&512)!=0){m=0;i=e;return m|0}q=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,q)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}q=b+204|0;if((ol(c[b+8>>2]|0,_&65535)|0)==0){c[q>>2]=-64;_=nG(c[n>>2]|0,(c[p>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[p>>2]|0)+16|0,-64);if((_&512)!=0){m=0;i=e;return m|0}_=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,_)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}else{c[q>>2]=0;q=nG(c[n>>2]|0,(c[p>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[p>>2]|0)+16|0,0);if((q&512)!=0){m=0;i=e;return m|0}q=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,q)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}}else if((o|0)==7){q=nG(c[n>>2]|0,(c[p>>2]|0)+22|0)|0;_=q&65535;if(q<<16>>16==0|(q&65535)>4){c[b+204>>2]=-56;r=nG(c[n>>2]|0,(c[p>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[p>>2]|0)+16|0,-56);if((r&512)!=0){m=0;i=e;return m|0}r=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,r)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}r=nH(c[n>>2]|0,308)|0;if((q&65535)<5){$=(_*66|0)+8+r|0}else{$=r}nK(c[n>>2]|0,$+3|0,0);nK(c[n>>2]|0,$+2|0,0);nK(c[n>>2]|0,$+18|0,0);c[b+204>>2]=0;$=nG(c[n>>2]|0,(c[p>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[p>>2]|0)+16|0,0);if(($&512)!=0){m=0;i=e;return m|0}$=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,$)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}else if((o|0)==8){c[b+56>>2]=(nH(c[n>>2]|0,(c[p>>2]|0)+28|0)|0)&16777215;c[b+204>>2]=0;$=nG(c[n>>2]|0,(c[p>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[p>>2]|0)+16|0,0);if(($&512)!=0){m=0;i=e;return m|0}$=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,$)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}else if((o|0)==9){c[b+204>>2]=-56;$=nG(c[n>>2]|0,(c[p>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[p>>2]|0)+16|0,-56);if(($&512)!=0){m=0;i=e;return m|0}$=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,$)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}else if((o|0)==6){$=nG(c[n>>2]|0,(c[p>>2]|0)+22|0)|0;r=$&65535;_=nG(c[n>>2]|0,(c[p>>2]|0)+28|0)|0;q=_&65535;if($<<16>>16==0|($&65535)>4){c[b+204>>2]=-56;t=nG(c[n>>2]|0,(c[p>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[p>>2]|0)+16|0,-56);if((t&512)!=0){m=0;i=e;return m|0}t=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,t)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}t=ol(c[b+8>>2]|0,r)|0;if((t|0)==0){c[b+204>>2]=-64;Z=nG(c[n>>2]|0,(c[p>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[p>>2]|0)+16|0,-64);if((Z&512)!=0){m=0;i=e;return m|0}Z=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,Z)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}if((a[t+56|0]|0)!=0){c[b+204>>2]=-44;Z=nG(c[n>>2]|0,(c[p>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[p>>2]|0)+16|0,-44);if((Z&512)!=0){m=0;i=e;return m|0}Z=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,Z)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}do{if(_<<16>>16==0){Q=2163}else{if(q>>>0>(c[b+64>>2]|0)>>>0){Q=2163;break}aa=c[b+68+((q<<1)-2<<2)>>2]|0}}while(0);do{if((Q|0)==2163){q=n8(t)|0;if((n1(t)|0)!=6){aa=q;break}aa=_<<16>>16==1?800:1600}}while(0);if((fA(t,aa)|0)!=0){c[b+204>>2]=-50;t=nG(c[n>>2]|0,(c[p>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[p>>2]|0)+16|0,-50);if((t&512)!=0){m=0;i=e;return m|0}t=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,t)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}t=nH(c[n>>2]|0,308)|0;if(($&65535)<5){ab=(r*66|0)+8+t|0}else{ab=t}nL(c[n>>2]|0,ab+18|0,aa&65535);nL(c[n>>2]|0,ab+20|0,aa>>>16&65535);c[b+204>>2]=0;aa=nG(c[n>>2]|0,(c[p>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[p>>2]|0)+16|0,0);if((aa&512)!=0){m=0;i=e;return m|0}aa=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,aa)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}else if((o|0)==21){fz(b);m=0;i=e;return m|0}else if((o|0)==22){fz(b);m=0;i=e;return m|0}else if((o|0)==23){aa=nG(c[n>>2]|0,(c[p>>2]|0)+22|0)|0;if(aa<<16>>16==0|(aa&65535)>4){c[b+204>>2]=-56;ab=nG(c[n>>2]|0,(c[p>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[p>>2]|0)+16|0,-56);if((ab&512)!=0){m=0;i=e;return m|0}ab=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,ab)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}else{ab=(aa&65535)-1|0;nM(c[n>>2]|0,(c[p>>2]|0)+28|0,(ab<<3&8|ab>>>1&1)<<8|4);c[b+204>>2]=0;ab=nG(c[n>>2]|0,(c[p>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[p>>2]|0)+16|0,0);if((ab&512)!=0){m=0;i=e;return m|0}ab=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,ab)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}}else if((o|0)==21315){ab=k|0;aa=l|0;t=nG(c[n>>2]|0,(c[p>>2]|0)+22|0)|0;r=nG(c[n>>2]|0,(c[p>>2]|0)+28|0)|0;$=r&65535;_=nH(c[n>>2]|0,(c[p>>2]|0)+30|0)|0;Q=nH(c[n>>2]|0,(c[p>>2]|0)+34|0)|0;if(t<<16>>16==0|(t&65535)>4){c[b+204>>2]=-56;q=nG(c[n>>2]|0,(c[p>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[p>>2]|0)+16|0,-56);if((q&512)!=0){m=0;i=e;return m|0}q=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,q)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}q=ol(c[b+8>>2]|0,t&65535)|0;if((q|0)==0){c[b+204>>2]=-64;t=nG(c[n>>2]|0,(c[p>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[p>>2]|0)+16|0,-64);if((t&512)!=0){m=0;i=e;return m|0}t=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,t)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}if((a[q+56|0]|0)!=0){c[b+204>>2]=-44;t=nG(c[n>>2]|0,(c[p>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[p>>2]|0)+16|0,-44);if((t&512)!=0){m=0;i=e;return m|0}t=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,t)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}do{if(r<<16>>16!=0){if($>>>0>(c[b+64>>2]|0)>>>0){break}t=c[b+68+(($<<1)-2<<2)>>2]|0;do{if(t>>>0<1120){ac=-2}else{if(t>>>0<1520){ac=0;break}if(t>>>0<2240){ac=-1;break}ac=t>>>0<5760?1:253}}while(0);if((fA(q,t)|0)!=0){c[b+204>>2]=-50;Z=nG(c[n>>2]|0,(c[p>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[p>>2]|0)+16|0,-50);if((Z&512)!=0){m=0;i=e;return m|0}Z=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,Z)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}Z=_&16777215;u6(aa|0,0,12);L2863:do{if((t|0)!=0){L2865:do{if(ac>>>0>1){Y=l+1|0;X=l+2|0;v=l+3|0;u=l+4|0;s=l+5|0;y=l+6|0;j=l+7|0;h=l+8|0;g=l+9|0;f=l+10|0;W=l+11|0;E=Q&16777215;z=0;F=Z;while(1){P=0;do{a[k+P|0]=nF(c[n>>2]|0,P+F|0)|0;P=P+1|0;}while(P>>>0<512);a[aa]=nF(c[n>>2]|0,E)|0;a[Y]=nF(c[n>>2]|0,E+1|0)|0;a[X]=nF(c[n>>2]|0,E+2|0)|0;a[v]=nF(c[n>>2]|0,E+3|0)|0;a[u]=nF(c[n>>2]|0,E+4|0)|0;a[s]=nF(c[n>>2]|0,E+5|0)|0;a[y]=nF(c[n>>2]|0,E+6|0)|0;a[j]=nF(c[n>>2]|0,E+7|0)|0;a[h]=nF(c[n>>2]|0,E+8|0)|0;a[g]=nF(c[n>>2]|0,E+9|0)|0;a[f]=nF(c[n>>2]|0,E+10|0)|0;a[W]=nF(c[n>>2]|0,E+11|0)|0;if((fB(q,ab,aa,z)|0)!=0){break L2865}P=z+1|0;if(P>>>0<t>>>0){E=E+12|0;z=P;F=F+512|0}else{break L2863}}}else{F=0;z=Z;while(1){E=0;do{a[k+E|0]=nF(c[n>>2]|0,E+z|0)|0;E=E+1|0;}while(E>>>0<512);if((fB(q,ab,aa,F)|0)!=0){break L2865}E=F+1|0;if(E>>>0<t>>>0){F=E;z=z+512|0}else{break L2863}}}}while(0);c[b+204>>2]=-1;z=nG(c[n>>2]|0,(c[p>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[p>>2]|0)+16|0,-1);if((z&512)!=0){m=0;i=e;return m|0}z=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,z)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}}while(0);c[b+204>>2]=0;t=nG(c[n>>2]|0,(c[p>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[p>>2]|0)+16|0,0);if((t&512)!=0){m=0;i=e;return m|0}t=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,t)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}}while(0);c[b+204>>2]=-50;aa=nG(c[n>>2]|0,(c[p>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[p>>2]|0)+16|0,-50);if((aa&512)!=0){m=0;i=e;return m|0}aa=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,aa)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}else{d$(31472,(x=i,i=i+8|0,c[x>>2]=o,x)|0);c[b+204>>2]=-17;o=nG(c[n>>2]|0,(c[p>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[p>>2]|0)+16|0,-17);if((o&512)!=0){m=0;i=e;return m|0}o=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,o)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}}else if((d|0)==19){n=b+4|0;o=b+208|0;p=(nG(c[n>>2]|0,(c[o>>2]|0)+26|0)|0)&65535;if((p|0)==6){aa=nG(c[n>>2]|0,(c[o>>2]|0)+22|0)|0;ab=(nG(c[n>>2]|0,(c[o>>2]|0)+28|0)|0)&65535;q=nH(c[n>>2]|0,(c[o>>2]|0)+30|0)|0;if(aa<<16>>16==0|(aa&65535)>4){c[b+204>>2]=-56;k=nG(c[n>>2]|0,(c[o>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[o>>2]|0)+16|0,-56);if((k&512)!=0){m=0;i=e;return m|0}k=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,k)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}k=ol(c[b+8>>2]|0,aa&65535)|0;if((k|0)==0){c[b+204>>2]=-64;aa=nG(c[n>>2]|0,(c[o>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[o>>2]|0)+16|0,-64);if((aa&512)!=0){m=0;i=e;return m|0}aa=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,aa)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}aa=n8(k)|0;Q=b+68|0;l=b+64|0;do{if((n1(k)|0)==6){c[l>>2]=4;c[Q>>2]=800;ac=b+72|0;c[ac>>2]=-2130050992;c[b+76>>2]=1600;_=b+80|0;c[_>>2]=-2113273776;c[b+84>>2]=1440;$=b+88|0;c[$>>2]=-2113339312;c[b+92>>2]=2880;r=b+96|0;c[r>>2]=-1844314032;if(aa>>>0<1120){c[ac>>2]=-1056309168;ad=4;break}if(aa>>>0<1520){c[$>>2]=-1039597488;ad=4;break}if(aa>>>0<2240){c[_>>2]=-1039531952;ad=4;break}if((a[b+60|0]|0)==0){c[l>>2]=1;c[Q>>2]=2880;c[ac>>2]=-770572208;ad=1;break}else{c[r>>2]=-770572208;ad=4;break}}else{c[l>>2]=1;c[Q>>2]=aa;c[b+72>>2]=0;ad=1}}while(0);aa=ab>>>0>ad>>>0?ad:ab;ab=c[n>>2]|0;if((aa|0)==0){ae=ab}else{ad=0;Q=ab;while(1){ab=(ad<<3)+q|0;l=ad<<1;nM(Q,ab,c[b+68+(l<<2)>>2]|0);nM(c[n>>2]|0,ab+4|0,c[b+68+((l|1)<<2)>>2]|0);l=ad+1|0;ab=c[n>>2]|0;if(l>>>0<aa>>>0){ad=l;Q=ab}else{ae=ab;break}}}nL(ae,(c[o>>2]|0)+28|0,aa&65535);c[b+204>>2]=0;aa=nG(c[n>>2]|0,(c[o>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[o>>2]|0)+16|0,0);if((aa&512)!=0){m=0;i=e;return m|0}aa=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,aa)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}else if((p|0)==8){aa=nG(c[n>>2]|0,(c[o>>2]|0)+22|0)|0;ae=aa&65535;if(aa<<16>>16==0|(aa&65535)>4){c[b+204>>2]=-56;Q=nG(c[n>>2]|0,(c[o>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[o>>2]|0)+16|0,-56);if((Q&512)!=0){m=0;i=e;return m|0}Q=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,Q)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}if((ol(c[b+8>>2]|0,ae)|0)==0){c[b+204>>2]=-64;Q=nG(c[n>>2]|0,(c[o>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[o>>2]|0)+16|0,-64);if((Q&512)!=0){m=0;i=e;return m|0}Q=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,Q)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}Q=nH(c[n>>2]|0,308)|0;if((aa&65535)<5){af=(ae*66|0)+8+Q|0}else{af=Q}Q=0;do{ae=Q<<1;aa=nG(c[n>>2]|0,ae+af|0)|0;nL(c[n>>2]|0,ae+28+(c[o>>2]|0)|0,aa);Q=Q+1|0;}while(Q>>>0<11);c[b+204>>2]=0;Q=nG(c[n>>2]|0,(c[o>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[o>>2]|0)+16|0,0);if((Q&512)!=0){m=0;i=e;return m|0}Q=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,Q)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0;m=0;i=e;return m|0}else{c[b+204>>2]=-18;Q=nG(c[n>>2]|0,(c[o>>2]|0)+6|0)|0;nL(c[n>>2]|0,(c[o>>2]|0)+16|0,-18);if((Q&512)==0){Q=nH(c[n>>2]|0,308)|0;c[b+212>>2]=nH(c[n>>2]|0,Q)|0;c[b+216>>2]=nH(c[n>>2]|0,2300)|0}d$(33632,(x=i,i=i+8|0,c[x>>2]=p,x)|0);m=0;i=e;return m|0}}else if((d|0)==20){m=0;i=e;return m|0}else{m=1;i=e;return m|0}return 0}function ft(a,b){a=a|0;b=b|0;c[a+4>>2]=b;return}function fu(a,b){a=a|0;b=b|0;c[a+764>>2]=b;return}function fv(a,b){a=a|0;b=b|0;var d=0;d=(b|0)!=0|0;b=a+760|0;if((c[b>>2]|0)==(d|0)){return}c[b>>2]=d;return}function fw(a,f){a=a|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=a+760|0;if((c[g>>2]|0)==0){return}h=a+4|0;if((c[h>>2]|0)==0){return}i=a+12|0;j=c[i>>2]|0;if(j>>>0>369){return}k=a+756|0;l=(c[k>>2]|0)+f|0;c[k>>2]=l;if(l>>>0<=351){return}c[k>>2]=(l>>>0)%352|0;k=8-(c[a+764>>2]|0)|0;f=a+8|0;m=a+820|0;n=a+824|0;o=(l>>>0)/352|0;l=j;while(1){if(l>>>0>=370){p=2367;break}j=c[f>>2]|0;do{if((c[g>>2]|0)==0){q=32768}else{r=(d[(c[h>>2]|0)+(j<<1)|0]|0)<<8;if(r>>>0<32768){q=32768-(((32768-r|0)>>>0)/(k>>>0)|0)|0;break}else{q=(((r-32768|0)>>>0)/(k>>>0)|0)+32768|0;break}}}while(0);r=j+1|0;c[f>>2]=r>>>0>369?0:r;r=q&65535;if((q|0)!=(e[m>>1]|0|0)){b[m>>1]=r;c[n>>2]=1}b[a+16+(l<<1)>>1]=r;r=(c[i>>2]|0)+1|0;c[i>>2]=r;s=o-1|0;if((s|0)==0){p=2371;break}else{o=s;l=r}}if((p|0)==2367){return}else if((p|0)==2371){return}}function fx(a){a=a|0;var b=0,d=0,f=0,g=0;if((a&61440|0)!=40960){b=0;return b|0}d=(a&2048|0)==0?63743:64511;f=0;while(1){if((f|0)==684){b=0;g=2378;break}if((((e[400+(f<<3)>>1]|0)^a)&d|0)==0){b=c[404+(f<<3)>>2]|0;g=2377;break}else{f=f+1|0}}if((g|0)==2377){return b|0}else if((g|0)==2378){return b|0}return 0}function fy(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b+1|0;do{if((a[d]|0)!=0){e=b+136|0;f=c[e>>2]|0;if((f|0)==0){break}if((c[b+132>>2]|0)==0){break}g=b+4|0;h=0;i=b+140|0;j=f;while(1){f=(nG(c[g>>2]|0,j+8+(h<<1)|0)|0)&65535;k=(c[e>>2]|0)+f|0;nI(c[g>>2]|0,k,a[i]|0);nI(c[g>>2]|0,k+1|0,a[i+1|0]|0);nI(c[g>>2]|0,k+2|0,a[i+2|0]|0);nI(c[g>>2]|0,k+3|0,a[i+3|0]|0);nI(c[g>>2]|0,k+4|0,a[i+4|0]|0);nI(c[g>>2]|0,k+5|0,a[i+5|0]|0);k=h+1|0;if(k>>>0>=5){break}h=k;i=i+6|0;j=c[e>>2]|0}a[d]=0}}while(0);a[b|0]=0;c[b+28>>2]=c[b+12>>2];c[b+32>>2]=c[b+16>>2];c[b+36>>2]=c[b+20>>2];c[b+40>>2]=c[b+24>>2];return}function fz(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=a+4|0;d=a+208|0;e=nG(c[b>>2]|0,(c[d>>2]|0)+22|0)|0;if(e<<16>>16==0|(e&65535)>4){c[a+204>>2]=-56;f=nG(c[b>>2]|0,(c[d>>2]|0)+6|0)|0;nL(c[b>>2]|0,(c[d>>2]|0)+16|0,-56);if((f&512)!=0){return}f=nH(c[b>>2]|0,308)|0;c[a+212>>2]=nH(c[b>>2]|0,f)|0;c[a+216>>2]=nH(c[b>>2]|0,2300)|0;return}f=c[a+48>>2]|0;g=c[a+52>>2]|0;h=ol(c[a+8>>2]|0,e&65535)|0;do{if((h|0)==0){i=f}else{e=n8(h)|0;if((e|0)==800|(e|0)==1600|(e|0)==1440|(e|0)==2880){i=f;break}i=g}}while(0);nM(c[b>>2]|0,(c[d>>2]|0)+28|0,i);c[a+204>>2]=0;i=nG(c[b>>2]|0,(c[d>>2]|0)+6|0)|0;nL(c[b>>2]|0,(c[d>>2]|0)+16|0,0);if((i&512)!=0){return}i=nH(c[b>>2]|0,308)|0;c[a+212>>2]=nH(c[b>>2]|0,i)|0;c[a+216>>2]=nH(c[b>>2]|0,2300)|0;return}function fA(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+512|0;e=d|0;if((n1(a)|0)!=6){if((n8(a)|0)!=(b|0)){f=1;i=d;return f|0}g=e|0;u6(g|0,0,512);if((b|0)==0){f=0;i=d;return f|0}else{h=0}while(1){op(a,g,h,1)|0;j=h+1|0;if(j>>>0<b>>>0){h=j}else{f=0;break}}i=d;return f|0}h=c[a+64>>2]|0;g=h;j=e|0;u6(j|0,0,12);do{if(b>>>0<1120){k=1;l=2409}else{if(b>>>0<1520){m=2}else{if(b>>>0<2240){k=2;l=2409;break}m=b>>>0<5760?3:255}nR(g)|0;e=(m|0)==2;if((m-2|0)>>>0>=2){f=1;i=d;return f|0}nJ(g,e?2:32770);n=e?9:18;e=0;do{o=0;while(1){p=o+1|0;nS(g,e,0,e,0,p,512,0)|0;if(p>>>0<n>>>0){o=p}else{q=0;break}}do{q=q+1|0;nS(g,e,1,e,1,q,512,0)|0;}while(q>>>0<n>>>0);e=e+1|0;}while(e>>>0<80)}}while(0);if((l|0)==2409){nR(g)|0;nJ(g,3);l=h+68|0;h=13;q=0;do{h=(((q&15|0)==0)<<31>>31)+h|0;if((h|0)!=0){m=0;do{b=0;do{nS(g,q,m,q,m,b,512,0)|0;e=qp(c[l>>2]|0,q,m,b,1)|0;if((e|0)!=0){qa(e,j,12)|0}b=b+1|0;}while(b>>>0<h>>>0);m=m+1|0;}while(m>>>0<k>>>0)}q=q+1|0;}while(q>>>0<80)}q=n8(a)|0;d$(55048,(x=i,i=i+8|0,c[x>>2]=q,x)|0);f=0;i=d;return f|0}function fB(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+32|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;if((n1(a)|0)!=6){l=(op(a,b,e,1)|0)!=0|0;i=f;return l|0}if((fC(n8(a)|0,e,g,h,j)|0)!=0){l=1;i=f;return l|0}e=n8(a)|0;if(e>>>0<1120|(e-1520|0)>>>0<720){e=a+64|0;m=c[e>>2]|0;n=c[g>>2]|0;o=c[h>>2]|0;p=c[j>>2]|0;nQ(m,d,12,n,o,p,0)|0;q=n;r=o;s=p;t=e}else{q=c[g>>2]|0;r=c[h>>2]|0;s=c[j>>2]|0;t=a+64|0}c[k>>2]=512;if((nP(c[t>>2]|0,b,k,q,r,s,0)|0)==0){l=0;i=f;return l|0}d$(30200,(x=i,i=i+24|0,c[x>>2]=q,c[x+8>>2]=r,c[x+16>>2]=s,x)|0);l=1;i=f;return l|0}function fC(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;L3105:do{if(a>>>0<1120){h=1}else{do{if(a>>>0<1520){c[f>>2]=((b>>>0)%9|0)+1;c[e>>2]=((b>>>0)/9|0)&1;j=(b>>>0)/18|0}else{if(a>>>0<2240){h=0;break L3105}if(a>>>0<5760){c[f>>2]=((b>>>0)%18|0)+1;c[e>>2]=((b>>>0)/18|0)&1;j=(b>>>0)/36|0;break}d$(29216,(x=i,i=i+16|0,c[x>>2]=a,c[x+8>>2]=b,x)|0);k=1;i=g;return k|0}}while(0);c[d>>2]=j;k=0;i=g;return k|0}}while(0);j=h?1:2;c[d>>2]=0;a=j*192|0;do{if(a>>>0>b>>>0){l=12;m=b}else{n=b-a|0;c[d>>2]=16;o=j*176|0;if(n>>>0<o>>>0){l=11;m=n;break}p=n-o|0;c[d>>2]=32;o=j*160|0;if(p>>>0<o>>>0){l=10;m=p;break}n=p-o|0;c[d>>2]=48;o=j*144|0;if(n>>>0<o>>>0){l=9;m=n;break}p=n-o|0;c[d>>2]=64;if(p>>>0<j<<7>>>0){l=8;m=p;break}c[d>>2]=80;k=1;i=g;return k|0}}while(0);c[f>>2]=(m>>>0)%(l>>>0)|0;c[e>>2]=((m>>>0)/(l>>>0)|0)&(h&1^1);h=(m>>>0)/((ac(l,j)|0)>>>0)|0;c[d>>2]=(c[d>>2]|0)+h;k=0;i=g;return k|0}function fD(a){a=a|0;c[a+756>>2]=0;c[a+760>>2]=0;c[a+764>>2]=0;u6(a|0,0,16);c[a+768>>2]=8e3;rt(a+772|0);b[a+820>>1]=-32768;c[a+824>>2]=0;c[a+828>>2]=60;return}function fE(a,b){a=a|0;b=b|0;c[a+768>>2]=b;rv(a+772|0,b,22255);return}function fF(a,b){a=a|0;b=b|0;var d=0,e=0;d=a|0;a=c[d>>2]|0;if((a|0)!=0){ry(a)}a=rB(b)|0;c[d>>2]=a;if((a|0)==0){e=1;return e|0}if((rA(a,1,22255,0)|0)==0){e=0;return e|0}ry(c[d>>2]|0);c[d>>2]=0;e=1;return e|0}function fG(a){a=a|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+8192|0;g=f|0;h=a+4|0;if((c[h>>2]|0)==0){i=f;return}j=a|0;if((c[j>>2]|0)==0){i=f;return}k=a+12|0;l=c[k>>2]|0;L3147:do{if(l>>>0<370){m=a+760|0;if((c[m>>2]|0)==0){if((c[a+828>>2]|0)>>>0>59&(l|0)==0){break}n=a+820|0;if((b[n>>1]|0)!=-32768){c[a+824>>2]=1}o=a+8|0;p=370-l|0;q=l;do{if(q>>>0>=370){break}b[a+16+(q<<1)>>1]=-32768;r=(c[o>>2]|0)+1|0;c[o>>2]=r>>>0>369?0:r;q=(c[k>>2]|0)+1|0;c[k>>2]=q;p=p-1|0;}while((p|0)!=0);b[n>>1]=-32768;break}p=8-(c[a+764>>2]|0)|0;q=a+8|0;o=a+820|0;r=a+824|0;s=370-l|0;t=l;do{if(t>>>0>=370){break L3147}u=c[q>>2]|0;do{if((c[m>>2]|0)==0){v=32768}else{w=d[(c[h>>2]|0)+(u<<1)|0]<<8;if(w>>>0<32768){v=32768-(((32768-w|0)>>>0)/(p>>>0)|0)|0;break}else{v=(((w-32768|0)>>>0)/(p>>>0)|0)+32768|0;break}}}while(0);w=u+1|0;c[q>>2]=w>>>0>369?0:w;w=v&65535;if((v|0)!=(e[o>>1]|0)){b[o>>1]=w;c[r>>2]=1}b[a+16+(t<<1)>>1]=w;t=(c[k>>2]|0)+1|0;c[k>>2]=t;s=s-1|0;}while((s|0)!=0)}}while(0);v=a+824|0;h=a+828|0;l=c[h>>2]|0;do{if((c[v>>2]|0)==0){if(l>>>0>=60){break}s=l+1|0;c[h>>2]=s;if(s>>>0<60){x=2500}}else{if(l>>>0>59){s=c[j>>2]|0;u6(g|0,0,8192);t=g|0;rz(s,t,4096)|0}c[h>>2]=0;x=2500}}while(0);if((x|0)==2500){if((c[a+768>>2]|0)==0){y=a+16|0}else{x=a+16|0;rk(a+772|0,x,x,c[k>>2]|0,1,0);y=x}x=c[j>>2]|0;j=c[k>>2]|0;rz(x,y,j)|0}c[v>>2]=0;c[a+8>>2]=16;c[k>>2]=0;c[a+756>>2]=0;i=f;return}function fH(a,b,d){a=a|0;b=b|0;d=d|0;c[a+52>>2]=b;c[a+56>>2]=d;return}function fI(a,b){a=a|0;b=b|0;c[a>>2]=b;return}function fJ(b,c,d){b=b|0;c=c|0;d=d|0;a[b+32|0]=c>>>16&255;a[b+35|0]=d>>>16&255;a[b+33|0]=c>>>8&255;a[b+36|0]=d>>>8&255;a[b+34|0]=c&255;a[b+37|0]=d&255;a[b+12|0]=1;return}function fK(b,d){b=b|0;d=d|0;var e=0;e=d>>>0>255?255:d;d=b+28|0;if((c[d>>2]|0)==(e|0)){return}a[b+12|0]=1;c[d>>2]=e;return}function fL(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=u0(60)|0;f=e;if((e|0)==0){g=0;return g|0}c[e>>2]=0;c[e+44>>2]=0;c[e+4>>2]=b;c[e+8>>2]=d;a[e+12|0]=0;c[e+16>>2]=8;h=u0(ac((b+7|0)>>>3,d)|0)|0;c[e+20>>2]=h;do{if((h|0)!=0){d=u0(b*24|0)|0;c[e+24>>2]=d;if((d|0)==0){break}c[e+28>>2]=255;a[e+32|0]=0;a[e+33|0]=0;a[e+34|0]=0;a[e+35|0]=-1;a[e+36|0]=-1;a[e+37|0]=-1;c[e+40>>2]=0;a[e+48|0]=0;c[e+52>>2]=0;c[e+56>>2]=0;g=f;return g|0}}while(0);u1(e);g=0;return g|0}function fM(a,b){a=a|0;b=b|0;c[a+44>>2]=b;if((b|0)==0){return}uG(b,c[a+4>>2]|0,c[a+8>>2]|0)|0;return}function fN(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;e=i;i=i+16|0;f=e|0;g=e+8|0;h=b+44|0;j=c[h>>2]|0;if((j|0)==0){i=e;return}k=b|0;if((c[k>>2]|0)==0){i=e;return}l=c[b+28>>2]|0;m=f|0;a[m]=(((ac(d[b+32|0]|0,l)|0)>>>0)/255|0)&255;n=g|0;a[n]=(((ac(d[b+35|0]|0,l)|0)>>>0)/255|0)&255;o=f+1|0;a[o]=(((ac(d[b+33|0]|0,l)|0)>>>0)/255|0)&255;p=g+1|0;a[p]=(((ac(d[b+36|0]|0,l)|0)>>>0)/255|0)&255;q=f+2|0;a[q]=(((ac(d[b+34|0]|0,l)|0)>>>0)/255|0)&255;f=g+2|0;a[f]=(((ac(d[b+37|0]|0,l)|0)>>>0)/255|0)&255;l=b+4|0;g=b+8|0;uK(j,c[l>>2]|0,c[g>>2]|0);j=c[b+24>>2]|0;r=c[g>>2]|0;L3218:do{if((r|0)==0){s=b+12|0}else{t=b+16|0;u=b+12|0;v=c[k>>2]|0;w=c[b+20>>2]|0;x=0;y=r;while(1){z=y-x|0;A=c[t>>2]|0;B=z>>>0>A>>>0?A:z;z=ac(((c[l>>2]|0)+7|0)>>>3,B)|0;if((a[u]|0)==0){if((va(w|0,v|0,z|0)|0)==0){C=y}else{D=2538}}else{D=2538}if((D|0)==2538){D=0;u7(w|0,v|0,z)|0;A=z<<3;if((A|0)!=0){E=0;F=0;while(1){if((d[w+(F>>>3)|0]&128>>>((F&7)>>>0)|0)==0){a[j+E|0]=a[n]|0;a[j+(E+1)|0]=a[p]|0;a[j+(E+2)|0]=a[f]|0}else{a[j+E|0]=a[m]|0;a[j+(E+1)|0]=a[o]|0;a[j+(E+2)|0]=a[q]|0}G=F+1|0;if(G>>>0<A>>>0){E=E+3|0;F=G}else{break}}}uL(c[h>>2]|0,j,x,B);C=c[g>>2]|0}F=B+x|0;if(F>>>0>=C>>>0){s=u;break L3218}v=v+z|0;w=w+z|0;x=F;y=C}}}while(0);a[s]=0;uM(c[h>>2]|0);i=e;return}function fO(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b+40|0;f=c[e>>2]|0;g=f+d|0;c[e>>2]=g;if(g>>>0<120384){return}do{if(f>>>0<120384){fN(b);g=b+48|0;if((a[g]|0)==1){break}a[g]=1;g=c[b+56>>2]|0;if((g|0)==0){break}b1[g&511](c[b+52>>2]|0,1)}}while(0);f=c[e>>2]|0;if(f>>>0<=130239){return}g=b+48|0;do{if((a[g]|0)==0){h=f}else{a[g]=0;d=c[b+56>>2]|0;if((d|0)==0){h=f;break}b1[d&511](c[b+52>>2]|0,0);h=c[e>>2]|0}}while(0);c[e>>2]=h-130240;return}function fP(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=i;i=i+16|0;j=h|0;k=e+36|0;l=e+32|0;m=e+8|0;n=e+4|0;e=0;do{o=e+g&16777215;if(o>>>0<(c[k>>2]|0)>>>0){p=a[(c[l>>2]|0)+o|0]|0}else{p=b6[c[m>>2]&63](c[n>>2]|0,o)|0}a[j+e|0]=p;e=e+1|0;}while(e>>>0<16);e=j|0;c[f>>2]=0;c[f+4>>2]=g;a[f+288|0]=0;g=a[e]|0;p=a[j+1|0]|0;b[f+12>>1]=(g&255)<<8|p&255;n=f+8|0;c[n>>2]=1;b1[c[20264+(((p&255)>>>6|(g&255)<<2)<<2)>>2]&511](f,e);if((c[n>>2]|0)==0){i=h;return}else{q=0}do{e=q<<1;b[f+12+(q<<1)>>1]=(d[j+e|0]|0)<<8|(d[j+(e|1)|0]|0);q=q+1|0;}while(q>>>0<(c[n>>2]|0)>>>0);i=h;return}function fQ(e,f){e=e|0;f=f|0;var g=0,h=0,j=0;g=i;h=(b[e+12>>1]&63)==60;j=e+32|0;a[j]=a[45856]|0;a[j+1|0]=a[45857|0]|0;a[j+2|0]=a[45858|0]|0;a[j+3|0]=a[45859|0]|0;a[j+4|0]=a[45860|0]|0;a[j+5|0]=a[45861|0]|0;c[e+28>>2]=2;j=d[f+3|0]|0;a2(e+96|0,52224,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=j,x)|0)|0;j=e+8|0;c[j>>2]=(c[j>>2]|0)+1;j=e+160|0;if(h){h=j;y=5391171;a[h]=y&255;y=y>>8;a[h+1|0]=y&255;y=y>>8;a[h+2|0]=y&255;y=y>>8;a[h+3|0]=y&255;i=g;return}else{ik(e,j,f,a[f+1|0]&63,8);i=g;return}}function fR(e,f){e=e|0;f=f|0;var g=0,h=0,j=0;g=i;h=(b[e+12>>1]&63)==60;j=e+32|0;a[j]=a[45896]|0;a[j+1|0]=a[45897|0]|0;a[j+2|0]=a[45898|0]|0;a[j+3|0]=a[45899|0]|0;a[j+4|0]=a[45900|0]|0;a[j+5|0]=a[45901|0]|0;c[e+28>>2]=2;j=((d[f+2|0]|0)<<8|(d[f+3|0]|0))&65535;a2(e+96|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=j,x)|0)|0;j=e+8|0;c[j>>2]=(c[j>>2]|0)+1;j=e+160|0;if(h){a[j]=a[49056]|0;a[j+1|0]=a[49057|0]|0;a[j+2|0]=a[49058|0]|0;h=e|0;c[h>>2]=c[h>>2]|1;i=g;return}else{ik(e,j,f,a[f+1|0]&63,16);i=g;return}}function fS(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[45912]|0;a[g+1|0]=a[45913|0]|0;a[g+2|0]=a[45914|0]|0;a[g+3|0]=a[45915|0]|0;a[g+4|0]=a[45916|0]|0;a[g+5|0]=a[45917|0]|0;c[b+28>>2]=2;g=(((d[e+2|0]|0)<<8|(d[e+3|0]|0))<<8|(d[e+4|0]|0))<<8|(d[e+5|0]|0);a2(b+96|0,51552,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=g,x)|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+2;ik(b,b+160|0,e,a[e+1|0]&63,32);i=f;return}function fT(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;g=b+8|0;h=c[g>>2]|0;j=a[e+(h<<1)|0]|0;c[g>>2]=h+1;h=b+32|0;if((j&8)==0){a[h]=a[46008]|0;a[h+1|0]=a[46009|0]|0;a[h+2|0]=a[46010|0]|0;a[h+3|0]=a[46011|0]|0;a[h+4|0]=a[46012|0]|0;a[h+5|0]=a[46013|0]|0;a[h+6|0]=a[46014|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,8);j=b+160|0;g=d[e+2|0]|0;k=(g&128|0)!=0?32752:31024;l=g>>>4&7;a2(j|0,35736,(x=i,i=i+16|0,c[x>>2]=k,c[x+8>>2]=l,x)|0)|0;m=b|0;n=c[m>>2]|0;o=n|128;c[m>>2]=o;i=f;return}else{a[h]=a[46056]|0;a[h+1|0]=a[46057|0]|0;a[h+2|0]=a[46058|0]|0;a[h+3|0]=a[46059|0]|0;a[h+4|0]=a[46060|0]|0;a[h+5|0]=a[46061|0]|0;a[h+6|0]=a[46062|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,8);h=b+160|0;l=d[e+2|0]|0;e=(l&128|0)!=0?32752:31024;k=l>>>4&7;a2(h|0,35736,(x=i,i=i+16|0,c[x>>2]=e,c[x+8>>2]=k,x)|0)|0;m=b|0;n=c[m>>2]|0;o=n|128;c[m>>2]=o;i=f;return}}function fU(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;h=b[e+12>>1]|0;j=e+32|0;if((h&56)==8){k=j;l=k|0;y=1163284301;a[l]=y&255;y=y>>8;a[l+1|0]=y&255;y=y>>8;a[l+2|0]=y&255;y=y>>8;a[l+3|0]=y&255;l=k+4|0;y=5713488;a[l]=y&255;y=y>>8;a[l+1|0]=y&255;y=y>>8;a[l+2|0]=y&255;y=y>>8;a[l+3|0]=y&255;c[e+28>>2]=2;l=e+96|0;k=((d[f+2|0]|0)<<8|(d[f+3|0]|0))&65535;m=(k&32768|0)!=0;n=m?53680:58240;o=(m?-k|0:k)&65535;k=h&7;a2(l|0,54880,(x=i,i=i+32|0,c[x>>2]=n,c[x+8>>2]=39144,c[x+16>>2]=o,c[x+24>>2]=k,x)|0)|0;k=e+8|0;c[k>>2]=(c[k>>2]|0)+1;k=e+160|0;o=(d[f]|0)>>>1&7;a2(k|0,42056,(x=i,i=i+8|0,c[x>>2]=o,x)|0)|0;i=g;return}else{a[j]=a[46584]|0;a[j+1|0]=a[46585|0]|0;a[j+2|0]=a[46586|0]|0;a[j+3|0]=a[46587|0]|0;a[j+4|0]=a[46588|0]|0;c[e+28>>2]=2;j=e+96|0;o=(d[f]|0)>>>1&7;a2(j|0,42056,(x=i,i=i+8|0,c[x>>2]=o,x)|0)|0;ik(e,e+160|0,f,a[f+1|0]&63,8);i=g;return}}function fV(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;h=b[e+12>>1]|0;j=e+32|0;if((h&56)==8){k=j;l=k|0;y=1163284301;a[l]=y&255;y=y>>8;a[l+1|0]=y&255;y=y>>8;a[l+2|0]=y&255;y=y>>8;a[l+3|0]=y&255;l=k+4|0;y=4992592;a[l]=y&255;y=y>>8;a[l+1|0]=y&255;y=y>>8;a[l+2|0]=y&255;y=y>>8;a[l+3|0]=y&255;c[e+28>>2]=2;l=e+96|0;k=((d[f+2|0]|0)<<8|(d[f+3|0]|0))&65535;m=(k&32768|0)!=0;n=m?53680:58240;o=(m?-k|0:k)&65535;k=h&7;a2(l|0,54880,(x=i,i=i+32|0,c[x>>2]=n,c[x+8>>2]=39144,c[x+16>>2]=o,c[x+24>>2]=k,x)|0)|0;k=e+8|0;c[k>>2]=(c[k>>2]|0)+1;k=e+160|0;o=(d[f]|0)>>>1&7;a2(k|0,42056,(x=i,i=i+8|0,c[x>>2]=o,x)|0)|0;i=g;return}else{a[j]=a[46616]|0;a[j+1|0]=a[46617|0]|0;a[j+2|0]=a[46618|0]|0;a[j+3|0]=a[46619|0]|0;a[j+4|0]=a[46620|0]|0;c[e+28>>2]=2;j=e+96|0;o=(d[f]|0)>>>1&7;a2(j|0,42056,(x=i,i=i+8|0,c[x>>2]=o,x)|0)|0;ik(e,e+160|0,f,a[f+1|0]&63,8);i=g;return}}function fW(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;h=e+12|0;j=e+32|0;if((b[h>>1]&56)==8){k=j;l=k|0;y=1163284301;a[l]=y&255;y=y>>8;a[l+1|0]=y&255;y=y>>8;a[l+2|0]=y&255;y=y>>8;a[l+3|0]=y&255;l=k+4|0;y=5713488;a[l]=y&255;y=y>>8;a[l+1|0]=y&255;y=y>>8;a[l+2|0]=y&255;y=y>>8;a[l+3|0]=y&255;c[e+28>>2]=2;l=e+96|0;k=(d[f]|0)>>>1&7;a2(l|0,42056,(x=i,i=i+8|0,c[x>>2]=k,x)|0)|0;k=e+160|0;l=((d[f+2|0]|0)<<8|(d[f+3|0]|0))&65535;m=(l&32768|0)!=0;n=m?53680:58240;o=(m?-l|0:l)&65535;l=b[h>>1]&7;a2(k|0,54880,(x=i,i=i+32|0,c[x>>2]=n,c[x+8>>2]=39144,c[x+16>>2]=o,c[x+24>>2]=l,x)|0)|0;l=e+8|0;c[l>>2]=(c[l>>2]|0)+1;i=g;return}else{a[j]=a[46672]|0;a[j+1|0]=a[46673|0]|0;a[j+2|0]=a[46674|0]|0;a[j+3|0]=a[46675|0]|0;a[j+4|0]=a[46676|0]|0;c[e+28>>2]=2;j=e+96|0;l=(d[f]|0)>>>1&7;a2(j|0,42056,(x=i,i=i+8|0,c[x>>2]=l,x)|0)|0;ik(e,e+160|0,f,a[f+1|0]&63,8);i=g;return}}function fX(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;h=e+12|0;j=e+32|0;if((b[h>>1]&56)==8){k=j;l=k|0;y=1163284301;a[l]=y&255;y=y>>8;a[l+1|0]=y&255;y=y>>8;a[l+2|0]=y&255;y=y>>8;a[l+3|0]=y&255;l=k+4|0;y=4992592;a[l]=y&255;y=y>>8;a[l+1|0]=y&255;y=y>>8;a[l+2|0]=y&255;y=y>>8;a[l+3|0]=y&255;c[e+28>>2]=2;l=e+96|0;k=(d[f]|0)>>>1&7;a2(l|0,42056,(x=i,i=i+8|0,c[x>>2]=k,x)|0)|0;k=e+160|0;l=((d[f+2|0]|0)<<8|(d[f+3|0]|0))&65535;m=(l&32768|0)!=0;n=m?53680:58240;o=(m?-l|0:l)&65535;l=b[h>>1]&7;a2(k|0,54880,(x=i,i=i+32|0,c[x>>2]=n,c[x+8>>2]=39144,c[x+16>>2]=o,c[x+24>>2]=l,x)|0)|0;l=e+8|0;c[l>>2]=(c[l>>2]|0)+1;i=g;return}else{a[j]=a[46760]|0;a[j+1|0]=a[46761|0]|0;a[j+2|0]=a[46762|0]|0;a[j+3|0]=a[46763|0]|0;a[j+4|0]=a[46764|0]|0;c[e+28>>2]=2;j=e+96|0;l=(d[f]|0)>>>1&7;a2(j|0,42056,(x=i,i=i+8|0,c[x>>2]=l,x)|0)|0;ik(e,e+160|0,f,a[f+1|0]&63,8);i=g;return}}function fY(e,f){e=e|0;f=f|0;var g=0,h=0,j=0;g=i;h=(b[e+12>>1]&63)==60;j=e+32|0;a[j]=a[46120]|0;a[j+1|0]=a[46121|0]|0;a[j+2|0]=a[46122|0]|0;a[j+3|0]=a[46123|0]|0;a[j+4|0]=a[46124|0]|0;a[j+5|0]=a[46125|0]|0;a[j+6|0]=a[46126|0]|0;c[e+28>>2]=2;j=d[f+3|0]|0;a2(e+96|0,52224,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=j,x)|0)|0;j=e+8|0;c[j>>2]=(c[j>>2]|0)+1;j=e+160|0;if(h){h=j;y=5391171;a[h]=y&255;y=y>>8;a[h+1|0]=y&255;y=y>>8;a[h+2|0]=y&255;y=y>>8;a[h+3|0]=y&255;i=g;return}else{ik(e,j,f,a[f+1|0]&63,8);i=g;return}}function fZ(e,f){e=e|0;f=f|0;var g=0,h=0,j=0;g=i;h=(b[e+12>>1]&63)==60;j=e+32|0;a[j]=a[46168]|0;a[j+1|0]=a[46169|0]|0;a[j+2|0]=a[46170|0]|0;a[j+3|0]=a[46171|0]|0;a[j+4|0]=a[46172|0]|0;a[j+5|0]=a[46173|0]|0;a[j+6|0]=a[46174|0]|0;c[e+28>>2]=2;j=((d[f+2|0]|0)<<8|(d[f+3|0]|0))&65535;a2(e+96|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=j,x)|0)|0;j=e+8|0;c[j>>2]=(c[j>>2]|0)+1;j=e+160|0;if(h){a[j]=a[49056]|0;a[j+1|0]=a[49057|0]|0;a[j+2|0]=a[49058|0]|0;h=e|0;c[h>>2]=c[h>>2]|1;i=g;return}else{ik(e,j,f,a[f+1|0]&63,16);i=g;return}}function f_(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[46192]|0;a[g+1|0]=a[46193|0]|0;a[g+2|0]=a[46194|0]|0;a[g+3|0]=a[46195|0]|0;a[g+4|0]=a[46196|0]|0;a[g+5|0]=a[46197|0]|0;a[g+6|0]=a[46198|0]|0;c[b+28>>2]=2;g=(((d[e+2|0]|0)<<8|(d[e+3|0]|0))<<8|(d[e+4|0]|0))<<8|(d[e+5|0]|0);a2(b+96|0,51552,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=g,x)|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+2;ik(b,b+160|0,e,a[e+1|0]&63,32);i=f;return}function f$(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;g=b+8|0;h=c[g>>2]|0;j=a[e+(h<<1)|0]|0;c[g>>2]=h+1;h=b+32|0;if((j&8)==0){a[h]=a[46208]|0;a[h+1|0]=a[46209|0]|0;a[h+2|0]=a[46210|0]|0;a[h+3|0]=a[46211|0]|0;a[h+4|0]=a[46212|0]|0;a[h+5|0]=a[46213|0]|0;a[h+6|0]=a[46214|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,16);j=b+160|0;g=d[e+2|0]|0;k=(g&128|0)!=0?32752:31024;l=g>>>4&7;a2(j|0,35736,(x=i,i=i+16|0,c[x>>2]=k,c[x+8>>2]=l,x)|0)|0;m=b|0;n=c[m>>2]|0;o=n|128;c[m>>2]=o;i=f;return}else{a[h]=a[46232]|0;a[h+1|0]=a[46233|0]|0;a[h+2|0]=a[46234|0]|0;a[h+3|0]=a[46235|0]|0;a[h+4|0]=a[46236|0]|0;a[h+5|0]=a[46237|0]|0;a[h+6|0]=a[46238|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,16);h=b+160|0;l=d[e+2|0]|0;e=(l&128|0)!=0?32752:31024;k=l>>>4&7;a2(h|0,35736,(x=i,i=i+16|0,c[x>>2]=e,c[x+8>>2]=k,x)|0)|0;m=b|0;n=c[m>>2]|0;o=n|128;c[m>>2]=o;i=f;return}}function f0(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[46264]|0;a[g+1|0]=a[46265|0]|0;a[g+2|0]=a[46266|0]|0;a[g+3|0]=a[46267|0]|0;a[g+4|0]=a[46268|0]|0;a[g+5|0]=a[46269|0]|0;a[g+6|0]=a[46270|0]|0;c[b+28>>2]=2;g=d[e+3|0]|0;a2(b+96|0,52224,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=g,x)|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+1;ik(b,b+160|0,e,a[e+1|0]&63,8);i=f;return}function f1(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[46328]|0;a[g+1|0]=a[46329|0]|0;a[g+2|0]=a[46330|0]|0;a[g+3|0]=a[46331|0]|0;a[g+4|0]=a[46332|0]|0;a[g+5|0]=a[46333|0]|0;a[g+6|0]=a[46334|0]|0;c[b+28>>2]=2;g=((d[e+2|0]|0)<<8|(d[e+3|0]|0))&65535;a2(b+96|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=g,x)|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+1;ik(b,b+160|0,e,a[e+1|0]&63,16);i=f;return}function f2(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[46400]|0;a[g+1|0]=a[46401|0]|0;a[g+2|0]=a[46402|0]|0;a[g+3|0]=a[46403|0]|0;a[g+4|0]=a[46404|0]|0;a[g+5|0]=a[46405|0]|0;a[g+6|0]=a[46406|0]|0;c[b+28>>2]=2;g=(((d[e+2|0]|0)<<8|(d[e+3|0]|0))<<8|(d[e+4|0]|0))<<8|(d[e+5|0]|0);a2(b+96|0,51552,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=g,x)|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+2;ik(b,b+160|0,e,a[e+1|0]&63,32);i=f;return}function f3(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;g=b+8|0;h=c[g>>2]|0;j=a[e+(h<<1)|0]|0;c[g>>2]=h+1;h=b+32|0;if((j&8)==0){a[h]=a[46424]|0;a[h+1|0]=a[46425|0]|0;a[h+2|0]=a[46426|0]|0;a[h+3|0]=a[46427|0]|0;a[h+4|0]=a[46428|0]|0;a[h+5|0]=a[46429|0]|0;a[h+6|0]=a[46430|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,32);j=b+160|0;g=d[e+2|0]|0;k=(g&128|0)!=0?32752:31024;l=g>>>4&7;a2(j|0,35736,(x=i,i=i+16|0,c[x>>2]=k,c[x+8>>2]=l,x)|0)|0;m=b|0;n=c[m>>2]|0;o=n|128;c[m>>2]=o;i=f;return}else{a[h]=a[46440]|0;a[h+1|0]=a[46441|0]|0;a[h+2|0]=a[46442|0]|0;a[h+3|0]=a[46443|0]|0;a[h+4|0]=a[46444|0]|0;a[h+5|0]=a[46445|0]|0;a[h+6|0]=a[46446|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,32);h=b+160|0;l=d[e+2|0]|0;e=(l&128|0)!=0?32752:31024;k=l>>>4&7;a2(h|0,35736,(x=i,i=i+16|0,c[x>>2]=e,c[x+8>>2]=k,x)|0)|0;m=b|0;n=c[m>>2]|0;o=n|128;c[m>>2]=o;i=f;return}}function f4(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[46488]|0;a[g+1|0]=a[46489|0]|0;a[g+2|0]=a[46490|0]|0;a[g+3|0]=a[46491|0]|0;a[g+4|0]=a[46492|0]|0;a[g+5|0]=a[46493|0]|0;a[g+6|0]=a[46494|0]|0;c[b+28>>2]=2;g=d[e+3|0]|0;a2(b+96|0,52224,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=g,x)|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+1;ik(b,b+160|0,e,a[e+1|0]&63,8);i=f;return}function f5(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[46520]|0;a[g+1|0]=a[46521|0]|0;a[g+2|0]=a[46522|0]|0;a[g+3|0]=a[46523|0]|0;a[g+4|0]=a[46524|0]|0;a[g+5|0]=a[46525|0]|0;a[g+6|0]=a[46526|0]|0;c[b+28>>2]=2;g=((d[e+2|0]|0)<<8|(d[e+3|0]|0))&65535;a2(b+96|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=g,x)|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+1;ik(b,b+160|0,e,a[e+1|0]&63,16);i=f;return}function f6(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[46560]|0;a[g+1|0]=a[46561|0]|0;a[g+2|0]=a[46562|0]|0;a[g+3|0]=a[46563|0]|0;a[g+4|0]=a[46564|0]|0;a[g+5|0]=a[46565|0]|0;a[g+6|0]=a[46566|0]|0;c[b+28>>2]=2;g=(((d[e+2|0]|0)<<8|(d[e+3|0]|0))<<8|(d[e+4|0]|0))<<8|(d[e+5|0]|0);a2(b+96|0,51552,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=g,x)|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+2;ik(b,b+160|0,e,a[e+1|0]&63,32);i=f;return}function f7(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[34016]|0;a[g+1|0]=a[34017|0]|0;a[g+2|0]=a[34018|0]|0;c[b+28>>2]=1;g=((d[e]|0)<<8|(d[e+1|0]|0))&65535;a2(b+96|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=g,x)|0)|0;i=f;return}function f8(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[46584]|0;a[g+1|0]=a[46585|0]|0;a[g+2|0]=a[46586|0]|0;a[g+3|0]=a[46587|0]|0;a[g+4|0]=a[46588|0]|0;c[b+28>>2]=2;g=d[e+3|0]|0;a2(b+96|0,52224,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=g,x)|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+1;ik(b,b+160|0,e,a[e+1|0]&63,8);i=f;return}function f9(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[46616]|0;a[g+1|0]=a[46617|0]|0;a[g+2|0]=a[46618|0]|0;a[g+3|0]=a[46619|0]|0;a[g+4|0]=a[46620|0]|0;c[b+28>>2]=2;g=d[e+3|0]|0;a2(b+96|0,52224,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=g,x)|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+1;ik(b,b+160|0,e,a[e+1|0]&63,8);i=f;return}function ga(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[46672]|0;a[g+1|0]=a[46673|0]|0;a[g+2|0]=a[46674|0]|0;a[g+3|0]=a[46675|0]|0;a[g+4|0]=a[46676|0]|0;c[b+28>>2]=2;g=d[e+3|0]|0;a2(b+96|0,52224,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=g,x)|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+1;ik(b,b+160|0,e,a[e+1|0]&63,8);i=f;return}function gb(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[46760]|0;a[g+1|0]=a[46761|0]|0;a[g+2|0]=a[46762|0]|0;a[g+3|0]=a[46763|0]|0;a[g+4|0]=a[46764|0]|0;c[b+28>>2]=2;g=d[e+3|0]|0;a2(b+96|0,52224,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=g,x)|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+1;ik(b,b+160|0,e,a[e+1|0]&63,8);i=f;return}function gc(e,f){e=e|0;f=f|0;var g=0,h=0,j=0;g=i;h=(b[e+12>>1]&63)==60;j=e+32|0;a[j]=a[46808]|0;a[j+1|0]=a[46809|0]|0;a[j+2|0]=a[46810|0]|0;a[j+3|0]=a[46811|0]|0;a[j+4|0]=a[46812|0]|0;a[j+5|0]=a[46813|0]|0;a[j+6|0]=a[46814|0]|0;c[e+28>>2]=2;j=d[f+3|0]|0;a2(e+96|0,52224,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=j,x)|0)|0;j=e+8|0;c[j>>2]=(c[j>>2]|0)+1;j=e+160|0;if(h){h=j;y=5391171;a[h]=y&255;y=y>>8;a[h+1|0]=y&255;y=y>>8;a[h+2|0]=y&255;y=y>>8;a[h+3|0]=y&255;i=g;return}else{ik(e,j,f,a[f+1|0]&63,8);i=g;return}}function gd(e,f){e=e|0;f=f|0;var g=0,h=0,j=0;g=i;h=(b[e+12>>1]&63)==60;j=e+32|0;a[j]=a[46856]|0;a[j+1|0]=a[46857|0]|0;a[j+2|0]=a[46858|0]|0;a[j+3|0]=a[46859|0]|0;a[j+4|0]=a[46860|0]|0;a[j+5|0]=a[46861|0]|0;a[j+6|0]=a[46862|0]|0;c[e+28>>2]=2;j=e+96|0;if(h){h=d[f+3|0]|0;a2(j|0,52224,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=h,x)|0)|0;h=e+8|0;c[h>>2]=(c[h>>2]|0)+1;h=e+160|0;a[h]=a[49056]|0;a[h+1|0]=a[49057|0]|0;a[h+2|0]=a[49058|0]|0;h=e|0;c[h>>2]=c[h>>2]|1;i=g;return}else{h=((d[f+2|0]|0)<<8|(d[f+3|0]|0))&65535;a2(j|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=h,x)|0)|0;h=e+8|0;c[h>>2]=(c[h>>2]|0)+1;ik(e,e+160|0,f,a[f+1|0]&63,16);i=g;return}}function ge(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[46880]|0;a[g+1|0]=a[46881|0]|0;a[g+2|0]=a[46882|0]|0;a[g+3|0]=a[46883|0]|0;a[g+4|0]=a[46884|0]|0;a[g+5|0]=a[46885|0]|0;a[g+6|0]=a[46886|0]|0;c[b+28>>2]=2;g=(((d[e+2|0]|0)<<8|(d[e+3|0]|0))<<8|(d[e+4|0]|0))<<8|(d[e+5|0]|0);a2(b+96|0,51552,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=g,x)|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+2;ik(b,b+160|0,e,a[e+1|0]&63,32);i=f;return}function gf(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[46904]|0;a[g+1|0]=a[46905|0]|0;a[g+2|0]=a[46906|0]|0;a[g+3|0]=a[46907|0]|0;a[g+4|0]=a[46908|0]|0;a[g+5|0]=a[46909|0]|0;a[g+6|0]=a[46910|0]|0;c[b+28>>2]=2;g=d[e+3|0]|0;a2(b+96|0,52224,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=g,x)|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+1;ik(b,b+160|0,e,a[e+1|0]&63,8);i=f;return}function gg(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[46928]|0;a[g+1|0]=a[46929|0]|0;a[g+2|0]=a[46930|0]|0;a[g+3|0]=a[46931|0]|0;a[g+4|0]=a[46932|0]|0;a[g+5|0]=a[46933|0]|0;a[g+6|0]=a[46934|0]|0;c[b+28>>2]=2;g=((d[e+2|0]|0)<<8|(d[e+3|0]|0))&65535;a2(b+96|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=g,x)|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+1;ik(b,b+160|0,e,a[e+1|0]&63,16);i=f;return}function gh(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[46968]|0;a[g+1|0]=a[46969|0]|0;a[g+2|0]=a[46970|0]|0;a[g+3|0]=a[46971|0]|0;a[g+4|0]=a[46972|0]|0;a[g+5|0]=a[46973|0]|0;a[g+6|0]=a[46974|0]|0;c[b+28>>2]=2;g=(((d[e+2|0]|0)<<8|(d[e+3|0]|0))<<8|(d[e+4|0]|0))<<8|(d[e+5|0]|0);a2(b+96|0,51552,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=g,x)|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+2;ik(b,b+160|0,e,a[e+1|0]&63,32);i=f;return}function gi(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;g=b+8|0;h=c[g>>2]|0;j=a[e+(h<<1)|0]|0;c[g>>2]=h+1;h=b+32|0;a[h]=a[46984]|0;a[h+1|0]=a[46985|0]|0;a[h+2|0]=a[46986|0]|0;a[h+3|0]=a[46987|0]|0;a[h+4|0]=a[46988|0]|0;a[h+5|0]=a[46989|0]|0;a[h+6|0]=a[46990|0]|0;c[b+28>>2]=2;h=b+96|0;if((j&8)==0){ik(b,h,e,a[e+1|0]&63,8);j=b+160|0;g=d[e+2|0]|0;k=(g&128|0)!=0?32752:31024;l=g>>>4&7;a2(j|0,35736,(x=i,i=i+16|0,c[x>>2]=k,c[x+8>>2]=l,x)|0)|0;m=b|0;n=c[m>>2]|0;o=n|64;c[m>>2]=o;i=f;return}else{l=d[e+2|0]|0;k=(l&128|0)!=0?32752:31024;j=l>>>4&7;a2(h|0,35736,(x=i,i=i+16|0,c[x>>2]=k,c[x+8>>2]=j,x)|0)|0;ik(b,b+160|0,e,a[e+1|0]&63,8);m=b|0;n=c[m>>2]|0;o=n|64;c[m>>2]=o;i=f;return}}function gj(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;g=b+8|0;h=c[g>>2]|0;j=a[e+(h<<1)|0]|0;c[g>>2]=h+1;h=b+32|0;a[h]=a[47016]|0;a[h+1|0]=a[47017|0]|0;a[h+2|0]=a[47018|0]|0;a[h+3|0]=a[47019|0]|0;a[h+4|0]=a[47020|0]|0;a[h+5|0]=a[47021|0]|0;a[h+6|0]=a[47022|0]|0;c[b+28>>2]=2;h=b+96|0;if((j&8)==0){ik(b,h,e,a[e+1|0]&63,16);j=b+160|0;g=d[e+2|0]|0;k=(g&128|0)!=0?32752:31024;l=g>>>4&7;a2(j|0,35736,(x=i,i=i+16|0,c[x>>2]=k,c[x+8>>2]=l,x)|0)|0;m=b|0;n=c[m>>2]|0;o=n|64;c[m>>2]=o;i=f;return}else{l=d[e+2|0]|0;k=(l&128|0)!=0?32752:31024;j=l>>>4&7;a2(h|0,35736,(x=i,i=i+16|0,c[x>>2]=k,c[x+8>>2]=j,x)|0)|0;ik(b,b+160|0,e,a[e+1|0]&63,16);m=b|0;n=c[m>>2]|0;o=n|64;c[m>>2]=o;i=f;return}}function gk(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;g=b+8|0;h=c[g>>2]|0;j=a[e+(h<<1)|0]|0;c[g>>2]=h+1;h=b+32|0;a[h]=a[47064]|0;a[h+1|0]=a[47065|0]|0;a[h+2|0]=a[47066|0]|0;a[h+3|0]=a[47067|0]|0;a[h+4|0]=a[47068|0]|0;a[h+5|0]=a[47069|0]|0;a[h+6|0]=a[47070|0]|0;c[b+28>>2]=2;h=b+96|0;if((j&8)==0){ik(b,h,e,a[e+1|0]&63,32);j=b+160|0;g=d[e+2|0]|0;k=(g&128|0)!=0?32752:31024;l=g>>>4&7;a2(j|0,35736,(x=i,i=i+16|0,c[x>>2]=k,c[x+8>>2]=l,x)|0)|0;m=b|0;n=c[m>>2]|0;o=n|64;c[m>>2]=o;i=f;return}else{l=d[e+2|0]|0;k=(l&128|0)!=0?32752:31024;j=l>>>4&7;a2(h|0,35736,(x=i,i=i+16|0,c[x>>2]=k,c[x+8>>2]=j,x)|0)|0;ik(b,b+160|0,e,a[e+1|0]&63,32);m=b|0;n=c[m>>2]|0;o=n|64;c[m>>2]=o;i=f;return}}function gl(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;y=5262666;a[e]=y&255;y=y>>8;a[e+1|0]=y&255;y=y>>8;a[e+2|0]=y&255;y=y>>8;a[e+3|0]=y&255;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,0);d=b|0;c[d>>2]=c[d>>2]|2;return}function gm(b,e){b=b|0;e=e|0;var f=0,g=0;f=b+32|0;a[f]=a[47240]|0;a[f+1|0]=a[47241|0]|0;a[f+2|0]=a[47242|0]|0;a[f+3|0]=a[47243|0]|0;a[f+4|0]=a[47244|0]|0;a[f+5|0]=a[47245|0]|0;a[f+6|0]=a[47246|0]|0;c[b+28>>2]=2;f=e+1|0;ik(b,b+96|0,e,a[f]&63,8);g=((d[e]|0)<<8|(d[f]|0))&65535;ik(b,b+160|0,e,g>>>3&56|g>>>9&7,8);return}function gn(b,e){b=b|0;e=e|0;var f=0,g=0;f=b+32|0;a[f]=a[47296]|0;a[f+1|0]=a[47297|0]|0;a[f+2|0]=a[47298|0]|0;a[f+3|0]=a[47299|0]|0;a[f+4|0]=a[47300|0]|0;a[f+5|0]=a[47301|0]|0;a[f+6|0]=a[47302|0]|0;c[b+28>>2]=2;f=e+1|0;ik(b,b+96|0,e,a[f]&63,32);g=((d[e]|0)<<8|(d[f]|0))&65535;ik(b,b+160|0,e,g>>>3&56|g>>>9&7,32);return}function go(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;g=b+32|0;h=g|0;y=1163284301;a[h]=y&255;y=y>>8;a[h+1|0]=y&255;y=y>>8;a[h+2|0]=y&255;y=y>>8;a[h+3|0]=y&255;h=g+4|0;y=4992577;a[h]=y&255;y=y>>8;a[h+1|0]=y&255;y=y>>8;a[h+2|0]=y&255;y=y>>8;a[h+3|0]=y&255;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,32);a2(b+160|0,38624,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function gp(b,e){b=b|0;e=e|0;var f=0,g=0;f=b+32|0;a[f]=a[48296]|0;a[f+1|0]=a[48297|0]|0;a[f+2|0]=a[48298|0]|0;a[f+3|0]=a[48299|0]|0;a[f+4|0]=a[48300|0]|0;a[f+5|0]=a[48301|0]|0;a[f+6|0]=a[48302|0]|0;c[b+28>>2]=2;f=e+1|0;ik(b,b+96|0,e,a[f]&63,16);g=((d[e]|0)<<8|(d[f]|0))&65535;ik(b,b+160|0,e,g>>>3&56|g>>>9&7,16);return}function gq(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;g=b+32|0;h=g|0;y=1163284301;a[h]=y&255;y=y>>8;a[h+1|0]=y&255;y=y>>8;a[h+2|0]=y&255;y=y>>8;a[h+3|0]=y&255;h=g+4|0;y=5713473;a[h]=y&255;y=y>>8;a[h+1|0]=y&255;y=y>>8;a[h+2|0]=y&255;y=y>>8;a[h+3|0]=y&255;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,16);a2(b+160|0,38624,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function gr(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[47536]|0;a[e+1|0]=a[47537|0]|0;a[e+2|0]=a[47538|0]|0;a[e+3|0]=a[47539|0]|0;a[e+4|0]=a[47540|0]|0;a[e+5|0]=a[47541|0]|0;a[e+6|0]=a[47542|0]|0;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,8);d=b|0;c[d>>2]=c[d>>2]|32;return}function gs(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[47576]|0;a[e+1|0]=a[47577|0]|0;a[e+2|0]=a[47578|0]|0;a[e+3|0]=a[47579|0]|0;a[e+4|0]=a[47580|0]|0;a[e+5|0]=a[47581|0]|0;a[e+6|0]=a[47582|0]|0;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,16);d=b|0;c[d>>2]=c[d>>2]|32;return}function gt(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[47720]|0;a[e+1|0]=a[47721|0]|0;a[e+2|0]=a[47722|0]|0;a[e+3|0]=a[47723|0]|0;a[e+4|0]=a[47724|0]|0;a[e+5|0]=a[47725|0]|0;a[e+6|0]=a[47726|0]|0;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,32);d=b|0;c[d>>2]=c[d>>2]|32;return}function gu(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[48296]|0;a[e+1|0]=a[48297|0]|0;a[e+2|0]=a[48298|0]|0;a[e+3|0]=a[48299|0]|0;a[e+4|0]=a[48300|0]|0;a[e+5|0]=a[48301|0]|0;a[e+6|0]=a[48302|0]|0;c[b+28>>2]=2;e=b+96|0;a[e]=a[49056]|0;a[e+1|0]=a[49057|0]|0;a[e+2|0]=a[49058|0]|0;ik(b,b+160|0,d,a[d+1|0]&63,16);return}function gv(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;y=4933699;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,16);a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function gw(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;y=4277580;a[g]=y&255;y=y>>8;a[g+1|0]=y&255;y=y>>8;a[g+2|0]=y&255;y=y>>8;a[g+3|0]=y&255;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,32);a2(b+160|0,38624,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function gx(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[47976]|0;a[e+1|0]=a[47977|0]|0;a[e+2|0]=a[47978|0]|0;a[e+3|0]=a[47979|0]|0;a[e+4|0]=a[47980|0]|0;a[e+5|0]=a[47981|0]|0;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,8);return}function gy(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[48072]|0;a[e+1|0]=a[48073|0]|0;a[e+2|0]=a[48074|0]|0;a[e+3|0]=a[48075|0]|0;a[e+4|0]=a[48076|0]|0;a[e+5|0]=a[48077|0]|0;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,16);return}function gz(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[48104]|0;a[e+1|0]=a[48105|0]|0;a[e+2|0]=a[48106|0]|0;a[e+3|0]=a[48107|0]|0;a[e+4|0]=a[48108|0]|0;a[e+5|0]=a[48109|0]|0;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,32);return}function gA(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[48296]|0;a[e+1|0]=a[48297|0]|0;a[e+2|0]=a[48298|0]|0;a[e+3|0]=a[48299|0]|0;a[e+4|0]=a[48300|0]|0;a[e+5|0]=a[48301|0]|0;a[e+6|0]=a[48302|0]|0;c[b+28>>2]=2;e=b+96|0;y=5391171;a[e]=y&255;y=y>>8;a[e+1|0]=y&255;y=y>>8;a[e+2|0]=y&255;y=y>>8;a[e+3|0]=y&255;ik(b,b+160|0,d,a[d+1|0]&63,16);d=b|0;c[d>>2]=c[d>>2]|64;return}function gB(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[48128]|0;a[e+1|0]=a[48129|0]|0;a[e+2|0]=a[48130|0]|0;a[e+3|0]=a[48131|0]|0;a[e+4|0]=a[48132|0]|0;a[e+5|0]=a[48133|0]|0;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,8);return}function gC(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[48152]|0;a[e+1|0]=a[48153|0]|0;a[e+2|0]=a[48154|0]|0;a[e+3|0]=a[48155|0]|0;a[e+4|0]=a[48156|0]|0;a[e+5|0]=a[48157|0]|0;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,16);return}function gD(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[48184]|0;a[e+1|0]=a[48185|0]|0;a[e+2|0]=a[48186|0]|0;a[e+3|0]=a[48187|0]|0;a[e+4|0]=a[48188|0]|0;a[e+5|0]=a[48189|0]|0;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,32);return}function gE(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[48296]|0;a[e+1|0]=a[48297|0]|0;a[e+2|0]=a[48298|0]|0;a[e+3|0]=a[48299|0]|0;a[e+4|0]=a[48300|0]|0;a[e+5|0]=a[48301|0]|0;a[e+6|0]=a[48302|0]|0;c[b+28>>2]=2;ik(b,b+96|0,d,a[d+1|0]&63,16);d=b+160|0;y=5391171;a[d]=y&255;y=y>>8;a[d+1|0]=y&255;y=y>>8;a[d+2|0]=y&255;y=y>>8;a[d+3|0]=y&255;return}function gF(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[48208]|0;a[e+1|0]=a[48209|0]|0;a[e+2|0]=a[48210|0]|0;a[e+3|0]=a[48211|0]|0;a[e+4|0]=a[48212|0]|0;a[e+5|0]=a[48213|0]|0;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,8);return}function gG(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[48232]|0;a[e+1|0]=a[48233|0]|0;a[e+2|0]=a[48234|0]|0;a[e+3|0]=a[48235|0]|0;a[e+4|0]=a[48236|0]|0;a[e+5|0]=a[48237|0]|0;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,16);return}function gH(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[48264]|0;a[e+1|0]=a[48265|0]|0;a[e+2|0]=a[48266|0]|0;a[e+3|0]=a[48267|0]|0;a[e+4|0]=a[48268|0]|0;a[e+5|0]=a[48269|0]|0;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,32);return}function gI(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[48296]|0;a[e+1|0]=a[48297|0]|0;a[e+2|0]=a[48298|0]|0;a[e+3|0]=a[48299|0]|0;a[e+4|0]=a[48300|0]|0;a[e+5|0]=a[48301|0]|0;a[e+6|0]=a[48302|0]|0;c[b+28>>2]=2;ik(b,b+96|0,d,a[d+1|0]&63,16);d=b+160|0;a[d]=a[49056]|0;a[d+1|0]=a[49057|0]|0;a[d+2|0]=a[49058|0]|0;d=b|0;c[d>>2]=c[d>>2]|1;return}function gJ(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[48400]|0;a[e+1|0]=a[48401|0]|0;a[e+2|0]=a[48402|0]|0;a[e+3|0]=a[48403|0]|0;a[e+4|0]=a[48404|0]|0;a[e+5|0]=a[48405|0]|0;a[e+6|0]=a[48406|0]|0;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,8);d=b|0;c[d>>2]=c[d>>2]|32;return}function gK(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;g=b[d+12>>1]|0;h=d+32|0;if((g&56)==0){a[h]=a[48544]|0;a[h+1|0]=a[48545|0]|0;a[h+2|0]=a[48546|0]|0;a[h+3|0]=a[48547|0]|0;a[h+4|0]=a[48548|0]|0;c[d+28>>2]=1;j=d+96|0;k=g&7;a2(j|0,42056,(x=i,i=i+8|0,c[x>>2]=k,x)|0)|0;i=f;return}else{k=h;y=4277584;a[k]=y&255;y=y>>8;a[k+1|0]=y&255;y=y>>8;a[k+2|0]=y&255;y=y>>8;a[k+3|0]=y&255;c[d+28>>2]=1;ik(d,d+96|0,e,a[e+1|0]&63,32);i=f;return}}function gL(b,d){b=b|0;d=d|0;var f=0,g=0,h=0,j=0,k=0;f=i;g=e[b+12>>1]|0;h=g>>>3&7;if((h|0)==0){j=b+32|0;a[j]=a[48576]|0;a[j+1|0]=a[48577|0]|0;a[j+2|0]=a[48578|0]|0;a[j+3|0]=a[48579|0]|0;a[j+4|0]=a[48580|0]|0;a[j+5|0]=a[48581|0]|0;c[b+28>>2]=1;j=b+96|0;k=g&7;a2(j|0,42056,(x=i,i=i+8|0,c[x>>2]=k,x)|0)|0;i=f;return}else if((h|0)==4){h=b+32|0;k=h|0;y=1163284301;a[k]=y&255;y=y>>8;a[k+1|0]=y&255;y=y>>8;a[k+2|0]=y&255;y=y>>8;a[k+3|0]=y&255;k=h+4|0;y=5713485;a[k]=y&255;y=y>>8;a[k+1|0]=y&255;y=y>>8;a[k+2|0]=y&255;y=y>>8;a[k+3|0]=y&255;c[b+28>>2]=2;h4(b,b+96|0,d,25,16);ik(b,b+160|0,d,a[d+1|0]&63,16);i=f;return}else{k=b+32|0;h=k|0;y=1163284301;a[h]=y&255;y=y>>8;a[h+1|0]=y&255;y=y>>8;a[h+2|0]=y&255;y=y>>8;a[h+3|0]=y&255;h=k+4|0;y=5713485;a[h]=y&255;y=y>>8;a[h+1|0]=y&255;y=y>>8;a[h+2|0]=y&255;y=y>>8;a[h+3|0]=y&255;c[b+28>>2]=2;h4(b,b+96|0,d,24,16);ik(b,b+160|0,d,a[d+1|0]&63,16);i=f;return}}function gM(b,d){b=b|0;d=d|0;var f=0,g=0,h=0,j=0,k=0;f=i;g=e[b+12>>1]|0;h=g>>>3&7;if((h|0)==4){j=b+32|0;k=j|0;y=1163284301;a[k]=y&255;y=y>>8;a[k+1|0]=y&255;y=y>>8;a[k+2|0]=y&255;y=y>>8;a[k+3|0]=y&255;k=j+4|0;y=4992589;a[k]=y&255;y=y>>8;a[k+1|0]=y&255;y=y>>8;a[k+2|0]=y&255;y=y>>8;a[k+3|0]=y&255;c[b+28>>2]=2;h4(b,b+96|0,d,25,32);ik(b,b+160|0,d,a[d+1|0]&63,32);i=f;return}else if((h|0)==0){h=b+32|0;a[h]=a[48600]|0;a[h+1|0]=a[48601|0]|0;a[h+2|0]=a[48602|0]|0;a[h+3|0]=a[48603|0]|0;a[h+4|0]=a[48604|0]|0;a[h+5|0]=a[48605|0]|0;c[b+28>>2]=1;a2(b+96|0,42056,(x=i,i=i+8|0,c[x>>2]=g&7,x)|0)|0;i=f;return}else{g=b+32|0;h=g|0;y=1163284301;a[h]=y&255;y=y>>8;a[h+1|0]=y&255;y=y>>8;a[h+2|0]=y&255;y=y>>8;a[h+3|0]=y&255;h=g+4|0;y=4992589;a[h]=y&255;y=y>>8;a[h+1|0]=y&255;y=y>>8;a[h+2|0]=y&255;y=y>>8;a[h+3|0]=y&255;c[b+28>>2]=2;h4(b,b+96|0,d,24,32);ik(b,b+160|0,d,a[d+1|0]&63,32);i=f;return}}function gN(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;h=b[e+12>>1]|0;j=e+32|0;if((h&56)==0){a[j]=a[48632]|0;a[j+1|0]=a[48633|0]|0;a[j+2|0]=a[48634|0]|0;a[j+3|0]=a[48635|0]|0;a[j+4|0]=a[48636|0]|0;a[j+5|0]=a[48637|0]|0;a[j+6|0]=a[48638|0]|0;c[e+28>>2]=1;k=e+96|0;l=h&7;a2(k|0,42056,(x=i,i=i+8|0,c[x>>2]=l,x)|0)|0;l=e|0;c[l>>2]=c[l>>2]|128;i=g;return}else{l=j;y=4277580;a[l]=y&255;y=y>>8;a[l+1|0]=y&255;y=y>>8;a[l+2|0]=y&255;y=y>>8;a[l+3|0]=y&255;c[e+28>>2]=2;ik(e,e+96|0,f,a[f+1|0]&63,32);l=e+160|0;e=(d[f]|0)>>>1&7;a2(l|0,38624,(x=i,i=i+8|0,c[x>>2]=e,x)|0)|0;i=g;return}}function gO(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[48656]|0;a[e+1|0]=a[48657|0]|0;a[e+2|0]=a[48658|0]|0;a[e+3|0]=a[48659|0]|0;a[e+4|0]=a[48660|0]|0;a[e+5|0]=a[48661|0]|0;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,8);return}function gP(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[48680]|0;a[e+1|0]=a[48681|0]|0;a[e+2|0]=a[48682|0]|0;a[e+3|0]=a[48683|0]|0;a[e+4|0]=a[48684|0]|0;a[e+5|0]=a[48685|0]|0;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,16);return}function gQ(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[48720]|0;a[e+1|0]=a[48721|0]|0;a[e+2|0]=a[48722|0]|0;a[e+3|0]=a[48723|0]|0;a[e+4|0]=a[48724|0]|0;a[e+5|0]=a[48725|0]|0;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,32);return}function gR(d,e){d=d|0;e=e|0;var f=0,g=0,h=0;f=d+32|0;if((b[d+12>>1]|0)==19196){g=f;h=g|0;y=1162628169;a[h]=y&255;y=y>>8;a[h+1|0]=y&255;y=y>>8;a[h+2|0]=y&255;y=y>>8;a[h+3|0]=y&255;h=g+4|0;y=4997447;a[h]=y&255;y=y>>8;a[h+1|0]=y&255;y=y>>8;a[h+2|0]=y&255;y=y>>8;a[h+3|0]=y&255;c[d+28>>2]=0;h=d|0;c[h>>2]=c[h>>2]|4;return}else{h=f;y=5456212;a[h]=y&255;y=y>>8;a[h+1|0]=y&255;y=y>>8;a[h+2|0]=y&255;y=y>>8;a[h+3|0]=y&255;c[d+28>>2]=1;ik(d,d+96|0,e,a[e+1|0]&63,8);return}}function gS(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=i;j=f+8|0;k=c[j>>2]|0;l=k<<1;m=(d[g+l|0]|0)<<8;n=m|(d[g+(l|1)|0]|0);c[j>>2]=k+1;k=f+14|0;b[k>>1]=n;n=f+32|0;a[n]=a[48968]|0;a[n+1|0]=a[48969|0]|0;a[n+2|0]=a[48970|0]|0;a[n+3|0]=a[48971|0]|0;a[n+4|0]=a[48972|0]|0;a[n+5|0]=a[48973|0]|0;a[n+6|0]=a[48974|0]|0;c[f+28>>2]=2;ik(f,f+96|0,g,a[g+1|0]&63,32);g=f+160|0;n=e[k>>1]|0;if((m&1024)==0){m=n>>>12&7;a2(g|0,42056,(x=i,i=i+8|0,c[x>>2]=m,x)|0)|0;o=f|0;p=c[o>>2]|0;q=p|128;c[o>>2]=q;i=h;return}else{m=n&7;k=n>>>12&7;a2(g|0,48160,(x=i,i=i+16|0,c[x>>2]=m,c[x+8>>2]=k,x)|0)|0;o=f|0;p=c[o>>2]|0;q=p|128;c[o>>2]=q;i=h;return}}function gT(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;j=f+8|0;k=c[j>>2]|0;l=k<<1;m=(d[g+l|0]|0)<<8;n=m|(d[g+(l|1)|0]|0);c[j>>2]=k+1;k=f+14|0;b[k>>1]=n;n=f+32|0;if((m&1024)==0){a[n]=a[49016]|0;a[n+1|0]=a[49017|0]|0;a[n+2|0]=a[49018|0]|0;a[n+3|0]=a[49019|0]|0;a[n+4|0]=a[49020|0]|0;a[n+5|0]=a[49021|0]|0;a[n+6|0]=a[49022|0]|0;c[f+28>>2]=2;ik(f,f+96|0,g,a[g+1|0]&63,32);m=f+160|0;j=e[k>>1]|0;l=j&7;o=j>>>12&7;a2(m|0,48160,(x=i,i=i+16|0,c[x>>2]=l,c[x+8>>2]=o,x)|0)|0;p=f|0;q=c[p>>2]|0;r=q|128;c[p>>2]=r;i=h;return}else{o=n;n=o|0;y=1431718212;a[n]=y&255;y=y>>8;a[n+1|0]=y&255;y=y>>8;a[n+2|0]=y&255;y=y>>8;a[n+3|0]=y&255;n=o+4|0;y=4992588;a[n]=y&255;y=y>>8;a[n+1|0]=y&255;y=y>>8;a[n+2|0]=y&255;y=y>>8;a[n+3|0]=y&255;c[f+28>>2]=2;ik(f,f+96|0,g,a[g+1|0]&63,32);g=f+160|0;n=e[k>>1]|0;k=n&7;o=n>>>12&7;a2(g|0,48160,(x=i,i=i+16|0,c[x>>2]=k,c[x+8>>2]=o,x)|0)|0;p=f|0;q=c[p>>2]|0;r=q|128;c[p>>2]=r;i=h;return}}function gU(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=e+32|0;if((b[e+12>>1]&56)==0){a[h]=a[34016]|0;a[h+1|0]=a[34017|0]|0;a[h+2|0]=a[34018|0]|0;c[e+28>>2]=1;j=e+96|0;k=((d[f]|0)<<8|(d[f+1|0]|0))&65535;a2(j|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=k,x)|0)|0;i=g;return}else{k=h;h=k|0;y=1163284301;a[h]=y&255;y=y>>8;a[h+1|0]=y&255;y=y>>8;a[h+2|0]=y&255;y=y>>8;a[h+3|0]=y&255;h=k+4|0;y=5713485;a[h]=y&255;y=y>>8;a[h+1|0]=y&255;y=y>>8;a[h+2|0]=y&255;y=y>>8;a[h+3|0]=y&255;c[e+28>>2]=2;h4(e,e+160|0,f,24,16);ik(e,e+96|0,f,a[f+1|0]&63,16);i=g;return}}function gV(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=e+32|0;if((b[e+12>>1]&56)==0){a[h]=a[34016]|0;a[h+1|0]=a[34017|0]|0;a[h+2|0]=a[34018|0]|0;c[e+28>>2]=1;j=e+96|0;k=((d[f]|0)<<8|(d[f+1|0]|0))&65535;a2(j|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=k,x)|0)|0;i=g;return}else{k=h;h=k|0;y=1163284301;a[h]=y&255;y=y>>8;a[h+1|0]=y&255;y=y>>8;a[h+2|0]=y&255;y=y>>8;a[h+3|0]=y&255;h=k+4|0;y=4992589;a[h]=y&255;y=y>>8;a[h+1|0]=y&255;y=y>>8;a[h+2|0]=y&255;y=y>>8;a[h+3|0]=y&255;c[e+28>>2]=2;h4(e,e+160|0,f,24,32);ik(e,e+96|0,f,a[f+1|0]&63,32);i=g;return}}function gW(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;h=b[e+12>>1]|0;j=h&65535;if((h<<16>>16|0)==20081){k=e+32|0;y=5263182;a[k]=y&255;y=y>>8;a[k+1|0]=y&255;y=y>>8;a[k+2|0]=y&255;y=y>>8;a[k+3|0]=y&255;c[e+28>>2]=0;i=g;return}else if((h<<16>>16|0)==20082){k=e+32|0;a[k]=a[49616]|0;a[k+1|0]=a[49617|0]|0;a[k+2|0]=a[49618|0]|0;a[k+3|0]=a[49619|0]|0;a[k+4|0]=a[49620|0]|0;c[e+28>>2]=1;k=((d[f+2|0]|0)<<8|(d[f+3|0]|0))&65535;a2(e+96|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=k,x)|0)|0;k=e+8|0;c[k>>2]=(c[k>>2]|0)+1;k=e|0;c[k>>2]=c[k>>2]|1;i=g;return}else if((h<<16>>16|0)==20090){k=e+8|0;c[k>>2]=(c[k>>2]|0)+1;k=e+32|0;a[k]=a[49392]|0;a[k+1|0]=a[49393|0]|0;a[k+2|0]=a[49394|0]|0;a[k+3|0]=a[49395|0]|0;a[k+4|0]=a[49396|0]|0;a[k+5|0]=a[49397|0]|0;c[e+28>>2]=2;k=e+96|0;l=f+2|0;m=((d[l]|0)<<8|(d[f+3|0]|0))&4095;if((m|0)==1){n=e|0;c[n>>2]=c[n>>2]|64;o=46144;p=2789}else if((m|0)==2048){n=e|0;c[n>>2]=c[n>>2]|64;o=48616;p=2789}else if((m|0)==0){n=e|0;c[n>>2]=c[n>>2]|64;o=46496;p=2789}else if((m|0)==2049){n=e|0;c[n>>2]=c[n>>2]|64;o=45808;p=2789}else{a2(k|0,45528,(x=i,i=i+8|0,c[x>>2]=m,x)|0)|0;m=e|0;c[m>>2]=c[m>>2]|64;q=m}if((p|0)==2789){m=o;o=k;y=d[m]|d[m+1|0]<<8|d[m+2|0]<<16|d[m+3|0]<<24|0;a[o]=y&255;y=y>>8;a[o+1|0]=y&255;y=y>>8;a[o+2|0]=y&255;y=y>>8;a[o+3|0]=y&255;q=e|0}o=d[l]|0;a2(e+160|0,35736,(x=i,i=i+16|0,c[x>>2]=(o&128|0)!=0?32752:31024,c[x+8>>2]=o>>>4&7,x)|0)|0;c[q>>2]=c[q>>2]|64;i=g;return}else if((h<<16>>16|0)==20091){q=e+8|0;c[q>>2]=(c[q>>2]|0)+1;q=e+32|0;a[q]=a[49392]|0;a[q+1|0]=a[49393|0]|0;a[q+2|0]=a[49394|0]|0;a[q+3|0]=a[49395|0]|0;a[q+4|0]=a[49396|0]|0;a[q+5|0]=a[49397|0]|0;c[e+28>>2]=2;q=f+2|0;o=d[q]|0;a2(e+96|0,35736,(x=i,i=i+16|0,c[x>>2]=(o&128|0)!=0?32752:31024,c[x+8>>2]=o>>>4&7,x)|0)|0;o=e+160|0;l=((d[q]|0)<<8|(d[f+3|0]|0))&4095;if((l|0)==2049){q=e|0;m=c[q>>2]|64;c[q>>2]=m;r=45808;s=m;p=2797}else if((l|0)==2048){m=e|0;q=c[m>>2]|64;c[m>>2]=q;r=48616;s=q;p=2797}else if((l|0)==0){q=e|0;m=c[q>>2]|64;c[q>>2]=m;r=46496;s=m;p=2797}else if((l|0)==1){m=e|0;q=c[m>>2]|64;c[m>>2]=q;r=46144;s=q;p=2797}else{a2(o|0,45528,(x=i,i=i+8|0,c[x>>2]=l,x)|0)|0;l=e|0;q=c[l>>2]|64;c[l>>2]=q;t=q;u=l}if((p|0)==2797){p=r;r=o;y=d[p]|d[p+1|0]<<8|d[p+2|0]<<16|d[p+3|0]<<24|0;a[r]=y&255;y=y>>8;a[r+1|0]=y&255;y=y>>8;a[r+2|0]=y&255;y=y>>8;a[r+3|0]=y&255;t=s;u=e|0}c[u>>2]=t|64;i=g;return}else if((h<<16>>16|0)==20080){t=e+32|0;a[t]=a[49672]|0;a[t+1|0]=a[49673|0]|0;a[t+2|0]=a[49674|0]|0;a[t+3|0]=a[49675|0]|0;a[t+4|0]=a[49676|0]|0;a[t+5|0]=a[49677|0]|0;c[e+28>>2]=0;t=e|0;c[t>>2]=c[t>>2]|1;i=g;return}else if((h<<16>>16|0)==20085){t=e+32|0;y=5461074;a[t]=y&255;y=y>>8;a[t+1|0]=y&255;y=y>>8;a[t+2|0]=y&255;y=y>>8;a[t+3|0]=y&255;c[e+28>>2]=0;t=e|0;c[t>>2]=c[t>>2]|16;i=g;return}else if((h<<16>>16|0)==20083){t=e+32|0;y=4543570;a[t]=y&255;y=y>>8;a[t+1|0]=y&255;y=y>>8;a[t+2|0]=y&255;y=y>>8;a[t+3|0]=y&255;c[e+28>>2]=0;t=e|0;c[t>>2]=c[t>>2]|9;i=g;return}else if((h<<16>>16|0)==20087){t=e+32|0;y=5395538;a[t]=y&255;y=y>>8;a[t+1|0]=y&255;y=y>>8;a[t+2|0]=y&255;y=y>>8;a[t+3|0]=y&255;c[e+28>>2]=0;i=g;return}else if((h<<16>>16|0)==20086){t=e+32|0;a[t]=a[49496]|0;a[t+1|0]=a[49497|0]|0;a[t+2|0]=a[49498|0]|0;a[t+3|0]=a[49499|0]|0;a[t+4|0]=a[49500|0]|0;a[t+5|0]=a[49501|0]|0;c[e+28>>2]=0;t=e|0;c[t>>2]=c[t>>2]|32;i=g;return}else if((h<<16>>16|0)==20084){h=e+32|0;y=4478034;a[h]=y&255;y=y>>8;a[h+1|0]=y&255;y=y>>8;a[h+2|0]=y&255;y=y>>8;a[h+3|0]=y&255;c[e+28>>2]=1;h=((d[f+2|0]|0)<<8|(d[f+3|0]|0))&65535;a2(e+96|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=h,x)|0)|0;h=e+8|0;c[h>>2]=(c[h>>2]|0)+1;h=e|0;c[h>>2]=c[h>>2]|80;i=g;return}else{if((j&48|0)==0){h=e+32|0;a[h]=a[49224]|0;a[h+1|0]=a[49225|0]|0;a[h+2|0]=a[49226|0]|0;a[h+3|0]=a[49227|0]|0;a[h+4|0]=a[49228|0]|0;c[e+28>>2]=1;h=e+96|0;t=j&15;a2(h|0,52224,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=t,x)|0)|0;i=g;return}t=j&56;if((t|0)==16){h=e+32|0;a[h]=a[49200]|0;a[h+1|0]=a[49201|0]|0;a[h+2|0]=a[49202|0]|0;a[h+3|0]=a[49203|0]|0;a[h+4|0]=a[49204|0]|0;c[e+28>>2]=2;h=e+96|0;u=j&7;a2(h|0,38624,(x=i,i=i+8|0,c[x>>2]=u,x)|0)|0;u=e+160|0;h=((d[f+2|0]|0)<<8|(d[f+3|0]|0))&65535;a2(u|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=h,x)|0)|0;h=e+8|0;c[h>>2]=(c[h>>2]|0)+1;i=g;return}else if((t|0)==24){h=e+32|0;a[h]=a[49136]|0;a[h+1|0]=a[49137|0]|0;a[h+2|0]=a[49138|0]|0;a[h+3|0]=a[49139|0]|0;a[h+4|0]=a[49140|0]|0;c[e+28>>2]=1;a2(e+96|0,38624,(x=i,i=i+8|0,c[x>>2]=j&7,x)|0)|0;i=g;return}else if((t|0)==32){h=e+32|0;a[h]=a[49096]|0;a[h+1|0]=a[49097|0]|0;a[h+2|0]=a[49098|0]|0;a[h+3|0]=a[49099|0]|0;a[h+4|0]=a[49100|0]|0;c[e+28>>2]=2;a2(e+96|0,38624,(x=i,i=i+8|0,c[x>>2]=j&7,x)|0)|0;h=e+160|0;y=5264213;a[h]=y&255;y=y>>8;a[h+1|0]=y&255;y=y>>8;a[h+2|0]=y&255;y=y>>8;a[h+3|0]=y&255;h=e|0;c[h>>2]=c[h>>2]|1;i=g;return}else if((t|0)==40){t=e+32|0;a[t]=a[49096]|0;a[t+1|0]=a[49097|0]|0;a[t+2|0]=a[49098|0]|0;a[t+3|0]=a[49099|0]|0;a[t+4|0]=a[49100|0]|0;c[e+28>>2]=2;t=e+96|0;y=5264213;a[t]=y&255;y=y>>8;a[t+1|0]=y&255;y=y>>8;a[t+2|0]=y&255;y=y>>8;a[t+3|0]=y&255;a2(e+160|0,38624,(x=i,i=i+8|0,c[x>>2]=j&7,x)|0)|0;j=e|0;c[j>>2]=c[j>>2]|1;i=g;return}else{j=e+32|0;a[j]=a[34016]|0;a[j+1|0]=a[34017|0]|0;a[j+2|0]=a[34018|0]|0;c[e+28>>2]=1;j=((d[f]|0)<<8|(d[f+1|0]|0))&65535;a2(e+96|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=j,x)|0)|0;i=g;return}}}function gX(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;y=5395274;a[e]=y&255;y=y>>8;a[e+1|0]=y&255;y=y>>8;a[e+2|0]=y&255;y=y>>8;a[e+3|0]=y&255;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,0);d=b|0;c[d>>2]=c[d>>2]|4;return}function gY(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f]=a[49856]|0;a[f+1|0]=a[49857|0]|0;a[f+2|0]=a[49858|0]|0;a[f+3|0]=a[49859|0]|0;a[f+4|0]=a[49860|0]|0;a[f+5|0]=a[49861|0]|0;a[f+6|0]=a[49862|0]|0;c[b+28>>2]=2;f=(a[d]&255)>>>1&7;a2(b+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=f<<16>>16==0?8:f&65535,x)|0)|0;ik(b,b+160|0,d,a[d+1|0]&63,8);i=e;return}function gZ(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f]=a[49984]|0;a[f+1|0]=a[49985|0]|0;a[f+2|0]=a[49986|0]|0;a[f+3|0]=a[49987|0]|0;a[f+4|0]=a[49988|0]|0;a[f+5|0]=a[49989|0]|0;a[f+6|0]=a[49990|0]|0;c[b+28>>2]=2;f=(a[d]&255)>>>1&7;a2(b+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=f<<16>>16==0?8:f&65535,x)|0)|0;ik(b,b+160|0,d,a[d+1|0]&63,16);i=e;return}function g_(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f]=a[50016]|0;a[f+1|0]=a[50017|0]|0;a[f+2|0]=a[50018|0]|0;a[f+3|0]=a[50019|0]|0;a[f+4|0]=a[50020|0]|0;a[f+5|0]=a[50021|0]|0;a[f+6|0]=a[50022|0]|0;c[b+28>>2]=2;f=(a[d]&255)>>>1&7;a2(b+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=f<<16>>16==0?8:f&65535,x)|0)|0;ik(b,b+160|0,d,a[d+1|0]&63,32);i=e;return}function g$(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;h=e+12|0;j=b[h>>1]|0;k=(j&65535)>>>8&15;if(k>>>0>1){l=e|0;c[l>>2]=c[l>>2]|32}if((j&56)==8){j=c[6992+(k<<2)>>2]|0;l=e+32|0;vb(l|0,j|0)|0;c[e+28>>2]=2;j=e+96|0;l=b[h>>1]&7;a2(j|0,42056,(x=i,i=i+8|0,c[x>>2]=l,x)|0)|0;l=e+160|0;j=e+8|0;h=c[j>>2]|0;m=h<<1;n=(d[f+m|0]|0)<<8|(d[f+(m|1)|0]|0);c[j>>2]=h+1;h=n&65535;n=(c[e+4>>2]|0)+2+((h&32768|0)!=0?h|-65536:h)|0;a2(l|0,50072,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=n,x)|0)|0;n=e|0;c[n>>2]=c[n>>2]|2;i=g;return}else{n=c[6928+(k<<2)>>2]|0;k=e+32|0;vb(k|0,n|0)|0;c[e+28>>2]=1;ik(e,e+96|0,f,a[f+1|0]&63,8);i=g;return}}function g0(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f]=a[52232]|0;a[f+1|0]=a[52233|0]|0;a[f+2|0]=a[52234|0]|0;a[f+3|0]=a[52235|0]|0;a[f+4|0]=a[52236|0]|0;a[f+5|0]=a[52237|0]|0;a[f+6|0]=a[52238|0]|0;c[b+28>>2]=2;f=(a[d]&255)>>>1&7;a2(b+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=f<<16>>16==0?8:f&65535,x)|0)|0;ik(b,b+160|0,d,a[d+1|0]&63,8);i=e;return}function g1(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f]=a[52304]|0;a[f+1|0]=a[52305|0]|0;a[f+2|0]=a[52306|0]|0;a[f+3|0]=a[52307|0]|0;a[f+4|0]=a[52308|0]|0;a[f+5|0]=a[52309|0]|0;a[f+6|0]=a[52310|0]|0;c[b+28>>2]=2;f=(a[d]&255)>>>1&7;a2(b+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=f<<16>>16==0?8:f&65535,x)|0)|0;ik(b,b+160|0,d,a[d+1|0]&63,16);i=e;return}function g2(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f]=a[52352]|0;a[f+1|0]=a[52353|0]|0;a[f+2|0]=a[52354|0]|0;a[f+3|0]=a[52355|0]|0;a[f+4|0]=a[52356|0]|0;a[f+5|0]=a[52357|0]|0;a[f+6|0]=a[52358|0]|0;c[b+28>>2]=2;f=(a[d]&255)>>>1&7;a2(b+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=f<<16>>16==0?8:f&65535,x)|0)|0;ik(b,b+160|0,d,a[d+1|0]&63,32);i=e;return}function g3(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;g=i;h=(e[b+12>>1]|0)>>>8&15;j=f+1|0;k=a[j]|0;if(k<<24>>24==0){l=c[7056+(h<<2)>>2]|0;m=b+32|0;vb(m|0,l|0)|0;c[b+28>>2]=1;l=b+96|0;n=b+8|0;o=c[n>>2]|0;p=o<<1;q=(d[f+p|0]|0)<<8|(d[f+(p|1)|0]|0);c[n>>2]=o+1;o=q&65535;q=(c[b+4>>2]|0)+2+((o&32768|0)!=0?o|-65536:o)|0;a2(l|0,50072,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=q,x)|0)|0;q=(u8(m|0)|0)+(b+32)|0;a[q]=a[43080]|0;a[q+1|0]=a[43081|0]|0;a[q+2|0]=a[43082|0]|0;r=(h|0)==1;s=b|0;t=c[s>>2]|0;u=r?4:2;v=t|u;w=h>>>0>1;y=v|32;z=w?y:v;c[s>>2]=z;i=g;return}q=b+32|0;vb(q|0,c[7056+(h<<2)>>2]|0)|0;c[b+28>>2]=1;m=b+96|0;if(k<<24>>24==-1){k=b+8|0;l=c[k>>2]|0;o=l<<1;n=(((d[f+o|0]|0)<<8|(d[f+(o|1)|0]|0))<<8|(d[f+(o+2)|0]|0))<<8|(d[f+(o+3)|0]|0);c[k>>2]=l+2;l=(c[b+4>>2]|0)+2+n|0;a2(m|0,50072,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=l,x)|0)|0;l=(u8(q|0)|0)+(b+32)|0;a[l]=a[43408]|0;a[l+1|0]=a[43409|0]|0;a[l+2|0]=a[43410|0]|0;l=b|0;c[l>>2]=c[l>>2]|128;r=(h|0)==1;s=b|0;t=c[s>>2]|0;u=r?4:2;v=t|u;w=h>>>0>1;y=v|32;z=w?y:v;c[s>>2]=z;i=g;return}else{l=d[j]|0;j=(c[b+4>>2]|0)+2+((l&128|0)!=0?l|-256:l)|0;a2(m|0,50072,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=j,x)|0)|0;j=(u8(q|0)|0)+(b+32)|0;a[j]=a[53632]|0;a[j+1|0]=a[53633|0]|0;a[j+2|0]=a[53634|0]|0;r=(h|0)==1;s=b|0;t=c[s>>2]|0;u=r?4:2;v=t|u;w=h>>>0>1;y=v|32;z=w?y:v;c[s>>2]=z;i=g;return}}function g4(b,f){b=b|0;f=f|0;var g=0,h=0;g=i;h=b+32|0;a[h]=a[53688]|0;a[h+1|0]=a[53689|0]|0;a[h+2|0]=a[53690|0]|0;a[h+3|0]=a[53691|0]|0;a[h+4|0]=a[53692|0]|0;a[h+5|0]=a[53693|0]|0;c[b+28>>2]=2;h=e[b+12>>1]|0;a2(b+96|0,51552,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=(h&128|0)!=0?h|-256:h&255,x)|0)|0;a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[f]|0)>>>1&7,x)|0)|0;i=g;return}function g5(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[54032]|0;a[g+1|0]=a[54033|0]|0;a[g+2|0]=a[54034|0]|0;a[g+3|0]=a[54035|0]|0;a[g+4|0]=a[54036|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,8);a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function g6(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[54296]|0;a[g+1|0]=a[54297|0]|0;a[g+2|0]=a[54298|0]|0;a[g+3|0]=a[54299|0]|0;a[g+4|0]=a[54300|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,16);a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function g7(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[54528]|0;a[g+1|0]=a[54529|0]|0;a[g+2|0]=a[54530|0]|0;a[g+3|0]=a[54531|0]|0;a[g+4|0]=a[54532|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,32);a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function g8(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[53840]|0;a[g+1|0]=a[53841|0]|0;a[g+2|0]=a[53842|0]|0;a[g+3|0]=a[53843|0]|0;a[g+4|0]=a[53844|0]|0;a[g+5|0]=a[53845|0]|0;a[g+6|0]=a[53846|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,16);a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function g9(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;h=b+12|0;j=e[h>>1]|0;k=j>>>3&7;if((k|0)==1){l=b+32|0;a[l]=a[54144]|0;a[l+1|0]=a[54145|0]|0;a[l+2|0]=a[54146|0]|0;a[l+3|0]=a[54147|0]|0;a[l+4|0]=a[54148|0]|0;a[l+5|0]=a[54149|0]|0;a[l+6|0]=a[54150|0]|0;c[b+28>>2]=2;l=b+96|0;m=j&7;a2(l|0,29072,(x=i,i=i+8|0,c[x>>2]=m,x)|0)|0;m=b+160|0;l=(e[h>>1]|0)>>>9&7;a2(m|0,29072,(x=i,i=i+8|0,c[x>>2]=l,x)|0)|0;l=b|0;c[l>>2]=c[l>>2]|32;i=g;return}else if((k|0)==0){k=b+32|0;a[k]=a[54144]|0;a[k+1|0]=a[54145|0]|0;a[k+2|0]=a[54146|0]|0;a[k+3|0]=a[54147|0]|0;a[k+4|0]=a[54148|0]|0;a[k+5|0]=a[54149|0]|0;a[k+6|0]=a[54150|0]|0;c[b+28>>2]=2;a2(b+96|0,42056,(x=i,i=i+8|0,c[x>>2]=j&7,x)|0)|0;a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[f]|0)>>>1&7,x)|0)|0;j=b|0;c[j>>2]=c[j>>2]|32;i=g;return}else{j=b+32|0;a[j]=a[54032]|0;a[j+1|0]=a[54033|0]|0;a[j+2|0]=a[54034|0]|0;a[j+3|0]=a[54035|0]|0;a[j+4|0]=a[54036|0]|0;c[b+28>>2]=2;a2(b+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[f]|0)>>>1&7,x)|0)|0;ik(b,b+160|0,f,a[f+1|0]&63,8);i=g;return}}function ha(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=e+32|0;if((b[e+12>>1]&48)>>>0<16){a[h]=a[34016]|0;a[h+1|0]=a[34017|0]|0;a[h+2|0]=a[34018|0]|0;c[e+28>>2]=1;j=e+96|0;k=((d[f]|0)<<8|(d[f+1|0]|0))&65535;a2(j|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=k,x)|0)|0;i=g;return}else{a[h]=a[54296]|0;a[h+1|0]=a[54297|0]|0;a[h+2|0]=a[54298|0]|0;a[h+3|0]=a[54299|0]|0;a[h+4|0]=a[54300|0]|0;c[e+28>>2]=2;h=e+96|0;k=(d[f]|0)>>>1&7;a2(h|0,42056,(x=i,i=i+8|0,c[x>>2]=k,x)|0)|0;ik(e,e+160|0,f,a[f+1|0]&63,16);i=g;return}}function hb(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=e+32|0;if((b[e+12>>1]&48)>>>0<16){a[h]=a[34016]|0;a[h+1|0]=a[34017|0]|0;a[h+2|0]=a[34018|0]|0;c[e+28>>2]=1;j=e+96|0;k=((d[f]|0)<<8|(d[f+1|0]|0))&65535;a2(j|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=k,x)|0)|0;i=g;return}else{a[h]=a[54528]|0;a[h+1|0]=a[54529|0]|0;a[h+2|0]=a[54530|0]|0;a[h+3|0]=a[54531|0]|0;a[h+4|0]=a[54532|0]|0;c[e+28>>2]=2;h=e+96|0;k=(d[f]|0)>>>1&7;a2(h|0,42056,(x=i,i=i+8|0,c[x>>2]=k,x)|0)|0;ik(e,e+160|0,f,a[f+1|0]&63,32);i=g;return}}function hc(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[54680]|0;a[g+1|0]=a[54681|0]|0;a[g+2|0]=a[54682|0]|0;a[g+3|0]=a[54683|0]|0;a[g+4|0]=a[54684|0]|0;a[g+5|0]=a[54685|0]|0;a[g+6|0]=a[54686|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,16);a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function hd(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[54792]|0;a[g+1|0]=a[54793|0]|0;a[g+2|0]=a[54794|0]|0;a[g+3|0]=a[54795|0]|0;a[g+4|0]=a[54796|0]|0;a[g+5|0]=a[54797|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,8);a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function he(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[54896]|0;a[g+1|0]=a[54897|0]|0;a[g+2|0]=a[54898|0]|0;a[g+3|0]=a[54899|0]|0;a[g+4|0]=a[54900|0]|0;a[g+5|0]=a[54901|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,16);a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function hf(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[54992]|0;a[g+1|0]=a[54993|0]|0;a[g+2|0]=a[54994|0]|0;a[g+3|0]=a[54995|0]|0;a[g+4|0]=a[54996|0]|0;a[g+5|0]=a[54997|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,32);a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function hg(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[54736]|0;a[g+1|0]=a[54737|0]|0;a[g+2|0]=a[54738|0]|0;a[g+3|0]=a[54739|0]|0;a[g+4|0]=a[54740|0]|0;a[g+5|0]=a[54741|0]|0;a[g+6|0]=a[54742|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,16);a2(b+160|0,38624,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function hh(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;h=b+12|0;j=e[h>>1]|0;k=j>>>3&7;if((k|0)==1){l=b+32|0;a[l]=a[54832]|0;a[l+1|0]=a[54833|0]|0;a[l+2|0]=a[54834|0]|0;a[l+3|0]=a[54835|0]|0;a[l+4|0]=a[54836|0]|0;a[l+5|0]=a[54837|0]|0;a[l+6|0]=a[54838|0]|0;c[b+28>>2]=2;l=b+96|0;m=j&7;a2(l|0,29072,(x=i,i=i+8|0,c[x>>2]=m,x)|0)|0;m=b+160|0;l=(e[h>>1]|0)>>>9&7;a2(m|0,29072,(x=i,i=i+8|0,c[x>>2]=l,x)|0)|0;l=b|0;c[l>>2]=c[l>>2]|32;i=g;return}else if((k|0)==0){k=b+32|0;a[k]=a[54832]|0;a[k+1|0]=a[54833|0]|0;a[k+2|0]=a[54834|0]|0;a[k+3|0]=a[54835|0]|0;a[k+4|0]=a[54836|0]|0;a[k+5|0]=a[54837|0]|0;a[k+6|0]=a[54838|0]|0;c[b+28>>2]=2;a2(b+96|0,42056,(x=i,i=i+8|0,c[x>>2]=j&7,x)|0)|0;a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[f]|0)>>>1&7,x)|0)|0;j=b|0;c[j>>2]=c[j>>2]|32;i=g;return}else{j=b+32|0;a[j]=a[54792]|0;a[j+1|0]=a[54793|0]|0;a[j+2|0]=a[54794|0]|0;a[j+3|0]=a[54795|0]|0;a[j+4|0]=a[54796|0]|0;a[j+5|0]=a[54797|0]|0;c[b+28>>2]=2;a2(b+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[f]|0)>>>1&7,x)|0)|0;ik(b,b+160|0,f,a[f+1|0]&63,8);i=g;return}}function hi(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;h=b+12|0;j=e[h>>1]|0;k=j>>>3&7;if((k|0)==0){l=b+32|0;a[l]=a[54944]|0;a[l+1|0]=a[54945|0]|0;a[l+2|0]=a[54946|0]|0;a[l+3|0]=a[54947|0]|0;a[l+4|0]=a[54948|0]|0;a[l+5|0]=a[54949|0]|0;a[l+6|0]=a[54950|0]|0;c[b+28>>2]=2;l=b+96|0;m=j&7;a2(l|0,42056,(x=i,i=i+8|0,c[x>>2]=m,x)|0)|0;m=b+160|0;l=(d[f]|0)>>>1&7;a2(m|0,42056,(x=i,i=i+8|0,c[x>>2]=l,x)|0)|0;l=b|0;c[l>>2]=c[l>>2]|32;i=g;return}else if((k|0)==1){k=b+32|0;a[k]=a[54944]|0;a[k+1|0]=a[54945|0]|0;a[k+2|0]=a[54946|0]|0;a[k+3|0]=a[54947|0]|0;a[k+4|0]=a[54948|0]|0;a[k+5|0]=a[54949|0]|0;a[k+6|0]=a[54950|0]|0;c[b+28>>2]=2;a2(b+96|0,29072,(x=i,i=i+8|0,c[x>>2]=j&7,x)|0)|0;a2(b+160|0,29072,(x=i,i=i+8|0,c[x>>2]=(e[h>>1]|0)>>>9&7,x)|0)|0;h=b|0;c[h>>2]=c[h>>2]|32;i=g;return}else{h=b+32|0;a[h]=a[54896]|0;a[h+1|0]=a[54897|0]|0;a[h+2|0]=a[54898|0]|0;a[h+3|0]=a[54899|0]|0;a[h+4|0]=a[54900|0]|0;a[h+5|0]=a[54901|0]|0;c[b+28>>2]=2;a2(b+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[f]|0)>>>1&7,x)|0)|0;ik(b,b+160|0,f,a[f+1|0]&63,16);i=g;return}}function hj(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;h=b+12|0;j=e[h>>1]|0;k=j>>>3&7;if((k|0)==0){l=b+32|0;a[l]=a[55088]|0;a[l+1|0]=a[55089|0]|0;a[l+2|0]=a[55090|0]|0;a[l+3|0]=a[55091|0]|0;a[l+4|0]=a[55092|0]|0;a[l+5|0]=a[55093|0]|0;a[l+6|0]=a[55094|0]|0;c[b+28>>2]=2;l=b+96|0;m=j&7;a2(l|0,42056,(x=i,i=i+8|0,c[x>>2]=m,x)|0)|0;m=b+160|0;l=(d[f]|0)>>>1&7;a2(m|0,42056,(x=i,i=i+8|0,c[x>>2]=l,x)|0)|0;l=b|0;c[l>>2]=c[l>>2]|32;i=g;return}else if((k|0)==1){k=b+32|0;a[k]=a[55088]|0;a[k+1|0]=a[55089|0]|0;a[k+2|0]=a[55090|0]|0;a[k+3|0]=a[55091|0]|0;a[k+4|0]=a[55092|0]|0;a[k+5|0]=a[55093|0]|0;a[k+6|0]=a[55094|0]|0;c[b+28>>2]=2;a2(b+96|0,29072,(x=i,i=i+8|0,c[x>>2]=j&7,x)|0)|0;a2(b+160|0,29072,(x=i,i=i+8|0,c[x>>2]=(e[h>>1]|0)>>>9&7,x)|0)|0;h=b|0;c[h>>2]=c[h>>2]|32;i=g;return}else{h=b+32|0;a[h]=a[54992]|0;a[h+1|0]=a[54993|0]|0;a[h+2|0]=a[54994|0]|0;a[h+3|0]=a[54995|0]|0;a[h+4|0]=a[54996|0]|0;a[h+5|0]=a[54997|0]|0;c[b+28>>2]=2;a2(b+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[f]|0)>>>1&7,x)|0)|0;ik(b,b+160|0,f,a[f+1|0]&63,32);i=g;return}}function hk(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[55160]|0;a[g+1|0]=a[55161|0]|0;a[g+2|0]=a[55162|0]|0;a[g+3|0]=a[55163|0]|0;a[g+4|0]=a[55164|0]|0;a[g+5|0]=a[55165|0]|0;a[g+6|0]=a[55166|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,32);a2(b+160|0,38624,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function hl(a,b){a=a|0;b=b|0;var d=0;b=i;i=i+16|0;d=b|0;a2(d|0,32392,(x=i,i=i+8|0,c[x>>2]=e[a+12>>1]|0,x)|0)|0;vb(a+32|0,d|0)|0;c[a+28>>2]=0;d=a|0;c[d>>2]=c[d>>2]|4;i=b;return}function hm(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[55344]|0;a[g+1|0]=a[55345|0]|0;a[g+2|0]=a[55346|0]|0;a[g+3|0]=a[55347|0]|0;a[g+4|0]=a[55348|0]|0;a[g+5|0]=a[55349|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,8);a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function hn(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[55480]|0;a[g+1|0]=a[55481|0]|0;a[g+2|0]=a[55482|0]|0;a[g+3|0]=a[55483|0]|0;a[g+4|0]=a[55484|0]|0;a[g+5|0]=a[55485|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,16);a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function ho(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[28856]|0;a[g+1|0]=a[28857|0]|0;a[g+2|0]=a[28858|0]|0;a[g+3|0]=a[28859|0]|0;a[g+4|0]=a[28860|0]|0;a[g+5|0]=a[28861|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,32);a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function hp(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[28936]|0;a[g+1|0]=a[28937|0]|0;a[g+2|0]=a[28938|0]|0;a[g+3|0]=a[28939|0]|0;a[g+4|0]=a[28940|0]|0;a[g+5|0]=a[28941|0]|0;a[g+6|0]=a[28942|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,16);a2(b+160|0,38624,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function hq(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;j=f+12|0;k=b[j>>1]|0;l=f+32|0;if((k&56)==8){a[l]=a[29080]|0;a[l+1|0]=a[29081|0]|0;a[l+2|0]=a[29082|0]|0;a[l+3|0]=a[29083|0]|0;a[l+4|0]=a[29084|0]|0;a[l+5|0]=a[29085|0]|0;a[l+6|0]=a[29086|0]|0;c[f+28>>2]=2;m=f+96|0;n=k&7;a2(m|0,29968,(x=i,i=i+8|0,c[x>>2]=n,x)|0)|0;n=f+160|0;m=(e[j>>1]|0)>>>9&7;a2(n|0,29968,(x=i,i=i+8|0,c[x>>2]=m,x)|0)|0;i=h;return}else{a[l]=a[29008]|0;a[l+1|0]=a[29009|0]|0;a[l+2|0]=a[29010|0]|0;a[l+3|0]=a[29011|0]|0;a[l+4|0]=a[29012|0]|0;a[l+5|0]=a[29013|0]|0;c[f+28>>2]=2;l=f+96|0;m=(d[g]|0)>>>1&7;a2(l|0,42056,(x=i,i=i+8|0,c[x>>2]=m,x)|0)|0;ik(f,f+160|0,g,a[g+1|0]&63,8);i=h;return}}function hr(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;j=f+12|0;k=b[j>>1]|0;l=f+32|0;if((k&56)==8){a[l]=a[29168]|0;a[l+1|0]=a[29169|0]|0;a[l+2|0]=a[29170|0]|0;a[l+3|0]=a[29171|0]|0;a[l+4|0]=a[29172|0]|0;a[l+5|0]=a[29173|0]|0;a[l+6|0]=a[29174|0]|0;c[f+28>>2]=2;m=f+96|0;n=k&7;a2(m|0,29968,(x=i,i=i+8|0,c[x>>2]=n,x)|0)|0;n=f+160|0;m=(e[j>>1]|0)>>>9&7;a2(n|0,29968,(x=i,i=i+8|0,c[x>>2]=m,x)|0)|0;i=h;return}else{a[l]=a[29128]|0;a[l+1|0]=a[29129|0]|0;a[l+2|0]=a[29130|0]|0;a[l+3|0]=a[29131|0]|0;a[l+4|0]=a[29132|0]|0;a[l+5|0]=a[29133|0]|0;c[f+28>>2]=2;l=f+96|0;m=(d[g]|0)>>>1&7;a2(l|0,42056,(x=i,i=i+8|0,c[x>>2]=m,x)|0)|0;ik(f,f+160|0,g,a[g+1|0]&63,16);i=h;return}}function hs(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;j=f+12|0;k=b[j>>1]|0;l=f+32|0;if((k&56)==8){a[l]=a[29344]|0;a[l+1|0]=a[29345|0]|0;a[l+2|0]=a[29346|0]|0;a[l+3|0]=a[29347|0]|0;a[l+4|0]=a[29348|0]|0;a[l+5|0]=a[29349|0]|0;a[l+6|0]=a[29350|0]|0;c[f+28>>2]=2;m=f+96|0;n=k&7;a2(m|0,29968,(x=i,i=i+8|0,c[x>>2]=n,x)|0)|0;n=f+160|0;m=(e[j>>1]|0)>>>9&7;a2(n|0,29968,(x=i,i=i+8|0,c[x>>2]=m,x)|0)|0;i=h;return}else{a[l]=a[29256]|0;a[l+1|0]=a[29257|0]|0;a[l+2|0]=a[29258|0]|0;a[l+3|0]=a[29259|0]|0;a[l+4|0]=a[29260|0]|0;a[l+5|0]=a[29261|0]|0;c[f+28>>2]=2;l=f+96|0;m=(d[g]|0)>>>1&7;a2(l|0,42056,(x=i,i=i+8|0,c[x>>2]=m,x)|0)|0;ik(f,f+160|0,g,a[g+1|0]&63,32);i=h;return}}function ht(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[29544]|0;a[g+1|0]=a[29545|0]|0;a[g+2|0]=a[29546|0]|0;a[g+3|0]=a[29547|0]|0;a[g+4|0]=a[29548|0]|0;a[g+5|0]=a[29549|0]|0;a[g+6|0]=a[29550|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,32);a2(b+160|0,38624,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function hu(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[29824]|0;a[g+1|0]=a[29825|0]|0;a[g+2|0]=a[29826|0]|0;a[g+3|0]=a[29827|0]|0;a[g+4|0]=a[29828|0]|0;a[g+5|0]=a[29829|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,8);a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function hv(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[29920]|0;a[g+1|0]=a[29921|0]|0;a[g+2|0]=a[29922|0]|0;a[g+3|0]=a[29923|0]|0;a[g+4|0]=a[29924|0]|0;a[g+5|0]=a[29925|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,16);a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function hw(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[29976]|0;a[g+1|0]=a[29977|0]|0;a[g+2|0]=a[29978|0]|0;a[g+3|0]=a[29979|0]|0;a[g+4|0]=a[29980|0]|0;a[g+5|0]=a[29981|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,32);a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function hx(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[29736]|0;a[g+1|0]=a[29737|0]|0;a[g+2|0]=a[29738|0]|0;a[g+3|0]=a[29739|0]|0;a[g+4|0]=a[29740|0]|0;a[g+5|0]=a[29741|0]|0;a[g+6|0]=a[29742|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,16);a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function hy(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;h=b+12|0;j=e[h>>1]|0;k=j>>>3&7;if((k|0)==1){l=b+32|0;a[l]=a[29880]|0;a[l+1|0]=a[29881|0]|0;a[l+2|0]=a[29882|0]|0;a[l+3|0]=a[29883|0]|0;a[l+4|0]=a[29884|0]|0;a[l+5|0]=a[29885|0]|0;a[l+6|0]=a[29886|0]|0;c[b+28>>2]=2;l=b+96|0;m=j&7;a2(l|0,29072,(x=i,i=i+8|0,c[x>>2]=m,x)|0)|0;m=b+160|0;l=(e[h>>1]|0)>>>9&7;a2(m|0,29072,(x=i,i=i+8|0,c[x>>2]=l,x)|0)|0;l=b|0;c[l>>2]=c[l>>2]|32;i=g;return}else if((k|0)==0){k=b+32|0;a[k]=a[29880]|0;a[k+1|0]=a[29881|0]|0;a[k+2|0]=a[29882|0]|0;a[k+3|0]=a[29883|0]|0;a[k+4|0]=a[29884|0]|0;a[k+5|0]=a[29885|0]|0;a[k+6|0]=a[29886|0]|0;c[b+28>>2]=2;a2(b+96|0,42056,(x=i,i=i+8|0,c[x>>2]=j&7,x)|0)|0;a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[f]|0)>>>1&7,x)|0)|0;j=b|0;c[j>>2]=c[j>>2]|32;i=g;return}else{j=b+32|0;a[j]=a[29824]|0;a[j+1|0]=a[29825|0]|0;a[j+2|0]=a[29826|0]|0;a[j+3|0]=a[29827|0]|0;a[j+4|0]=a[29828|0]|0;a[j+5|0]=a[29829|0]|0;c[b+28>>2]=2;a2(b+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[f]|0)>>>1&7,x)|0)|0;ik(b,b+160|0,f,a[f+1|0]&63,8);i=g;return}}function hz(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0;h=i;j=f+12|0;k=(e[j>>1]|0)>>>3&7;if((k|0)==1){l=f+32|0;y=4675653;a[l]=y&255;y=y>>8;a[l+1|0]=y&255;y=y>>8;a[l+2|0]=y&255;y=y>>8;a[l+3|0]=y&255;c[f+28>>2]=2;l=f+96|0;m=(d[g]|0)>>>1&7;a2(l|0,38624,(x=i,i=i+8|0,c[x>>2]=m,x)|0)|0;m=f+160|0;l=b[j>>1]&7;a2(m|0,38624,(x=i,i=i+8|0,c[x>>2]=l,x)|0)|0;i=h;return}else if((k|0)==0){k=f+32|0;y=4675653;a[k]=y&255;y=y>>8;a[k+1|0]=y&255;y=y>>8;a[k+2|0]=y&255;y=y>>8;a[k+3|0]=y&255;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else{j=f+32|0;a[j]=a[29920]|0;a[j+1|0]=a[29921|0]|0;a[j+2|0]=a[29922|0]|0;a[j+3|0]=a[29923|0]|0;a[j+4|0]=a[29924|0]|0;a[j+5|0]=a[29925|0]|0;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;ik(f,f+160|0,g,a[g+1|0]&63,16);i=h;return}}function hA(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0;h=i;j=f+12|0;k=(e[j>>1]|0)>>>3&7;if((k|0)==0){l=f+32|0;a[l]=a[34016]|0;a[l+1|0]=a[34017|0]|0;a[l+2|0]=a[34018|0]|0;c[f+28>>2]=1;l=f+96|0;m=((d[g]|0)<<8|(d[g+1|0]|0))&65535;a2(l|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=m,x)|0)|0;i=h;return}else if((k|0)==1){k=f+32|0;y=4675653;a[k]=y&255;y=y>>8;a[k+1|0]=y&255;y=y>>8;a[k+2|0]=y&255;y=y>>8;a[k+3|0]=y&255;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;a2(f+160|0,38624,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else{j=f+32|0;a[j]=a[29976]|0;a[j+1|0]=a[29977|0]|0;a[j+2|0]=a[29978|0]|0;a[j+3|0]=a[29979|0]|0;a[j+4|0]=a[29980|0]|0;a[j+5|0]=a[29981|0]|0;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;ik(f,f+160|0,g,a[g+1|0]&63,32);i=h;return}}function hB(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[30112]|0;a[g+1|0]=a[30113|0]|0;a[g+2|0]=a[30114|0]|0;a[g+3|0]=a[30115|0]|0;a[g+4|0]=a[30116|0]|0;a[g+5|0]=a[30117|0]|0;a[g+6|0]=a[30118|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,16);a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function hC(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[30320]|0;a[g+1|0]=a[30321|0]|0;a[g+2|0]=a[30322|0]|0;a[g+3|0]=a[30323|0]|0;a[g+4|0]=a[30324|0]|0;a[g+5|0]=a[30325|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,8);a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function hD(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[30648]|0;a[g+1|0]=a[30649|0]|0;a[g+2|0]=a[30650|0]|0;a[g+3|0]=a[30651|0]|0;a[g+4|0]=a[30652|0]|0;a[g+5|0]=a[30653|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,16);a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function hE(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[30800]|0;a[g+1|0]=a[30801|0]|0;a[g+2|0]=a[30802|0]|0;a[g+3|0]=a[30803|0]|0;a[g+4|0]=a[30804|0]|0;a[g+5|0]=a[30805|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,32);a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function hF(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[30232]|0;a[g+1|0]=a[30233|0]|0;a[g+2|0]=a[30234|0]|0;a[g+3|0]=a[30235|0]|0;a[g+4|0]=a[30236|0]|0;a[g+5|0]=a[30237|0]|0;a[g+6|0]=a[30238|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,16);a2(b+160|0,38624,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function hG(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;h=b+12|0;j=e[h>>1]|0;k=j>>>3&7;if((k|0)==0){l=b+32|0;a[l]=a[30472]|0;a[l+1|0]=a[30473|0]|0;a[l+2|0]=a[30474|0]|0;a[l+3|0]=a[30475|0]|0;a[l+4|0]=a[30476|0]|0;a[l+5|0]=a[30477|0]|0;a[l+6|0]=a[30478|0]|0;c[b+28>>2]=2;l=b+96|0;m=j&7;a2(l|0,42056,(x=i,i=i+8|0,c[x>>2]=m,x)|0)|0;m=b+160|0;l=(d[f]|0)>>>1&7;a2(m|0,42056,(x=i,i=i+8|0,c[x>>2]=l,x)|0)|0;l=b|0;c[l>>2]=c[l>>2]|32;i=g;return}else if((k|0)==1){k=b+32|0;a[k]=a[30472]|0;a[k+1|0]=a[30473|0]|0;a[k+2|0]=a[30474|0]|0;a[k+3|0]=a[30475|0]|0;a[k+4|0]=a[30476|0]|0;a[k+5|0]=a[30477|0]|0;a[k+6|0]=a[30478|0]|0;c[b+28>>2]=2;a2(b+96|0,29072,(x=i,i=i+8|0,c[x>>2]=j&7,x)|0)|0;a2(b+160|0,29072,(x=i,i=i+8|0,c[x>>2]=(e[h>>1]|0)>>>9&7,x)|0)|0;h=b|0;c[h>>2]=c[h>>2]|32;i=g;return}else{h=b+32|0;a[h]=a[30320]|0;a[h+1|0]=a[30321|0]|0;a[h+2|0]=a[30322|0]|0;a[h+3|0]=a[30323|0]|0;a[h+4|0]=a[30324|0]|0;a[h+5|0]=a[30325|0]|0;c[b+28>>2]=2;a2(b+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[f]|0)>>>1&7,x)|0)|0;ik(b,b+160|0,f,a[f+1|0]&63,8);i=g;return}}function hH(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;h=b+12|0;j=e[h>>1]|0;k=j>>>3&7;if((k|0)==0){l=b+32|0;a[l]=a[30752]|0;a[l+1|0]=a[30753|0]|0;a[l+2|0]=a[30754|0]|0;a[l+3|0]=a[30755|0]|0;a[l+4|0]=a[30756|0]|0;a[l+5|0]=a[30757|0]|0;a[l+6|0]=a[30758|0]|0;c[b+28>>2]=2;l=b+96|0;m=j&7;a2(l|0,42056,(x=i,i=i+8|0,c[x>>2]=m,x)|0)|0;m=b+160|0;l=(d[f]|0)>>>1&7;a2(m|0,42056,(x=i,i=i+8|0,c[x>>2]=l,x)|0)|0;l=b|0;c[l>>2]=c[l>>2]|32;i=g;return}else if((k|0)==1){k=b+32|0;a[k]=a[30752]|0;a[k+1|0]=a[30753|0]|0;a[k+2|0]=a[30754|0]|0;a[k+3|0]=a[30755|0]|0;a[k+4|0]=a[30756|0]|0;a[k+5|0]=a[30757|0]|0;a[k+6|0]=a[30758|0]|0;c[b+28>>2]=2;a2(b+96|0,29072,(x=i,i=i+8|0,c[x>>2]=j&7,x)|0)|0;a2(b+160|0,29072,(x=i,i=i+8|0,c[x>>2]=(e[h>>1]|0)>>>9&7,x)|0)|0;h=b|0;c[h>>2]=c[h>>2]|32;i=g;return}else{h=b+32|0;a[h]=a[30648]|0;a[h+1|0]=a[30649|0]|0;a[h+2|0]=a[30650|0]|0;a[h+3|0]=a[30651|0]|0;a[h+4|0]=a[30652|0]|0;a[h+5|0]=a[30653|0]|0;c[b+28>>2]=2;a2(b+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[f]|0)>>>1&7,x)|0)|0;ik(b,b+160|0,f,a[f+1|0]&63,16);i=g;return}}function hI(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;h=b+12|0;j=e[h>>1]|0;k=j>>>3&7;if((k|0)==1){l=b+32|0;a[l]=a[30912]|0;a[l+1|0]=a[30913|0]|0;a[l+2|0]=a[30914|0]|0;a[l+3|0]=a[30915|0]|0;a[l+4|0]=a[30916|0]|0;a[l+5|0]=a[30917|0]|0;a[l+6|0]=a[30918|0]|0;c[b+28>>2]=2;l=b+96|0;m=j&7;a2(l|0,29072,(x=i,i=i+8|0,c[x>>2]=m,x)|0)|0;m=b+160|0;l=(e[h>>1]|0)>>>9&7;a2(m|0,29072,(x=i,i=i+8|0,c[x>>2]=l,x)|0)|0;l=b|0;c[l>>2]=c[l>>2]|32;i=g;return}else if((k|0)==0){k=b+32|0;a[k]=a[30912]|0;a[k+1|0]=a[30913|0]|0;a[k+2|0]=a[30914|0]|0;a[k+3|0]=a[30915|0]|0;a[k+4|0]=a[30916|0]|0;a[k+5|0]=a[30917|0]|0;a[k+6|0]=a[30918|0]|0;c[b+28>>2]=2;a2(b+96|0,42056,(x=i,i=i+8|0,c[x>>2]=j&7,x)|0)|0;a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[f]|0)>>>1&7,x)|0)|0;j=b|0;c[j>>2]=c[j>>2]|32;i=g;return}else{j=b+32|0;a[j]=a[30800]|0;a[j+1|0]=a[30801|0]|0;a[j+2|0]=a[30802|0]|0;a[j+3|0]=a[30803|0]|0;a[j+4|0]=a[30804|0]|0;a[j+5|0]=a[30805|0]|0;c[b+28>>2]=2;a2(b+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[f]|0)>>>1&7,x)|0)|0;ik(b,b+160|0,f,a[f+1|0]&63,32);i=g;return}}function hJ(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[31032]|0;a[g+1|0]=a[31033|0]|0;a[g+2|0]=a[31034|0]|0;a[g+3|0]=a[31035|0]|0;a[g+4|0]=a[31036|0]|0;a[g+5|0]=a[31037|0]|0;a[g+6|0]=a[31038|0]|0;c[b+28>>2]=2;ik(b,b+96|0,e,a[e+1|0]&63,32);a2(b+160|0,38624,(x=i,i=i+8|0,c[x>>2]=(d[e]|0)>>>1&7,x)|0)|0;i=f;return}function hK(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;j=f+12|0;k=(e[j>>1]|0)>>>3&7;if((k|0)==0){l=f+32|0;a[l]=a[31664]|0;a[l+1|0]=a[31665|0]|0;a[l+2|0]=a[31666|0]|0;a[l+3|0]=a[31667|0]|0;a[l+4|0]=a[31668|0]|0;a[l+5|0]=a[31669|0]|0;c[f+28>>2]=2;l=f+96|0;m=(a[g]&255)>>>1&7;n=m<<16>>16==0?8:m&65535;a2(l|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=n,x)|0)|0;n=f+160|0;l=b[j>>1]&7;a2(n|0,42056,(x=i,i=i+8|0,c[x>>2]=l,x)|0)|0;i=h;return}else if((k|0)==4){l=f+32|0;a[l]=a[31664]|0;a[l+1|0]=a[31665|0]|0;a[l+2|0]=a[31666|0]|0;a[l+3|0]=a[31667|0]|0;a[l+4|0]=a[31668|0]|0;a[l+5|0]=a[31669|0]|0;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==1){l=f+32|0;a[l]=a[31512]|0;a[l+1|0]=a[31513|0]|0;a[l+2|0]=a[31514|0]|0;a[l+3|0]=a[31515|0]|0;a[l+4|0]=a[31516|0]|0;a[l+5|0]=a[31517|0]|0;c[f+28>>2]=2;l=(a[g]&255)>>>1&7;a2(f+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=l<<16>>16==0?8:l&65535,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==3){l=f+32|0;a[l]=a[31224]|0;a[l+1|0]=a[31225|0]|0;a[l+2|0]=a[31226|0]|0;a[l+3|0]=a[31227|0]|0;a[l+4|0]=a[31228|0]|0;a[l+5|0]=a[31229|0]|0;c[f+28>>2]=2;l=(a[g]&255)>>>1&7;a2(f+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=l<<16>>16==0?8:l&65535,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==7){l=f+32|0;a[l]=a[31224]|0;a[l+1|0]=a[31225|0]|0;a[l+2|0]=a[31226|0]|0;a[l+3|0]=a[31227|0]|0;a[l+4|0]=a[31228|0]|0;a[l+5|0]=a[31229|0]|0;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==5){l=f+32|0;a[l]=a[31512]|0;a[l+1|0]=a[31513|0]|0;a[l+2|0]=a[31514|0]|0;a[l+3|0]=a[31515|0]|0;a[l+4|0]=a[31516|0]|0;a[l+5|0]=a[31517|0]|0;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==6){l=f+32|0;a[l]=a[31336]|0;a[l+1|0]=a[31337|0]|0;a[l+2|0]=a[31338|0]|0;a[l+3|0]=a[31339|0]|0;a[l+4|0]=a[31340|0]|0;a[l+5|0]=a[31341|0]|0;a[l+6|0]=a[31342|0]|0;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;l=f|0;c[l>>2]=c[l>>2]|32;i=h;return}else if((k|0)==2){k=f+32|0;a[k]=a[31336]|0;a[k+1|0]=a[31337|0]|0;a[k+2|0]=a[31338|0]|0;a[k+3|0]=a[31339|0]|0;a[k+4|0]=a[31340|0]|0;a[k+5|0]=a[31341|0]|0;a[k+6|0]=a[31342|0]|0;c[f+28>>2]=2;k=(a[g]&255)>>>1&7;a2(f+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=k<<16>>16==0?8:k&65535,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;j=f|0;c[j>>2]=c[j>>2]|32;i=h;return}else{j=f+32|0;a[j]=a[34016]|0;a[j+1|0]=a[34017|0]|0;a[j+2|0]=a[34018|0]|0;c[f+28>>2]=1;j=((d[g]|0)<<8|(d[g+1|0]|0))&65535;a2(f+96|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=j,x)|0)|0;i=h;return}}function hL(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;j=f+12|0;k=(e[j>>1]|0)>>>3&7;if((k|0)==2){l=f+32|0;a[l]=a[36224]|0;a[l+1|0]=a[36225|0]|0;a[l+2|0]=a[36226|0]|0;a[l+3|0]=a[36227|0]|0;a[l+4|0]=a[36228|0]|0;a[l+5|0]=a[36229|0]|0;a[l+6|0]=a[36230|0]|0;c[f+28>>2]=2;l=f+96|0;m=(a[g]&255)>>>1&7;n=m<<16>>16==0?8:m&65535;a2(l|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=n,x)|0)|0;n=f+160|0;l=b[j>>1]&7;a2(n|0,42056,(x=i,i=i+8|0,c[x>>2]=l,x)|0)|0;l=f|0;c[l>>2]=c[l>>2]|32;i=h;return}else if((k|0)==7){l=f+32|0;a[l]=a[36816]|0;a[l+1|0]=a[36817|0]|0;a[l+2|0]=a[36818|0]|0;a[l+3|0]=a[36819|0]|0;a[l+4|0]=a[36820|0]|0;a[l+5|0]=a[36821|0]|0;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==3){l=f+32|0;a[l]=a[36816]|0;a[l+1|0]=a[36817|0]|0;a[l+2|0]=a[36818|0]|0;a[l+3|0]=a[36819|0]|0;a[l+4|0]=a[36820|0]|0;a[l+5|0]=a[36821|0]|0;c[f+28>>2]=2;l=(a[g]&255)>>>1&7;a2(f+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=l<<16>>16==0?8:l&65535,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==1){l=f+32|0;a[l]=a[35760]|0;a[l+1|0]=a[35761|0]|0;a[l+2|0]=a[35762|0]|0;a[l+3|0]=a[35763|0]|0;a[l+4|0]=a[35764|0]|0;a[l+5|0]=a[35765|0]|0;c[f+28>>2]=2;l=(a[g]&255)>>>1&7;a2(f+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=l<<16>>16==0?8:l&65535,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==5){l=f+32|0;a[l]=a[35760]|0;a[l+1|0]=a[35761|0]|0;a[l+2|0]=a[35762|0]|0;a[l+3|0]=a[35763|0]|0;a[l+4|0]=a[35764|0]|0;a[l+5|0]=a[35765|0]|0;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==0){l=f+32|0;a[l]=a[32560]|0;a[l+1|0]=a[32561|0]|0;a[l+2|0]=a[32562|0]|0;a[l+3|0]=a[32563|0]|0;a[l+4|0]=a[32564|0]|0;a[l+5|0]=a[32565|0]|0;c[f+28>>2]=2;l=(a[g]&255)>>>1&7;a2(f+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=l<<16>>16==0?8:l&65535,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==6){l=f+32|0;a[l]=a[36224]|0;a[l+1|0]=a[36225|0]|0;a[l+2|0]=a[36226|0]|0;a[l+3|0]=a[36227|0]|0;a[l+4|0]=a[36228|0]|0;a[l+5|0]=a[36229|0]|0;a[l+6|0]=a[36230|0]|0;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;l=f|0;c[l>>2]=c[l>>2]|32;i=h;return}else if((k|0)==4){k=f+32|0;a[k]=a[32560]|0;a[k+1|0]=a[32561|0]|0;a[k+2|0]=a[32562|0]|0;a[k+3|0]=a[32563|0]|0;a[k+4|0]=a[32564|0]|0;a[k+5|0]=a[32565|0]|0;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else{j=f+32|0;a[j]=a[34016]|0;a[j+1|0]=a[34017|0]|0;a[j+2|0]=a[34018|0]|0;c[f+28>>2]=1;j=((d[g]|0)<<8|(d[g+1|0]|0))&65535;a2(f+96|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=j,x)|0)|0;i=h;return}}function hM(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;j=f+12|0;k=(e[j>>1]|0)>>>3&7;if((k|0)==0){l=f+32|0;a[l]=a[32368]|0;a[l+1|0]=a[32369|0]|0;a[l+2|0]=a[32370|0]|0;a[l+3|0]=a[32371|0]|0;a[l+4|0]=a[32372|0]|0;a[l+5|0]=a[32373|0]|0;c[f+28>>2]=2;l=f+96|0;m=(a[g]&255)>>>1&7;n=m<<16>>16==0?8:m&65535;a2(l|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=n,x)|0)|0;n=f+160|0;l=b[j>>1]&7;a2(n|0,42056,(x=i,i=i+8|0,c[x>>2]=l,x)|0)|0;i=h;return}else if((k|0)==4){l=f+32|0;a[l]=a[32368]|0;a[l+1|0]=a[32369|0]|0;a[l+2|0]=a[32370|0]|0;a[l+3|0]=a[32371|0]|0;a[l+4|0]=a[32372|0]|0;a[l+5|0]=a[32373|0]|0;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==1){l=f+32|0;a[l]=a[32192]|0;a[l+1|0]=a[32193|0]|0;a[l+2|0]=a[32194|0]|0;a[l+3|0]=a[32195|0]|0;a[l+4|0]=a[32196|0]|0;a[l+5|0]=a[32197|0]|0;c[f+28>>2]=2;l=(a[g]&255)>>>1&7;a2(f+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=l<<16>>16==0?8:l&65535,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==3){l=f+32|0;a[l]=a[31904]|0;a[l+1|0]=a[31905|0]|0;a[l+2|0]=a[31906|0]|0;a[l+3|0]=a[31907|0]|0;a[l+4|0]=a[31908|0]|0;a[l+5|0]=a[31909|0]|0;c[f+28>>2]=2;l=(a[g]&255)>>>1&7;a2(f+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=l<<16>>16==0?8:l&65535,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==7){l=f+32|0;a[l]=a[31904]|0;a[l+1|0]=a[31905|0]|0;a[l+2|0]=a[31906|0]|0;a[l+3|0]=a[31907|0]|0;a[l+4|0]=a[31908|0]|0;a[l+5|0]=a[31909|0]|0;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==5){l=f+32|0;a[l]=a[32192]|0;a[l+1|0]=a[32193|0]|0;a[l+2|0]=a[32194|0]|0;a[l+3|0]=a[32195|0]|0;a[l+4|0]=a[32196|0]|0;a[l+5|0]=a[32197|0]|0;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==6){l=f+32|0;a[l]=a[32104]|0;a[l+1|0]=a[32105|0]|0;a[l+2|0]=a[32106|0]|0;a[l+3|0]=a[32107|0]|0;a[l+4|0]=a[32108|0]|0;a[l+5|0]=a[32109|0]|0;a[l+6|0]=a[32110|0]|0;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;l=f|0;c[l>>2]=c[l>>2]|32;i=h;return}else if((k|0)==2){k=f+32|0;a[k]=a[32104]|0;a[k+1|0]=a[32105|0]|0;a[k+2|0]=a[32106|0]|0;a[k+3|0]=a[32107|0]|0;a[k+4|0]=a[32108|0]|0;a[k+5|0]=a[32109|0]|0;a[k+6|0]=a[32110|0]|0;c[f+28>>2]=2;k=(a[g]&255)>>>1&7;a2(f+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=k<<16>>16==0?8:k&65535,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;j=f|0;c[j>>2]=c[j>>2]|32;i=h;return}else{j=f+32|0;a[j]=a[34016]|0;a[j+1|0]=a[34017|0]|0;a[j+2|0]=a[34018|0]|0;c[f+28>>2]=1;j=((d[g]|0)<<8|(d[g+1|0]|0))&65535;a2(f+96|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=j,x)|0)|0;i=h;return}}function hN(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[32560]|0;a[e+1|0]=a[32561|0]|0;a[e+2|0]=a[32562|0]|0;a[e+3|0]=a[32563|0]|0;a[e+4|0]=a[32564|0]|0;a[e+5|0]=a[32565|0]|0;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,16);return}function hO(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0;h=i;j=f+12|0;k=(e[j>>1]|0)>>>3&7;if((k|0)==7){l=f+32|0;a[l]=a[32792]|0;a[l+1|0]=a[32793|0]|0;a[l+2|0]=a[32794|0]|0;a[l+3|0]=a[32795|0]|0;a[l+4|0]=a[32796|0]|0;a[l+5|0]=a[32797|0]|0;c[f+28>>2]=2;l=f+96|0;m=(d[g]|0)>>>1&7;a2(l|0,42056,(x=i,i=i+8|0,c[x>>2]=m,x)|0)|0;m=f+160|0;l=b[j>>1]&7;a2(m|0,42056,(x=i,i=i+8|0,c[x>>2]=l,x)|0)|0;i=h;return}else if((k|0)==2){l=f+32|0;a[l]=a[33088]|0;a[l+1|0]=a[33089|0]|0;a[l+2|0]=a[33090|0]|0;a[l+3|0]=a[33091|0]|0;a[l+4|0]=a[33092|0]|0;a[l+5|0]=a[33093|0]|0;a[l+6|0]=a[33094|0]|0;c[f+28>>2]=2;l=(a[g]&255)>>>1&7;a2(f+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=l<<16>>16==0?8:l&65535,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;l=f|0;c[l>>2]=c[l>>2]|32;i=h;return}else if((k|0)==5){l=f+32|0;a[l]=a[33344]|0;a[l+1|0]=a[33345|0]|0;a[l+2|0]=a[33346|0]|0;a[l+3|0]=a[33347|0]|0;a[l+4|0]=a[33348|0]|0;a[l+5|0]=a[33349|0]|0;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==3){l=f+32|0;a[l]=a[32792]|0;a[l+1|0]=a[32793|0]|0;a[l+2|0]=a[32794|0]|0;a[l+3|0]=a[32795|0]|0;a[l+4|0]=a[32796|0]|0;a[l+5|0]=a[32797|0]|0;c[f+28>>2]=2;l=(a[g]&255)>>>1&7;a2(f+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=l<<16>>16==0?8:l&65535,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==1){l=f+32|0;a[l]=a[33344]|0;a[l+1|0]=a[33345|0]|0;a[l+2|0]=a[33346|0]|0;a[l+3|0]=a[33347|0]|0;a[l+4|0]=a[33348|0]|0;a[l+5|0]=a[33349|0]|0;c[f+28>>2]=2;l=(a[g]&255)>>>1&7;a2(f+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=l<<16>>16==0?8:l&65535,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==6){l=f+32|0;a[l]=a[33088]|0;a[l+1|0]=a[33089|0]|0;a[l+2|0]=a[33090|0]|0;a[l+3|0]=a[33091|0]|0;a[l+4|0]=a[33092|0]|0;a[l+5|0]=a[33093|0]|0;a[l+6|0]=a[33094|0]|0;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;l=f|0;c[l>>2]=c[l>>2]|32;i=h;return}else if((k|0)==0){l=f+32|0;a[l]=a[33688]|0;a[l+1|0]=a[33689|0]|0;a[l+2|0]=a[33690|0]|0;a[l+3|0]=a[33691|0]|0;a[l+4|0]=a[33692|0]|0;a[l+5|0]=a[33693|0]|0;c[f+28>>2]=2;l=(a[g]&255)>>>1&7;a2(f+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=l<<16>>16==0?8:l&65535,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==4){k=f+32|0;a[k]=a[33688]|0;a[k+1|0]=a[33689|0]|0;a[k+2|0]=a[33690|0]|0;a[k+3|0]=a[33691|0]|0;a[k+4|0]=a[33692|0]|0;a[k+5|0]=a[33693|0]|0;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else{j=f+32|0;a[j]=a[34016]|0;a[j+1|0]=a[34017|0]|0;a[j+2|0]=a[34018|0]|0;c[f+28>>2]=1;j=((d[g]|0)<<8|(d[g+1|0]|0))&65535;a2(f+96|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=j,x)|0)|0;i=h;return}}function hP(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;j=f+12|0;k=(e[j>>1]|0)>>>3&7;if((k|0)==0){l=f+32|0;a[l]=a[35536]|0;a[l+1|0]=a[35537|0]|0;a[l+2|0]=a[35538|0]|0;a[l+3|0]=a[35539|0]|0;a[l+4|0]=a[35540|0]|0;a[l+5|0]=a[35541|0]|0;c[f+28>>2]=2;l=f+96|0;m=(a[g]&255)>>>1&7;n=m<<16>>16==0?8:m&65535;a2(l|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=n,x)|0)|0;n=f+160|0;l=b[j>>1]&7;a2(n|0,42056,(x=i,i=i+8|0,c[x>>2]=l,x)|0)|0;i=h;return}else if((k|0)==4){l=f+32|0;a[l]=a[35536]|0;a[l+1|0]=a[35537|0]|0;a[l+2|0]=a[35538|0]|0;a[l+3|0]=a[35539|0]|0;a[l+4|0]=a[35540|0]|0;a[l+5|0]=a[35541|0]|0;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==1){l=f+32|0;a[l]=a[35976]|0;a[l+1|0]=a[35977|0]|0;a[l+2|0]=a[35978|0]|0;a[l+3|0]=a[35979|0]|0;a[l+4|0]=a[35980|0]|0;a[l+5|0]=a[35981|0]|0;c[f+28>>2]=2;l=(a[g]&255)>>>1&7;a2(f+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=l<<16>>16==0?8:l&65535,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==3){l=f+32|0;a[l]=a[37200]|0;a[l+1|0]=a[37201|0]|0;a[l+2|0]=a[37202|0]|0;a[l+3|0]=a[37203|0]|0;a[l+4|0]=a[37204|0]|0;a[l+5|0]=a[37205|0]|0;c[f+28>>2]=2;l=(a[g]&255)>>>1&7;a2(f+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=l<<16>>16==0?8:l&65535,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==7){l=f+32|0;a[l]=a[37200]|0;a[l+1|0]=a[37201|0]|0;a[l+2|0]=a[37202|0]|0;a[l+3|0]=a[37203|0]|0;a[l+4|0]=a[37204|0]|0;a[l+5|0]=a[37205|0]|0;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==5){l=f+32|0;a[l]=a[35976]|0;a[l+1|0]=a[35977|0]|0;a[l+2|0]=a[35978|0]|0;a[l+3|0]=a[35979|0]|0;a[l+4|0]=a[35980|0]|0;a[l+5|0]=a[35981|0]|0;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==6){l=f+32|0;a[l]=a[36512]|0;a[l+1|0]=a[36513|0]|0;a[l+2|0]=a[36514|0]|0;a[l+3|0]=a[36515|0]|0;a[l+4|0]=a[36516|0]|0;a[l+5|0]=a[36517|0]|0;a[l+6|0]=a[36518|0]|0;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;l=f|0;c[l>>2]=c[l>>2]|32;i=h;return}else if((k|0)==2){k=f+32|0;a[k]=a[36512]|0;a[k+1|0]=a[36513|0]|0;a[k+2|0]=a[36514|0]|0;a[k+3|0]=a[36515|0]|0;a[k+4|0]=a[36516|0]|0;a[k+5|0]=a[36517|0]|0;a[k+6|0]=a[36518|0]|0;c[f+28>>2]=2;k=(a[g]&255)>>>1&7;a2(f+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=k<<16>>16==0?8:k&65535,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;j=f|0;c[j>>2]=c[j>>2]|32;i=h;return}else{j=f+32|0;a[j]=a[34016]|0;a[j+1|0]=a[34017|0]|0;a[j+2|0]=a[34018|0]|0;c[f+28>>2]=1;j=((d[g]|0)<<8|(d[g+1|0]|0))&65535;a2(f+96|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=j,x)|0)|0;i=h;return}}function hQ(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0;h=i;j=f+12|0;k=(e[j>>1]|0)>>>3&7;if((k|0)==6){l=f+32|0;a[l]=a[34816]|0;a[l+1|0]=a[34817|0]|0;a[l+2|0]=a[34818|0]|0;a[l+3|0]=a[34819|0]|0;a[l+4|0]=a[34820|0]|0;a[l+5|0]=a[34821|0]|0;a[l+6|0]=a[34822|0]|0;c[f+28>>2]=2;l=f+96|0;m=(d[g]|0)>>>1&7;a2(l|0,42056,(x=i,i=i+8|0,c[x>>2]=m,x)|0)|0;m=f+160|0;l=b[j>>1]&7;a2(m|0,42056,(x=i,i=i+8|0,c[x>>2]=l,x)|0)|0;l=f|0;c[l>>2]=c[l>>2]|32;i=h;return}else if((k|0)==2){l=f+32|0;a[l]=a[34816]|0;a[l+1|0]=a[34817|0]|0;a[l+2|0]=a[34818|0]|0;a[l+3|0]=a[34819|0]|0;a[l+4|0]=a[34820|0]|0;a[l+5|0]=a[34821|0]|0;a[l+6|0]=a[34822|0]|0;c[f+28>>2]=2;l=(a[g]&255)>>>1&7;a2(f+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=l<<16>>16==0?8:l&65535,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;l=f|0;c[l>>2]=c[l>>2]|32;i=h;return}else if((k|0)==7){l=f+32|0;a[l]=a[34392]|0;a[l+1|0]=a[34393|0]|0;a[l+2|0]=a[34394|0]|0;a[l+3|0]=a[34395|0]|0;a[l+4|0]=a[34396|0]|0;a[l+5|0]=a[34397|0]|0;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==5){l=f+32|0;a[l]=a[35080]|0;a[l+1|0]=a[35081|0]|0;a[l+2|0]=a[35082|0]|0;a[l+3|0]=a[35083|0]|0;a[l+4|0]=a[35084|0]|0;a[l+5|0]=a[35085|0]|0;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==3){l=f+32|0;a[l]=a[34392]|0;a[l+1|0]=a[34393|0]|0;a[l+2|0]=a[34394|0]|0;a[l+3|0]=a[34395|0]|0;a[l+4|0]=a[34396|0]|0;a[l+5|0]=a[34397|0]|0;c[f+28>>2]=2;l=(a[g]&255)>>>1&7;a2(f+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=l<<16>>16==0?8:l&65535,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==1){l=f+32|0;a[l]=a[35080]|0;a[l+1|0]=a[35081|0]|0;a[l+2|0]=a[35082|0]|0;a[l+3|0]=a[35083|0]|0;a[l+4|0]=a[35084|0]|0;a[l+5|0]=a[35085|0]|0;c[f+28>>2]=2;l=(a[g]&255)>>>1&7;a2(f+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=l<<16>>16==0?8:l&65535,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==0){l=f+32|0;a[l]=a[35296]|0;a[l+1|0]=a[35297|0]|0;a[l+2|0]=a[35298|0]|0;a[l+3|0]=a[35299|0]|0;a[l+4|0]=a[35300|0]|0;a[l+5|0]=a[35301|0]|0;c[f+28>>2]=2;l=(a[g]&255)>>>1&7;a2(f+96|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=l<<16>>16==0?8:l&65535,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else if((k|0)==4){k=f+32|0;a[k]=a[35296]|0;a[k+1|0]=a[35297|0]|0;a[k+2|0]=a[35298|0]|0;a[k+3|0]=a[35299|0]|0;a[k+4|0]=a[35300|0]|0;a[k+5|0]=a[35301|0]|0;c[f+28>>2]=2;a2(f+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[g]|0)>>>1&7,x)|0)|0;a2(f+160|0,42056,(x=i,i=i+8|0,c[x>>2]=b[j>>1]&7,x)|0)|0;i=h;return}else{j=f+32|0;a[j]=a[34016]|0;a[j+1|0]=a[34017|0]|0;a[j+2|0]=a[34018|0]|0;c[f+28>>2]=1;j=((d[g]|0)<<8|(d[g+1|0]|0))&65535;a2(f+96|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=j,x)|0)|0;i=h;return}}function hR(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[35536]|0;a[e+1|0]=a[35537|0]|0;a[e+2|0]=a[35538|0]|0;a[e+3|0]=a[35539|0]|0;a[e+4|0]=a[35540|0]|0;a[e+5|0]=a[35541|0]|0;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,16);return}function hS(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[35760]|0;a[e+1|0]=a[35761|0]|0;a[e+2|0]=a[35762|0]|0;a[e+3|0]=a[35763|0]|0;a[e+4|0]=a[35764|0]|0;a[e+5|0]=a[35765|0]|0;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,16);return}function hT(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[35976]|0;a[e+1|0]=a[35977|0]|0;a[e+2|0]=a[35978|0]|0;a[e+3|0]=a[35979|0]|0;a[e+4|0]=a[35980|0]|0;a[e+5|0]=a[35981|0]|0;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,16);return}function hU(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[36224]|0;a[e+1|0]=a[36225|0]|0;a[e+2|0]=a[36226|0]|0;a[e+3|0]=a[36227|0]|0;a[e+4|0]=a[36228|0]|0;a[e+5|0]=a[36229|0]|0;a[e+6|0]=a[36230|0]|0;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,16);d=b|0;c[d>>2]=c[d>>2]|32;return}function hV(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[36512]|0;a[e+1|0]=a[36513|0]|0;a[e+2|0]=a[36514|0]|0;a[e+3|0]=a[36515|0]|0;a[e+4|0]=a[36516|0]|0;a[e+5|0]=a[36517|0]|0;a[e+6|0]=a[36518|0]|0;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,16);d=b|0;c[d>>2]=c[d>>2]|32;return}function hW(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[36816]|0;a[e+1|0]=a[36817|0]|0;a[e+2|0]=a[36818|0]|0;a[e+3|0]=a[36819|0]|0;a[e+4|0]=a[36820|0]|0;a[e+5|0]=a[36821|0]|0;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,16);return}function hX(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[37200]|0;a[e+1|0]=a[37201|0]|0;a[e+2|0]=a[37202|0]|0;a[e+3|0]=a[37203|0]|0;a[e+4|0]=a[37204|0]|0;a[e+5|0]=a[37205|0]|0;c[b+28>>2]=1;ik(b,b+96|0,d,a[d+1|0]&63,16);return}function hY(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[37672]|0;a[e+1|0]=a[37673|0]|0;a[e+2|0]=a[37674|0]|0;a[e+3|0]=a[37675|0]|0;a[e+4|0]=a[37676|0]|0;a[e+5|0]=a[37677|0]|0;c[b+28>>2]=1;h4(b,b+96|0,d,33,8);return}function hZ(b,d){b=b|0;d=d|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[37920]|0;a[g+1|0]=a[37921|0]|0;a[g+2|0]=a[37922|0]|0;a[g+3|0]=a[37923|0]|0;a[g+4|0]=a[37924|0]|0;a[g+5|0]=a[37925|0]|0;a[g+6|0]=a[37926|0]|0;c[b+28>>2]=2;h4(b,b+96|0,d,33,8);a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(e[b+14>>1]|0)>>>12&7,x)|0)|0;i=f;return}function h_(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[38176]|0;a[e+1|0]=a[38177|0]|0;a[e+2|0]=a[38178|0]|0;a[e+3|0]=a[38179|0]|0;a[e+4|0]=a[38180|0]|0;a[e+5|0]=a[38181|0]|0;c[b+28>>2]=1;h4(b,b+96|0,d,33,8);return}function h$(b,d){b=b|0;d=d|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[38424]|0;a[g+1|0]=a[38425|0]|0;a[g+2|0]=a[38426|0]|0;a[g+3|0]=a[38427|0]|0;a[g+4|0]=a[38428|0]|0;a[g+5|0]=a[38429|0]|0;a[g+6|0]=a[38430|0]|0;c[b+28>>2]=2;h4(b,b+96|0,d,33,8);a2(b+160|0,42056,(x=i,i=i+8|0,c[x>>2]=(e[b+14>>1]|0)>>>12&7,x)|0)|0;i=f;return}function h0(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[38648]|0;a[e+1|0]=a[38649|0]|0;a[e+2|0]=a[38650|0]|0;a[e+3|0]=a[38651|0]|0;a[e+4|0]=a[38652|0]|0;a[e+5|0]=a[38653|0]|0;c[b+28>>2]=1;h4(b,b+96|0,d,33,8);return}function h1(b,d){b=b|0;d=d|0;var e=0;e=b+32|0;a[e]=a[38896]|0;a[e+1|0]=a[38897|0]|0;a[e+2|0]=a[38898|0]|0;a[e+3|0]=a[38899|0]|0;a[e+4|0]=a[38900|0]|0;a[e+5|0]=a[38901|0]|0;c[b+28>>2]=1;h4(b,b+96|0,d,33,8);return}function h2(b,d){b=b|0;d=d|0;var f=0,g=0;f=i;g=b+32|0;a[g]=a[50048]|0;a[g+1|0]=a[50049|0]|0;a[g+2|0]=a[50050|0]|0;a[g+3|0]=a[50051|0]|0;a[g+4|0]=a[50052|0]|0;a[g+5|0]=a[50053|0]|0;c[b+28>>2]=2;a2(b+96|0,42056,(x=i,i=i+8|0,c[x>>2]=(e[b+14>>1]|0)>>>12&7,x)|0)|0;h4(b,b+160|0,d,33,8);i=f;return}function h3(a,b){a=a|0;b=b|0;var d=0;b=i;i=i+16|0;d=b|0;a2(d|0,32392,(x=i,i=i+8|0,c[x>>2]=e[a+12>>1]|0,x)|0)|0;vb(a+32|0,d|0)|0;c[a+28>>2]=0;d=a|0;c[d>>2]=c[d>>2]|4;i=b;return}function h4(f,g,h,j,k){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,z=0,A=0,B=0;l=i;i=i+16|0;m=l|0;n=l+8|0;if((j|0)==0){a[g]=0;i=l;return}else if((j|0)==4){o=((d[h]|0)<<8|(d[h+1|0]|0))&65535;ik(f,g,h,o>>>3&56|o>>>9&7,k);i=l;return}else if((j|0)==24){o=(d[h+2|0]|0)<<8|(d[h+3|0]|0);c[n>>2]=1;a[g]=0;p=o&65535;o=0;q=0;r=0;while(1){if((o|0)!=8|(r|0)==0){s=r}else{il(g,q,r,n);s=0}t=(s|0)==0;do{if((1<<o&p|0)==0){if(t){u=0;v=q;break}il(g,q,s,n);u=0;v=q}else{u=s+1|0;v=t?o:q}}while(0);t=o+1|0;if(t>>>0<16){o=t;q=v;r=u}else{break}}if((u|0)!=0){il(g,v,u,n)}n=f+8|0;c[n>>2]=(c[n>>2]|0)+1;i=l;return}else if((j|0)==25){n=d[h+2|0]|0;u=d[h+3|0]|0;c[m>>2]=1;a[g]=0;v=(((((((n&65535)>>>2&1|n&2|((((((((u&65535)>>>2&1|u&2|((n<<8|u)<<1|u&1)<<2)<<1|(u&65535)>>>3&1)<<1|(u&65535)>>>4&1)<<1|(u&65535)>>>5&1)<<1|(u&65535)>>>6&1)<<1|(u&65535)>>>7)<<1|n&1)<<2)<<1|(n&65535)>>>3&1)<<1|(n&65535)>>>4&1)<<1|(n&65535)>>>5&1)<<1|(n&65535)>>>6&1)<<1|(n&65535)>>>7)&65535;n=0;u=0;r=0;while(1){if((n|0)!=8|(r|0)==0){w=r}else{il(g,u,r,m);w=0}q=(w|0)==0;do{if((1<<n&v|0)==0){if(q){z=0;A=u;break}il(g,u,w,m);z=0;A=u}else{z=w+1|0;A=q?n:u}}while(0);q=n+1|0;if(q>>>0<16){n=q;u=A;r=z}else{break}}if((z|0)!=0){il(g,A,z,m)}m=f+8|0;c[m>>2]=(c[m>>2]|0)+1;i=l;return}else if((j|0)==12){a2(g|0,29072,(x=i,i=i+8|0,c[x>>2]=b[f+12>>1]&7,x)|0)|0;i=l;return}else if((j|0)==13){a2(g|0,29072,(x=i,i=i+8|0,c[x>>2]=(e[f+12>>1]|0)>>>9&7,x)|0)|0;i=l;return}else if((j|0)==1){m=((d[h]|0)<<8|(d[h+1|0]|0))&65535;a2(g|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=m,x)|0)|0;i=l;return}else if((j|0)==9){m=d[h+2|0]|0;a2(g|0,35736,(x=i,i=i+16|0,c[x>>2]=(m&128|0)!=0?32752:31024,c[x+8>>2]=m>>>4&7,x)|0)|0;i=l;return}else if((j|0)==31){m=e[f+14>>1]|0;a2(g|0,48160,(x=i,i=i+16|0,c[x>>2]=m&7,c[x+8>>2]=m>>>12&7,x)|0)|0;i=l;return}else if((j|0)==32|(j|0)==34){a2(g|0,42056,(x=i,i=i+8|0,c[x>>2]=(e[f+14>>1]|0)>>>12&7,x)|0)|0;i=l;return}else if((j|0)==3){ik(f,g,h,a[h+1|0]&63,k);i=l;return}else if((j|0)==28){k=g;y=5264213;a[k]=y&255;y=y>>8;a[k+1|0]=y&255;y=y>>8;a[k+2|0]=y&255;y=y>>8;a[k+3|0]=y&255;i=l;return}else if((j|0)==29){k=((d[h+2|0]|0)<<8|(d[h+3|0]|0))&4095;if((k|0)==1){m=f|0;c[m>>2]=c[m>>2]|64;B=46144}else if((k|0)==2048){m=f|0;c[m>>2]=c[m>>2]|64;B=48616}else if((k|0)==2049){m=f|0;c[m>>2]=c[m>>2]|64;B=45808}else if((k|0)==0){m=f|0;c[m>>2]=c[m>>2]|64;B=46496}else{a2(g|0,45528,(x=i,i=i+8|0,c[x>>2]=k,x)|0)|0;k=f|0;c[k>>2]=c[k>>2]|64;i=l;return}k=B;B=g;y=d[k]|d[k+1|0]<<8|d[k+2|0]<<16|d[k+3|0]<<24|0;a[B]=y&255;y=y>>8;a[B+1|0]=y&255;y=y>>8;a[B+2|0]=y&255;y=y>>8;a[B+3|0]=y&255;i=l;return}else if((j|0)==7){a2(g|0,38624,(x=i,i=i+8|0,c[x>>2]=b[f+12>>1]&7,x)|0)|0;i=l;return}else if((j|0)==5){a2(g|0,42056,(x=i,i=i+8|0,c[x>>2]=b[f+12>>1]&7,x)|0)|0;i=l;return}else if((j|0)==10){a2(g|0,29968,(x=i,i=i+8|0,c[x>>2]=b[f+12>>1]&7,x)|0)|0;i=l;return}else if((j|0)==11){a2(g|0,29968,(x=i,i=i+8|0,c[x>>2]=(e[f+12>>1]|0)>>>9&7,x)|0)|0;i=l;return}else if((j|0)==14){B=((d[h+2|0]|0)<<8|(d[h+3|0]|0))&65535;k=(B&32768|0)!=0;m=b[f+12>>1]&7;a2(g|0,54880,(x=i,i=i+32|0,c[x>>2]=k?53680:58240,c[x+8>>2]=39144,c[x+16>>2]=(k?-B|0:B)&65535,c[x+24>>2]=m,x)|0)|0;m=f+8|0;c[m>>2]=(c[m>>2]|0)+1;i=l;return}else if((j|0)==15){m=d[h+3|0]|0;a2(g|0,52224,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=m,x)|0)|0;m=f+8|0;c[m>>2]=(c[m>>2]|0)+1;i=l;return}else if((j|0)==6){a2(g|0,42056,(x=i,i=i+8|0,c[x>>2]=(d[h]|0)>>>1&7,x)|0)|0;i=l;return}else if((j|0)==21){m=d[h+1|0]|0;B=(c[f+4>>2]|0)+2+((m&128|0)!=0?m|-256:m)|0;a2(g|0,50072,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=B,x)|0)|0;i=l;return}else if((j|0)==8){a2(g|0,38624,(x=i,i=i+8|0,c[x>>2]=(d[h]|0)>>>1&7,x)|0)|0;i=l;return}else if((j|0)==33){B=f+8|0;m=c[B>>2]|0;k=m<<1;z=(d[h+k|0]|0)<<8|(d[h+(k|1)|0]|0);k=m+1|0;c[B>>2]=k;b[f+12+(k<<1)>>1]=z;ik(f,g,h,a[h+1|0]&63,8);z=u8(g|0)|0;a[g+z|0]=32;k=z+2|0;B=g+k|0;a[g+(z+1)|0]=123;z=f+14|0;m=e[z>>1]|0;A=m>>>6;if((m&2048|0)==0){m=A&31;a2(B|0,47512,(x=i,i=i+8|0,c[x>>2]=m,x)|0)|0}else{m=A&7;a2(B|0,42056,(x=i,i=i+8|0,c[x>>2]=m,x)|0)|0}m=(u8(B|0)|0)+k|0;k=m+1|0;B=g+k|0;a[g+m|0]=58;m=b[z>>1]|0;z=m&31;A=(z|0)==0?32:z;if((m&32)==0){a2(B|0,47512,(x=i,i=i+8|0,c[x>>2]=A,x)|0)|0}else{m=A&7;a2(B|0,42056,(x=i,i=i+8|0,c[x>>2]=m,x)|0)|0}m=g+((u8(B|0)|0)+k)|0;y=125;a[m]=y&255;y=y>>8;a[m+1|0]=y&255;i=l;return}else if((j|0)==27){a[g]=a[49056]|0;a[g+1|0]=a[49057|0]|0;a[g+2|0]=a[49058|0]|0;i=l;return}else if((j|0)==19){m=b[f+12>>1]&15;a2(g|0,52224,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=m,x)|0)|0;i=l;return}else if((j|0)==20){m=e[f+12>>1]|0;a2(g|0,51552,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=(m&128|0)!=0?m|-256:m&255,x)|0)|0;i=l;return}else if((j|0)==18){m=(a[h]&255)>>>1&7;a2(g|0,50736,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=m<<16>>16==0?8:m&65535,x)|0)|0;i=l;return}else if((j|0)==26){m=g;y=5391171;a[m]=y&255;y=y>>8;a[m+1|0]=y&255;y=y>>8;a[m+2|0]=y&255;y=y>>8;a[m+3|0]=y&255;i=l;return}else if((j|0)==16){m=((d[h+2|0]|0)<<8|(d[h+3|0]|0))&65535;a2(g|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=m,x)|0)|0;m=f+8|0;c[m>>2]=(c[m>>2]|0)+1;i=l;return}else if((j|0)==17){m=(((d[h+2|0]|0)<<8|(d[h+3|0]|0))<<8|(d[h+4|0]|0))<<8|(d[h+5|0]|0);a2(g|0,51552,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=m,x)|0)|0;m=f+8|0;c[m>>2]=(c[m>>2]|0)+2;i=l;return}else if((j|0)==22){m=f+8|0;k=c[m>>2]|0;B=k<<1;A=(d[h+B|0]|0)<<8|(d[h+(B|1)|0]|0);c[m>>2]=k+1;k=A&65535;A=(c[f+4>>2]|0)+2+((k&32768|0)!=0?k|-65536:k)|0;a2(g|0,50072,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=A,x)|0)|0;i=l;return}else if((j|0)==23){A=f+8|0;k=c[A>>2]|0;m=k<<1;B=(((d[h+m|0]|0)<<8|(d[h+(m|1)|0]|0))<<8|(d[h+(m+2)|0]|0))<<8|(d[h+(m+3)|0]|0);c[A>>2]=k+2;k=(c[f+4>>2]|0)+2+B|0;a2(g|0,50072,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=k,x)|0)|0;i=l;return}else if((j|0)==2){k=((d[h+2|0]|0)<<8|(d[h+3|0]|0))&65535;a2(g|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=k,x)|0)|0;i=l;return}else if((j|0)==30){j=e[f+14>>1]|0;a2(g|0,48160,(x=i,i=i+16|0,c[x>>2]=j&7,c[x+8>>2]=j>>>12&7,x)|0)|0;i=l;return}else{a[g]=0;i=l;return}}function h5(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;c[a+4>>2]=b;c[a+8>>2]=d;c[a+12>>2]=e;c[a+16>>2]=f;c[a+20>>2]=g;c[a+24>>2]=h;c[a+28>>2]=i;return}function h6(a,b,d){a=a|0;b=b|0;d=d|0;c[a+32>>2]=b;c[a+36>>2]=(b|0)==0?0:d;return}function h7(a,b,d){a=a|0;b=b|0;d=d|0;c[a+40>>2]=b;c[a+44>>2]=d;return}function h8(a,b,d){a=a|0;b=b|0;d=d|0;c[a+52>>2]=b;c[a+56>>2]=d;return}function h9(a,b){a=a|0;b=b|0;var d=0;d=a|0;a=c[d>>2]|0;c[d>>2]=(b|0)==0?a|1:a&-2;return}function ia(a){a=a|0;var b=0;b=a+280|0;return(G=c[b+4>>2]|0,c[b>>2]|0)|0}function ib(a){a=a|0;var b=0;b=a+288|0;return(G=c[b+4>>2]|0,c[b>>2]|0)|0}function ic(a){a=a|0;return c[a+268>>2]|0}function id(a){a=a|0;return d[a+189|0]|0|0}function ie(b,c){b=b|0;c=c|0;a[b+189|0]=c&3;return}function ig(a){a=a|0;return c[a+272>>2]|0}function ih(a){a=a|0;return c[a+276>>2]|0}function ii(a){a=a|0;return c[a+180>>2]|0}function ij(a){a=a|0;return b[a+184>>1]|0}function ik(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;j=f>>>3&7;if((j|0)==6){k=a+8|0;l=c[k>>2]|0;m=l<<1;n=((d[e+m|0]|0)<<8|(d[e+(m|1)|0]|0))&65535;c[k>>2]=l+1;if((n&256|0)!=0){im(a,b,e);i=h;return}l=(n&128|0)!=0;k=l?53680:58240;m=(l?-n|0:n)&255;l=f&7;o=(n&32768|0)!=0?32752:31024;p=n>>>12&7;q=(n&2048|0)!=0?43408:43080;r=1<<(n>>>9&3);a2(b|0,43856,(x=i,i=i+64|0,c[x>>2]=k,c[x+8>>2]=39144,c[x+16>>2]=m,c[x+24>>2]=l,c[x+32>>2]=o,c[x+40>>2]=p,c[x+48>>2]=q,c[x+56>>2]=r,x)|0)|0;if((n&1536|0)==0){i=h;return}n=a|0;c[n>>2]=c[n>>2]|128;i=h;return}else if((j|0)==2){a2(b|0,44312,(x=i,i=i+8|0,c[x>>2]=f&7,x)|0)|0;i=h;return}else if((j|0)==5){n=a+8|0;r=c[n>>2]|0;q=r<<1;p=((d[e+q|0]|0)<<8|(d[e+(q|1)|0]|0))&65535;c[n>>2]=r+1;r=(p&32768|0)!=0;a2(b|0,54880,(x=i,i=i+32|0,c[x>>2]=r?53680:58240,c[x+8>>2]=39144,c[x+16>>2]=(r?-p|0:p)&65535,c[x+24>>2]=f&7,x)|0)|0;i=h;return}else if((j|0)==3){a2(b|0,29968,(x=i,i=i+8|0,c[x>>2]=f&7,x)|0)|0;i=h;return}else if((j|0)==1){a2(b|0,38624,(x=i,i=i+8|0,c[x>>2]=f&7,x)|0)|0;i=h;return}else if((j|0)==0){a2(b|0,42056,(x=i,i=i+8|0,c[x>>2]=f&7,x)|0)|0;i=h;return}else if((j|0)==7){p=f&7;if((p|0)==0){r=a+8|0;n=c[r>>2]|0;q=n<<1;o=((d[e+q|0]|0)<<8|(d[e+(q|1)|0]|0))&65535;c[r>>2]=n+1;n=(o&32768|0)!=0;r=n?53680:58240;q=(n?-o|0:o)&65535;a2(b|0,42776,(x=i,i=i+24|0,c[x>>2]=r,c[x+8>>2]=39144,c[x+16>>2]=q,x)|0)|0;i=h;return}else if((p|0)==1){q=a+8|0;r=c[q>>2]|0;o=r<<1;n=((d[e+o|0]|0)<<8|(d[e+(o|1)|0]|0))&65535;o=r+1|0;c[q>>2]=o;l=o<<1;o=((d[e+l|0]|0)<<8|(d[e+(l|1)|0]|0))&65535;c[q>>2]=r+2;a2(b|0,50072,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=o|n<<16,x)|0)|0;i=h;return}else if((p|0)==2){n=a+8|0;o=c[n>>2]|0;r=o<<1;q=((d[e+r|0]|0)<<8|(d[e+(r|1)|0]|0))&65535;c[n>>2]=o+1;o=(c[a+4>>2]|0)+2+((q&32768|0)!=0?q|-65536:q)|0;a2(b|0,42376,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=o,x)|0)|0;i=h;return}else if((p|0)==3){o=a+8|0;q=c[o>>2]|0;n=q<<1;r=((d[e+n|0]|0)<<8|(d[e+(n|1)|0]|0))&65535;c[o>>2]=q+1;if((r&256|0)!=0){im(a,b,e);i=h;return}q=(r&128|0)!=0;a2(b|0,42080,(x=i,i=i+56|0,c[x>>2]=q?53680:58240,c[x+8>>2]=39144,c[x+16>>2]=(q?-r|0:r)&255,c[x+24>>2]=(r&32768|0)!=0?32752:31024,c[x+32>>2]=r>>>12&7,c[x+40>>2]=(r&2048|0)!=0?43408:43080,c[x+48>>2]=1<<(r>>>9&3),x)|0)|0;if((r&1536|0)==0){i=h;return}r=a|0;c[r>>2]=c[r>>2]|128;i=h;return}else if((p|0)==4){if((g|0)==8){p=a+8|0;r=c[p>>2]|0;q=d[e+(r<<1|1)|0]|0;c[p>>2]=r+1;a2(b|0,52224,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=q,x)|0)|0;i=h;return}else if((g|0)==16){q=a+8|0;r=c[q>>2]|0;p=r<<1;o=((d[e+p|0]|0)<<8|(d[e+(p|1)|0]|0))&65535;c[q>>2]=r+1;a2(b|0,45504,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=o,x)|0)|0;i=h;return}else if((g|0)==32){g=a+8|0;a=c[g>>2]|0;o=a<<1;r=((d[e+o|0]|0)<<8|(d[e+(o|1)|0]|0))&65535;o=a+1|0;c[g>>2]=o;q=o<<1;o=((d[e+q|0]|0)<<8|(d[e+(q|1)|0]|0))&65535;c[g>>2]=a+2;a2(b|0,51552,(x=i,i=i+16|0,c[x>>2]=39144,c[x+8>>2]=o|r<<16,x)|0)|0;i=h;return}else{i=h;return}}else{a2(b|0,41792,(x=i,i=i+8|0,c[x>>2]=f&63,x)|0)|0;i=h;return}}else if((j|0)==4){a2(b|0,29072,(x=i,i=i+8|0,c[x>>2]=f&7,x)|0)|0;i=h;return}else{a2(b|0,41792,(x=i,i=i+8|0,c[x>>2]=f&63,x)|0)|0;i=h;return}}function il(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+32|0;h=g|0;j=d>>>0<8;k=j?d:d-8|0;d=j?31024:32752;if((c[f>>2]|0)==0){j=b+(u8(b|0)|0)|0;y=47;a[j]=y&255;y=y>>8;a[j+1|0]=y&255}if(e>>>0>2){j=h|0;l=e-1+k|0;a2(j|0,44928,(x=i,i=i+32|0,c[x>>2]=d,c[x+8>>2]=k,c[x+16>>2]=d,c[x+24>>2]=l,x)|0)|0;m=h|0;n=u9(b|0,m|0)|0;c[f>>2]=0;i=g;return}l=h|0;if((e|0)==2){e=k+1|0;a2(l|0,44600,(x=i,i=i+32|0,c[x>>2]=d,c[x+8>>2]=k,c[x+16>>2]=d,c[x+24>>2]=e,x)|0)|0;m=h|0;n=u9(b|0,m|0)|0;c[f>>2]=0;i=g;return}else{a2(l|0,35736,(x=i,i=i+16|0,c[x>>2]=d,c[x+8>>2]=k,x)|0)|0;m=h|0;n=u9(b|0,m|0)|0;c[f>>2]=0;i=g;return}}function im(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0;j=i;i=i+32|0;k=j|0;l=j+16|0;m=l|0;n=i;i=i+16|0;o=n|0;p=i;i=i+16|0;q=p|0;r=i;i=i+16|0;s=e[f+14>>1]|0;t=(s&64|0)==0;do{if((s&128|0)==0){u=e[f+12>>1]|0;v=k;if((u&56|0)==56){a[v]=a[41512]|0;a[v+1|0]=a[41513|0]|0;a[v+2|0]=a[41514|0]|0;break}else{w=u&7;a2(v|0,38624,(x=i,i=i+8|0,c[x>>2]=w,x)|0)|0;break}}else{b[k>>1]=45}}while(0);if(t){t=l;w=(s&32768|0)!=0?32752:31024;v=s>>>12&7;u=(s&2048|0)!=0?43408:43080;a2(t|0,41144,(x=i,i=i+24|0,c[x>>2]=w,c[x+8>>2]=v,c[x+16>>2]=u,x)|0)|0}else{b[m>>1]=45}m=s>>>9&3;u=r|0;if((m|0)==0){a[u]=0}else{r=1<<m;a2(u|0,40792,(x=i,i=i+8|0,c[x>>2]=r,x)|0)|0}r=s>>>4&3;if((r|0)==0|(r|0)==1){b[o>>1]=45}else if((r|0)==2){m=f+8|0;v=c[m>>2]|0;w=v<<1;t=((d[h+w|0]|0)<<8|(d[h+(w|1)|0]|0))&65535;c[m>>2]=v+1;v=(t&32768|0)!=0;if(v){y=-t&65535}else{y=t}a2(n|0,42776,(x=i,i=i+24|0,c[x>>2]=v?53680:58240,c[x+8>>2]=39144,c[x+16>>2]=y,x)|0)|0}else if((r|0)==3){r=f+8|0;y=c[r>>2]|0;v=y<<1;t=((d[h+v|0]|0)<<8|(d[h+(v|1)|0]|0))&65535;v=y+1|0;c[r>>2]=v;m=v<<1;v=((d[h+m|0]|0)<<8|(d[h+(m|1)|0]|0))&65535;c[r>>2]=y+2;y=v|t<<16;t=(y|0)<0;a2(n|0,40320,(x=i,i=i+24|0,c[x>>2]=t?53680:58240,c[x+8>>2]=39144,c[x+16>>2]=t?-y|0:y,x)|0)|0}y=s&3;if((y|0)==0|(y|0)==1){b[q>>1]=45}else if((y|0)==2){t=f+8|0;n=c[t>>2]|0;v=n<<1;r=((d[h+v|0]|0)<<8|(d[h+(v|1)|0]|0))&65535;c[t>>2]=n+1;n=(r&32768|0)!=0;if(n){z=-r&65535}else{z=r}a2(p|0,42776,(x=i,i=i+24|0,c[x>>2]=n?53680:58240,c[x+8>>2]=39144,c[x+16>>2]=z,x)|0)|0}else if((y|0)==3){y=f+8|0;z=c[y>>2]|0;n=z<<1;r=((d[h+n|0]|0)<<8|(d[h+(n|1)|0]|0))&65535;n=z+1|0;c[y>>2]=n;t=n<<1;n=((d[h+t|0]|0)<<8|(d[h+(t|1)|0]|0))&65535;c[y>>2]=z+2;z=n|r<<16;r=(z|0)<0;a2(p|0,40320,(x=i,i=i+24|0,c[x>>2]=r?53680:58240,c[x+8>>2]=39144,c[x+16>>2]=r?-z|0:z,x)|0)|0}if((s&4|0)==0){a2(g|0,39512,(x=i,i=i+40|0,c[x>>2]=k,c[x+8>>2]=o,c[x+16>>2]=l,c[x+24>>2]=u,c[x+32>>2]=q,x)|0)|0;A=f|0;B=c[A>>2]|0;C=B|128;c[A>>2]=C;i=j;return}else{a2(g|0,39832,(x=i,i=i+40|0,c[x>>2]=k,c[x+8>>2]=o,c[x+16>>2]=l,c[x+24>>2]=u,c[x+32>>2]=q,x)|0)|0;A=f|0;B=c[A>>2]|0;C=B|128;c[A>>2]=C;i=j;return}}function io(){var d=0,e=0,f=0,g=0,h=0;d=u0(4424)|0;e=d;if((d|0)==0){f=0;return f|0}g=d+188|0;u6(d|0,0,49);u6(d+52|0,0,28);a[g]=1;a[d+189|0]=2;c[d+192>>2]=0;c[d+252>>2]=0;a[d+256|0]=0;c[d+260>>2]=0;c[d+264>>2]=0;c[d+268>>2]=1;c[d+272>>2]=0;c[d+276>>2]=29504;u6(d+280|0,0,16);iy(e);b[d+148>>1]=8192;h=d+140|0;u6(d+80|0,0,64);if((a[g]|0)==0){c[h>>2]=0;c[d+156>>2]=0}else{c[d+152>>2]=0;c[h>>2]=0}c[d+144>>2]=0;u6(d+160|0,0,28);f=e;return f|0}function ip(a){a=a|0;c[a>>2]=0;iy(a);return}function iq(a){a=a|0;c[a>>2]=2;iy(a);return}function ir(a){a=a|0;c[a>>2]=7;li(a);return}function is(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=d+148|0;if(((b[f>>1]^e)&8192)==0){g=e&-22753;b[f>>1]=g;return}h=e&8192;i=d+188|0;j=d+140|0;k=c[j>>2]|0;if((a[i]|0)==0){l=d+152|0;c[l>>2]=k;m=l;n=d+156|0}else{l=d+156|0;c[l>>2]=k;m=d+152|0;n=l}c[j>>2]=c[(h<<16>>16!=0?n:m)>>2];a[i]=(h&65535)>>>13&255;g=e&-22753;b[f>>1]=g;return}function it(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;i=(a[g]|0)==37?g+1|0:g;if((aQ(i|0,48880)|0)==0){c[h>>2]=c[f+144>>2];j=0;return j|0}if((aQ(i|0,44768)|0)==0){c[h>>2]=c[f+180>>2];j=0;return j|0}g=a[i]|0;do{if(g<<24>>24==111){if((a[i+1|0]|0)!=112){break}k=a[i+2|0]|0;if((k-48&255)<10){l=i;m=0;n=k;while(1){o=(m*10|0)-48+(n<<24>>24)|0;p=a[l+3|0]|0;if((p-48&255)<10){l=l+1|0;m=o;n=p}else{break}}q=o<<1;r=p}else{q=0;r=k}if(r<<24>>24!=0){j=1;return j|0}n=(c[f+144>>2]|0)+q&16777215;m=n+1|0;if(m>>>0<(c[f+36>>2]|0)>>>0){l=c[f+32>>2]|0;s=d[l+n|0]<<8|d[l+m|0]}else{s=b6[c[f+12>>2]&63](c[f+4>>2]|0,n)|0}c[h>>2]=s&65535;j=0;return j|0}}while(0);if((aQ(i|0,41336)|0)==0){c[h>>2]=e[f+148>>1]|0;j=0;return j|0}if((aQ(i|0,38064)|0)==0){c[h>>2]=c[f+140>>2];j=0;return j|0}if((aQ(i|0,35192)|0)==0){c[h>>2]=b[f+148>>1]&255;j=0;return j|0}if((aQ(i|0,32232)|0)==0){c[h>>2]=c[((a[f+188|0]|0)==0?f+140|0:f+152|0)>>2];j=0;return j|0}if((aQ(i|0,30776)|0)==0){c[h>>2]=c[((a[f+188|0]|0)==0?f+156|0:f+140|0)>>2];j=0;return j|0}if((g<<24>>24|0)==100|(g<<24>>24|0)==68){t=100}else if((g<<24>>24|0)==97|(g<<24>>24|0)==65){t=97}else{j=1;return j|0}g=i+1|0;s=a[g]|0;if((s-48&255)<10){q=0;r=g;p=s;while(1){u=(q*10|0)-48+(p<<24>>24)|0;v=r+1|0;s=a[v]|0;if((s-48&255)<10){q=u;r=v;p=s}else{break}}w=r;x=u&7;y=v}else{w=i;x=0;y=g}if((t|0)==97){z=f+112+(x<<2)|0}else{z=f+80+(x<<2)|0}x=c[z>>2]|0;c[h>>2]=x;z=a[y]|0;if(z<<24>>24==46){y=a[w+2|0]|0;if((y|0)==98|(y|0)==66){c[h>>2]=x&255}else if((y|0)==119|(y|0)==87){c[h>>2]=x&65535}else if(!((y|0)==108|(y|0)==76)){j=1;return j|0}A=a[w+3|0]|0}else{A=z}j=A<<24>>24!=0|0;return j|0}function iu(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=(a[e]|0)==37?e+1|0:e;if((aQ(g|0,48880)|0)==0){c[d+144>>2]=f;h=0;return h|0}if((aQ(g|0,44768)|0)==0){c[d+180>>2]=f;h=0;return h|0}if((aQ(g|0,41336)|0)==0){e=f&65535;i=d+148|0;if(((b[i>>1]^e)&8192)!=0){j=e&8192;k=d+188|0;l=d+140|0;m=c[l>>2]|0;if((a[k]|0)==0){n=d+152|0;c[n>>2]=m;o=n;p=d+156|0}else{n=d+156|0;c[n>>2]=m;o=d+152|0;p=n}c[l>>2]=c[(j<<16>>16!=0?p:o)>>2];a[k]=(j&65535)>>>13&255}b[i>>1]=e&-22753;h=0;return h|0}if((aQ(g|0,38064)|0)==0){c[d+140>>2]=f;h=0;return h|0}if((aQ(g|0,35192)|0)==0){e=d+148|0;b[e>>1]=b[e>>1]&-256|f&255;h=0;return h|0}if((aQ(g|0,32232)|0)==0){if((a[d+188|0]|0)==0){c[d+140>>2]=f;h=0;return h|0}else{c[d+152>>2]=f;h=0;return h|0}}if((aQ(g|0,30776)|0)==0){if((a[d+188|0]|0)==0){c[d+156>>2]=f;h=0;return h|0}else{c[d+140>>2]=f;h=0;return h|0}}e=a[g]|0;if((e<<24>>24|0)==100|(e<<24>>24|0)==68){q=100}else if((e<<24>>24|0)==97|(e<<24>>24|0)==65){q=97}else{h=1;return h|0}e=g+1|0;i=a[e]|0;if((i-48&255)<10){j=0;k=e;e=i;while(1){r=(j*10|0)-48+(e<<24>>24)|0;o=k+1|0;s=a[o]|0;if((s-48&255)<10){j=r;k=o;e=s}else{break}}t=k;u=r&7;v=s}else{t=g;u=0;v=i}if(v<<24>>24==46){i=a[t+2|0]|0;if((i|0)==119|(i|0)==87){w=65535}else if((i|0)==108|(i|0)==76){w=-1}else if((i|0)==98|(i|0)==66){w=255}else{h=1;return h|0}x=w;y=a[t+3|0]|0}else{x=-1;y=v}if(y<<24>>24!=0){h=1;return h|0}if((q|0)==97){q=d+112+(u<<2)|0;c[q>>2]=c[q>>2]&~x|x&f;h=0;return h|0}else{q=d+80+(u<<2)|0;c[q>>2]=c[q>>2]&~x|x&f;h=0;return h|0}return 0}function iv(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;c[e+272>>2]=0;c[e+276>>2]=29848;f=e+148|0;g=b[f>>1]|0;h=g&1823|8192;if((g&8192)==0){g=e+188|0;i=e+140|0;j=c[i>>2]|0;if((a[g]|0)==0){c[e+152>>2]=j;k=c[e+156>>2]|0}else{c[e+156>>2]=j;k=j}c[i>>2]=k;a[g]=1}b[f>>1]=h;h=e+36|0;f=c[h>>2]|0;if(f>>>0>3){g=c[e+32>>2]|0;l=((d[g]<<8|d[g+1|0])<<8|d[g+2|0])<<8|d[g+3|0];m=f}else{f=b6[c[e+16>>2]&63](c[e+4>>2]|0,0)|0;l=f;m=c[h>>2]|0}c[e+140>>2]=l;if(m>>>0>7){m=c[e+32>>2]|0;n=((d[m+4|0]<<8|d[m+5|0])<<8|d[m+6|0])<<8|d[m+7|0];o=e+144|0;c[o>>2]=n;p=e+268|0;q=c[p>>2]|0;r=q+64|0;c[p>>2]=r;return}else{n=b6[c[e+16>>2]&63](c[e+4>>2]|0,4)|0;o=e+144|0;c[o>>2]=n;p=e+268|0;q=c[p>>2]|0;r=q+64|0;c[p>>2]=r;return}}function iw(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;iz(d,3,8,28880);h=b[d+196>>1]|0;i=d+140|0;j=c[i>>2]|0;k=j-2|0;l=k&16777215;m=l+1|0;n=d+36|0;if(m>>>0<(c[n>>2]|0)>>>0){o=d+32|0;a[(c[o>>2]|0)+l|0]=(h&65535)>>>8&255;a[(c[o>>2]|0)+m|0]=h&255}else{b3[c[d+24>>2]&63](c[d+4>>2]|0,l,h)}c[i>>2]=k;k=j-6|0;h=k&16777215;l=h+3|0;if(l>>>0<(c[n>>2]|0)>>>0){m=d+32|0;a[(c[m>>2]|0)+h|0]=e>>>24&255;a[(c[m>>2]|0)+(h+1)|0]=e>>>16&255;a[(c[m>>2]|0)+(h+2)|0]=e>>>8&255;a[(c[m>>2]|0)+l|0]=e&255}else{b3[c[d+28>>2]&63](c[d+4>>2]|0,h,e)}c[i>>2]=k;k=(g|0)==0?16:0;g=(f|0)==0?k:k|8;k=j-8|0;j=k&16777215;f=j+1|0;if(f>>>0<(c[n>>2]|0)>>>0){n=d+32|0;a[(c[n>>2]|0)+j|0]=0;a[(c[n>>2]|0)+f|0]=g&255;c[i>>2]=k;p=d+268|0;q=c[p>>2]|0;r=q+64|0;c[p>>2]=r;return}else{b3[c[d+24>>2]&63](c[d+4>>2]|0,j,g);c[i>>2]=k;p=d+268|0;q=c[p>>2]|0;r=q+64|0;c[p>>2]=r;return}}function ix(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0;do{if((d|0)!=0){g=b+189|0;a[g]=a[g]&-2;if((d|0)!=7){break}if((c[b+252>>2]|0)==7){break}a[b+256|0]=1}}while(0);c[b+252>>2]=d;c[b+260>>2]=e;c[b+264>>2]=f;return}function iy(a){a=a|0;var b=0,d=0;b=0;do{d=c[15912+(b<<2)>>2]|0;c[a+296+(b<<2)>>2]=(d|0)==0?302:d;b=b+1|0;}while(b>>>0<1024);c[a+4392>>2]=302;c[a+4396>>2]=222;c[a+4400>>2]=222;c[a+4404>>2]=222;c[a+4408>>2]=222;c[a+4412>>2]=222;c[a+4416>>2]=222;c[a+4420>>2]=222;return}function iz(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;i=f&255;c[e+272>>2]=i;c[e+276>>2]=h;h=c[e+72>>2]|0;if((h|0)!=0){b1[h&511](c[e+60>>2]|0,i)}h=e+148|0;f=b[h>>1]|0;j=f&1823|8192;if((f&8192)==0){k=e+188|0;l=e+140|0;m=c[l>>2]|0;if((a[k]|0)==0){c[e+152>>2]=m;n=c[e+156>>2]|0}else{c[e+156>>2]=m;n=m}c[l>>2]=n;a[k]=1}b[h>>1]=j;if((c[e>>2]&2|0)==0){o=c[e+140>>2]|0;p=e+36|0}else{j=i<<2;h=(g<<12|j)&65535;g=e+140|0;k=(c[g>>2]|0)-2|0;n=k&16777215;l=n+1|0;m=e+36|0;if(l>>>0<(c[m>>2]|0)>>>0){q=e+32|0;a[(c[q>>2]|0)+n|0]=(h&65535)>>>8&255;a[(c[q>>2]|0)+l|0]=j&255}else{b3[c[e+24>>2]&63](c[e+4>>2]|0,n,h)}c[g>>2]=k;o=k;p=m}m=e+144|0;k=c[m>>2]|0;g=e+140|0;h=o-4|0;n=h&16777215;j=n+3|0;if(j>>>0<(c[p>>2]|0)>>>0){l=e+32|0;a[(c[l>>2]|0)+n|0]=k>>>24&255;a[(c[l>>2]|0)+(n+1)|0]=k>>>16&255;a[(c[l>>2]|0)+(n+2)|0]=k>>>8&255;a[(c[l>>2]|0)+j|0]=k&255}else{b3[c[e+28>>2]&63](c[e+4>>2]|0,n,k)}c[g>>2]=h;h=o-6|0;o=h&16777215;k=o+1|0;if(k>>>0<(c[p>>2]|0)>>>0){n=e+32|0;a[(c[n>>2]|0)+o|0]=(f&65535)>>>8&255;a[(c[n>>2]|0)+k|0]=f&255}else{b3[c[e+24>>2]&63](c[e+4>>2]|0,o,f)}c[g>>2]=h;h=(c[e+160>>2]|0)+(i<<2)&16777215;i=h+3|0;if(i>>>0<(c[p>>2]|0)>>>0){p=c[e+32>>2]|0;r=((d[p+h|0]<<8|d[p+(h+1)|0])<<8|d[p+(h+2)|0])<<8|d[p+i|0];c[m>>2]=r;return}else{r=b6[c[e+16>>2]&63](c[e+4>>2]|0,h)|0;c[m>>2]=r;return}}function iA(a){a=a|0;var b=0;b=c[a+68>>2]|0;if((b|0)!=0){b1[b&511](c[a+60>>2]|0,e[a+196>>1]|0)}iz(a,4,0,54760);b=a+268|0;c[b>>2]=(c[b>>2]|0)+62;return}function iB(a){a=a|0;var b=0;iz(a,5,0,53528);b=a+268|0;c[b>>2]=(c[b>>2]|0)+66;return}function iC(a){a=a|0;var b=0;iz(a,6,0,52768);b=a+268|0;c[b>>2]=(c[b>>2]|0)+68;return}function iD(a){a=a|0;var b=0;iz(a,7,0,52080);b=a+268|0;c[b>>2]=(c[b>>2]|0)+68;return}function iE(a){a=a|0;var b=0;iz(a,8,0,51456);b=a+268|0;c[b>>2]=(c[b>>2]|0)+62;return}function iF(a){a=a|0;var b=0;iz(a,10,0,50664);b=a+268|0;c[b>>2]=(c[b>>2]|0)+62;return}function iG(a){a=a|0;var b=0;iz(a,11,0,50024);b=a+268|0;c[b>>2]=(c[b>>2]|0)+62;return}function iH(a){a=a|0;var b=0;iz(a,14,0,49520);b=a+268|0;c[b>>2]=(c[b>>2]|0)+62;return}function iI(a,b){a=a|0;b=b|0;iz(a,b+32|0,0,48552);b=a+268|0;c[b>>2]=(c[b>>2]|0)+62;return}function iJ(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=d+48|0;if((a[e]|0)!=0){return}a[e]=1;f=d+44|0;g=c[f>>2]|0;if((g|0)!=0){b1[g&511](c[d+40>>2]|0,1)}g=d+148|0;h=d+188|0;i=a[h]|0;do{if((b[g>>1]&8192)==0){j=d+140|0;k=c[j>>2]|0;if(i<<24>>24==0){c[d+152>>2]=k}else{c[d+156>>2]=k}a[h]=1;b[g>>1]=8192;u6(d+80|0,0,60);c[j>>2]=0;l=j;m=3528}else{j=d+140|0;b[g>>1]=8192;u6(d+80|0,0,60);c[j>>2]=0;if(i<<24>>24!=0){l=j;m=3528;break}c[j>>2]=0;c[d+156>>2]=0}}while(0);if((m|0)==3528){c[d+152>>2]=0;c[l>>2]=0}a[d+189|0]=0;u6(d+160|0,0,16);iv(d);if((a[e]|0)==0){return}a[e]=0;e=c[f>>2]|0;if((e|0)==0){return}b1[e&511](c[d+40>>2]|0,0);return}function iK(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=f+144|0;h=c[g>>2]|0;c[f+180>>2]=h;if((h&1|0)==0){i=h}else{iw(f,h,0,0);i=c[g>>2]|0}h=i&16777215;i=h+1|0;if(i>>>0<(c[f+36>>2]|0)>>>0){j=c[f+32>>2]|0;k=d[j+h|0]<<8|d[j+i|0]}else{k=b6[c[f+12>>2]&63](c[f+4>>2]|0,h)|0}h=f+196|0;b[h>>1]=k;c[f+192>>2]=1;i=c[f+64>>2]|0;if((i|0)==0){l=k}else{b1[i&511](c[f+60>>2]|0,k&65535);l=b[h>>1]|0}h=b_[c[f+296+((l&65535)>>>6<<2)>>2]&511](f)|0;c[g>>2]=(c[g>>2]|0)+(h<<1);h=f+280|0;g=vf(c[h>>2]|0,c[h+4>>2]|0,1,0)|0;c[h>>2]=g;c[h+4>>2]=G;h=f+256|0;if((a[h]|0)!=0){iz(f,31,0,49024);g=f+148|0;b[g>>1]=b[g>>1]|1792;g=f+268|0;c[g>>2]=(c[g>>2]|0)+62;a[h]=0;return}h=c[f+252>>2]|0;if((h|0)==0){return}g=f+148|0;if(((e[g>>1]|0)>>>8&7)>>>0>=h>>>0){return}if((c[f+264>>2]|0)==0){iz(f,c[f+260>>2]|0,0,48112);b[g>>1]=(b[g>>1]&-1793&65535|h<<8&1792)&65535;l=f+268|0;c[l>>2]=(c[l>>2]|0)+62;return}else{iz(f,h+24|0,0,49024);b[g>>1]=(b[g>>1]&-1793&65535|h<<8&1792)&65535;h=f+268|0;c[h>>2]=(c[h>>2]|0)+62;return}}function iL(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;f=b+268|0;g=b+288|0;h=b+189|0;j=d;d=c[f>>2]|0;while(1){if(j>>>0<d>>>0){k=j;l=d;break}m=j-d|0;n=vf(c[g>>2]|0,c[g+4>>2]|0,d,0)|0;c[g>>2]=n;c[g+4>>2]=G;c[f>>2]=0;if((a[h]|0)!=0){o=3566;break}iK(b);n=c[f>>2]|0;if((n|0)==0){o=3562;break}else{j=m;d=n}}if((o|0)==3566){i=e;return}else if((o|0)==3562){bN(c[q>>2]|0,47312,(x=i,i=i+8|0,c[x>>2]=c[b+144>>2],x)|0)|0;ay(c[q>>2]|0)|0;k=m;l=c[f>>2]|0}m=vf(c[g>>2]|0,c[g+4>>2]|0,k,0)|0;c[g>>2]=m;c[g+4>>2]=G;c[f>>2]=l-k;i=e;return}function iM(a){a=a|0;var b=0;iA(a);b=a+268|0;c[b>>2]=(c[b>>2]|0)+2;return 0}function iN(a){a=a|0;var d=0,f=0,g=0;d=a+196|0;f=b[d>>1]&63;if((b5[c[20008+(f<<2)>>2]&127](a,f,2020,32)|0)!=0){g=0;return g|0}if((c[a+228>>2]|0)==2){c[a+112+(((e[d>>1]|0)>>>9&7)<<2)>>2]=c[a+232>>2];d=a+268|0;c[d>>2]=(c[d>>2]|0)+4;g=c[a+192>>2]|0;return g|0}else{iA(a);g=0;return g|0}return 0}function iO(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+8|0;g=f|0;h=e+196|0;j=b[h>>1]|0;k=(c[e+144>>2]|0)+2&16777215;l=k+1|0;m=l>>>0<(c[e+36>>2]|0)>>>0;if((j&63)==60){if(m){n=c[e+32>>2]|0;o=(d[n+k|0]|0)<<8|(d[n+l|0]|0)}else{o=b6[c[e+12>>2]&63](c[e+4>>2]|0,k)|0}b[e+198>>1]=o;c[e+192>>2]=2;n=e+148|0;p=b[n>>1]|0;b[n>>1]=(p|o)&31|p&-256;p=e+268|0;c[p>>2]=(c[p>>2]|0)+20;q=2;i=f;return q|0}if(m){m=c[e+32>>2]|0;r=(d[m+k|0]|0)<<8|(d[m+l|0]|0);s=j}else{j=b6[c[e+12>>2]&63](c[e+4>>2]|0,k)|0;r=j;s=b[h>>1]|0}b[e+198>>1]=r;h=e+192|0;c[h>>2]=2;j=s&63;if((b5[c[20008+(j<<2)>>2]&127](e,j,509,8)|0)!=0){q=0;i=f;return q|0}if((mm(e,g)|0)!=0){q=0;i=f;return q|0}j=a[g]|r&255;if((mp(e,j)|0)!=0){q=0;i=f;return q|0}lM(e,15,j);j=e+268|0;c[j>>2]=(c[j>>2]|0)+8;q=c[h>>2]|0;i=f;return q|0}function iP(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+8|0;g=f|0;h=e+196|0;j=b[h>>1]|0;if((j&63)==60){if((a[e+188|0]|0)==0){iE(e);k=0;i=f;return k|0}l=(c[e+144>>2]|0)+2&16777215;m=l+1|0;if(m>>>0<(c[e+36>>2]|0)>>>0){n=c[e+32>>2]|0;o=d[n+l|0]<<8|d[n+m|0]}else{o=b6[c[e+12>>2]&63](c[e+4>>2]|0,l)|0}b[e+198>>1]=o;c[e+192>>2]=2;is(e,(b[e+148>>1]|o)&-22753);o=e+268|0;c[o>>2]=(c[o>>2]|0)+20;k=2;i=f;return k|0}o=(c[e+144>>2]|0)+2&16777215;l=o+1|0;if(l>>>0<(c[e+36>>2]|0)>>>0){m=c[e+32>>2]|0;p=d[m+o|0]<<8|d[m+l|0];q=j}else{j=b6[c[e+12>>2]&63](c[e+4>>2]|0,o)|0;p=j;q=b[h>>1]|0}b[e+198>>1]=p;h=e+192|0;c[h>>2]=2;j=q&63;if((b5[c[20008+(j<<2)>>2]&127](e,j,509,16)|0)!=0){k=0;i=f;return k|0}if((mn(e,g)|0)!=0){k=0;i=f;return k|0}j=b[g>>1]|p;if((mq(e,j)|0)!=0){k=0;i=f;return k|0}lN(e,15,j);j=e+268|0;c[j>>2]=(c[j>>2]|0)+8;k=c[h>>2]|0;i=f;return k|0}function iQ(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+8|0;f=e|0;g=a+144|0;h=c[g>>2]|0;j=h+2&16777215;k=j+1|0;l=a+36|0;m=c[l>>2]|0;if(k>>>0<m>>>0){n=c[a+32>>2]|0;o=(d[n+j|0]|0)<<8|(d[n+k|0]|0);p=h;q=m}else{m=b6[c[a+12>>2]&63](c[a+4>>2]|0,j)|0;o=m;p=c[g>>2]|0;q=c[l>>2]|0}l=a+198|0;b[l>>1]=o;g=a+192|0;c[g>>2]=2;m=p+4&16777215;p=m+1|0;if(p>>>0<q>>>0){q=c[a+32>>2]|0;r=(d[q+m|0]|0)<<8|(d[q+p|0]|0);s=o}else{o=b6[c[a+12>>2]&63](c[a+4>>2]|0,m)|0;r=o;s=b[l>>1]|0}b[a+200>>1]=r;c[g>>2]=3;l=b[a+196>>1]&63;if((b5[c[20008+(l<<2)>>2]&127](a,l,509,32)|0)!=0){t=0;i=e;return t|0}if((mo(a,f)|0)!=0){t=0;i=e;return t|0}l=(s&65535)<<16|r&65535|c[f>>2];if((mr(a,l)|0)!=0){t=0;i=e;return t|0}lO(a,15,l);l=a+268|0;c[l>>2]=(c[l>>2]|0)+16;t=c[g>>2]|0;i=e;return t|0}function iR(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;i=i+8|0;h=g|0;j=f+196|0;k=b[j>>1]|0;l=k&65535;m=l&56;if((m|0)==8){n=(c[f+144>>2]|0)+2&16777215;o=n+1|0;p=f+36|0;q=c[p>>2]|0;if(o>>>0<q>>>0){r=c[f+32>>2]|0;s=(d[r+n|0]|0)<<8|(d[r+o|0]|0);t=q;u=k}else{k=b6[c[f+12>>2]&63](c[f+4>>2]|0,n)|0;s=k;t=c[p>>2]|0;u=b[j>>1]|0}b[f+198>>1]=s;c[f+192>>2]=2;k=s&65535;s=((k&32768|0)!=0?k|-65536:k)+(c[f+112+((u&7)<<2)>>2]|0)|0;u=s&16777215;if(u>>>0<t>>>0){v=a[(c[f+32>>2]|0)+u|0]|0;w=t}else{t=b6[c[f+8>>2]&63](c[f+4>>2]|0,u)|0;v=t;w=c[p>>2]|0}p=s+2&16777215;if(p>>>0<w>>>0){x=a[(c[f+32>>2]|0)+p|0]|0}else{x=b6[c[f+8>>2]&63](c[f+4>>2]|0,p)|0}p=f+80+(((e[j>>1]|0)>>>9&7)<<2)|0;c[p>>2]=c[p>>2]&-65536|(x&255|(v&255)<<8)&65535;v=f+268|0;c[v>>2]=(c[v>>2]|0)+16;y=2;i=g;return y|0}else if((m|0)==0){m=f+148|0;v=b[m>>1]|0;b[m>>1]=(1<<(c[f+80+((l>>>9&7)<<2)>>2]&31)&c[f+80+((l&7)<<2)>>2]|0)==0?v|4:v&-5;v=f+268|0;c[v>>2]=(c[v>>2]|0)+6;y=1;i=g;return y|0}else{v=l&63;if((b5[c[20008+(v<<2)>>2]&127](f,v,4092,8)|0)!=0){y=0;i=g;return y|0}if((mm(f,h)|0)!=0){y=0;i=g;return y|0}v=f+148|0;l=b[v>>1]|0;b[v>>1]=(1<<(c[f+80+(((e[j>>1]|0)>>>9&7)<<2)>>2]&7)&(d[h]|0)|0)==0?l|4:l&-5;l=f+268|0;c[l>>2]=(c[l>>2]|0)+4;y=c[f+192>>2]|0;i=g;return y|0}return 0}function iS(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=i;i=i+8|0;h=g|0;j=f+196|0;k=b[j>>1]|0;l=k&65535;m=l>>>3&7;if((m|0)==1){n=(c[f+144>>2]|0)+2&16777215;o=n+1|0;p=f+36|0;q=c[p>>2]|0;if(o>>>0<q>>>0){r=c[f+32>>2]|0;s=(d[r+n|0]|0)<<8|(d[r+o|0]|0);t=q;u=k}else{k=b6[c[f+12>>2]&63](c[f+4>>2]|0,n)|0;s=k;t=c[p>>2]|0;u=b[j>>1]|0}b[f+198>>1]=s;c[f+192>>2]=2;k=s&65535;s=((k&32768|0)!=0?k|-65536:k)+(c[f+112+((u&7)<<2)>>2]|0)|0;u=s&16777215;if(u>>>0<t>>>0){v=a[(c[f+32>>2]|0)+u|0]|0;w=t}else{t=b6[c[f+8>>2]&63](c[f+4>>2]|0,u)|0;v=t;w=c[p>>2]|0}t=s+2&16777215;if(t>>>0<w>>>0){x=a[(c[f+32>>2]|0)+t|0]|0;y=w}else{w=b6[c[f+8>>2]&63](c[f+4>>2]|0,t)|0;x=w;y=c[p>>2]|0}w=s+4&16777215;if(w>>>0<y>>>0){z=a[(c[f+32>>2]|0)+w|0]|0;A=y}else{y=b6[c[f+8>>2]&63](c[f+4>>2]|0,w)|0;z=y;A=c[p>>2]|0}p=s+6&16777215;if(p>>>0<A>>>0){B=a[(c[f+32>>2]|0)+p|0]|0}else{B=b6[c[f+8>>2]&63](c[f+4>>2]|0,p)|0}c[f+80+(((e[j>>1]|0)>>>9&7)<<2)>>2]=B&255|(z&255|(x&255|(v&255)<<8)<<8)<<8;v=f+268|0;c[v>>2]=(c[v>>2]|0)+24;C=2;i=g;return C|0}else if((m|0)==0){m=f+80+((l&7)<<2)|0;v=c[m>>2]|0;x=1<<(c[f+80+((l>>>9&7)<<2)>>2]&31);c[m>>2]=x^v;m=f+148|0;z=b[m>>1]|0;b[m>>1]=(x&v|0)==0?z|4:z&-5;z=f+268|0;c[z>>2]=(c[z>>2]|0)+8;C=1;i=g;return C|0}else{z=l&63;if((b5[c[20008+(z<<2)>>2]&127](f,z,508,8)|0)!=0){C=0;i=g;return C|0}if((mm(f,h)|0)!=0){C=0;i=g;return C|0}z=1<<(c[f+80+(((e[j>>1]|0)>>>9&7)<<2)>>2]&7);if((mp(f,((d[h]|0)^z)&255)|0)!=0){C=0;i=g;return C|0}j=f+148|0;l=b[j>>1]|0;b[j>>1]=(z&(d[h]|0)|0)==0?l|4:l&-5;l=f+268|0;c[l>>2]=(c[l>>2]|0)+8;C=c[f+192>>2]|0;i=g;return C|0}return 0}function iT(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+8|0;h=g|0;j=f+196|0;k=b[j>>1]|0;l=k&65535;m=l>>>3&7;if((m|0)==1){n=(c[f+144>>2]|0)+2&16777215;o=n+1|0;p=f+36|0;q=c[p>>2]|0;if(o>>>0<q>>>0){r=c[f+32>>2]|0;s=(d[r+n|0]|0)<<8|(d[r+o|0]|0);t=q;u=k}else{k=b6[c[f+12>>2]&63](c[f+4>>2]|0,n)|0;s=k;t=c[p>>2]|0;u=b[j>>1]|0}b[f+198>>1]=s;c[f+192>>2]=2;k=u&65535;u=s&65535;s=((u&32768|0)!=0?u|-65536:u)+(c[f+112+((k&7)<<2)>>2]|0)|0;u=c[f+80+((k>>>9&7)<<2)>>2]|0;k=u>>>8&255;n=s&16777215;if(n>>>0<t>>>0){a[(c[f+32>>2]|0)+n|0]=k}else{b3[c[f+20>>2]&63](c[f+4>>2]|0,n,k)}k=u&255;u=s+2&16777215;if(u>>>0<(c[p>>2]|0)>>>0){a[(c[f+32>>2]|0)+u|0]=k}else{b3[c[f+20>>2]&63](c[f+4>>2]|0,u,k)}k=f+268|0;c[k>>2]=(c[k>>2]|0)+16;v=2;i=g;return v|0}else if((m|0)==0){m=f+80+((l&7)<<2)|0;k=c[m>>2]|0;u=1<<(c[f+80+((l>>>9&7)<<2)>>2]&31);c[m>>2]=k&~u;m=f+148|0;p=b[m>>1]|0;b[m>>1]=(u&k|0)==0?p|4:p&-5;p=f+268|0;c[p>>2]=(c[p>>2]|0)+10;v=1;i=g;return v|0}else{p=l&63;if((b5[c[20008+(p<<2)>>2]&127](f,p,508,8)|0)!=0){v=0;i=g;return v|0}if((mm(f,h)|0)!=0){v=0;i=g;return v|0}p=1<<(c[f+80+(((e[j>>1]|0)>>>9&7)<<2)>>2]&7);if((mp(f,(p^255)&(d[h]|0)&255)|0)!=0){v=0;i=g;return v|0}j=f+148|0;l=b[j>>1]|0;b[j>>1]=(p&(d[h]|0)|0)==0?l|4:l&-5;l=f+268|0;c[l>>2]=(c[l>>2]|0)+8;v=c[f+192>>2]|0;i=g;return v|0}return 0}function iU(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+8|0;h=g|0;j=f+196|0;k=b[j>>1]|0;l=k&65535;m=l>>>3&7;if((m|0)==0){n=f+80+((l&7)<<2)|0;o=c[n>>2]|0;p=1<<(c[f+80+((l>>>9&7)<<2)>>2]&31);c[n>>2]=p|o;n=f+148|0;q=b[n>>1]|0;b[n>>1]=(p&o|0)==0?q|4:q&-5;q=f+268|0;c[q>>2]=(c[q>>2]|0)+8;r=1;i=g;return r|0}else if((m|0)==1){m=(c[f+144>>2]|0)+2&16777215;q=m+1|0;o=f+36|0;p=c[o>>2]|0;if(q>>>0<p>>>0){n=c[f+32>>2]|0;s=(d[n+m|0]|0)<<8|(d[n+q|0]|0);t=p;u=k}else{k=b6[c[f+12>>2]&63](c[f+4>>2]|0,m)|0;s=k;t=c[o>>2]|0;u=b[j>>1]|0}b[f+198>>1]=s;c[f+192>>2]=2;k=u&65535;u=s&65535;s=((u&32768|0)!=0?u|-65536:u)+(c[f+112+((k&7)<<2)>>2]|0)|0;u=c[f+80+((k>>>9&7)<<2)>>2]|0;k=u>>>24&255;m=s&16777215;if(m>>>0<t>>>0){a[(c[f+32>>2]|0)+m|0]=k}else{b3[c[f+20>>2]&63](c[f+4>>2]|0,m,k)}k=u>>>16&255;m=s+2&16777215;if(m>>>0<(c[o>>2]|0)>>>0){a[(c[f+32>>2]|0)+m|0]=k}else{b3[c[f+20>>2]&63](c[f+4>>2]|0,m,k)}k=u>>>8&255;m=s+4&16777215;if(m>>>0<(c[o>>2]|0)>>>0){a[(c[f+32>>2]|0)+m|0]=k}else{b3[c[f+20>>2]&63](c[f+4>>2]|0,m,k)}k=u&255;u=s+6&16777215;if(u>>>0<(c[o>>2]|0)>>>0){a[(c[f+32>>2]|0)+u|0]=k}else{b3[c[f+20>>2]&63](c[f+4>>2]|0,u,k)}k=f+268|0;c[k>>2]=(c[k>>2]|0)+24;r=2;i=g;return r|0}else{k=l&63;if((b5[c[20008+(k<<2)>>2]&127](f,k,508,8)|0)!=0){r=0;i=g;return r|0}if((mm(f,h)|0)!=0){r=0;i=g;return r|0}k=1<<(c[f+80+(((e[j>>1]|0)>>>9&7)<<2)>>2]&7);if((mp(f,(d[h]|0|k)&255)|0)!=0){r=0;i=g;return r|0}j=f+148|0;l=b[j>>1]|0;b[j>>1]=(k&(d[h]|0)|0)==0?l|4:l&-5;l=f+268|0;c[l>>2]=(c[l>>2]|0)+8;r=c[f+192>>2]|0;i=g;return r|0}return 0}function iV(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+8|0;g=f|0;h=e+196|0;j=b[h>>1]|0;k=(c[e+144>>2]|0)+2&16777215;l=k+1|0;m=l>>>0<(c[e+36>>2]|0)>>>0;if((j&63)==60){if(m){n=c[e+32>>2]|0;o=(d[n+k|0]|0)<<8|(d[n+l|0]|0)}else{o=b6[c[e+12>>2]&63](c[e+4>>2]|0,k)|0}b[e+198>>1]=o;c[e+192>>2]=2;n=e+148|0;b[n>>1]=(o&31|-256)&b[n>>1];n=e+268|0;c[n>>2]=(c[n>>2]|0)+20;p=2;i=f;return p|0}if(m){m=c[e+32>>2]|0;q=(d[m+k|0]|0)<<8|(d[m+l|0]|0);r=j}else{j=b6[c[e+12>>2]&63](c[e+4>>2]|0,k)|0;q=j;r=b[h>>1]|0}b[e+198>>1]=q;h=e+192|0;c[h>>2]=2;j=r&63;if((b5[c[20008+(j<<2)>>2]&127](e,j,509,8)|0)!=0){p=0;i=f;return p|0}if((mm(e,g)|0)!=0){p=0;i=f;return p|0}j=a[g]&(q&255);if((mp(e,j)|0)!=0){p=0;i=f;return p|0}lM(e,15,j);j=e+268|0;c[j>>2]=(c[j>>2]|0)+8;p=c[h>>2]|0;i=f;return p|0}function iW(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+8|0;g=f|0;h=e+196|0;j=b[h>>1]|0;if((j&63)==60){if((a[e+188|0]|0)==0){iE(e);k=0;i=f;return k|0}l=(c[e+144>>2]|0)+2&16777215;m=l+1|0;if(m>>>0<(c[e+36>>2]|0)>>>0){n=c[e+32>>2]|0;o=d[n+l|0]<<8|d[n+m|0]}else{o=b6[c[e+12>>2]&63](c[e+4>>2]|0,l)|0}b[e+198>>1]=o;c[e+192>>2]=2;is(e,b[e+148>>1]&o);o=e+268|0;c[o>>2]=(c[o>>2]|0)+20;k=2;i=f;return k|0}o=(c[e+144>>2]|0)+2&16777215;l=o+1|0;if(l>>>0<(c[e+36>>2]|0)>>>0){m=c[e+32>>2]|0;p=d[m+o|0]<<8|d[m+l|0];q=j}else{j=b6[c[e+12>>2]&63](c[e+4>>2]|0,o)|0;p=j;q=b[h>>1]|0}b[e+198>>1]=p;h=e+192|0;c[h>>2]=2;j=q&63;if((b5[c[20008+(j<<2)>>2]&127](e,j,509,16)|0)!=0){k=0;i=f;return k|0}if((mn(e,g)|0)!=0){k=0;i=f;return k|0}j=b[g>>1]&p;if((mq(e,j)|0)!=0){k=0;i=f;return k|0}lN(e,15,j);j=e+268|0;c[j>>2]=(c[j>>2]|0)+8;k=c[h>>2]|0;i=f;return k|0}function iX(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+8|0;f=e|0;g=a+144|0;h=c[g>>2]|0;j=h+2&16777215;k=j+1|0;l=a+36|0;m=c[l>>2]|0;if(k>>>0<m>>>0){n=c[a+32>>2]|0;o=(d[n+j|0]|0)<<8|(d[n+k|0]|0);p=h;q=m}else{m=b6[c[a+12>>2]&63](c[a+4>>2]|0,j)|0;o=m;p=c[g>>2]|0;q=c[l>>2]|0}l=a+198|0;b[l>>1]=o;g=a+192|0;c[g>>2]=2;m=p+4&16777215;p=m+1|0;if(p>>>0<q>>>0){q=c[a+32>>2]|0;r=(d[q+m|0]|0)<<8|(d[q+p|0]|0);s=o}else{o=b6[c[a+12>>2]&63](c[a+4>>2]|0,m)|0;r=o;s=b[l>>1]|0}b[a+200>>1]=r;c[g>>2]=3;l=b[a+196>>1]&63;if((b5[c[20008+(l<<2)>>2]&127](a,l,509,32)|0)!=0){t=0;i=e;return t|0}if((mo(a,f)|0)!=0){t=0;i=e;return t|0}l=c[f>>2]&((s&65535)<<16|r&65535);if((mr(a,l)|0)!=0){t=0;i=e;return t|0}lO(a,15,l);l=a+268|0;c[l>>2]=(c[l>>2]|0)+16;t=c[g>>2]|0;i=e;return t|0}function iY(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+8|0;g=f|0;h=(c[e+144>>2]|0)+2&16777215;j=h+1|0;if(j>>>0<(c[e+36>>2]|0)>>>0){k=c[e+32>>2]|0;l=(d[k+h|0]|0)<<8|(d[k+j|0]|0)}else{l=b6[c[e+12>>2]&63](c[e+4>>2]|0,h)|0}b[e+198>>1]=l;h=e+192|0;c[h>>2]=2;j=l&255;l=b[e+196>>1]&63;if((b5[c[20008+(l<<2)>>2]&127](e,l,509,8)|0)!=0){m=0;i=f;return m|0}if((mm(e,g)|0)!=0){m=0;i=f;return m|0}l=(a[g]|0)-j&255;if((mp(e,l)|0)!=0){m=0;i=f;return m|0}l1(e,l,j,a[g]|0);g=e+268|0;c[g>>2]=(c[g>>2]|0)+8;m=c[h>>2]|0;i=f;return m|0}function iZ(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+8|0;f=e|0;g=(c[a+144>>2]|0)+2&16777215;h=g+1|0;if(h>>>0<(c[a+36>>2]|0)>>>0){j=c[a+32>>2]|0;k=(d[j+g|0]|0)<<8|(d[j+h|0]|0)}else{k=b6[c[a+12>>2]&63](c[a+4>>2]|0,g)|0}b[a+198>>1]=k;g=a+192|0;c[g>>2]=2;h=b[a+196>>1]&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,509,16)|0)!=0){l=0;i=e;return l|0}if((mn(a,f)|0)!=0){l=0;i=e;return l|0}h=(b[f>>1]|0)-k&65535;if((mq(a,h)|0)!=0){l=0;i=e;return l|0}l2(a,h,k,b[f>>1]|0);f=a+268|0;c[f>>2]=(c[f>>2]|0)+8;l=c[g>>2]|0;i=e;return l|0}function i_(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+8|0;f=e|0;g=a+144|0;h=c[g>>2]|0;j=h+2&16777215;k=j+1|0;l=a+36|0;m=c[l>>2]|0;if(k>>>0<m>>>0){n=c[a+32>>2]|0;o=(d[n+j|0]|0)<<8|(d[n+k|0]|0);p=h;q=m}else{m=b6[c[a+12>>2]&63](c[a+4>>2]|0,j)|0;o=m;p=c[g>>2]|0;q=c[l>>2]|0}l=a+198|0;b[l>>1]=o;g=a+192|0;c[g>>2]=2;m=p+4&16777215;p=m+1|0;if(p>>>0<q>>>0){q=c[a+32>>2]|0;r=(d[q+m|0]|0)<<8|(d[q+p|0]|0);s=o}else{o=b6[c[a+12>>2]&63](c[a+4>>2]|0,m)|0;r=o;s=b[l>>1]|0}b[a+200>>1]=r;c[g>>2]=3;l=(s&65535)<<16|r&65535;r=b[a+196>>1]&63;if((b5[c[20008+(r<<2)>>2]&127](a,r,509,32)|0)!=0){t=0;i=e;return t|0}if((mo(a,f)|0)!=0){t=0;i=e;return t|0}r=(c[f>>2]|0)-l|0;if((mr(a,r)|0)!=0){t=0;i=e;return t|0}l3(a,r,l,c[f>>2]|0);f=a+268|0;c[f>>2]=(c[f>>2]|0)+16;t=c[g>>2]|0;i=e;return t|0}function i$(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+8|0;g=f|0;h=(c[e+144>>2]|0)+2&16777215;j=h+1|0;if(j>>>0<(c[e+36>>2]|0)>>>0){k=c[e+32>>2]|0;l=(d[k+h|0]|0)<<8|(d[k+j|0]|0)}else{l=b6[c[e+12>>2]&63](c[e+4>>2]|0,h)|0}b[e+198>>1]=l;h=e+192|0;c[h>>2]=2;j=l&255;l=b[e+196>>1]&63;if((b5[c[20008+(l<<2)>>2]&127](e,l,509,8)|0)!=0){m=0;i=f;return m|0}if((mm(e,g)|0)!=0){m=0;i=f;return m|0}l=(a[g]|0)+j&255;if((mp(e,l)|0)!=0){m=0;i=f;return m|0}lP(e,l,j,a[g]|0);g=e+268|0;c[g>>2]=(c[g>>2]|0)+8;m=c[h>>2]|0;i=f;return m|0}function i0(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+8|0;f=e|0;g=(c[a+144>>2]|0)+2&16777215;h=g+1|0;if(h>>>0<(c[a+36>>2]|0)>>>0){j=c[a+32>>2]|0;k=(d[j+g|0]|0)<<8|(d[j+h|0]|0)}else{k=b6[c[a+12>>2]&63](c[a+4>>2]|0,g)|0}b[a+198>>1]=k;g=a+192|0;c[g>>2]=2;h=b[a+196>>1]&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,509,16)|0)!=0){l=0;i=e;return l|0}if((mn(a,f)|0)!=0){l=0;i=e;return l|0}h=(b[f>>1]|0)+k&65535;if((mq(a,h)|0)!=0){l=0;i=e;return l|0}lQ(a,h,k,b[f>>1]|0);f=a+268|0;c[f>>2]=(c[f>>2]|0)+8;l=c[g>>2]|0;i=e;return l|0}function i1(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+8|0;f=e|0;g=a+144|0;h=c[g>>2]|0;j=h+2&16777215;k=j+1|0;l=a+36|0;m=c[l>>2]|0;if(k>>>0<m>>>0){n=c[a+32>>2]|0;o=(d[n+j|0]|0)<<8|(d[n+k|0]|0);p=h;q=m}else{m=b6[c[a+12>>2]&63](c[a+4>>2]|0,j)|0;o=m;p=c[g>>2]|0;q=c[l>>2]|0}l=a+198|0;b[l>>1]=o;g=a+192|0;c[g>>2]=2;m=p+4&16777215;p=m+1|0;if(p>>>0<q>>>0){q=c[a+32>>2]|0;r=(d[q+m|0]|0)<<8|(d[q+p|0]|0);s=o}else{o=b6[c[a+12>>2]&63](c[a+4>>2]|0,m)|0;r=o;s=b[l>>1]|0}b[a+200>>1]=r;c[g>>2]=3;l=(s&65535)<<16|r&65535;r=b[a+196>>1]&63;if((b5[c[20008+(r<<2)>>2]&127](a,r,509,32)|0)!=0){t=0;i=e;return t|0}if((mo(a,f)|0)!=0){t=0;i=e;return t|0}r=(c[f>>2]|0)+l|0;if((mr(a,r)|0)!=0){t=0;i=e;return t|0}lR(a,r,l,c[f>>2]|0);f=a+268|0;c[f>>2]=(c[f>>2]|0)+16;t=c[g>>2]|0;i=e;return t|0}function i2(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+8|0;f=e|0;g=a+196|0;h=b[g>>1]|0;j=(c[a+144>>2]|0)+2&16777215;k=j+1|0;l=k>>>0<(c[a+36>>2]|0)>>>0;if((h&56)==0){if(l){m=c[a+32>>2]|0;n=(d[m+j|0]|0)<<8|(d[m+k|0]|0);o=h}else{m=b6[c[a+12>>2]&63](c[a+4>>2]|0,j)|0;n=m;o=b[g>>1]|0}b[a+198>>1]=n;c[a+192>>2]=2;m=a+148|0;p=b[m>>1]|0;b[m>>1]=(1<<(n&31)&c[a+80+((o&7)<<2)>>2]|0)==0?p|4:p&-5;p=a+268|0;c[p>>2]=(c[p>>2]|0)+10;q=2;i=e;return q|0}if(l){l=c[a+32>>2]|0;r=(d[l+j|0]|0)<<8|(d[l+k|0]|0);s=h}else{h=b6[c[a+12>>2]&63](c[a+4>>2]|0,j)|0;r=h;s=b[g>>1]|0}g=a+198|0;b[g>>1]=r;r=a+192|0;c[r>>2]=2;h=s&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,2044,8)|0)!=0){q=0;i=e;return q|0}if((mm(a,f)|0)!=0){q=0;i=e;return q|0}h=a+148|0;s=b[h>>1]|0;b[h>>1]=((d[f]|0)&1<<(b[g>>1]&7)|0)==0?s|4:s&-5;s=a+268|0;c[s>>2]=(c[s>>2]|0)+8;q=c[r>>2]|0;i=e;return q|0}function i3(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+8|0;f=e|0;g=a+196|0;h=b[g>>1]|0;j=(c[a+144>>2]|0)+2&16777215;k=j+1|0;l=k>>>0<(c[a+36>>2]|0)>>>0;if((h&56)==0){if(l){m=c[a+32>>2]|0;n=(d[m+j|0]|0)<<8|(d[m+k|0]|0);o=h}else{m=b6[c[a+12>>2]&63](c[a+4>>2]|0,j)|0;n=m;o=b[g>>1]|0}b[a+198>>1]=n;c[a+192>>2]=2;m=a+80+((o&7)<<2)|0;o=c[m>>2]|0;p=1<<(n&31);c[m>>2]=p^o;m=a+148|0;n=b[m>>1]|0;b[m>>1]=(p&o|0)==0?n|4:n&-5;n=a+268|0;c[n>>2]=(c[n>>2]|0)+12;q=2;i=e;return q|0}if(l){l=c[a+32>>2]|0;r=(d[l+j|0]|0)<<8|(d[l+k|0]|0);s=h}else{h=b6[c[a+12>>2]&63](c[a+4>>2]|0,j)|0;r=h;s=b[g>>1]|0}g=a+198|0;b[g>>1]=r;r=a+192|0;c[r>>2]=2;h=s&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,508,8)|0)!=0){q=0;i=e;return q|0}if((mm(a,f)|0)!=0){q=0;i=e;return q|0}h=1<<(b[g>>1]&7);if((mp(a,(h^(d[f]|0))&255)|0)!=0){q=0;i=e;return q|0}g=a+148|0;s=b[g>>1]|0;b[g>>1]=(h&(d[f]|0)|0)==0?s|4:s&-5;s=a+268|0;c[s>>2]=(c[s>>2]|0)+12;q=c[r>>2]|0;i=e;return q|0}function i4(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+8|0;f=e|0;g=a+196|0;h=b[g>>1]|0;j=(c[a+144>>2]|0)+2&16777215;k=j+1|0;l=k>>>0<(c[a+36>>2]|0)>>>0;if((h&56)==0){if(l){m=c[a+32>>2]|0;n=(d[m+j|0]|0)<<8|(d[m+k|0]|0);o=h}else{m=b6[c[a+12>>2]&63](c[a+4>>2]|0,j)|0;n=m;o=b[g>>1]|0}b[a+198>>1]=n;c[a+192>>2]=2;m=a+80+((o&7)<<2)|0;o=c[m>>2]|0;p=1<<(n&31);c[m>>2]=o&~p;m=a+148|0;n=b[m>>1]|0;b[m>>1]=(p&o|0)==0?n|4:n&-5;n=a+268|0;c[n>>2]=(c[n>>2]|0)+14;q=2;i=e;return q|0}if(l){l=c[a+32>>2]|0;r=(d[l+j|0]|0)<<8|(d[l+k|0]|0);s=h}else{h=b6[c[a+12>>2]&63](c[a+4>>2]|0,j)|0;r=h;s=b[g>>1]|0}g=a+198|0;b[g>>1]=r;r=a+192|0;c[r>>2]=2;h=s&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,508,8)|0)!=0){q=0;i=e;return q|0}if((mm(a,f)|0)!=0){q=0;i=e;return q|0}h=1<<(b[g>>1]&7);if((mp(a,(h^255)&(d[f]|0)&255)|0)!=0){q=0;i=e;return q|0}g=a+148|0;s=b[g>>1]|0;b[g>>1]=(h&(d[f]|0)|0)==0?s|4:s&-5;s=a+268|0;c[s>>2]=(c[s>>2]|0)+12;q=c[r>>2]|0;i=e;return q|0}function i5(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;i=i+8|0;f=e|0;g=a+196|0;h=b[g>>1]|0;j=(c[a+144>>2]|0)+2&16777215;k=j+1|0;l=k>>>0<(c[a+36>>2]|0)>>>0;if((h&56)==0){if(l){m=c[a+32>>2]|0;n=(d[m+j|0]|0)<<8|(d[m+k|0]|0);o=h}else{m=b6[c[a+12>>2]&63](c[a+4>>2]|0,j)|0;n=m;o=b[g>>1]|0}b[a+198>>1]=n;c[a+192>>2]=2;m=a+80+((o&7)<<2)|0;o=c[m>>2]|0;p=1<<(n&31);c[m>>2]=p|o;m=a+148|0;n=b[m>>1]|0;b[m>>1]=(p&o|0)==0?n|4:n&-5;n=a+268|0;c[n>>2]=(c[n>>2]|0)+12;q=2;i=e;return q|0}if(l){l=c[a+32>>2]|0;r=(d[l+j|0]|0)<<8|(d[l+k|0]|0);s=h}else{h=b6[c[a+12>>2]&63](c[a+4>>2]|0,j)|0;r=h;s=b[g>>1]|0}g=a+198|0;b[g>>1]=r;r=a+192|0;c[r>>2]=2;h=s&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,508,8)|0)!=0){q=0;i=e;return q|0}if((mm(a,f)|0)!=0){q=0;i=e;return q|0}h=1<<(b[g>>1]&7);if((mp(a,(h|(d[f]|0))&255)|0)!=0){q=0;i=e;return q|0}g=a+148|0;s=b[g>>1]|0;b[g>>1]=(h&(d[f]|0)|0)==0?s|4:s&-5;s=a+268|0;c[s>>2]=(c[s>>2]|0)+12;q=c[r>>2]|0;i=e;return q|0}function i6(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+8|0;g=f|0;h=e+196|0;j=b[h>>1]|0;k=(c[e+144>>2]|0)+2&16777215;l=k+1|0;m=l>>>0<(c[e+36>>2]|0)>>>0;if((j&63)==60){if(m){n=c[e+32>>2]|0;o=(d[n+k|0]|0)<<8|(d[n+l|0]|0)}else{o=b6[c[e+12>>2]&63](c[e+4>>2]|0,k)|0}b[e+198>>1]=o;c[e+192>>2]=2;n=e+148|0;p=b[n>>1]|0;b[n>>1]=(p^o)&31|p&-256;p=e+268|0;c[p>>2]=(c[p>>2]|0)+20;q=2;i=f;return q|0}if(m){m=c[e+32>>2]|0;r=(d[m+k|0]|0)<<8|(d[m+l|0]|0);s=j}else{j=b6[c[e+12>>2]&63](c[e+4>>2]|0,k)|0;r=j;s=b[h>>1]|0}b[e+198>>1]=r;h=e+192|0;c[h>>2]=2;j=s&63;if((b5[c[20008+(j<<2)>>2]&127](e,j,509,8)|0)!=0){q=0;i=f;return q|0}if((mm(e,g)|0)!=0){q=0;i=f;return q|0}j=a[g]^r&255;if((mp(e,j)|0)!=0){q=0;i=f;return q|0}lM(e,15,j);j=e+268|0;c[j>>2]=(c[j>>2]|0)+8;q=c[h>>2]|0;i=f;return q|0}function i7(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+8|0;g=f|0;h=e+196|0;j=b[h>>1]|0;if((j&63)==60){if((a[e+188|0]|0)==0){iE(e);k=0;i=f;return k|0}l=(c[e+144>>2]|0)+2&16777215;m=l+1|0;if(m>>>0<(c[e+36>>2]|0)>>>0){n=c[e+32>>2]|0;o=d[n+l|0]<<8|d[n+m|0]}else{o=b6[c[e+12>>2]&63](c[e+4>>2]|0,l)|0}b[e+198>>1]=o;c[e+192>>2]=2;is(e,(b[e+148>>1]^o)&-22753);o=e+268|0;c[o>>2]=(c[o>>2]|0)+20;k=2;i=f;return k|0}o=(c[e+144>>2]|0)+2&16777215;l=o+1|0;if(l>>>0<(c[e+36>>2]|0)>>>0){m=c[e+32>>2]|0;p=d[m+o|0]<<8|d[m+l|0];q=j}else{j=b6[c[e+12>>2]&63](c[e+4>>2]|0,o)|0;p=j;q=b[h>>1]|0}b[e+198>>1]=p;h=e+192|0;c[h>>2]=2;j=q&63;if((b5[c[20008+(j<<2)>>2]&127](e,j,509,16)|0)!=0){k=0;i=f;return k|0}if((mn(e,g)|0)!=0){k=0;i=f;return k|0}j=b[g>>1]^p;if((mq(e,j)|0)!=0){k=0;i=f;return k|0}lN(e,15,j);j=e+268|0;c[j>>2]=(c[j>>2]|0)+8;k=c[h>>2]|0;i=f;return k|0}function i8(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+8|0;f=e|0;g=a+144|0;h=c[g>>2]|0;j=h+2&16777215;k=j+1|0;l=a+36|0;m=c[l>>2]|0;if(k>>>0<m>>>0){n=c[a+32>>2]|0;o=(d[n+j|0]|0)<<8|(d[n+k|0]|0);p=h;q=m}else{m=b6[c[a+12>>2]&63](c[a+4>>2]|0,j)|0;o=m;p=c[g>>2]|0;q=c[l>>2]|0}l=a+198|0;b[l>>1]=o;g=a+192|0;c[g>>2]=2;m=p+4&16777215;p=m+1|0;if(p>>>0<q>>>0){q=c[a+32>>2]|0;r=(d[q+m|0]|0)<<8|(d[q+p|0]|0);s=o}else{o=b6[c[a+12>>2]&63](c[a+4>>2]|0,m)|0;r=o;s=b[l>>1]|0}b[a+200>>1]=r;c[g>>2]=3;l=b[a+196>>1]&63;if((b5[c[20008+(l<<2)>>2]&127](a,l,509,32)|0)!=0){t=0;i=e;return t|0}if((mo(a,f)|0)!=0){t=0;i=e;return t|0}l=c[f>>2]^((s&65535)<<16|r&65535);if((mr(a,l)|0)!=0){t=0;i=e;return t|0}lO(a,15,l);l=a+268|0;c[l>>2]=(c[l>>2]|0)+12;t=c[g>>2]|0;i=e;return t|0}function i9(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+8|0;g=f|0;h=(c[e+144>>2]|0)+2&16777215;j=h+1|0;if(j>>>0<(c[e+36>>2]|0)>>>0){k=c[e+32>>2]|0;l=(d[k+h|0]|0)<<8|(d[k+j|0]|0)}else{l=b6[c[e+12>>2]&63](c[e+4>>2]|0,h)|0}b[e+198>>1]=l;h=e+192|0;c[h>>2]=2;j=l&255;l=b[e+196>>1]&63;if((b5[c[20008+(l<<2)>>2]&127](e,l,2045,8)|0)!=0){m=0;i=f;return m|0}if((mm(e,g)|0)!=0){m=0;i=f;return m|0}l=a[g]|0;lV(e,l-j&255,j,l);l=e+268|0;c[l>>2]=(c[l>>2]|0)+8;m=c[h>>2]|0;i=f;return m|0}function ja(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+8|0;f=e|0;g=(c[a+144>>2]|0)+2&16777215;h=g+1|0;if(h>>>0<(c[a+36>>2]|0)>>>0){j=c[a+32>>2]|0;k=(d[j+g|0]|0)<<8|(d[j+h|0]|0)}else{k=b6[c[a+12>>2]&63](c[a+4>>2]|0,g)|0}b[a+198>>1]=k;g=a+192|0;c[g>>2]=2;h=b[a+196>>1]&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,2045,16)|0)!=0){l=0;i=e;return l|0}if((mn(a,f)|0)!=0){l=0;i=e;return l|0}h=b[f>>1]|0;lW(a,h-k&65535,k,h);h=a+268|0;c[h>>2]=(c[h>>2]|0)+8;l=c[g>>2]|0;i=e;return l|0}function jb(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+8|0;f=e|0;g=a+144|0;h=c[g>>2]|0;j=h+2&16777215;k=j+1|0;l=a+36|0;m=c[l>>2]|0;if(k>>>0<m>>>0){n=c[a+32>>2]|0;o=(d[n+j|0]|0)<<8|(d[n+k|0]|0);p=h;q=m}else{m=b6[c[a+12>>2]&63](c[a+4>>2]|0,j)|0;o=m;p=c[g>>2]|0;q=c[l>>2]|0}l=a+198|0;b[l>>1]=o;g=a+192|0;c[g>>2]=2;m=p+4&16777215;p=m+1|0;if(p>>>0<q>>>0){q=c[a+32>>2]|0;r=(d[q+m|0]|0)<<8|(d[q+p|0]|0);s=o}else{o=b6[c[a+12>>2]&63](c[a+4>>2]|0,m)|0;r=o;s=b[l>>1]|0}b[a+200>>1]=r;c[g>>2]=3;l=(s&65535)<<16|r&65535;r=b[a+196>>1]&63;if((b5[c[20008+(r<<2)>>2]&127](a,r,2045,32)|0)!=0){t=0;i=e;return t|0}if((mo(a,f)|0)!=0){t=0;i=e;return t|0}r=c[f>>2]|0;l0(a,r-l|0,l,r);r=a+268|0;c[r>>2]=(c[r>>2]|0)+12;t=c[g>>2]|0;i=e;return t|0}function jc(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+8|0;g=f|0;if((c[e>>2]&2|0)==0){iA(e);h=e+268|0;c[h>>2]=(c[h>>2]|0)+2;j=0;i=f;return j|0}h=(c[e+144>>2]|0)+2&16777215;k=h+1|0;if(k>>>0<(c[e+36>>2]|0)>>>0){l=c[e+32>>2]|0;m=(d[l+h|0]|0)<<8|(d[l+k|0]|0)}else{m=b6[c[e+12>>2]&63](c[e+4>>2]|0,h)|0}b[e+198>>1]=m;h=e+192|0;c[h>>2]=2;k=e+196|0;l=m&65535;m=l>>>12;do{if((l&2048|0)==0){n=b[k>>1]&63;if((b5[c[20008+(n<<2)>>2]&127](e,n,508,8)|0)!=0){j=0;i=f;return j|0}if((mm(e,g)|0)!=0){j=0;i=f;return j|0}n=m&7;o=a[g]|0;if((m&8|0)==0){p=e+80+(n<<2)|0;c[p>>2]=c[p>>2]&-256|o&255;break}else{p=o&255;c[e+112+(n<<2)>>2]=(p&128|0)!=0?p|-256:p;break}}else{p=m&7;if((m&8|0)==0){q=e+80+(p<<2)|0}else{q=e+112+(p<<2)|0}a[g]=c[q>>2]&255;p=b[k>>1]&63;if((b5[c[20008+(p<<2)>>2]&127](e,p,508,8)|0)!=0){j=0;i=f;return j|0}if((mp(e,a[g]|0)|0)==0){break}else{j=0}i=f;return j|0}}while(0);g=e+268|0;c[g>>2]=(c[g>>2]|0)+4;j=c[h>>2]|0;i=f;return j|0}function jd(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+8|0;f=e|0;if((c[a>>2]&2|0)==0){iA(a);g=a+268|0;c[g>>2]=(c[g>>2]|0)+2;h=0;i=e;return h|0}g=(c[a+144>>2]|0)+2&16777215;j=g+1|0;if(j>>>0<(c[a+36>>2]|0)>>>0){k=c[a+32>>2]|0;l=(d[k+g|0]|0)<<8|(d[k+j|0]|0)}else{l=b6[c[a+12>>2]&63](c[a+4>>2]|0,g)|0}b[a+198>>1]=l;g=a+192|0;c[g>>2]=2;j=a+196|0;k=l&65535;l=k>>>12;do{if((k&2048|0)==0){m=b[j>>1]&63;if((b5[c[20008+(m<<2)>>2]&127](a,m,508,16)|0)!=0){h=0;i=e;return h|0}if((mn(a,f)|0)!=0){h=0;i=e;return h|0}m=l&7;n=b[f>>1]|0;if((l&8|0)==0){o=a+80+(m<<2)|0;c[o>>2]=c[o>>2]&-65536|n&65535;break}else{o=n&65535;c[a+112+(m<<2)>>2]=(o&32768|0)==0?o:o|-65536;break}}else{o=l&7;if((l&8|0)==0){p=a+80+(o<<2)|0}else{p=a+112+(o<<2)|0}b[f>>1]=c[p>>2]&65535;o=b[j>>1]&63;if((b5[c[20008+(o<<2)>>2]&127](a,o,508,16)|0)!=0){h=0;i=e;return h|0}if((mq(a,b[f>>1]|0)|0)==0){break}else{h=0}i=e;return h|0}}while(0);f=a+268|0;c[f>>2]=(c[f>>2]|0)+4;h=c[g>>2]|0;i=e;return h|0}function je(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+8|0;f=e|0;if((c[a>>2]&2|0)==0){iA(a);g=a+268|0;c[g>>2]=(c[g>>2]|0)+2;h=0;i=e;return h|0}g=(c[a+144>>2]|0)+2&16777215;j=g+1|0;if(j>>>0<(c[a+36>>2]|0)>>>0){k=c[a+32>>2]|0;l=(d[k+g|0]|0)<<8|(d[k+j|0]|0)}else{l=b6[c[a+12>>2]&63](c[a+4>>2]|0,g)|0}b[a+198>>1]=l;g=a+192|0;c[g>>2]=2;j=a+196|0;k=l&65535;l=k>>>12;do{if((k&2048|0)==0){m=b[j>>1]&63;if((b5[c[20008+(m<<2)>>2]&127](a,m,508,32)|0)!=0){h=0;i=e;return h|0}if((mo(a,f)|0)!=0){h=0;i=e;return h|0}m=l&7;n=c[f>>2]|0;if((l&8|0)==0){c[a+80+(m<<2)>>2]=n;break}else{c[a+112+(m<<2)>>2]=n;break}}else{n=l&7;if((l&8|0)==0){o=a+80+(n<<2)|0}else{o=a+112+(n<<2)|0}c[f>>2]=c[o>>2];n=b[j>>1]&63;if((b5[c[20008+(n<<2)>>2]&127](a,n,508,32)|0)!=0){h=0;i=e;return h|0}if((mr(a,c[f>>2]|0)|0)==0){break}else{h=0}i=e;return h|0}}while(0);f=a+268|0;c[f>>2]=(c[f>>2]|0)+4;h=c[g>>2]|0;i=e;return h|0}function jf(d){d=d|0;var f=0,g=0,h=0,j=0,k=0;f=i;i=i+8|0;g=f|0;h=d+196|0;j=b[h>>1]&63;if((b5[c[20008+(j<<2)>>2]&127](d,j,4095,8)|0)!=0){k=0;i=f;return k|0}if((mm(d,g)|0)!=0){k=0;i=f;return k|0}j=e[h>>1]|0;h=j>>>3&56|j>>>9&7;if((b5[c[20008+(h<<2)>>2]&127](d,h,509,8)|0)!=0){k=0;i=f;return k|0}if((mp(d,a[g]|0)|0)!=0){k=0;i=f;return k|0}lM(d,15,a[g]|0);g=d+268|0;c[g>>2]=(c[g>>2]|0)+4;k=c[d+192>>2]|0;i=f;return k|0}function jg(a){a=a|0;var d=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;f=d|0;g=a+196|0;h=b[g>>1]&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,4095,32)|0)!=0){j=0;i=d;return j|0}if((mo(a,f)|0)!=0){j=0;i=d;return j|0}h=e[g>>1]|0;g=h>>>3&56|h>>>9&7;if((b5[c[20008+(g<<2)>>2]&127](a,g,509,32)|0)!=0){j=0;i=d;return j|0}if((mr(a,c[f>>2]|0)|0)!=0){j=0;i=d;return j|0}lO(a,15,c[f>>2]|0);f=a+268|0;c[f>>2]=(c[f>>2]|0)+4;j=c[a+192>>2]|0;i=d;return j|0}function jh(a){a=a|0;var d=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;f=d|0;g=a+196|0;h=b[g>>1]&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,4095,32)|0)!=0){j=0;i=d;return j|0}if((mo(a,f)|0)!=0){j=0;i=d;return j|0}c[a+112+(((e[g>>1]|0)>>>9&7)<<2)>>2]=c[f>>2];f=a+268|0;c[f>>2]=(c[f>>2]|0)+4;j=c[a+192>>2]|0;i=d;return j|0}function ji(a){a=a|0;var d=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;f=d|0;g=a+196|0;h=b[g>>1]&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,4095,16)|0)!=0){j=0;i=d;return j|0}if((mn(a,f)|0)!=0){j=0;i=d;return j|0}h=e[g>>1]|0;g=h>>>3&56|h>>>9&7;if((b5[c[20008+(g<<2)>>2]&127](a,g,509,16)|0)!=0){j=0;i=d;return j|0}if((mq(a,b[f>>1]|0)|0)!=0){j=0;i=d;return j|0}lN(a,15,b[f>>1]|0);f=a+268|0;c[f>>2]=(c[f>>2]|0)+4;j=c[a+192>>2]|0;i=d;return j|0}function jj(a){a=a|0;var d=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;f=d|0;g=a+196|0;h=b[g>>1]&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,4095,16)|0)!=0){j=0;i=d;return j|0}if((mn(a,f)|0)!=0){j=0;i=d;return j|0}h=e[f>>1]|0;c[a+112+(((e[g>>1]|0)>>>9&7)<<2)>>2]=(h&32768|0)!=0?h|-65536:h;h=a+268|0;c[h>>2]=(c[h>>2]|0)+4;j=c[a+192>>2]|0;i=d;return j|0}function jk(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+8|0;f=e|0;g=b[a+196>>1]&63;if((b5[c[20008+(g<<2)>>2]&127](a,g,509,8)|0)!=0){h=0;i=e;return h|0}if((mm(a,f)|0)!=0){h=0;i=e;return h|0}g=a+148|0;j=b[g>>1]|0;k=-(((j&65535)>>>4&1)+(d[f]|0)|0)|0;if((k&255|0)!=0){b[g>>1]=j&-5}if((mp(a,k&255)|0)!=0){h=0;i=e;return h|0}j=k&128;l=b[g>>1]|0;m=(j|0)==0?l&-9:l|8;l=d[f]|0;f=(j&l|0)==0?m&-3:m|2;b[g>>1]=((l|k)&128|0)==0?f&-18:f|17;f=a+268|0;c[f>>2]=(c[f>>2]|0)+8;h=c[a+192>>2]|0;i=e;return h|0}function jl(a){a=a|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+8|0;f=d|0;g=b[a+196>>1]&63;if((b5[c[20008+(g<<2)>>2]&127](a,g,509,16)|0)!=0){h=0;i=d;return h|0}if((mn(a,f)|0)!=0){h=0;i=d;return h|0}g=a+148|0;j=b[g>>1]|0;k=-(((j&65535)>>>4&1)+(e[f>>1]|0)|0)|0;if((k&65535|0)!=0){b[g>>1]=j&-5}if((mq(a,k&65535)|0)!=0){h=0;i=d;return h|0}j=k&32768;l=b[g>>1]|0;m=(j|0)==0?l&-9:l|8;l=e[f>>1]|0;f=(j&l|0)==0?m&-3:m|2;b[g>>1]=((l|k)&32768|0)==0?f&-18:f|17;f=a+268|0;c[f>>2]=(c[f>>2]|0)+8;h=c[a+192>>2]|0;i=d;return h|0}function jm(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+8|0;e=d|0;f=b[a+196>>1]&63;if((b5[c[20008+(f<<2)>>2]&127](a,f,509,32)|0)!=0){g=0;i=d;return g|0}if((mo(a,e)|0)!=0){g=0;i=d;return g|0}f=-(c[e>>2]|0)|0;h=a+148|0;j=b[h>>1]|0;k=(j&65535)>>>4&1;l=f-k|0;if((k|0)!=(f|0)){b[h>>1]=j&-5}if((mr(a,l)|0)!=0){g=0;i=d;return g|0}j=b[h>>1]|0;f=(l|0)<0?j|8:j&-9;j=c[e>>2]|0;e=(j&l|0)<0?f|2:f&-3;b[h>>1]=(j|l|0)<0?e|17:e&-18;e=a+268|0;c[e>>2]=(c[e>>2]|0)+10;g=c[a+192>>2]|0;i=d;return g|0}function jn(d){d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+8|0;f=e|0;do{if((c[d>>2]&2|0)!=0){if((a[d+188|0]|0)!=0){break}iE(d);g=0;i=e;return g|0}}while(0);h=b[d+196>>1]&63;if((b5[c[20008+(h<<2)>>2]&127](d,h,509,16)|0)!=0){g=0;i=e;return g|0}if((mn(d,f)|0)!=0){g=0;i=e;return g|0}h=b[d+148>>1]&-22753;b[f>>1]=h;if((mq(d,h)|0)!=0){g=0;i=e;return g|0}h=d+268|0;c[h>>2]=(c[h>>2]|0)+4;g=c[d+192>>2]|0;i=e;return g|0}function jo(a){a=a|0;var d=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;f=d|0;g=a+196|0;h=b[g>>1]&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,4093,16)|0)!=0){j=0;i=d;return j|0}if((mn(a,f)|0)!=0){j=0;i=d;return j|0}h=c[a+80+(((e[g>>1]|0)>>>9&7)<<2)>>2]|0;do{if((h&32768|0)==0){g=e[f>>1]|0;if((g&32768|0)!=0|(h&65535)>>>0>g>>>0){g=a+148|0;b[g>>1]=b[g>>1]&-9;break}g=a+268|0;c[g>>2]=(c[g>>2]|0)+14;j=c[a+192>>2]|0;i=d;return j|0}else{g=a+148|0;b[g>>1]=b[g>>1]|8}}while(0);iC(a);j=0;i=d;return j|0}function jp(a){a=a|0;var d=0,e=0;d=b[a+196>>1]&63;if((b5[c[20008+(d<<2)>>2]&127](a,d,509,8)|0)!=0){e=0;return e|0}if((mp(a,0)|0)!=0){e=0;return e|0}d=a+148|0;b[d>>1]=b[d>>1]&-16|4;d=a+268|0;c[d>>2]=(c[d>>2]|0)+4;e=c[a+192>>2]|0;return e|0}function jq(a){a=a|0;var d=0,e=0;d=b[a+196>>1]&63;if((b5[c[20008+(d<<2)>>2]&127](a,d,509,16)|0)!=0){e=0;return e|0}if((mq(a,0)|0)!=0){e=0;return e|0}d=a+148|0;b[d>>1]=b[d>>1]&-16|4;d=a+268|0;c[d>>2]=(c[d>>2]|0)+4;e=c[a+192>>2]|0;return e|0}function jr(a){a=a|0;var d=0,e=0;d=b[a+196>>1]&63;if((b5[c[20008+(d<<2)>>2]&127](a,d,509,32)|0)!=0){e=0;return e|0}if((mr(a,0)|0)!=0){e=0;return e|0}d=a+148|0;b[d>>1]=b[d>>1]&-16|4;d=a+268|0;c[d>>2]=(c[d>>2]|0)+6;e=c[a+192>>2]|0;return e|0}function js(a){a=a|0;var d=0,e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;if((c[a>>2]&2|0)==0){iA(a);f=a+268|0;c[f>>2]=(c[f>>2]|0)+2;g=0;i=d;return g|0}f=b[a+196>>1]&63;if((b5[c[20008+(f<<2)>>2]&127](a,f,509,16)|0)!=0){g=0;i=d;return g|0}if((mn(a,e)|0)!=0){g=0;i=d;return g|0}f=b[a+148>>1]&31;b[e>>1]=f;if((mq(a,f)|0)!=0){g=0;i=d;return g|0}f=a+268|0;c[f>>2]=(c[f>>2]|0)+4;g=c[a+192>>2]|0;i=d;return g|0}function jt(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+8|0;f=e|0;g=b[a+196>>1]&63;if((b5[c[20008+(g<<2)>>2]&127](a,g,509,8)|0)!=0){h=0;i=e;return h|0}if((mm(a,f)|0)!=0){h=0;i=e;return h|0}g=-(d[f]|0)|0;if((mp(a,g&255)|0)!=0){h=0;i=e;return h|0}j=g&128;k=a+148|0;l=b[k>>1]|0;m=(j|0)==0?l&-9:l|8;l=d[f]|0;f=(j&l|0)==0?m&-3:m|2;m=(g&255|0)==0?f|4:f&-5;b[k>>1]=((l|g)&128|0)==0?m&-18:m|17;m=a+268|0;c[m>>2]=(c[m>>2]|0)+4;h=c[a+192>>2]|0;i=e;return h|0}function ju(a){a=a|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+8|0;f=d|0;g=b[a+196>>1]&63;if((b5[c[20008+(g<<2)>>2]&127](a,g,509,16)|0)!=0){h=0;i=d;return h|0}if((mn(a,f)|0)!=0){h=0;i=d;return h|0}g=-(e[f>>1]|0)|0;if((mq(a,g&65535)|0)!=0){h=0;i=d;return h|0}j=g&32768;k=a+148|0;l=b[k>>1]|0;m=(j|0)==0?l&-9:l|8;l=e[f>>1]|0;f=(j&l|0)==0?m&-3:m|2;m=(g&65535|0)==0?f|4:f&-5;b[k>>1]=((l|g)&32768|0)==0?m&-18:m|17;m=a+268|0;c[m>>2]=(c[m>>2]|0)+4;h=c[a+192>>2]|0;i=d;return h|0}function jv(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+8|0;e=d|0;f=b[a+196>>1]&63;if((b5[c[20008+(f<<2)>>2]&127](a,f,509,32)|0)!=0){g=0;i=d;return g|0}if((mo(a,e)|0)!=0){g=0;i=d;return g|0}f=c[e>>2]|0;h=-f|0;if((mr(a,h)|0)!=0){g=0;i=d;return g|0}j=a+148|0;k=b[j>>1]|0;l=(h|0)<0?k|8:k&-9;k=c[e>>2]|0;e=(k&h|0)<0?l|2:l&-3;l=(f|0)==0?e|4:e&-5;b[j>>1]=(k|h|0)<0?l|17:l&-18;l=a+268|0;c[l>>2]=(c[l>>2]|0)+6;g=c[a+192>>2]|0;i=d;return g|0}function jw(a){a=a|0;var d=0,e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;f=b[a+196>>1]&63;if((b5[c[20008+(f<<2)>>2]&127](a,f,4093,16)|0)!=0){g=0;i=d;return g|0}if((mn(a,e)|0)!=0){g=0;i=d;return g|0}f=a+148|0;b[f>>1]=b[f>>1]&-256|b[e>>1]&31;e=a+268|0;c[e>>2]=(c[e>>2]|0)+12;g=c[a+192>>2]|0;i=d;return g|0}function jx(d){d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+8|0;f=e|0;g=b[d+196>>1]&63;if((b5[c[20008+(g<<2)>>2]&127](d,g,509,8)|0)!=0){h=0;i=e;return h|0}if((mm(d,f)|0)!=0){h=0;i=e;return h|0}g=~a[f];if((mp(d,g)|0)!=0){h=0;i=e;return h|0}lM(d,15,g);g=d+268|0;c[g>>2]=(c[g>>2]|0)+4;h=c[d+192>>2]|0;i=e;return h|0}function jy(a){a=a|0;var d=0,e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;f=b[a+196>>1]&63;if((b5[c[20008+(f<<2)>>2]&127](a,f,509,16)|0)!=0){g=0;i=d;return g|0}if((mn(a,e)|0)!=0){g=0;i=d;return g|0}f=~b[e>>1];if((mq(a,f)|0)!=0){g=0;i=d;return g|0}lN(a,15,f);f=a+268|0;c[f>>2]=(c[f>>2]|0)+4;g=c[a+192>>2]|0;i=d;return g|0}function jz(a){a=a|0;var d=0,e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;f=b[a+196>>1]&63;if((b5[c[20008+(f<<2)>>2]&127](a,f,509,32)|0)!=0){g=0;i=d;return g|0}if((mo(a,e)|0)!=0){g=0;i=d;return g|0}f=~c[e>>2];if((mr(a,f)|0)!=0){g=0;i=d;return g|0}lO(a,15,f);f=a+268|0;c[f>>2]=(c[f>>2]|0)+6;g=c[a+192>>2]|0;i=d;return g|0}function jA(d){d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+8|0;f=e|0;if((a[d+188|0]|0)==0){iE(d);g=0;i=e;return g|0}h=b[d+196>>1]&63;if((b5[c[20008+(h<<2)>>2]&127](d,h,4093,16)|0)!=0){g=0;i=e;return g|0}if((mn(d,f)|0)!=0){g=0;i=e;return g|0}is(d,b[f>>1]&-22753);f=d+268|0;c[f>>2]=(c[f>>2]|0)+12;g=c[d+192>>2]|0;i=e;return g|0}
function jB(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+8|0;f=e|0;g=b[a+196>>1]&63;if((b5[c[20008+(g<<2)>>2]&127](a,g,509,8)|0)!=0){h=0;i=e;return h|0}if((mm(a,f)|0)!=0){h=0;i=e;return h|0}g=a+148|0;j=b[g>>1]|0;k=((j&65535)>>>4&1)+(d[f]|0)&65535;f=-k&65535;l=(f&15)==0?f:-6-k&65535;k=(l&240)==0?l:l-96&65535;l=k&65535;f=(l&65280|0)==0?j&-18:j|17;b[g>>1]=(l&255|0)==0?f:f&-5;if((mp(a,k&255)|0)!=0){h=0;i=e;return h|0}k=a+268|0;c[k>>2]=(c[k>>2]|0)+6;h=c[a+192>>2]|0;i=e;return h|0}function jC(b){b=b|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0;d=e[b+196>>1]|0;if((d&56|0)==0){f=b+80+((d&7)<<2)|0;g=c[f>>2]|0;h=g<<16|g>>>16;c[f>>2]=h;lO(b,15,h);h=b+268|0;c[h>>2]=(c[h>>2]|0)+4;i=1;return i|0}h=d&63;if((b5[c[20008+(h<<2)>>2]&127](b,h,2020,32)|0)!=0){i=0;return i|0}if((c[b+228>>2]|0)!=2){iA(b);i=0;return i|0}h=c[b+232>>2]|0;d=b+140|0;f=(c[d>>2]|0)-4|0;g=f&16777215;j=g+3|0;if(j>>>0<(c[b+36>>2]|0)>>>0){k=b+32|0;a[(c[k>>2]|0)+g|0]=h>>>24&255;a[(c[k>>2]|0)+(g+1)|0]=h>>>16&255;a[(c[k>>2]|0)+(g+2)|0]=h>>>8&255;a[(c[k>>2]|0)+j|0]=h&255}else{b3[c[b+28>>2]&63](c[b+4>>2]|0,g,h)}c[d>>2]=f;f=b+268|0;c[f>>2]=(c[f>>2]|0)+12;i=c[b+192>>2]|0;return i|0}function jD(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=e+196|0;g=b[f>>1]|0;h=g&65535;i=h>>>3&7;if((i|0)==0){j=e+80+((h&7)<<2)|0;h=c[j>>2]|0;k=(h&128|0)!=0?h|65280:h&255;c[j>>2]=k&65535|h&-65536;lN(e,15,k&65535);k=e+268|0;c[k>>2]=(c[k>>2]|0)+4;l=1;return l|0}else if((i|0)==4){i=(c[e+144>>2]|0)+2&16777215;k=i+1|0;h=e+36|0;if(k>>>0<(c[h>>2]|0)>>>0){j=c[e+32>>2]|0;m=(d[j+i|0]|0)<<8|(d[j+k|0]|0);n=g}else{k=b6[c[e+12>>2]&63](c[e+4>>2]|0,i)|0;m=k;n=b[f>>1]|0}b[e+198>>1]=m;c[e+192>>2]=2;k=c[e+112+((n&7)<<2)>>2]|0;do{if(m<<16>>16==0){o=0}else{if((c[e>>2]&1|0)!=0){o=m;break}if((k&1|0)==0){o=m;break}iw(e,k,1,1);l=0;return l|0}}while(0);m=e+32|0;n=e+268|0;i=e+24|0;j=e+4|0;p=0;q=o;o=k;while(1){if((q&1)==0){r=o}else{k=o-2|0;if(p>>>0<8){s=e+112+((7-p&7)<<2)|0}else{s=e+80+((15-p&7)<<2)|0}t=c[s>>2]|0;u=t&65535;v=k&16777215;w=v+1|0;if(w>>>0<(c[h>>2]|0)>>>0){a[(c[m>>2]|0)+v|0]=(u&65535)>>>8&255;a[(c[m>>2]|0)+w|0]=t&255}else{b3[c[i>>2]&63](c[j>>2]|0,v,u)}c[n>>2]=(c[n>>2]|0)+4;r=k}k=p+1|0;if(k>>>0<16){p=k;q=(q&65535)>>>1;o=r}else{break}}c[e+112+((b[f>>1]&7)<<2)>>2]=r;c[n>>2]=(c[n>>2]|0)+8;l=2;return l|0}else{n=(c[e+144>>2]|0)+2&16777215;r=n+1|0;o=e+36|0;if(r>>>0<(c[o>>2]|0)>>>0){q=c[e+32>>2]|0;x=(d[q+n|0]|0)<<8|(d[q+r|0]|0);y=g}else{g=b6[c[e+12>>2]&63](c[e+4>>2]|0,n)|0;x=g;y=b[f>>1]|0}b[e+198>>1]=x;f=e+192|0;c[f>>2]=2;g=y&63;if((b5[c[20008+(g<<2)>>2]&127](e,g,484,16)|0)!=0){l=0;return l|0}if((c[e+228>>2]|0)!=2){iA(e);l=0;return l|0}g=c[e+232>>2]|0;do{if(x<<16>>16==0){z=0}else{if((c[e>>2]&1|0)!=0){z=x;break}if((g&1|0)==0){z=x;break}iw(e,g,1,1);l=0;return l|0}}while(0);x=e+32|0;y=e+268|0;n=e+24|0;r=e+4|0;q=0;p=z;z=g;while(1){if((p&1)==0){A=z}else{g=q&7;if(q>>>0<8){B=e+80+(g<<2)|0}else{B=e+112+(g<<2)|0}g=c[B>>2]|0;j=g&65535;i=z&16777215;m=i+1|0;if(m>>>0<(c[o>>2]|0)>>>0){a[(c[x>>2]|0)+i|0]=(j&65535)>>>8&255;a[(c[x>>2]|0)+m|0]=g&255}else{b3[c[n>>2]&63](c[r>>2]|0,i,j)}c[y>>2]=(c[y>>2]|0)+4;A=z+2|0}j=q+1|0;if(j>>>0<16){q=j;p=(p&65535)>>>1;z=A}else{break}}c[y>>2]=(c[y>>2]|0)+8;l=c[f>>2]|0;return l|0}return 0}function jE(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=e+196|0;g=b[f>>1]|0;h=g&65535;i=h>>>3&7;if((i|0)==0){j=e+80+((h&7)<<2)|0;h=c[j>>2]|0;k=(h&32768|0)!=0?h|-65536:h&65535;c[j>>2]=k;lO(e,15,k);k=e+268|0;c[k>>2]=(c[k>>2]|0)+4;l=1;return l|0}else if((i|0)==4){i=(c[e+144>>2]|0)+2&16777215;k=i+1|0;j=e+36|0;if(k>>>0<(c[j>>2]|0)>>>0){h=c[e+32>>2]|0;m=(d[h+i|0]|0)<<8|(d[h+k|0]|0);n=g}else{k=b6[c[e+12>>2]&63](c[e+4>>2]|0,i)|0;m=k;n=b[f>>1]|0}b[e+198>>1]=m;c[e+192>>2]=2;k=c[e+112+((n&7)<<2)>>2]|0;do{if(m<<16>>16==0){o=0}else{if((c[e>>2]&1|0)!=0){o=m;break}if((k&1|0)==0){o=m;break}iw(e,k,1,1);l=0;return l|0}}while(0);m=e+32|0;n=e+268|0;i=e+28|0;h=e+4|0;p=0;q=o;o=k;while(1){if((q&1)==0){r=o}else{k=o-4|0;if(p>>>0<8){s=e+112+((7-p&7)<<2)|0}else{s=e+80+((15-p&7)<<2)|0}t=c[s>>2]|0;u=k&16777215;v=u+3|0;if(v>>>0<(c[j>>2]|0)>>>0){a[(c[m>>2]|0)+u|0]=t>>>24&255;a[(c[m>>2]|0)+(u+1)|0]=t>>>16&255;a[(c[m>>2]|0)+(u+2)|0]=t>>>8&255;a[(c[m>>2]|0)+v|0]=t&255}else{b3[c[i>>2]&63](c[h>>2]|0,u,t)}c[n>>2]=(c[n>>2]|0)+8;r=k}k=p+1|0;if(k>>>0<16){p=k;q=(q&65535)>>>1;o=r}else{break}}c[e+112+((b[f>>1]&7)<<2)>>2]=r;c[n>>2]=(c[n>>2]|0)+8;l=2;return l|0}else{n=(c[e+144>>2]|0)+2&16777215;r=n+1|0;o=e+36|0;if(r>>>0<(c[o>>2]|0)>>>0){q=c[e+32>>2]|0;w=(d[q+n|0]|0)<<8|(d[q+r|0]|0);x=g}else{g=b6[c[e+12>>2]&63](c[e+4>>2]|0,n)|0;w=g;x=b[f>>1]|0}b[e+198>>1]=w;f=e+192|0;c[f>>2]=2;g=x&63;if((b5[c[20008+(g<<2)>>2]&127](e,g,484,32)|0)!=0){l=0;return l|0}if((c[e+228>>2]|0)!=2){iA(e);l=0;return l|0}g=c[e+232>>2]|0;do{if(w<<16>>16==0){y=0}else{if((c[e>>2]&1|0)!=0){y=w;break}if((g&1|0)==0){y=w;break}iw(e,g,1,1);l=0;return l|0}}while(0);w=e+32|0;x=e+268|0;n=e+28|0;r=e+4|0;q=0;p=y;y=g;while(1){if((p&1)==0){z=y}else{g=q&7;if(q>>>0<8){A=e+80+(g<<2)|0}else{A=e+112+(g<<2)|0}g=c[A>>2]|0;h=y&16777215;i=h+3|0;if(i>>>0<(c[o>>2]|0)>>>0){a[(c[w>>2]|0)+h|0]=g>>>24&255;a[(c[w>>2]|0)+(h+1)|0]=g>>>16&255;a[(c[w>>2]|0)+(h+2)|0]=g>>>8&255;a[(c[w>>2]|0)+i|0]=g&255}else{b3[c[n>>2]&63](c[r>>2]|0,h,g)}c[x>>2]=(c[x>>2]|0)+8;z=y+4|0}g=q+1|0;if(g>>>0<16){q=g;p=(p&65535)>>>1;y=z}else{break}}c[x>>2]=(c[x>>2]|0)+8;l=c[f>>2]|0;return l|0}return 0}function jF(a){a=a|0;return b_[c[a+4392+(((b[a+196>>1]&65535)>>>3&7)<<2)>>2]&511](a)|0}function jG(d){d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+8|0;f=e|0;g=b[d+196>>1]&63;if((b5[c[20008+(g<<2)>>2]&127](d,g,509,8)|0)!=0){h=0;i=e;return h|0}if((mm(d,f)|0)!=0){h=0;i=e;return h|0}lM(d,15,a[f]|0);f=d+268|0;c[f>>2]=(c[f>>2]|0)+8;h=c[d+192>>2]|0;i=e;return h|0}function jH(a){a=a|0;var d=0,e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;f=b[a+196>>1]&63;if((b5[c[20008+(f<<2)>>2]&127](a,f,509,16)|0)!=0){g=0;i=d;return g|0}if((mn(a,e)|0)!=0){g=0;i=d;return g|0}lN(a,15,b[e>>1]|0);e=a+268|0;c[e>>2]=(c[e>>2]|0)+8;g=c[a+192>>2]|0;i=d;return g|0}function jI(a){a=a|0;var d=0,e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;f=b[a+196>>1]&63;if((b5[c[20008+(f<<2)>>2]&127](a,f,509,32)|0)!=0){g=0;i=d;return g|0}if((mo(a,e)|0)!=0){g=0;i=d;return g|0}lO(a,15,c[e>>2]|0);e=a+268|0;c[e>>2]=(c[e>>2]|0)+8;g=c[a+192>>2]|0;i=d;return g|0}function jJ(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+8|0;g=f|0;h=b[e+196>>1]|0;if(h<<16>>16!=19196){j=h&63;if((b5[c[20008+(j<<2)>>2]&127](e,j,509,8)|0)!=0){k=0;i=f;return k|0}if((mm(e,g)|0)!=0){k=0;i=f;return k|0}if((mp(e,a[g]|-128)|0)!=0){k=0;i=f;return k|0}lM(e,15,a[g]|0);g=e+268|0;c[g>>2]=(c[g>>2]|0)+8;k=c[e+192>>2]|0;i=f;return k|0}g=(c[e+144>>2]|0)+2&16777215;j=g+1|0;if(j>>>0<(c[e+36>>2]|0)>>>0){h=c[e+32>>2]|0;l=(d[h+g|0]|0)<<8|(d[h+j|0]|0)}else{l=b6[c[e+12>>2]&63](c[e+4>>2]|0,g)|0}b[e+198>>1]=l;c[e+192>>2]=2;g=c[e+56>>2]|0;do{if((g|0)!=0){if((b6[g&63](c[e+52>>2]|0,l&65535)|0)!=0){break}j=e+268|0;c[j>>2]=(c[j>>2]|0)+8;k=0;i=f;return k|0}}while(0);iA(e);k=0;i=f;return k|0}function jK(a){a=a|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=a+196|0;f=b[e>>1]|0;g=(f&65535)>>>3&7;if((g|0)==3){h=(c[a+144>>2]|0)+2&16777215;i=h+1|0;j=a+36|0;if(i>>>0<(c[j>>2]|0)>>>0){k=c[a+32>>2]|0;l=(d[k+h|0]|0)<<8|(d[k+i|0]|0);m=f}else{i=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0;l=i;m=b[e>>1]|0}b[a+198>>1]=l;c[a+192>>2]=2;i=c[a+112+((m&7)<<2)>>2]|0;do{if(l<<16>>16==0){n=0}else{if((c[a>>2]&1|0)!=0){n=l;break}if((i&1|0)==0){n=l;break}iw(a,i,1,0);o=0;return o|0}}while(0);l=a+32|0;m=a+268|0;h=a+12|0;k=a+4|0;p=0;q=n;n=i;while(1){if((q&1)==0){r=n}else{i=n&16777215;s=i+1|0;if(s>>>0<(c[j>>2]|0)>>>0){t=c[l>>2]|0;u=(d[t+i|0]|0)<<8|(d[t+s|0]|0)}else{u=b6[c[h>>2]&63](c[k>>2]|0,i)|0}i=u&65535;s=(i&32768|0)!=0?i|-65536:i;i=p&7;if(p>>>0<8){c[a+80+(i<<2)>>2]=s}else{c[a+112+(i<<2)>>2]=s}c[m>>2]=(c[m>>2]|0)+4;r=n+2|0}s=p+1|0;if(s>>>0<16){p=s;q=(q&65535)>>>1;n=r}else{break}}c[a+112+((b[e>>1]&7)<<2)>>2]=r;c[m>>2]=(c[m>>2]|0)+12;o=2;return o|0}else if((g|0)==0){iA(a);g=a+268|0;c[g>>2]=(c[g>>2]|0)+2;o=0;return o|0}else{g=(c[a+144>>2]|0)+2&16777215;m=g+1|0;r=a+36|0;if(m>>>0<(c[r>>2]|0)>>>0){n=c[a+32>>2]|0;v=(d[n+g|0]|0)<<8|(d[n+m|0]|0);w=f}else{f=b6[c[a+12>>2]&63](c[a+4>>2]|0,g)|0;v=f;w=b[e>>1]|0}b[a+198>>1]=v;e=a+192|0;c[e>>2]=2;f=w&63;if((b5[c[20008+(f<<2)>>2]&127](a,f,2028,16)|0)!=0){o=0;return o|0}if((c[a+228>>2]|0)!=2){iA(a);o=0;return o|0}f=c[a+232>>2]|0;do{if(v<<16>>16==0){x=0}else{if((c[a>>2]&1|0)!=0){x=v;break}if((f&1|0)==0){x=v;break}iw(a,f,1,0);o=0;return o|0}}while(0);v=a+32|0;w=a+268|0;g=a+12|0;m=a+4|0;n=0;q=x;x=f;while(1){if((q&1)==0){y=x}else{f=x&16777215;p=f+1|0;if(p>>>0<(c[r>>2]|0)>>>0){u=c[v>>2]|0;z=(d[u+f|0]|0)<<8|(d[u+p|0]|0)}else{z=b6[c[g>>2]&63](c[m>>2]|0,f)|0}f=z&65535;p=(f&32768|0)!=0?f|-65536:f;f=n&7;if(n>>>0<8){c[a+80+(f<<2)>>2]=p}else{c[a+112+(f<<2)>>2]=p}c[w>>2]=(c[w>>2]|0)+4;y=x+2|0}p=n+1|0;if(p>>>0<16){n=p;q=(q&65535)>>>1;x=y}else{break}}c[w>>2]=(c[w>>2]|0)+12;o=c[e>>2]|0;return o|0}return 0}function jL(a){a=a|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=a+196|0;f=b[e>>1]|0;g=(f&65535)>>>3&7;if((g|0)==0){iA(a);h=a+268|0;c[h>>2]=(c[h>>2]|0)+2;i=0;return i|0}else if((g|0)==3){g=(c[a+144>>2]|0)+2&16777215;h=g+1|0;j=a+36|0;if(h>>>0<(c[j>>2]|0)>>>0){k=c[a+32>>2]|0;l=(d[k+g|0]|0)<<8|(d[k+h|0]|0);m=f}else{h=b6[c[a+12>>2]&63](c[a+4>>2]|0,g)|0;l=h;m=b[e>>1]|0}b[a+198>>1]=l;c[a+192>>2]=2;h=c[a+112+((m&7)<<2)>>2]|0;do{if(l<<16>>16==0){n=0}else{if((c[a>>2]&1|0)!=0){n=l;break}if((h&1|0)==0){n=l;break}iw(a,h,1,0);i=0;return i|0}}while(0);l=a+32|0;m=a+268|0;g=a+16|0;k=a+4|0;o=0;p=n;n=h;while(1){if((p&1)==0){q=n}else{h=n&16777215;r=h+3|0;if(r>>>0<(c[j>>2]|0)>>>0){s=c[l>>2]|0;t=(((d[s+h|0]|0)<<8|(d[s+(h+1)|0]|0))<<8|(d[s+(h+2)|0]|0))<<8|(d[s+r|0]|0)}else{t=b6[c[g>>2]&63](c[k>>2]|0,h)|0}h=o&7;if(o>>>0<8){c[a+80+(h<<2)>>2]=t}else{c[a+112+(h<<2)>>2]=t}c[m>>2]=(c[m>>2]|0)+8;q=n+4|0}h=o+1|0;if(h>>>0<16){o=h;p=(p&65535)>>>1;n=q}else{break}}c[a+112+((b[e>>1]&7)<<2)>>2]=q;c[m>>2]=(c[m>>2]|0)+12;i=2;return i|0}else{m=(c[a+144>>2]|0)+2&16777215;q=m+1|0;n=a+36|0;if(q>>>0<(c[n>>2]|0)>>>0){p=c[a+32>>2]|0;u=(d[p+m|0]|0)<<8|(d[p+q|0]|0);v=f}else{f=b6[c[a+12>>2]&63](c[a+4>>2]|0,m)|0;u=f;v=b[e>>1]|0}b[a+198>>1]=u;e=a+192|0;c[e>>2]=2;f=v&63;if((b5[c[20008+(f<<2)>>2]&127](a,f,2028,32)|0)!=0){i=0;return i|0}if((c[a+228>>2]|0)!=2){iA(a);i=0;return i|0}f=c[a+232>>2]|0;do{if(u<<16>>16==0){w=0}else{if((c[a>>2]&1|0)!=0){w=u;break}if((f&1|0)==0){w=u;break}iw(a,f,1,0);i=0;return i|0}}while(0);u=a+32|0;v=a+268|0;m=a+16|0;q=a+4|0;p=0;o=w;w=f;while(1){if((o&1)==0){x=w}else{f=w&16777215;t=f+3|0;if(t>>>0<(c[n>>2]|0)>>>0){k=c[u>>2]|0;y=(((d[k+f|0]|0)<<8|(d[k+(f+1)|0]|0))<<8|(d[k+(f+2)|0]|0))<<8|(d[k+t|0]|0)}else{y=b6[c[m>>2]&63](c[q>>2]|0,f)|0}f=p&7;if(p>>>0<8){c[a+80+(f<<2)>>2]=y}else{c[a+112+(f<<2)>>2]=y}c[v>>2]=(c[v>>2]|0)+8;x=w+4|0}f=p+1|0;if(f>>>0<16){p=f;o=(o&65535)>>>1;w=x}else{break}}c[v>>2]=(c[v>>2]|0)+12;i=c[e>>2]|0;return i|0}return 0}function jM(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;f=e+196|0;g=b[f>>1]|0;h=g&65535;if((h|0)==20080){if((a[e+188|0]|0)==0){iE(e);i=0;return i|0}else{iJ(e);j=e+268|0;c[j>>2]=(c[j>>2]|0)+132;i=0;return i|0}}else if((h|0)==20081){j=e+268|0;c[j>>2]=(c[j>>2]|0)+4;i=1;return i|0}else if((h|0)==20082){if((a[e+188|0]|0)==0){iE(e);i=0;return i|0}j=(c[e+144>>2]|0)+2&16777215;k=j+1|0;if(k>>>0<(c[e+36>>2]|0)>>>0){l=c[e+32>>2]|0;m=d[l+j|0]<<8|d[l+k|0]}else{m=b6[c[e+12>>2]&63](c[e+4>>2]|0,j)|0}b[e+198>>1]=m;c[e+192>>2]=2;is(e,m);m=e+268|0;c[m>>2]=(c[m>>2]|0)+4;m=e+189|0;a[m]=a[m]|1;i=2;return i|0}else if((h|0)==20083){m=e+188|0;if((a[m]|0)==0){iE(e);i=0;return i|0}j=e+140|0;k=c[j>>2]|0;l=k&16777215;n=l+1|0;o=e+36|0;p=c[o>>2]|0;if(n>>>0<p>>>0){q=c[e+32>>2]|0;r=d[q+l|0]<<8|d[q+n|0];s=p}else{p=b6[c[e+12>>2]&63](c[e+4>>2]|0,l)|0;r=p;s=c[o>>2]|0}p=k+2&16777215;l=p+3|0;if(l>>>0<s>>>0){s=c[e+32>>2]|0;t=((d[s+p|0]<<8|d[s+(p+1)|0])<<8|d[s+(p+2)|0])<<8|d[s+l|0]}else{t=b6[c[e+16>>2]&63](c[e+4>>2]|0,p)|0}p=e|0;do{if((c[p>>2]&2|0)!=0){l=k+6&16777215;s=l+1|0;if(s>>>0<(c[o>>2]|0)>>>0){n=c[e+32>>2]|0;u=d[n+l|0]<<8|d[n+s|0]}else{u=b6[c[e+12>>2]&63](c[e+4>>2]|0,l)|0}l=(u&65535)>>>12;if((l|0)==0|(l|0)==8){break}iH(e);i=0;return i|0}}while(0);is(e,r);c[e+144>>2]=t;do{if((c[p>>2]&2|0)==0){t=k+6|0;if((a[m]|0)==0){c[e+156>>2]=t;break}else{c[j>>2]=t;break}}else{t=k+8|0;if((a[m]|0)==0){c[e+156>>2]=t;break}else{c[j>>2]=t;break}}}while(0);j=e+268|0;c[j>>2]=(c[j>>2]|0)+20;i=0;return i|0}else if((h|0)==20084){if((c[e>>2]&2|0)==0){iA(e);j=e+268|0;c[j>>2]=(c[j>>2]|0)+2;i=0;return i|0}j=e+144|0;m=(c[j>>2]|0)+2&16777215;k=m+1|0;p=e+36|0;t=c[p>>2]|0;if(k>>>0<t>>>0){r=c[e+32>>2]|0;v=d[r+m|0]<<8|d[r+k|0];w=t}else{t=b6[c[e+12>>2]&63](c[e+4>>2]|0,m)|0;v=t;w=c[p>>2]|0}b[e+198>>1]=v;c[e+192>>2]=2;p=v&65535;v=e+140|0;t=c[v>>2]|0;m=t&16777215;k=m+3|0;if(k>>>0<w>>>0){w=c[e+32>>2]|0;x=((d[w+m|0]<<8|d[w+(m+1)|0])<<8|d[w+(m+2)|0])<<8|d[w+k|0]}else{x=b6[c[e+16>>2]&63](c[e+4>>2]|0,m)|0}c[j>>2]=x;c[v>>2]=t+4+((p&32768|0)!=0?p|-65536:p);p=e+268|0;c[p>>2]=(c[p>>2]|0)+16;i=0;return i|0}else if((h|0)==20085){p=e+140|0;t=c[p>>2]|0;v=t&16777215;x=v+3|0;if(x>>>0<(c[e+36>>2]|0)>>>0){j=c[e+32>>2]|0;y=((d[j+v|0]<<8|d[j+(v+1)|0])<<8|d[j+(v+2)|0])<<8|d[j+x|0]}else{y=b6[c[e+16>>2]&63](c[e+4>>2]|0,v)|0}c[e+144>>2]=y;c[p>>2]=t+4;t=e+268|0;c[t>>2]=(c[t>>2]|0)+16;i=0;return i|0}else if((h|0)==20086){t=e+144|0;c[t>>2]=(c[t>>2]|0)+2;if((b[e+148>>1]&2)!=0){iD(e)}t=e+268|0;c[t>>2]=(c[t>>2]|0)+4;i=0;return i|0}else if((h|0)==20087){t=e+140|0;p=c[t>>2]|0;y=p&16777215;v=y+1|0;x=e+36|0;j=c[x>>2]|0;if(v>>>0<j>>>0){z=a[(c[e+32>>2]|0)+v|0]|0;A=j}else{j=(b6[c[e+12>>2]&63](c[e+4>>2]|0,y)|0)&255;z=j;A=c[x>>2]|0}x=e+148|0;b[x>>1]=b[x>>1]&-256|z&31;z=p+2&16777215;x=z+3|0;if(x>>>0<A>>>0){A=c[e+32>>2]|0;B=((d[A+z|0]<<8|d[A+(z+1)|0])<<8|d[A+(z+2)|0])<<8|d[A+x|0]}else{B=b6[c[e+16>>2]&63](c[e+4>>2]|0,z)|0}c[e+144>>2]=B;c[t>>2]=p+6;p=e+268|0;c[p>>2]=(c[p>>2]|0)+20;i=0;return i|0}else if((h|0)==20090){p=e|0;if((c[p>>2]&2|0)==0){iA(e);t=e+268|0;c[t>>2]=(c[t>>2]|0)+2;i=0;return i|0}t=e+188|0;if((a[t]|0)==0){iE(e);i=0;return i|0}B=(c[e+144>>2]|0)+2&16777215;z=B+1|0;if(z>>>0<(c[e+36>>2]|0)>>>0){x=c[e+32>>2]|0;C=d[x+B|0]<<8|d[x+z|0]}else{C=b6[c[e+12>>2]&63](c[e+4>>2]|0,B)|0}b[e+198>>1]=C;c[e+192>>2]=2;B=C&65535;C=B&4095;z=B>>>12;do{if((C|0)==0){D=c[e+164>>2]&3}else if((C|0)==1){D=c[e+168>>2]&3}else if((C|0)==2){if((c[p>>2]&4|0)!=0){D=c[e+160>>2]|0;break}iA(e);B=e+268|0;c[B>>2]=(c[B>>2]|0)+2;i=0;return i|0}else if((C|0)==2048){D=c[((a[t]|0)==0?e+140|0:e+152|0)>>2]|0}else if((C|0)==2049){D=c[e+160>>2]|0}else if((C|0)==2050){if((c[p>>2]&4|0)!=0){D=c[e+160>>2]|0;break}iA(e);B=e+268|0;c[B>>2]=(c[B>>2]|0)+2;i=0;return i|0}else{iA(e);i=0;return i|0}}while(0);p=z&7;if((z&8|0)==0){c[e+80+(p<<2)>>2]=D}else{c[e+112+(p<<2)>>2]=D}D=e+268|0;c[D>>2]=(c[D>>2]|0)+12;i=2;return i|0}else if((h|0)==20091){D=e|0;if((c[D>>2]&2|0)==0){iA(e);p=e+268|0;c[p>>2]=(c[p>>2]|0)+2;i=0;return i|0}p=e+188|0;if((a[p]|0)==0){iE(e);i=0;return i|0}z=(c[e+144>>2]|0)+2&16777215;C=z+1|0;if(C>>>0<(c[e+36>>2]|0)>>>0){t=c[e+32>>2]|0;E=d[t+z|0]<<8|d[t+C|0]}else{E=b6[c[e+12>>2]&63](c[e+4>>2]|0,z)|0}b[e+198>>1]=E;c[e+192>>2]=2;z=E&65535;E=z&4095;C=z>>>12;z=C&7;if((C&8|0)==0){F=e+80+(z<<2)|0}else{F=e+112+(z<<2)|0}z=c[F>>2]|0;do{if((E|0)==0){c[e+164>>2]=z&3}else if((E|0)==1){c[e+168>>2]=z&3}else if((E|0)==2){if((c[D>>2]&4|0)!=0){c[e+172>>2]=z;break}iA(e);F=e+268|0;c[F>>2]=(c[F>>2]|0)+2;i=0;return i|0}else if((E|0)==2048){if((a[p]|0)==0){c[e+140>>2]=z;break}else{c[e+152>>2]=z;break}}else if((E|0)==2049){c[e+160>>2]=z}else if((E|0)==2050){if((c[D>>2]&4|0)!=0){c[e+172>>2]=z;break}iA(e);F=e+268|0;c[F>>2]=(c[F>>2]|0)+2;i=0;return i|0}else{iA(e);i=0;return i|0}}while(0);z=e+268|0;c[z>>2]=(c[z>>2]|0)+10;i=2;return i|0}else{z=h>>>3&7;if((z|0)==0|(z|0)==1){D=e+144|0;c[D>>2]=(c[D>>2]|0)+2;iI(e,h&15);i=0;return i|0}else if((z|0)==2){D=(c[e+144>>2]|0)+2&16777215;E=D+1|0;p=e+36|0;F=c[p>>2]|0;if(E>>>0<F>>>0){C=c[e+32>>2]|0;G=d[C+D|0]<<8|d[C+E|0];H=F;I=g}else{g=b6[c[e+12>>2]&63](c[e+4>>2]|0,D)|0;G=g;H=c[p>>2]|0;I=b[f>>1]|0}b[e+198>>1]=G;c[e+192>>2]=2;f=G&65535;G=e+140|0;p=(c[G>>2]|0)-4|0;c[G>>2]=p;g=e+112+((I&7)<<2)|0;I=c[g>>2]|0;D=p&16777215;p=D+3|0;if(p>>>0<H>>>0){H=e+32|0;a[(c[H>>2]|0)+D|0]=I>>>24&255;a[(c[H>>2]|0)+(D+1)|0]=I>>>16&255;a[(c[H>>2]|0)+(D+2)|0]=I>>>8&255;a[(c[H>>2]|0)+p|0]=I&255}else{b3[c[e+28>>2]&63](c[e+4>>2]|0,D,I)}c[g>>2]=c[G>>2];c[G>>2]=(c[G>>2]|0)+((f&32768|0)!=0?f|-65536:f);f=e+268|0;c[f>>2]=(c[f>>2]|0)+16;i=2;return i|0}else if((z|0)==3){f=e+112+((h&7)<<2)|0;G=c[f>>2]|0;do{if((c[e>>2]&1|0)==0){if((G&1|0)==0){break}iw(e,G,1,0);i=0;return i|0}}while(0);g=e+140|0;c[g>>2]=G;I=G&16777215;G=I+3|0;if(G>>>0<(c[e+36>>2]|0)>>>0){D=c[e+32>>2]|0;J=((d[D+I|0]<<8|d[D+(I+1)|0])<<8|d[D+(I+2)|0])<<8|d[D+G|0]}else{J=b6[c[e+16>>2]&63](c[e+4>>2]|0,I)|0}c[f>>2]=J;c[g>>2]=(c[g>>2]|0)+4;g=e+268|0;c[g>>2]=(c[g>>2]|0)+12;i=1;return i|0}else if((z|0)==4){if((a[e+188|0]|0)==0){iE(e);i=0;return i|0}else{c[e+152>>2]=c[e+112+((h&7)<<2)>>2];g=e+268|0;c[g>>2]=(c[g>>2]|0)+4;i=1;return i|0}}else if((z|0)==5){if((a[e+188|0]|0)==0){iE(e);i=0;return i|0}else{c[e+112+((h&7)<<2)>>2]=c[e+152>>2];h=e+268|0;c[h>>2]=(c[h>>2]|0)+4;i=1;return i|0}}else{iA(e);h=e+268|0;c[h>>2]=(c[h>>2]|0)+2;i=0;return i|0}}return 0}function jN(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b[d+196>>1]&63;if((b5[c[20008+(e<<2)>>2]&127](d,e,2020,32)|0)!=0){return 0}if((c[d+228>>2]|0)!=2){iA(d);return 0}e=d+144|0;f=(c[d+192>>2]<<1)+(c[e>>2]|0)|0;g=d+140|0;h=(c[g>>2]|0)-4|0;i=h&16777215;j=i+3|0;if(j>>>0<(c[d+36>>2]|0)>>>0){k=d+32|0;a[(c[k>>2]|0)+i|0]=f>>>24&255;a[(c[k>>2]|0)+(i+1)|0]=f>>>16&255;a[(c[k>>2]|0)+(i+2)|0]=f>>>8&255;a[(c[k>>2]|0)+j|0]=f&255}else{b3[c[d+28>>2]&63](c[d+4>>2]|0,i,f)}c[g>>2]=h;c[e>>2]=c[d+232>>2];e=d+268|0;c[e>>2]=(c[e>>2]|0)+16;return 0}function jO(a){a=a|0;var d=0;d=b[a+196>>1]&63;if((b5[c[20008+(d<<2)>>2]&127](a,d,2020,32)|0)!=0){return 0}if((c[a+228>>2]|0)==2){c[a+144>>2]=c[a+232>>2];d=a+268|0;c[d>>2]=(c[d>>2]|0)+8;return 0}else{iA(a);return 0}return 0}function jP(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;i=i+8|0;f=e|0;g=b[d+196>>1]|0;h=(g&65535)>>>9&7;j=g&63;if((b5[c[20008+(j<<2)>>2]&127](d,j,509,8)|0)!=0){k=0;i=e;return k|0}if((mm(d,f)|0)!=0){k=0;i=e;return k|0}j=h<<24>>24==0?8:h;h=(a[f]|0)+j&255;if((mp(d,h)|0)!=0){k=0;i=e;return k|0}lP(d,h,j,a[f]|0);f=d+268|0;c[f>>2]=(c[f>>2]|0)+8;k=c[d+192>>2]|0;i=e;return k|0}function jQ(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+8|0;e=d|0;f=b[a+196>>1]|0;g=f&65535;if((g&56|0)==8){h=g>>>9&7;j=a+112+((g&7)<<2)|0;c[j>>2]=(c[j>>2]|0)+((h|0)==0?8:h);h=a+268|0;c[h>>2]=(c[h>>2]|0)+8;k=1;i=d;return k|0}h=(f&65535)>>>9&7;f=g&63;if((b5[c[20008+(f<<2)>>2]&127](a,f,509,16)|0)!=0){k=0;i=d;return k|0}if((mn(a,e)|0)!=0){k=0;i=d;return k|0}f=h<<16>>16==0?8:h;h=(b[e>>1]|0)+f&65535;if((mq(a,h)|0)!=0){k=0;i=d;return k|0}lQ(a,h,f,b[e>>1]|0);e=a+268|0;c[e>>2]=(c[e>>2]|0)+8;k=c[a+192>>2]|0;i=d;return k|0}function jR(a){a=a|0;var b=0,d=0,f=0,g=0,h=0,j=0;b=i;i=i+8|0;d=b|0;f=e[a+196>>1]|0;if((f&56|0)==8){g=f>>>9&7;h=a+112+((f&7)<<2)|0;c[h>>2]=(c[h>>2]|0)+((g|0)==0?8:g);g=a+268|0;c[g>>2]=(c[g>>2]|0)+12;j=1;i=b;return j|0}g=f>>>9&7;h=f&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,509,32)|0)!=0){j=0;i=b;return j|0}if((mo(a,d)|0)!=0){j=0;i=b;return j|0}h=(g|0)==0?8:g;g=(c[d>>2]|0)+h|0;if((mr(a,g)|0)!=0){j=0;i=b;return j|0}lR(a,g,h,c[d>>2]|0);d=a+268|0;c[d>>2]=(c[d>>2]|0)+12;j=c[a+192>>2]|0;i=b;return j|0}function jS(a){a=a|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=b[a+196>>1]|0;if((e&56)==8){f=(c[a+144>>2]|0)+2&16777215;g=f+1|0;if(g>>>0<(c[a+36>>2]|0)>>>0){h=c[a+32>>2]|0;i=(d[h+f|0]|0)<<8|(d[h+g|0]|0)}else{i=b6[c[a+12>>2]&63](c[a+4>>2]|0,f)|0}b[a+198>>1]=i;c[a+192>>2]=2;i=a+268|0;c[i>>2]=(c[i>>2]|0)+12;j=2;return j|0}i=e&63;if((b5[c[20008+(i<<2)>>2]&127](a,i,509,8)|0)!=0){j=0;return j|0}if((mp(a,-1)|0)!=0){j=0;return j|0}i=a+268|0;c[i>>2]=(c[i>>2]|0)+4;j=c[a+192>>2]|0;return j|0}function jT(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;i=i+8|0;f=e|0;g=b[d+196>>1]|0;h=(g&65535)>>>9&7;j=g&63;if((b5[c[20008+(j<<2)>>2]&127](d,j,509,8)|0)!=0){k=0;i=e;return k|0}if((mm(d,f)|0)!=0){k=0;i=e;return k|0}j=h<<24>>24==0?8:h;h=(a[f]|0)-j&255;if((mp(d,h)|0)!=0){k=0;i=e;return k|0}l1(d,h,j,a[f]|0);f=d+268|0;c[f>>2]=(c[f>>2]|0)+8;k=c[d+192>>2]|0;i=e;return k|0}function jU(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+8|0;e=d|0;f=b[a+196>>1]|0;g=f&65535;if((g&56|0)==8){h=g>>>9&7;j=a+112+((g&7)<<2)|0;c[j>>2]=(c[j>>2]|0)-((h|0)==0?8:h);h=a+268|0;c[h>>2]=(c[h>>2]|0)+8;k=1;i=d;return k|0}h=(f&65535)>>>9&7;f=g&63;if((b5[c[20008+(f<<2)>>2]&127](a,f,509,16)|0)!=0){k=0;i=d;return k|0}if((mn(a,e)|0)!=0){k=0;i=d;return k|0}f=h<<16>>16==0?8:h;h=(b[e>>1]|0)-f&65535;if((mq(a,h)|0)!=0){k=0;i=d;return k|0}l2(a,h,f,b[e>>1]|0);e=a+268|0;c[e>>2]=(c[e>>2]|0)+8;k=c[a+192>>2]|0;i=d;return k|0}function jV(a){a=a|0;var b=0,d=0,f=0,g=0,h=0,j=0;b=i;i=i+8|0;d=b|0;f=e[a+196>>1]|0;if((f&56|0)==8){g=f>>>9&7;h=a+112+((f&7)<<2)|0;c[h>>2]=(c[h>>2]|0)-((g|0)==0?8:g);g=a+268|0;c[g>>2]=(c[g>>2]|0)+12;j=1;i=b;return j|0}g=f>>>9&7;h=f&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,509,32)|0)!=0){j=0;i=b;return j|0}if((mo(a,d)|0)!=0){j=0;i=b;return j|0}h=(g|0)==0?8:g;g=(c[d>>2]|0)-h|0;if((mr(a,g)|0)!=0){j=0;i=b;return j|0}l3(a,g,h,c[d>>2]|0);d=a+268|0;c[d>>2]=(c[d>>2]|0)+12;j=c[a+192>>2]|0;i=b;return j|0}function jW(a){a=a|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=a+196|0;f=b[e>>1]|0;if((f&56)!=8){g=f&63;if((b5[c[20008+(g<<2)>>2]&127](a,g,509,8)|0)!=0){h=0;return h|0}if((mp(a,0)|0)!=0){h=0;return h|0}g=a+268|0;c[g>>2]=(c[g>>2]|0)+4;h=c[a+192>>2]|0;return h|0}g=a+144|0;i=(c[g>>2]|0)+2&16777215;j=i+1|0;if(j>>>0<(c[a+36>>2]|0)>>>0){k=c[a+32>>2]|0;l=(d[k+i|0]|0)<<8|(d[k+j|0]|0);m=f}else{f=b6[c[a+12>>2]&63](c[a+4>>2]|0,i)|0;l=f;m=b[e>>1]|0}b[a+198>>1]=l;c[a+192>>2]=2;e=l&65535;l=a+80+((m&7)<<2)|0;m=c[l>>2]|0;f=m+65535&65535;c[l>>2]=f|m&-65536;if((f|0)==65535){f=a+268|0;c[f>>2]=(c[f>>2]|0)+14;h=2;return h|0}else{c[g>>2]=((e&32768|0)!=0?e|-65536:e)+2+(c[g>>2]|0);g=a+268|0;c[g>>2]=(c[g>>2]|0)+10;h=0;return h|0}return 0}function jX(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=e[a+148>>1]|0;if((f&1|0)==0){g=f>>>2&1^1}else{g=0}f=a+196|0;h=b[f>>1]|0;if((h&56)!=8){i=h&63;if((b5[c[20008+(i<<2)>>2]&127](a,i,509,8)|0)!=0){j=0;return j|0}if((mp(a,((g|0)!=0)<<31>>31)|0)!=0){j=0;return j|0}i=a+268|0;c[i>>2]=(c[i>>2]|0)+4;j=c[a+192>>2]|0;return j|0}i=a+144|0;h=(c[i>>2]|0)+2&16777215;k=h+1|0;if(k>>>0<(c[a+36>>2]|0)>>>0){l=c[a+32>>2]|0;m=(d[l+h|0]|0)<<8|(d[l+k|0]|0)}else{m=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0}b[a+198>>1]=m;c[a+192>>2]=2;h=m&65535;if((g|0)!=0){g=a+268|0;c[g>>2]=(c[g>>2]|0)+12;j=2;return j|0}g=a+80+((b[f>>1]&7)<<2)|0;f=c[g>>2]|0;m=f+65535&65535;c[g>>2]=m|f&-65536;if((m|0)==65535){m=a+268|0;c[m>>2]=(c[m>>2]|0)+14;j=2;return j|0}else{c[i>>2]=((h&32768|0)!=0?h|-65536:h)+2+(c[i>>2]|0);i=a+268|0;c[i>>2]=(c[i>>2]|0)+10;j=0;return j|0}return 0}function jY(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=e[a+148>>1]|0;if((f&1|0)==0){g=f>>>2&1}else{g=1}f=a+196|0;h=b[f>>1]|0;if((h&56)!=8){i=h&63;if((b5[c[20008+(i<<2)>>2]&127](a,i,509,8)|0)!=0){j=0;return j|0}if((mp(a,g<<31>>31&255)|0)!=0){j=0;return j|0}i=a+268|0;c[i>>2]=(c[i>>2]|0)+4;j=c[a+192>>2]|0;return j|0}i=a+144|0;h=(c[i>>2]|0)+2&16777215;k=h+1|0;if(k>>>0<(c[a+36>>2]|0)>>>0){l=c[a+32>>2]|0;m=(d[l+h|0]|0)<<8|(d[l+k|0]|0)}else{m=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0}b[a+198>>1]=m;c[a+192>>2]=2;h=m&65535;if((g|0)!=0){g=a+268|0;c[g>>2]=(c[g>>2]|0)+12;j=2;return j|0}g=a+80+((b[f>>1]&7)<<2)|0;f=c[g>>2]|0;m=f+65535&65535;c[g>>2]=m|f&-65536;if((m|0)==65535){m=a+268|0;c[m>>2]=(c[m>>2]|0)+14;j=2;return j|0}else{c[i>>2]=((h&32768|0)!=0?h|-65536:h)+2+(c[i>>2]|0);i=a+268|0;c[i>>2]=(c[i>>2]|0)+10;j=0;return j|0}return 0}function jZ(a){a=a|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=b[a+148>>1]&1;f=a+196|0;g=b[f>>1]|0;if((g&56)!=8){h=g&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,509,8)|0)!=0){i=0;return i|0}if((mp(a,e+255&255)|0)!=0){i=0;return i|0}h=a+268|0;c[h>>2]=(c[h>>2]|0)+4;i=c[a+192>>2]|0;return i|0}h=a+144|0;g=(c[h>>2]|0)+2&16777215;j=g+1|0;if(j>>>0<(c[a+36>>2]|0)>>>0){k=c[a+32>>2]|0;l=(d[k+g|0]|0)<<8|(d[k+j|0]|0)}else{l=b6[c[a+12>>2]&63](c[a+4>>2]|0,g)|0}b[a+198>>1]=l;c[a+192>>2]=2;g=l&65535;if(e<<16>>16==0){e=a+268|0;c[e>>2]=(c[e>>2]|0)+12;i=2;return i|0}e=a+80+((b[f>>1]&7)<<2)|0;f=c[e>>2]|0;l=f+65535&65535;c[e>>2]=l|f&-65536;if((l|0)==65535){l=a+268|0;c[l>>2]=(c[l>>2]|0)+14;i=2;return i|0}else{c[h>>2]=((g&32768|0)!=0?g|-65536:g)+2+(c[h>>2]|0);h=a+268|0;c[h>>2]=(c[h>>2]|0)+10;i=0;return i|0}return 0}function j_(a){a=a|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=b[a+148>>1]|0;f=e&1;g=a+196|0;h=b[g>>1]|0;if((h&56)!=8){i=h&63;if((b5[c[20008+(i<<2)>>2]&127](a,i,509,8)|0)!=0){j=0;return j|0}if((mp(a,e<<15<<16>>16>>15&255)|0)!=0){j=0;return j|0}e=a+268|0;c[e>>2]=(c[e>>2]|0)+4;j=c[a+192>>2]|0;return j|0}e=a+144|0;i=(c[e>>2]|0)+2&16777215;h=i+1|0;if(h>>>0<(c[a+36>>2]|0)>>>0){k=c[a+32>>2]|0;l=(d[k+i|0]|0)<<8|(d[k+h|0]|0)}else{l=b6[c[a+12>>2]&63](c[a+4>>2]|0,i)|0}b[a+198>>1]=l;c[a+192>>2]=2;i=l&65535;if(f<<16>>16!=0){f=a+268|0;c[f>>2]=(c[f>>2]|0)+12;j=2;return j|0}f=a+80+((b[g>>1]&7)<<2)|0;g=c[f>>2]|0;l=g+65535&65535;c[f>>2]=l|g&-65536;if((l|0)==65535){l=a+268|0;c[l>>2]=(c[l>>2]|0)+14;j=2;return j|0}else{c[e>>2]=((i&32768|0)!=0?i|-65536:i)+2+(c[e>>2]|0);e=a+268|0;c[e>>2]=(c[e>>2]|0)+10;j=0;return j|0}return 0}function j$(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=(e[a+148>>1]|0)>>>2&1;g=a+196|0;h=b[g>>1]|0;if((h&56)!=8){i=h&63;if((b5[c[20008+(i<<2)>>2]&127](a,i,509,8)|0)!=0){j=0;return j|0}if((mp(a,f+255&255)|0)!=0){j=0;return j|0}i=a+268|0;c[i>>2]=(c[i>>2]|0)+4;j=c[a+192>>2]|0;return j|0}i=a+144|0;h=(c[i>>2]|0)+2&16777215;k=h+1|0;if(k>>>0<(c[a+36>>2]|0)>>>0){l=c[a+32>>2]|0;m=(d[l+h|0]|0)<<8|(d[l+k|0]|0)}else{m=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0}b[a+198>>1]=m;c[a+192>>2]=2;h=m&65535;if(f<<16>>16==0){f=a+268|0;c[f>>2]=(c[f>>2]|0)+12;j=2;return j|0}f=a+80+((b[g>>1]&7)<<2)|0;g=c[f>>2]|0;m=g+65535&65535;c[f>>2]=m|g&-65536;if((m|0)==65535){m=a+268|0;c[m>>2]=(c[m>>2]|0)+14;j=2;return j|0}else{c[i>>2]=((h&32768|0)!=0?h|-65536:h)+2+(c[i>>2]|0);i=a+268|0;c[i>>2]=(c[i>>2]|0)+10;j=0;return j|0}return 0}function j0(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=(e[a+148>>1]|0)>>>2;g=f&1;h=a+196|0;i=b[h>>1]|0;if((i&56)!=8){j=i&63;if((b5[c[20008+(j<<2)>>2]&127](a,j,509,8)|0)!=0){k=0;return k|0}if((mp(a,f<<15<<16>>16>>15&255)|0)!=0){k=0;return k|0}f=a+268|0;c[f>>2]=(c[f>>2]|0)+4;k=c[a+192>>2]|0;return k|0}f=a+144|0;j=(c[f>>2]|0)+2&16777215;i=j+1|0;if(i>>>0<(c[a+36>>2]|0)>>>0){l=c[a+32>>2]|0;m=(d[l+j|0]|0)<<8|(d[l+i|0]|0)}else{m=b6[c[a+12>>2]&63](c[a+4>>2]|0,j)|0}b[a+198>>1]=m;c[a+192>>2]=2;j=m&65535;if(g<<16>>16!=0){g=a+268|0;c[g>>2]=(c[g>>2]|0)+12;k=2;return k|0}g=a+80+((b[h>>1]&7)<<2)|0;h=c[g>>2]|0;m=h+65535&65535;c[g>>2]=m|h&-65536;if((m|0)==65535){m=a+268|0;c[m>>2]=(c[m>>2]|0)+14;k=2;return k|0}else{c[f>>2]=((j&32768|0)!=0?j|-65536:j)+2+(c[f>>2]|0);f=a+268|0;c[f>>2]=(c[f>>2]|0)+10;k=0;return k|0}return 0}function j1(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=(e[a+148>>1]|0)>>>1&1;g=a+196|0;h=b[g>>1]|0;if((h&56)!=8){i=h&63;if((b5[c[20008+(i<<2)>>2]&127](a,i,509,8)|0)!=0){j=0;return j|0}if((mp(a,f+255&255)|0)!=0){j=0;return j|0}i=a+268|0;c[i>>2]=(c[i>>2]|0)+4;j=c[a+192>>2]|0;return j|0}i=a+144|0;h=(c[i>>2]|0)+2&16777215;k=h+1|0;if(k>>>0<(c[a+36>>2]|0)>>>0){l=c[a+32>>2]|0;m=(d[l+h|0]|0)<<8|(d[l+k|0]|0)}else{m=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0}b[a+198>>1]=m;c[a+192>>2]=2;h=m&65535;if(f<<16>>16==0){f=a+268|0;c[f>>2]=(c[f>>2]|0)+12;j=2;return j|0}f=a+80+((b[g>>1]&7)<<2)|0;g=c[f>>2]|0;m=g+65535&65535;c[f>>2]=m|g&-65536;if((m|0)==65535){m=a+268|0;c[m>>2]=(c[m>>2]|0)+14;j=2;return j|0}else{c[i>>2]=((h&32768|0)!=0?h|-65536:h)+2+(c[i>>2]|0);i=a+268|0;c[i>>2]=(c[i>>2]|0)+10;j=0;return j|0}return 0}function j2(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=(e[a+148>>1]|0)>>>1;g=f&1;h=a+196|0;i=b[h>>1]|0;if((i&56)!=8){j=i&63;if((b5[c[20008+(j<<2)>>2]&127](a,j,509,8)|0)!=0){k=0;return k|0}if((mp(a,f<<15<<16>>16>>15&255)|0)!=0){k=0;return k|0}f=a+268|0;c[f>>2]=(c[f>>2]|0)+4;k=c[a+192>>2]|0;return k|0}f=a+144|0;j=(c[f>>2]|0)+2&16777215;i=j+1|0;if(i>>>0<(c[a+36>>2]|0)>>>0){l=c[a+32>>2]|0;m=(d[l+j|0]|0)<<8|(d[l+i|0]|0)}else{m=b6[c[a+12>>2]&63](c[a+4>>2]|0,j)|0}b[a+198>>1]=m;c[a+192>>2]=2;j=m&65535;if(g<<16>>16!=0){g=a+268|0;c[g>>2]=(c[g>>2]|0)+12;k=2;return k|0}g=a+80+((b[h>>1]&7)<<2)|0;h=c[g>>2]|0;m=h+65535&65535;c[g>>2]=m|h&-65536;if((m|0)==65535){m=a+268|0;c[m>>2]=(c[m>>2]|0)+14;k=2;return k|0}else{c[f>>2]=((j&32768|0)!=0?j|-65536:j)+2+(c[f>>2]|0);f=a+268|0;c[f>>2]=(c[f>>2]|0)+10;k=0;return k|0}return 0}function j3(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=(e[a+148>>1]|0)>>>3&1;g=a+196|0;h=b[g>>1]|0;if((h&56)!=8){i=h&63;if((b5[c[20008+(i<<2)>>2]&127](a,i,509,8)|0)!=0){j=0;return j|0}if((mp(a,f+255&255)|0)!=0){j=0;return j|0}i=a+268|0;c[i>>2]=(c[i>>2]|0)+4;j=c[a+192>>2]|0;return j|0}i=a+144|0;h=(c[i>>2]|0)+2&16777215;k=h+1|0;if(k>>>0<(c[a+36>>2]|0)>>>0){l=c[a+32>>2]|0;m=(d[l+h|0]|0)<<8|(d[l+k|0]|0)}else{m=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0}b[a+198>>1]=m;c[a+192>>2]=2;h=m&65535;if(f<<16>>16==0){f=a+268|0;c[f>>2]=(c[f>>2]|0)+12;j=2;return j|0}f=a+80+((b[g>>1]&7)<<2)|0;g=c[f>>2]|0;m=g+65535&65535;c[f>>2]=m|g&-65536;if((m|0)==65535){m=a+268|0;c[m>>2]=(c[m>>2]|0)+14;j=2;return j|0}else{c[i>>2]=((h&32768|0)!=0?h|-65536:h)+2+(c[i>>2]|0);i=a+268|0;c[i>>2]=(c[i>>2]|0)+10;j=0;return j|0}return 0}function j4(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=(e[a+148>>1]|0)>>>3;g=f&1;h=a+196|0;i=b[h>>1]|0;if((i&56)!=8){j=i&63;if((b5[c[20008+(j<<2)>>2]&127](a,j,509,8)|0)!=0){k=0;return k|0}if((mp(a,f<<15<<16>>16>>15&255)|0)!=0){k=0;return k|0}f=a+268|0;c[f>>2]=(c[f>>2]|0)+4;k=c[a+192>>2]|0;return k|0}f=a+144|0;j=(c[f>>2]|0)+2&16777215;i=j+1|0;if(i>>>0<(c[a+36>>2]|0)>>>0){l=c[a+32>>2]|0;m=(d[l+j|0]|0)<<8|(d[l+i|0]|0)}else{m=b6[c[a+12>>2]&63](c[a+4>>2]|0,j)|0}b[a+198>>1]=m;c[a+192>>2]=2;j=m&65535;if(g<<16>>16!=0){g=a+268|0;c[g>>2]=(c[g>>2]|0)+12;k=2;return k|0}g=a+80+((b[h>>1]&7)<<2)|0;h=c[g>>2]|0;m=h+65535&65535;c[g>>2]=m|h&-65536;if((m|0)==65535){m=a+268|0;c[m>>2]=(c[m>>2]|0)+14;k=2;return k|0}else{c[f>>2]=((j&32768|0)!=0?j|-65536:j)+2+(c[f>>2]|0);f=a+268|0;c[f>>2]=(c[f>>2]|0)+10;k=0;return k|0}return 0}function j5(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=e[a+148>>1]|0;g=(f>>>3^f>>>1)&1;f=a+196|0;h=b[f>>1]|0;if((h&56)!=8){i=h&63;if((b5[c[20008+(i<<2)>>2]&127](a,i,509,8)|0)!=0){j=0;return j|0}if((mp(a,g+255&255)|0)!=0){j=0;return j|0}i=a+268|0;c[i>>2]=(c[i>>2]|0)+4;j=c[a+192>>2]|0;return j|0}i=a+144|0;h=(c[i>>2]|0)+2&16777215;k=h+1|0;if(k>>>0<(c[a+36>>2]|0)>>>0){l=c[a+32>>2]|0;m=(d[l+h|0]|0)<<8|(d[l+k|0]|0)}else{m=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0}b[a+198>>1]=m;c[a+192>>2]=2;h=m&65535;if((g|0)==0){g=a+268|0;c[g>>2]=(c[g>>2]|0)+12;j=2;return j|0}g=a+80+((b[f>>1]&7)<<2)|0;f=c[g>>2]|0;m=f+65535&65535;c[g>>2]=m|f&-65536;if((m|0)==65535){m=a+268|0;c[m>>2]=(c[m>>2]|0)+14;j=2;return j|0}else{c[i>>2]=((h&32768|0)!=0?h|-65536:h)+2+(c[i>>2]|0);i=a+268|0;c[i>>2]=(c[i>>2]|0)+10;j=0;return j|0}return 0}function j6(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=e[a+148>>1]|0;g=f>>>3^f>>>1;f=g&1;h=a+196|0;i=b[h>>1]|0;if((i&56)!=8){j=i&63;if((b5[c[20008+(j<<2)>>2]&127](a,j,509,8)|0)!=0){k=0;return k|0}if((mp(a,g<<31>>31&255)|0)!=0){k=0;return k|0}g=a+268|0;c[g>>2]=(c[g>>2]|0)+4;k=c[a+192>>2]|0;return k|0}g=a+144|0;j=(c[g>>2]|0)+2&16777215;i=j+1|0;if(i>>>0<(c[a+36>>2]|0)>>>0){l=c[a+32>>2]|0;m=(d[l+j|0]|0)<<8|(d[l+i|0]|0)}else{m=b6[c[a+12>>2]&63](c[a+4>>2]|0,j)|0}b[a+198>>1]=m;c[a+192>>2]=2;j=m&65535;if((f|0)!=0){f=a+268|0;c[f>>2]=(c[f>>2]|0)+12;k=2;return k|0}f=a+80+((b[h>>1]&7)<<2)|0;h=c[f>>2]|0;m=h+65535&65535;c[f>>2]=m|h&-65536;if((m|0)==65535){m=a+268|0;c[m>>2]=(c[m>>2]|0)+14;k=2;return k|0}else{c[g>>2]=((j&32768|0)!=0?j|-65536:j)+2+(c[g>>2]|0);g=a+268|0;c[g>>2]=(c[g>>2]|0)+10;k=0;return k|0}return 0}function j7(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=e[a+148>>1]|0;if(((f>>>3^f>>>1)&1|0)==0){g=f>>>2&1^1}else{g=0}f=a+196|0;h=b[f>>1]|0;if((h&56)!=8){i=h&63;if((b5[c[20008+(i<<2)>>2]&127](a,i,509,8)|0)!=0){j=0;return j|0}if((mp(a,((g|0)!=0)<<31>>31)|0)!=0){j=0;return j|0}i=a+268|0;c[i>>2]=(c[i>>2]|0)+4;j=c[a+192>>2]|0;return j|0}i=a+144|0;h=(c[i>>2]|0)+2&16777215;k=h+1|0;if(k>>>0<(c[a+36>>2]|0)>>>0){l=c[a+32>>2]|0;m=(d[l+h|0]|0)<<8|(d[l+k|0]|0)}else{m=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0}b[a+198>>1]=m;c[a+192>>2]=2;h=m&65535;if((g|0)!=0){g=a+268|0;c[g>>2]=(c[g>>2]|0)+12;j=2;return j|0}g=a+80+((b[f>>1]&7)<<2)|0;f=c[g>>2]|0;m=f+65535&65535;c[g>>2]=m|f&-65536;if((m|0)==65535){m=a+268|0;c[m>>2]=(c[m>>2]|0)+14;j=2;return j|0}else{c[i>>2]=((h&32768|0)!=0?h|-65536:h)+2+(c[i>>2]|0);i=a+268|0;c[i>>2]=(c[i>>2]|0)+10;j=0;return j|0}return 0}function j8(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=e[a+148>>1]|0;if(((f>>>3^f>>>1)&1|0)==0){g=f>>>2&1}else{g=1}f=a+196|0;h=b[f>>1]|0;if((h&56)!=8){i=h&63;if((b5[c[20008+(i<<2)>>2]&127](a,i,509,8)|0)!=0){j=0;return j|0}if((mp(a,g<<31>>31&255)|0)!=0){j=0;return j|0}i=a+268|0;c[i>>2]=(c[i>>2]|0)+4;j=c[a+192>>2]|0;return j|0}i=a+144|0;h=(c[i>>2]|0)+2&16777215;k=h+1|0;if(k>>>0<(c[a+36>>2]|0)>>>0){l=c[a+32>>2]|0;m=(d[l+h|0]|0)<<8|(d[l+k|0]|0)}else{m=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0}b[a+198>>1]=m;c[a+192>>2]=2;h=m&65535;if((g|0)!=0){g=a+268|0;c[g>>2]=(c[g>>2]|0)+12;j=2;return j|0}g=a+80+((b[f>>1]&7)<<2)|0;f=c[g>>2]|0;m=f+65535&65535;c[g>>2]=m|f&-65536;if((m|0)==65535){m=a+268|0;c[m>>2]=(c[m>>2]|0)+14;j=2;return j|0}else{c[i>>2]=((h&32768|0)!=0?h|-65536:h)+2+(c[i>>2]|0);i=a+268|0;c[i>>2]=(c[i>>2]|0)+10;j=0;return j|0}return 0}function j9(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=e[a+196>>1]|0;g=(f&128|0)!=0?f|-256:f&255;f=a+144|0;if((g|0)!=0){h=g;i=c[f>>2]|0;j=h+2|0;k=j+i|0;c[f>>2]=k;l=a+268|0;m=c[l>>2]|0;n=m+10|0;c[l>>2]=n;return 0}g=(c[f>>2]|0)+2&16777215;o=g+1|0;if(o>>>0<(c[a+36>>2]|0)>>>0){p=c[a+32>>2]|0;q=(d[p+g|0]|0)<<8|(d[p+o|0]|0)}else{q=b6[c[a+12>>2]&63](c[a+4>>2]|0,g)|0}b[a+198>>1]=q;c[a+192>>2]=2;g=q&65535;h=(g&32768|0)!=0?g|-65536:g;i=c[f>>2]|0;j=h+2|0;k=j+i|0;c[f>>2]=k;l=a+268|0;m=c[l>>2]|0;n=m+10|0;c[l>>2]=n;return 0}function ka(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=e[f+196>>1]|0;h=(g&128|0)!=0?g|-256:g&255;if((h|0)==0){g=f+144|0;i=(c[g>>2]|0)+2&16777215;j=i+1|0;k=f+36|0;if(j>>>0<(c[k>>2]|0)>>>0){l=c[f+32>>2]|0;m=(d[l+i|0]|0)<<8|(d[l+j|0]|0)}else{m=b6[c[f+12>>2]&63](c[f+4>>2]|0,i)|0}b[f+198>>1]=m;c[f+192>>2]=2;i=m&65535;n=(i&32768|0)!=0?i|-65536:i;o=4;p=g;q=k}else{n=h;o=c[f+192>>2]<<1;p=f+144|0;q=f+36|0}h=o+(c[p>>2]|0)|0;o=f+140|0;k=(c[o>>2]|0)-4|0;g=k&16777215;i=g+3|0;if(i>>>0<(c[q>>2]|0)>>>0){q=f+32|0;a[(c[q>>2]|0)+g|0]=h>>>24&255;a[(c[q>>2]|0)+(g+1)|0]=h>>>16&255;a[(c[q>>2]|0)+(g+2)|0]=h>>>8&255;a[(c[q>>2]|0)+i|0]=h&255;c[o>>2]=k;r=c[p>>2]|0;s=n+2|0;t=s+r|0;c[p>>2]=t;u=f+268|0;v=c[u>>2]|0;w=v+18|0;c[u>>2]=w;return 0}else{b3[c[f+28>>2]&63](c[f+4>>2]|0,g,h);c[o>>2]=k;r=c[p>>2]|0;s=n+2|0;t=s+r|0;c[p>>2]=t;u=f+268|0;v=c[u>>2]|0;w=v+18|0;c[u>>2]=w;return 0}return 0}function kb(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=e[a+148>>1]|0;if((f&1|0)==0){g=f>>>2&1^1}else{g=0}f=a+196|0;h=e[f>>1]|0;i=(h&128|0)!=0?h|-256:h&255;if((i|0)==0){h=(c[a+144>>2]|0)+2&16777215;j=h+1|0;if(j>>>0<(c[a+36>>2]|0)>>>0){k=c[a+32>>2]|0;l=(d[k+h|0]|0)<<8|(d[k+j|0]|0)}else{l=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0}b[a+198>>1]=l;c[a+192>>2]=2;h=l&65535;m=(h&32768|0)!=0?h|-65536:h}else{m=i}if((g|0)==0){g=a+268|0;c[g>>2]=((b[f>>1]&255)==0?12:8)+(c[g>>2]|0);n=c[a+192>>2]|0;return n|0}else{g=a+144|0;c[g>>2]=m+2+(c[g>>2]|0);g=a+268|0;c[g>>2]=(c[g>>2]|0)+10;n=0;return n|0}return 0}function kc(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=e[a+148>>1]|0;if((f&1|0)==0){g=f>>>2&1}else{g=1}f=a+196|0;h=e[f>>1]|0;i=(h&128|0)!=0?h|-256:h&255;if((i|0)==0){h=(c[a+144>>2]|0)+2&16777215;j=h+1|0;if(j>>>0<(c[a+36>>2]|0)>>>0){k=c[a+32>>2]|0;l=(d[k+h|0]|0)<<8|(d[k+j|0]|0)}else{l=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0}b[a+198>>1]=l;c[a+192>>2]=2;h=l&65535;m=(h&32768|0)!=0?h|-65536:h}else{m=i}if((g|0)==0){g=a+268|0;c[g>>2]=((b[f>>1]&255)==0?12:8)+(c[g>>2]|0);n=c[a+192>>2]|0;return n|0}else{g=a+144|0;c[g>>2]=m+2+(c[g>>2]|0);g=a+268|0;c[g>>2]=(c[g>>2]|0)+10;n=0;return n|0}return 0}function kd(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b[a+148>>1]&1;g=a+196|0;h=e[g>>1]|0;i=(h&128|0)!=0?h|-256:h&255;if((i|0)==0){h=(c[a+144>>2]|0)+2&16777215;j=h+1|0;if(j>>>0<(c[a+36>>2]|0)>>>0){k=c[a+32>>2]|0;l=(d[k+h|0]|0)<<8|(d[k+j|0]|0)}else{l=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0}b[a+198>>1]=l;c[a+192>>2]=2;h=l&65535;m=(h&32768|0)!=0?h|-65536:h}else{m=i}if(f<<16>>16==0){f=a+144|0;c[f>>2]=m+2+(c[f>>2]|0);f=a+268|0;c[f>>2]=(c[f>>2]|0)+10;n=0;return n|0}else{f=a+268|0;c[f>>2]=((b[g>>1]&255)==0?12:8)+(c[f>>2]|0);n=c[a+192>>2]|0;return n|0}return 0}function ke(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b[a+148>>1]&1;g=a+196|0;h=e[g>>1]|0;i=(h&128|0)!=0?h|-256:h&255;if((i|0)==0){h=(c[a+144>>2]|0)+2&16777215;j=h+1|0;if(j>>>0<(c[a+36>>2]|0)>>>0){k=c[a+32>>2]|0;l=(d[k+h|0]|0)<<8|(d[k+j|0]|0)}else{l=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0}b[a+198>>1]=l;c[a+192>>2]=2;h=l&65535;m=(h&32768|0)!=0?h|-65536:h}else{m=i}if(f<<16>>16==0){f=a+268|0;c[f>>2]=((b[g>>1]&255)==0?12:8)+(c[f>>2]|0);n=c[a+192>>2]|0;return n|0}else{f=a+144|0;c[f>>2]=m+2+(c[f>>2]|0);f=a+268|0;c[f>>2]=(c[f>>2]|0)+10;n=0;return n|0}return 0}function kf(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b[a+148>>1]&4;g=a+196|0;h=e[g>>1]|0;i=(h&128|0)!=0?h|-256:h&255;if((i|0)==0){h=(c[a+144>>2]|0)+2&16777215;j=h+1|0;if(j>>>0<(c[a+36>>2]|0)>>>0){k=c[a+32>>2]|0;l=(d[k+h|0]|0)<<8|(d[k+j|0]|0)}else{l=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0}b[a+198>>1]=l;c[a+192>>2]=2;h=l&65535;m=(h&32768|0)!=0?h|-65536:h}else{m=i}if(f<<16>>16==0){f=a+144|0;c[f>>2]=m+2+(c[f>>2]|0);f=a+268|0;c[f>>2]=(c[f>>2]|0)+10;n=0;return n|0}else{f=a+268|0;c[f>>2]=((b[g>>1]&255)==0?12:8)+(c[f>>2]|0);n=c[a+192>>2]|0;return n|0}return 0}function kg(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b[a+148>>1]&4;g=a+196|0;h=e[g>>1]|0;i=(h&128|0)!=0?h|-256:h&255;if((i|0)==0){h=(c[a+144>>2]|0)+2&16777215;j=h+1|0;if(j>>>0<(c[a+36>>2]|0)>>>0){k=c[a+32>>2]|0;l=(d[k+h|0]|0)<<8|(d[k+j|0]|0)}else{l=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0}b[a+198>>1]=l;c[a+192>>2]=2;h=l&65535;m=(h&32768|0)!=0?h|-65536:h}else{m=i}if(f<<16>>16==0){f=a+268|0;c[f>>2]=((b[g>>1]&255)==0?12:8)+(c[f>>2]|0);n=c[a+192>>2]|0;return n|0}else{f=a+144|0;c[f>>2]=m+2+(c[f>>2]|0);f=a+268|0;c[f>>2]=(c[f>>2]|0)+10;n=0;return n|0}return 0}function kh(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b[a+148>>1]&2;g=a+196|0;h=e[g>>1]|0;i=(h&128|0)!=0?h|-256:h&255;if((i|0)==0){h=(c[a+144>>2]|0)+2&16777215;j=h+1|0;if(j>>>0<(c[a+36>>2]|0)>>>0){k=c[a+32>>2]|0;l=(d[k+h|0]|0)<<8|(d[k+j|0]|0)}else{l=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0}b[a+198>>1]=l;c[a+192>>2]=2;h=l&65535;m=(h&32768|0)!=0?h|-65536:h}else{m=i}if(f<<16>>16==0){f=a+144|0;c[f>>2]=m+2+(c[f>>2]|0);f=a+268|0;c[f>>2]=(c[f>>2]|0)+10;n=0;return n|0}else{f=a+268|0;c[f>>2]=((b[g>>1]&255)==0?12:8)+(c[f>>2]|0);n=c[a+192>>2]|0;return n|0}return 0}function ki(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b[a+148>>1]&2;g=a+196|0;h=e[g>>1]|0;i=(h&128|0)!=0?h|-256:h&255;if((i|0)==0){h=(c[a+144>>2]|0)+2&16777215;j=h+1|0;if(j>>>0<(c[a+36>>2]|0)>>>0){k=c[a+32>>2]|0;l=(d[k+h|0]|0)<<8|(d[k+j|0]|0)}else{l=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0}b[a+198>>1]=l;c[a+192>>2]=2;h=l&65535;m=(h&32768|0)!=0?h|-65536:h}else{m=i}if(f<<16>>16==0){f=a+268|0;c[f>>2]=((b[g>>1]&255)==0?12:8)+(c[f>>2]|0);n=c[a+192>>2]|0;return n|0}else{f=a+144|0;c[f>>2]=m+2+(c[f>>2]|0);f=a+268|0;c[f>>2]=(c[f>>2]|0)+10;n=0;return n|0}return 0}function kj(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b[a+148>>1]&8;g=a+196|0;h=e[g>>1]|0;i=(h&128|0)!=0?h|-256:h&255;if((i|0)==0){h=(c[a+144>>2]|0)+2&16777215;j=h+1|0;if(j>>>0<(c[a+36>>2]|0)>>>0){k=c[a+32>>2]|0;l=(d[k+h|0]|0)<<8|(d[k+j|0]|0)}else{l=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0}b[a+198>>1]=l;c[a+192>>2]=2;h=l&65535;m=(h&32768|0)!=0?h|-65536:h}else{m=i}if(f<<16>>16==0){f=a+144|0;c[f>>2]=m+2+(c[f>>2]|0);f=a+268|0;c[f>>2]=(c[f>>2]|0)+10;n=0;return n|0}else{f=a+268|0;c[f>>2]=((b[g>>1]&255)==0?12:8)+(c[f>>2]|0);n=c[a+192>>2]|0;return n|0}return 0}function kk(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b[a+148>>1]&8;g=a+196|0;h=e[g>>1]|0;i=(h&128|0)!=0?h|-256:h&255;if((i|0)==0){h=(c[a+144>>2]|0)+2&16777215;j=h+1|0;if(j>>>0<(c[a+36>>2]|0)>>>0){k=c[a+32>>2]|0;l=(d[k+h|0]|0)<<8|(d[k+j|0]|0)}else{l=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0}b[a+198>>1]=l;c[a+192>>2]=2;h=l&65535;m=(h&32768|0)!=0?h|-65536:h}else{m=i}if(f<<16>>16==0){f=a+268|0;c[f>>2]=((b[g>>1]&255)==0?12:8)+(c[f>>2]|0);n=c[a+192>>2]|0;return n|0}else{f=a+144|0;c[f>>2]=m+2+(c[f>>2]|0);f=a+268|0;c[f>>2]=(c[f>>2]|0)+10;n=0;return n|0}return 0}function kl(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=e[a+148>>1]|0;g=(f>>>3^f>>>1)&1;f=a+196|0;h=e[f>>1]|0;i=(h&128|0)!=0?h|-256:h&255;if((i|0)==0){h=(c[a+144>>2]|0)+2&16777215;j=h+1|0;if(j>>>0<(c[a+36>>2]|0)>>>0){k=c[a+32>>2]|0;l=(d[k+h|0]|0)<<8|(d[k+j|0]|0)}else{l=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0}b[a+198>>1]=l;c[a+192>>2]=2;h=l&65535;m=(h&32768|0)!=0?h|-65536:h}else{m=i}if((g|0)==0){g=a+144|0;c[g>>2]=m+2+(c[g>>2]|0);g=a+268|0;c[g>>2]=(c[g>>2]|0)+10;n=0;return n|0}else{g=a+268|0;c[g>>2]=((b[f>>1]&255)==0?12:8)+(c[g>>2]|0);n=c[a+192>>2]|0;return n|0}return 0}function km(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=e[a+148>>1]|0;g=(f>>>3^f>>>1)&1;f=a+196|0;h=e[f>>1]|0;i=(h&128|0)!=0?h|-256:h&255;if((i|0)==0){h=(c[a+144>>2]|0)+2&16777215;j=h+1|0;if(j>>>0<(c[a+36>>2]|0)>>>0){k=c[a+32>>2]|0;l=(d[k+h|0]|0)<<8|(d[k+j|0]|0)}else{l=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0}b[a+198>>1]=l;c[a+192>>2]=2;h=l&65535;m=(h&32768|0)!=0?h|-65536:h}else{m=i}if((g|0)==0){g=a+268|0;c[g>>2]=((b[f>>1]&255)==0?12:8)+(c[g>>2]|0);n=c[a+192>>2]|0;return n|0}else{g=a+144|0;c[g>>2]=m+2+(c[g>>2]|0);g=a+268|0;c[g>>2]=(c[g>>2]|0)+10;n=0;return n|0}return 0}function kn(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=e[a+148>>1]|0;if(((f>>>3^f>>>1)&1|0)==0){g=f>>>2&1^1}else{g=0}f=a+196|0;h=e[f>>1]|0;i=(h&128|0)!=0?h|-256:h&255;if((i|0)==0){h=(c[a+144>>2]|0)+2&16777215;j=h+1|0;if(j>>>0<(c[a+36>>2]|0)>>>0){k=c[a+32>>2]|0;l=(d[k+h|0]|0)<<8|(d[k+j|0]|0)}else{l=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0}b[a+198>>1]=l;c[a+192>>2]=2;h=l&65535;m=(h&32768|0)!=0?h|-65536:h}else{m=i}if((g|0)==0){g=a+268|0;c[g>>2]=((b[f>>1]&255)==0?12:8)+(c[g>>2]|0);n=c[a+192>>2]|0;return n|0}else{g=a+144|0;c[g>>2]=m+2+(c[g>>2]|0);g=a+268|0;c[g>>2]=(c[g>>2]|0)+10;n=0;return n|0}return 0}function ko(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=e[a+148>>1]|0;if(((f>>>3^f>>>1)&1|0)==0){g=f>>>2&1}else{g=1}f=a+196|0;h=e[f>>1]|0;i=(h&128|0)!=0?h|-256:h&255;if((i|0)==0){h=(c[a+144>>2]|0)+2&16777215;j=h+1|0;if(j>>>0<(c[a+36>>2]|0)>>>0){k=c[a+32>>2]|0;l=(d[k+h|0]|0)<<8|(d[k+j|0]|0)}else{l=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0}b[a+198>>1]=l;c[a+192>>2]=2;h=l&65535;m=(h&32768|0)!=0?h|-65536:h}else{m=i}if((g|0)==0){g=a+268|0;c[g>>2]=((b[f>>1]&255)==0?12:8)+(c[g>>2]|0);n=c[a+192>>2]|0;return n|0}else{g=a+144|0;c[g>>2]=m+2+(c[g>>2]|0);g=a+268|0;c[g>>2]=(c[g>>2]|0)+10;n=0;return n|0}return 0}function kp(a){a=a|0;var b=0,d=0;b=e[a+196>>1]|0;d=(b&128|0)!=0?b|-256:b&255;c[a+80+((b>>>9&7)<<2)>>2]=d;lO(a,15,d);d=a+268|0;c[d>>2]=(c[d>>2]|0)+4;return 1}function kq(a){a=a|0;var b=0,f=0,g=0,h=0,j=0;b=i;i=i+8|0;f=b|0;g=e[a+196>>1]|0;h=g&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,4093,8)|0)!=0){j=0;i=b;return j|0}if((mm(a,f)|0)!=0){j=0;i=b;return j|0}h=a+80+((g>>>9&7)<<2)|0;g=d[f]|0|c[h>>2];c[h>>2]=g;lM(a,15,g&255);g=a+268|0;c[g>>2]=(c[g>>2]|0)+8;j=c[a+192>>2]|0;i=b;return j|0}function kr(a){a=a|0;var b=0,d=0,f=0,g=0,h=0;b=i;i=i+8|0;d=b|0;f=e[a+196>>1]|0;g=f&63;if((b5[c[20008+(g<<2)>>2]&127](a,g,4093,16)|0)!=0){h=0;i=b;return h|0}if((mn(a,d)|0)!=0){h=0;i=b;return h|0}g=a+80+((f>>>9&7)<<2)|0;f=e[d>>1]|0|c[g>>2];c[g>>2]=f;lN(a,15,f&65535);f=a+268|0;c[f>>2]=(c[f>>2]|0)+8;h=c[a+192>>2]|0;i=b;return h|0}function ks(a){a=a|0;var b=0,d=0,f=0,g=0,h=0;b=i;i=i+8|0;d=b|0;f=e[a+196>>1]|0;g=f&63;if((b5[c[20008+(g<<2)>>2]&127](a,g,4093,32)|0)!=0){h=0;i=b;return h|0}if((mo(a,d)|0)!=0){h=0;i=b;return h|0}g=a+80+((f>>>9&7)<<2)|0;f=c[d>>2]|c[g>>2];c[g>>2]=f;lO(a,15,f);f=a+268|0;c[f>>2]=(c[f>>2]|0)+10;h=c[a+192>>2]|0;i=b;return h|0}function kt(a){a=a|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+8|0;f=d|0;g=e[a+196>>1]|0;h=g&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,4093,16)|0)!=0){j=0;i=d;return j|0}if((mn(a,f)|0)!=0){j=0;i=d;return j|0}h=a+80+((g>>>9&7)<<2)|0;g=c[h>>2]|0;k=b[f>>1]|0;f=k&65535;if(k<<16>>16==0){iB(a);j=0;i=d;return j|0}k=(g>>>0)/(f>>>0)|0;if(k>>>0>65535){l=a+148|0;b[l>>1]=b[l>>1]&-4|2}else{c[h>>2]=((g>>>0)%(f>>>0)|0)<<16|k&65535;lN(a,15,k&65535)}k=a+268|0;c[k>>2]=(c[k>>2]|0)+144;j=c[a+192>>2]|0;i=d;return j|0}function ku(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+24|0;h=g|0;j=g+8|0;k=g+16|0;l=e[f+196>>1]|0;if((l&48|0)!=0){m=c[f+80+((l>>>9&7)<<2)>>2]|0;n=l&63;if((b5[c[20008+(n<<2)>>2]&127](f,n,508,8)|0)!=0){o=0;i=g;return o|0}if((mm(f,k)|0)!=0){o=0;i=g;return o|0}n=(d[k]|0|m)&255;if((mp(f,n)|0)!=0){o=0;i=g;return o|0}lM(f,15,n);n=f+268|0;c[n>>2]=(c[n>>2]|0)+8;o=c[f+192>>2]|0;i=g;return o|0}n=l&7;m=l>>>9&7;if((l&8|0)==0){p=m;q=n}else{p=m|32;q=n|32}if((b5[c[20008+(q<<2)>>2]&127](f,q,17,8)|0)!=0){o=0;i=g;return o|0}if((mm(f,h)|0)!=0){o=0;i=g;return o|0}if((b5[c[20008+(p<<2)>>2]&127](f,p,17,8)|0)!=0){o=0;i=g;return o|0}if((mm(f,j)|0)!=0){o=0;i=g;return o|0}p=a[j]|0;j=a[h]|0;h=f+148|0;q=b[h>>1]|0;n=((p&255)-(j&255)&65535)-((q&65535)>>>4&1)&65535;m=(p&15)>>>0<(j&15)>>>0?n-6&65535:n;n=(m&65535)>159?m-96&65535:m;m=n&65535;j=(m&65280|0)==0?q&-18:q|17;b[h>>1]=(m&255|0)==0?j:j&-5;if((mp(f,n&255)|0)!=0){o=0;i=g;return o|0}n=f+268|0;c[n>>2]=(c[n>>2]|0)+10;o=c[f+192>>2]|0;i=g;return o|0}function kv(a){a=a|0;var b=0,d=0,f=0,g=0,h=0,j=0;b=i;i=i+8|0;d=b|0;f=e[a+196>>1]|0;g=c[a+80+((f>>>9&7)<<2)>>2]|0;h=f&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,508,16)|0)!=0){j=0;i=b;return j|0}if((mn(a,d)|0)!=0){j=0;i=b;return j|0}h=(e[d>>1]|0|g)&65535;if((mq(a,h)|0)!=0){j=0;i=b;return j|0}lN(a,15,h);h=a+268|0;c[h>>2]=(c[h>>2]|0)+8;j=c[a+192>>2]|0;i=b;return j|0}function kw(a){a=a|0;var b=0,d=0,f=0,g=0,h=0,j=0;b=i;i=i+8|0;d=b|0;f=e[a+196>>1]|0;g=c[a+80+((f>>>9&7)<<2)>>2]|0;h=f&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,508,32)|0)!=0){j=0;i=b;return j|0}if((mo(a,d)|0)!=0){j=0;i=b;return j|0}h=c[d>>2]|g;if((mr(a,h)|0)!=0){j=0;i=b;return j|0}lO(a,15,h);h=a+268|0;c[h>>2]=(c[h>>2]|0)+10;j=c[a+192>>2]|0;i=b;return j|0}function kx(a){a=a|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+8|0;f=d|0;g=e[a+196>>1]|0;h=g&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,4093,16)|0)!=0){j=0;i=d;return j|0}if((mn(a,f)|0)!=0){j=0;i=d;return j|0}h=a+80+((g>>>9&7)<<2)|0;g=c[h>>2]|0;k=b[f>>1]|0;if(k<<16>>16==0){iB(a);j=0;i=d;return j|0}l=g>>>31;m=(g|0)<0?-g|0:g;if(k<<16>>16>-1){n=0;o=k}else{g=-k&65535;b[f>>1]=g;n=1;o=g}g=o&65535;o=(m>>>0)/(g>>>0)|0;f=(m>>>0)%(g>>>0)|0;if((l|0)==0){p=f}else{p=-f&65535}f=(n|0)==(l|0)?o:-o|0;o=a+268|0;c[o>>2]=(c[o>>2]|0)+162;o=f&-32768;if((o|0)==0|(o|0)==(-32768|0)){c[h>>2]=p<<16|f&65535;lN(a,15,f&65535)}else{f=a+148|0;b[f>>1]=b[f>>1]&-4|2}j=c[a+192>>2]|0;i=d;return j|0}function ky(b){b=b|0;var d=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+8|0;f=d|0;g=e[b+196>>1]|0;h=g&63;if((b5[c[20008+(h<<2)>>2]&127](b,h,4093,8)|0)!=0){j=0;i=d;return j|0}if((mm(b,f)|0)!=0){j=0;i=d;return j|0}h=b+80+((g>>>9&7)<<2)|0;g=c[h>>2]|0;k=a[f]|0;f=g-(k&255)|0;c[h>>2]=f&255|g&-256;l1(b,f&255,k,g&255);g=b+268|0;c[g>>2]=(c[g>>2]|0)+8;j=c[b+192>>2]|0;i=d;return j|0}function kz(a){a=a|0;var d=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+8|0;f=d|0;g=e[a+196>>1]|0;h=g&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,4095,16)|0)!=0){j=0;i=d;return j|0}if((mn(a,f)|0)!=0){j=0;i=d;return j|0}h=a+80+((g>>>9&7)<<2)|0;g=c[h>>2]|0;k=b[f>>1]|0;f=g-(k&65535)|0;c[h>>2]=f&65535|g&-65536;l2(a,f&65535,k,g&65535);g=a+268|0;c[g>>2]=(c[g>>2]|0)+8;j=c[a+192>>2]|0;i=d;return j|0}function kA(a){a=a|0;var b=0,d=0,f=0,g=0,h=0,j=0;b=i;i=i+8|0;d=b|0;f=e[a+196>>1]|0;g=f&63;if((b5[c[20008+(g<<2)>>2]&127](a,g,4095,32)|0)!=0){h=0;i=b;return h|0}if((mo(a,d)|0)!=0){h=0;i=b;return h|0}g=a+80+((f>>>9&7)<<2)|0;f=c[g>>2]|0;j=c[d>>2]|0;d=f-j|0;c[g>>2]=d;l3(a,d,j,f);f=a+268|0;c[f>>2]=(c[f>>2]|0)+10;h=c[a+192>>2]|0;i=b;return h|0}function kB(a){a=a|0;var b=0,d=0,f=0,g=0,h=0;b=i;i=i+8|0;d=b|0;f=e[a+196>>1]|0;g=f&63;if((b5[c[20008+(g<<2)>>2]&127](a,g,4095,16)|0)!=0){h=0;i=b;return h|0}if((mn(a,d)|0)!=0){h=0;i=b;return h|0}g=e[d>>1]|0;d=a+112+((f>>>9&7)<<2)|0;c[d>>2]=(c[d>>2]|0)-((g&32768|0)!=0?g|-65536:g);g=a+268|0;c[g>>2]=(c[g>>2]|0)+8;h=c[a+192>>2]|0;i=b;return h|0}function kC(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+24|0;g=f|0;h=f+8|0;j=f+16|0;k=e[b+196>>1]|0;if((k&48|0)!=0){l=c[b+80+((k>>>9&7)<<2)>>2]|0;m=k&63;if((b5[c[20008+(m<<2)>>2]&127](b,m,508,8)|0)!=0){n=0;i=f;return n|0}if((mm(b,j)|0)!=0){n=0;i=f;return n|0}m=(d[j]|0)-l&255;if((mp(b,m)|0)!=0){n=0;i=f;return n|0}l1(b,m,l&255,a[j]|0);j=b+268|0;c[j>>2]=(c[j>>2]|0)+8;n=c[b+192>>2]|0;i=f;return n|0}j=k&7;l=k>>>9&7;if((k&8|0)==0){o=l;p=j}else{o=l|32;p=j|32}if((b5[c[20008+(p<<2)>>2]&127](b,p,17,8)|0)!=0){n=0;i=f;return n|0}if((mm(b,g)|0)!=0){n=0;i=f;return n|0}if((b5[c[20008+(o<<2)>>2]&127](b,o,17,8)|0)!=0){n=0;i=f;return n|0}if((mm(b,h)|0)!=0){n=0;i=f;return n|0}o=((a[h]|0)-(a[g]|0)&255)-((e[b+148>>1]|0)>>>4&1)&255;if((mp(b,o)|0)!=0){n=0;i=f;return n|0}l4(b,o,a[g]|0,a[h]|0);h=b+268|0;c[h>>2]=(c[h>>2]|0)+8;n=c[b+192>>2]|0;i=f;return n|0}function kD(a){a=a|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+24|0;f=d|0;g=d+8|0;h=d+16|0;j=e[a+196>>1]|0;if((j&48|0)!=0){k=c[a+80+((j>>>9&7)<<2)>>2]|0;l=j&63;if((b5[c[20008+(l<<2)>>2]&127](a,l,508,16)|0)!=0){m=0;i=d;return m|0}if((mn(a,h)|0)!=0){m=0;i=d;return m|0}l=(e[h>>1]|0)-k&65535;if((mq(a,l)|0)!=0){m=0;i=d;return m|0}l2(a,l,k&65535,b[h>>1]|0);h=a+268|0;c[h>>2]=(c[h>>2]|0)+8;m=c[a+192>>2]|0;i=d;return m|0}h=j&7;k=j>>>9&7;if((j&8|0)==0){n=k;o=h}else{n=k|32;o=h|32}if((b5[c[20008+(o<<2)>>2]&127](a,o,17,16)|0)!=0){m=0;i=d;return m|0}if((mn(a,f)|0)!=0){m=0;i=d;return m|0}if((b5[c[20008+(n<<2)>>2]&127](a,n,17,16)|0)!=0){m=0;i=d;return m|0}if((mn(a,g)|0)!=0){m=0;i=d;return m|0}n=((b[g>>1]|0)-(b[f>>1]|0)&65535)-((e[a+148>>1]|0)>>>4&1)&65535;if((mq(a,n)|0)!=0){m=0;i=d;return m|0}l5(a,n,b[f>>1]|0,b[g>>1]|0);g=a+268|0;c[g>>2]=(c[g>>2]|0)+8;m=c[a+192>>2]|0;i=d;return m|0}function kE(a){a=a|0;var b=0,d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+24|0;d=b|0;f=b+8|0;g=b+16|0;h=e[a+196>>1]|0;if((h&48|0)!=0){j=c[a+80+((h>>>9&7)<<2)>>2]|0;k=h&63;if((b5[c[20008+(k<<2)>>2]&127](a,k,508,32)|0)!=0){l=0;i=b;return l|0}if((mo(a,g)|0)!=0){l=0;i=b;return l|0}k=(c[g>>2]|0)-j|0;if((mr(a,k)|0)!=0){l=0;i=b;return l|0}l3(a,k,j,c[g>>2]|0);g=a+268|0;c[g>>2]=(c[g>>2]|0)+12;l=c[a+192>>2]|0;i=b;return l|0}g=h&7;j=h>>>9&7;if((h&8|0)==0){m=j;n=g}else{m=j|32;n=g|32}if((b5[c[20008+(n<<2)>>2]&127](a,n,17,32)|0)!=0){l=0;i=b;return l|0}if((mo(a,d)|0)!=0){l=0;i=b;return l|0}if((b5[c[20008+(m<<2)>>2]&127](a,m,17,32)|0)!=0){l=0;i=b;return l|0}if((mo(a,f)|0)!=0){l=0;i=b;return l|0}m=(c[f>>2]|0)-(c[d>>2]|0)-((e[a+148>>1]|0)>>>4&1)|0;if((mr(a,m)|0)!=0){l=0;i=b;return l|0}l6(a,m,c[d>>2]|0,c[f>>2]|0);f=a+268|0;c[f>>2]=(c[f>>2]|0)+12;l=c[a+192>>2]|0;i=b;return l|0}function kF(a){a=a|0;var b=0,d=0,f=0,g=0,h=0;b=i;i=i+8|0;d=b|0;f=e[a+196>>1]|0;g=f&63;if((b5[c[20008+(g<<2)>>2]&127](a,g,4095,32)|0)!=0){h=0;i=b;return h|0}if((mo(a,d)|0)!=0){h=0;i=b;return h|0}g=a+112+((f>>>9&7)<<2)|0;c[g>>2]=(c[g>>2]|0)-(c[d>>2]|0);d=a+268|0;c[d>>2]=(c[d>>2]|0)+10;h=c[a+192>>2]|0;i=b;return h|0}function kG(a){a=a|0;b[a+184>>1]=b[a+196>>1]|0;iF(a);return 0}function kH(d){d=d|0;var f=0,g=0,h=0,j=0,k=0;f=i;i=i+8|0;g=f|0;h=d+196|0;j=b[h>>1]&63;if((b5[c[20008+(j<<2)>>2]&127](d,j,4093,8)|0)!=0){k=0;i=f;return k|0}if((mm(d,g)|0)!=0){k=0;i=f;return k|0}j=c[d+80+(((e[h>>1]|0)>>>9&7)<<2)>>2]|0;h=a[g]|0;lV(d,j-(h&255)&255,h,j&255);j=d+268|0;c[j>>2]=(c[j>>2]|0)+4;k=c[d+192>>2]|0;i=f;return k|0}function kI(a){a=a|0;var d=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;f=d|0;g=a+196|0;h=b[g>>1]&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,4095,16)|0)!=0){j=0;i=d;return j|0}if((mn(a,f)|0)!=0){j=0;i=d;return j|0}h=c[a+80+(((e[g>>1]|0)>>>9&7)<<2)>>2]|0;g=b[f>>1]|0;lW(a,h-(g&65535)&65535,g,h&65535);h=a+268|0;c[h>>2]=(c[h>>2]|0)+4;j=c[a+192>>2]|0;i=d;return j|0}function kJ(a){a=a|0;var d=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;f=d|0;g=a+196|0;h=b[g>>1]&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,4095,32)|0)!=0){j=0;i=d;return j|0}if((mo(a,f)|0)!=0){j=0;i=d;return j|0}h=c[a+80+(((e[g>>1]|0)>>>9&7)<<2)>>2]|0;g=c[f>>2]|0;l0(a,h-g|0,g,h);h=a+268|0;c[h>>2]=(c[h>>2]|0)+6;j=c[a+192>>2]|0;i=d;return j|0}function kK(a){a=a|0;var d=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;f=d|0;g=a+196|0;h=b[g>>1]&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,4095,16)|0)!=0){j=0;i=d;return j|0}if((mn(a,f)|0)!=0){j=0;i=d;return j|0}h=e[f>>1]|0;f=(h&32768|0)!=0?h|-65536:h;h=c[a+112+(((e[g>>1]|0)>>>9&7)<<2)>>2]|0;l0(a,h-f|0,f,h);h=a+268|0;c[h>>2]=(c[h>>2]|0)+8;j=c[a+192>>2]|0;i=d;return j|0}function kL(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+24|0;g=f|0;h=f+8|0;j=f+16|0;k=b+196|0;l=e[k>>1]|0;if((l&56|0)!=8){m=c[b+80+((l>>>9&7)<<2)>>2]|0;n=l&63;if((b5[c[20008+(n<<2)>>2]&127](b,n,509,8)|0)!=0){o=0;i=f;return o|0}if((mm(b,j)|0)!=0){o=0;i=f;return o|0}n=((d[j]|0)^m)&255;if((mp(b,n)|0)!=0){o=0;i=f;return o|0}lM(b,15,n);n=b+268|0;c[n>>2]=(c[n>>2]|0)+8;o=c[b+192>>2]|0;i=f;return o|0}n=l&7|24;if((b5[c[20008+(n<<2)>>2]&127](b,n,8,8)|0)!=0){o=0;i=f;return o|0}if((mm(b,g)|0)!=0){o=0;i=f;return o|0}n=(e[k>>1]|0)>>>9&7|24;if((b5[c[20008+(n<<2)>>2]&127](b,n,8,8)|0)!=0){o=0;i=f;return o|0}if((mm(b,h)|0)!=0){o=0;i=f;return o|0}n=a[h]|0;h=a[g]|0;lV(b,n-h&255,h,n);n=b+268|0;c[n>>2]=(c[n>>2]|0)+16;o=1;i=f;return o|0}function kM(a){a=a|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+24|0;f=d|0;g=d+8|0;h=d+16|0;j=a+196|0;k=e[j>>1]|0;if((k&56|0)!=8){l=c[a+80+((k>>>9&7)<<2)>>2]|0;m=k&63;if((b5[c[20008+(m<<2)>>2]&127](a,m,509,16)|0)!=0){n=0;i=d;return n|0}if((mn(a,h)|0)!=0){n=0;i=d;return n|0}m=((e[h>>1]|0)^l)&65535;if((mq(a,m)|0)!=0){n=0;i=d;return n|0}lN(a,15,m);m=a+268|0;c[m>>2]=(c[m>>2]|0)+8;n=c[a+192>>2]|0;i=d;return n|0}m=k&7|24;if((b5[c[20008+(m<<2)>>2]&127](a,m,8,16)|0)!=0){n=0;i=d;return n|0}if((mn(a,f)|0)!=0){n=0;i=d;return n|0}m=(e[j>>1]|0)>>>9&7|24;if((b5[c[20008+(m<<2)>>2]&127](a,m,8,16)|0)!=0){n=0;i=d;return n|0}if((mn(a,g)|0)!=0){n=0;i=d;return n|0}m=b[g>>1]|0;g=b[f>>1]|0;lW(a,m-g&65535,g,m);m=a+268|0;c[m>>2]=(c[m>>2]|0)+12;n=1;i=d;return n|0}function kN(a){a=a|0;var b=0,d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+24|0;d=b|0;f=b+8|0;g=b+16|0;h=a+196|0;j=e[h>>1]|0;if((j&56|0)!=8){k=c[a+80+((j>>>9&7)<<2)>>2]|0;l=j&63;if((b5[c[20008+(l<<2)>>2]&127](a,l,509,32)|0)!=0){m=0;i=b;return m|0}if((mo(a,g)|0)!=0){m=0;i=b;return m|0}l=c[g>>2]^k;if((mr(a,l)|0)!=0){m=0;i=b;return m|0}lO(a,15,l);l=a+268|0;c[l>>2]=(c[l>>2]|0)+12;m=c[a+192>>2]|0;i=b;return m|0}l=j&7|24;if((b5[c[20008+(l<<2)>>2]&127](a,l,8,32)|0)!=0){m=0;i=b;return m|0}if((mo(a,d)|0)!=0){m=0;i=b;return m|0}l=(e[h>>1]|0)>>>9&7|24;if((b5[c[20008+(l<<2)>>2]&127](a,l,8,32)|0)!=0){m=0;i=b;return m|0}if((mo(a,f)|0)!=0){m=0;i=b;return m|0}l=c[f>>2]|0;f=c[d>>2]|0;l0(a,l-f|0,f,l);l=a+268|0;c[l>>2]=(c[l>>2]|0)+20;m=1;i=b;return m|0}function kO(a){a=a|0;var d=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;f=d|0;g=a+196|0;h=b[g>>1]&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,4095,32)|0)!=0){j=0;i=d;return j|0}if((mo(a,f)|0)!=0){j=0;i=d;return j|0}h=c[a+112+(((e[g>>1]|0)>>>9&7)<<2)>>2]|0;g=c[f>>2]|0;l0(a,h-g|0,g,h);h=a+268|0;c[h>>2]=(c[h>>2]|0)+8;j=c[a+192>>2]|0;i=d;return j|0}function kP(a){a=a|0;var b=0,f=0,g=0,h=0,j=0,k=0;b=i;i=i+8|0;f=b|0;g=e[a+196>>1]|0;h=g&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,4093,8)|0)!=0){j=0;i=b;return j|0}if((mm(a,f)|0)!=0){j=0;i=b;return j|0}h=a+80+((g>>>9&7)<<2)|0;g=c[h>>2]|0;k=(d[f]|0)&g;c[h>>2]=k|g&-256;lM(a,15,k&255);k=a+268|0;c[k>>2]=(c[k>>2]|0)+4;j=c[a+192>>2]|0;i=b;return j|0}function kQ(a){a=a|0;var b=0,d=0,f=0,g=0,h=0,j=0;b=i;i=i+8|0;d=b|0;f=e[a+196>>1]|0;g=f&63;if((b5[c[20008+(g<<2)>>2]&127](a,g,4093,16)|0)!=0){h=0;i=b;return h|0}if((mn(a,d)|0)!=0){h=0;i=b;return h|0}g=a+80+((f>>>9&7)<<2)|0;f=c[g>>2]|0;j=(e[d>>1]|0)&f;c[g>>2]=j|f&-65536;lN(a,15,j&65535);j=a+268|0;c[j>>2]=(c[j>>2]|0)+4;h=c[a+192>>2]|0;i=b;return h|0}function kR(a){a=a|0;var b=0,d=0,f=0,g=0,h=0;b=i;i=i+8|0;d=b|0;f=e[a+196>>1]|0;g=f&63;if((b5[c[20008+(g<<2)>>2]&127](a,g,4093,32)|0)!=0){h=0;i=b;return h|0}if((mo(a,d)|0)!=0){h=0;i=b;return h|0}g=a+80+((f>>>9&7)<<2)|0;f=c[d>>2]&c[g>>2];c[g>>2]=f;lO(a,15,f);f=a+268|0;c[f>>2]=(c[f>>2]|0)+6;h=c[a+192>>2]|0;i=b;return h|0}function kS(a){a=a|0;var b=0,d=0,f=0,g=0,h=0;b=i;i=i+8|0;d=b|0;f=e[a+196>>1]|0;g=f&63;if((b5[c[20008+(g<<2)>>2]&127](a,g,4093,16)|0)!=0){h=0;i=b;return h|0}if((mn(a,d)|0)!=0){h=0;i=b;return h|0}g=a+80+((f>>>9&7)<<2)|0;f=ac(e[d>>1]|0,c[g>>2]&65535)|0;d=a+268|0;c[d>>2]=(c[d>>2]|0)+74;c[g>>2]=f;lO(a,15,f);h=c[a+192>>2]|0;i=b;return h|0}function kT(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+24|0;h=g|0;j=g+8|0;k=g+16|0;l=e[f+196>>1]|0;if((l&48|0)!=0){m=c[f+80+((l>>>9&7)<<2)>>2]|0;n=l&63;if((b5[c[20008+(n<<2)>>2]&127](f,n,508,8)|0)!=0){o=0;i=g;return o|0}if((mm(f,k)|0)!=0){o=0;i=g;return o|0}n=(d[k]|0)&m&255;if((mp(f,n)|0)!=0){o=0;i=g;return o|0}lM(f,15,n);n=f+268|0;c[n>>2]=(c[n>>2]|0)+4;o=c[f+192>>2]|0;i=g;return o|0}n=l&7;m=l>>>9&7;if((l&8|0)==0){p=m;q=n}else{p=m|32;q=n|32}if((b5[c[20008+(q<<2)>>2]&127](f,q,17,8)|0)!=0){o=0;i=g;return o|0}if((mm(f,h)|0)!=0){o=0;i=g;return o|0}if((b5[c[20008+(p<<2)>>2]&127](f,p,17,8)|0)!=0){o=0;i=g;return o|0}if((mm(f,j)|0)!=0){o=0;i=g;return o|0}p=a[h]|0;h=a[j]|0;j=f+148|0;q=b[j>>1]|0;n=((h&255)+(p&255)&65535)+((q&65535)>>>4&1)&65535;m=((h&15)+(p&15)|0)>9?n+6&65535:n;if((m&65535)>159){r=m+96&65535;s=q|17}else{r=m;s=q&-18}b[j>>1]=(r&255)==0?s:s&-5;if((mp(f,r&255)|0)!=0){o=0;i=g;return o|0}r=f+268|0;c[r>>2]=(c[r>>2]|0)+6;o=c[f+192>>2]|0;i=g;return o|0}function kU(a){a=a|0;var b=0,d=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;i=i+8|0;d=b|0;f=e[a+196>>1]|0;g=f>>>3&7;if((g|0)==1){h=a+112+((f>>>9&7)<<2)|0;j=c[h>>2]|0;k=a+112+((f&7)<<2)|0;c[h>>2]=c[k>>2];c[k>>2]=j;j=a+268|0;c[j>>2]=(c[j>>2]|0)+10;l=1;i=b;return l|0}else if((g|0)==0){g=a+80+((f>>>9&7)<<2)|0;j=c[g>>2]|0;k=a+80+((f&7)<<2)|0;c[g>>2]=c[k>>2];c[k>>2]=j;j=a+268|0;c[j>>2]=(c[j>>2]|0)+10;l=1;i=b;return l|0}else{j=c[a+80+((f>>>9&7)<<2)>>2]|0;k=f&63;if((b5[c[20008+(k<<2)>>2]&127](a,k,508,16)|0)!=0){l=0;i=b;return l|0}if((mn(a,d)|0)!=0){l=0;i=b;return l|0}k=(e[d>>1]|0)&j&65535;if((mq(a,k)|0)!=0){l=0;i=b;return l|0}lN(a,15,k);k=a+268|0;c[k>>2]=(c[k>>2]|0)+4;l=c[a+192>>2]|0;i=b;return l|0}return 0}function kV(a){a=a|0;var b=0,d=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;i=i+8|0;d=b|0;f=e[a+196>>1]|0;g=f>>>9&7;if((f&56|0)==8){h=a+80+(g<<2)|0;j=c[h>>2]|0;k=a+112+((f&7)<<2)|0;c[h>>2]=c[k>>2];c[k>>2]=j;j=a+268|0;c[j>>2]=(c[j>>2]|0)+10;l=c[a+192>>2]|0;i=b;return l|0}j=c[a+80+(g<<2)>>2]|0;g=f&63;if((b5[c[20008+(g<<2)>>2]&127](a,g,508,32)|0)!=0){l=0;i=b;return l|0}if((mo(a,d)|0)!=0){l=0;i=b;return l|0}g=c[d>>2]&j;if((mr(a,g)|0)!=0){l=0;i=b;return l|0}lO(a,15,g);g=a+268|0;c[g>>2]=(c[g>>2]|0)+6;l=c[a+192>>2]|0;i=b;return l|0}function kW(a){a=a|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+8|0;f=d|0;g=e[a+196>>1]|0;h=g&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,4093,16)|0)!=0){j=0;i=d;return j|0}if((mn(a,f)|0)!=0){j=0;i=d;return j|0}h=a+80+((g>>>9&7)<<2)|0;g=c[h>>2]|0;k=b[f>>1]|0;if(k<<16>>16>-1){l=0;m=k}else{n=-k&65535;b[f>>1]=n;l=1;m=n}if((g&32768|0)==0){o=g&65535;p=0}else{o=(g^65535)+1&65535;p=1}g=ac(m&65535,o&65535)|0;o=(l|0)==(p|0)?g:-g|0;g=a+268|0;c[g>>2]=(c[g>>2]|0)+74;c[h>>2]=o;lO(a,15,o);j=c[a+192>>2]|0;i=d;return j|0}function kX(b){b=b|0;var d=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+8|0;f=d|0;g=e[b+196>>1]|0;h=g&63;if((b5[c[20008+(h<<2)>>2]&127](b,h,4093,8)|0)!=0){j=0;i=d;return j|0}if((mm(b,f)|0)!=0){j=0;i=d;return j|0}h=b+80+((g>>>9&7)<<2)|0;g=c[h>>2]|0;k=a[f]|0;f=(k&255)+g|0;c[h>>2]=f&255|g&-256;lP(b,f&255,k,g&255);g=b+268|0;c[g>>2]=(c[g>>2]|0)+4;j=c[b+192>>2]|0;i=d;return j|0}function kY(a){a=a|0;var d=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+8|0;f=d|0;g=e[a+196>>1]|0;h=g&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,4095,16)|0)!=0){j=0;i=d;return j|0}if((mn(a,f)|0)!=0){j=0;i=d;return j|0}h=a+80+((g>>>9&7)<<2)|0;g=c[h>>2]|0;k=b[f>>1]|0;f=(k&65535)+g|0;c[h>>2]=f&65535|g&-65536;lQ(a,f&65535,k,g&65535);g=a+268|0;c[g>>2]=(c[g>>2]|0)+4;j=c[a+192>>2]|0;i=d;return j|0}function kZ(a){a=a|0;var b=0,d=0,f=0,g=0,h=0,j=0;b=i;i=i+8|0;d=b|0;f=e[a+196>>1]|0;g=f&63;if((b5[c[20008+(g<<2)>>2]&127](a,g,4095,32)|0)!=0){h=0;i=b;return h|0}if((mo(a,d)|0)!=0){h=0;i=b;return h|0}g=a+80+((f>>>9&7)<<2)|0;f=c[g>>2]|0;j=c[d>>2]|0;d=j+f|0;c[g>>2]=d;lR(a,d,j,f);f=a+268|0;c[f>>2]=(c[f>>2]|0)+6;h=c[a+192>>2]|0;i=b;return h|0}function k_(a){a=a|0;var b=0,d=0,f=0,g=0,h=0;b=i;i=i+8|0;d=b|0;f=e[a+196>>1]|0;g=f&63;if((b5[c[20008+(g<<2)>>2]&127](a,g,4095,16)|0)!=0){h=0;i=b;return h|0}if((mn(a,d)|0)!=0){h=0;i=b;return h|0}g=e[d>>1]|0;d=a+112+((f>>>9&7)<<2)|0;c[d>>2]=((g&32768|0)!=0?g|-65536:g)+(c[d>>2]|0);d=a+268|0;c[d>>2]=(c[d>>2]|0)+8;h=c[a+192>>2]|0;i=b;return h|0}function k$(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+24|0;g=f|0;h=f+8|0;j=f+16|0;k=e[b+196>>1]|0;if((k&48|0)!=0){l=c[b+80+((k>>>9&7)<<2)>>2]|0;m=k&63;if((b5[c[20008+(m<<2)>>2]&127](b,m,508,8)|0)!=0){n=0;i=f;return n|0}if((mm(b,j)|0)!=0){n=0;i=f;return n|0}m=(d[j]|0)+l&255;if((mp(b,m)|0)!=0){n=0;i=f;return n|0}lP(b,m,l&255,a[j]|0);j=b+268|0;c[j>>2]=(c[j>>2]|0)+8;n=c[b+192>>2]|0;i=f;return n|0}j=k&7;l=k>>>9&7;if((k&8|0)==0){o=l;p=j}else{o=l|32;p=j|32}if((b5[c[20008+(p<<2)>>2]&127](b,p,17,8)|0)!=0){n=0;i=f;return n|0}if((mm(b,g)|0)!=0){n=0;i=f;return n|0}if((b5[c[20008+(o<<2)>>2]&127](b,o,17,8)|0)!=0){n=0;i=f;return n|0}if((mm(b,h)|0)!=0){n=0;i=f;return n|0}o=((a[h]|0)+(a[g]|0)&255)+((e[b+148>>1]|0)>>>4&1)&255;if((mp(b,o)|0)!=0){n=0;i=f;return n|0}lS(b,o,a[g]|0,a[h]|0);h=b+268|0;c[h>>2]=(c[h>>2]|0)+8;n=c[b+192>>2]|0;i=f;return n|0}function k0(a){a=a|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+24|0;f=d|0;g=d+8|0;h=d+16|0;j=e[a+196>>1]|0;if((j&48|0)!=0){k=c[a+80+((j>>>9&7)<<2)>>2]|0;l=j&63;if((b5[c[20008+(l<<2)>>2]&127](a,l,508,16)|0)!=0){m=0;i=d;return m|0}if((mn(a,h)|0)!=0){m=0;i=d;return m|0}l=(e[h>>1]|0)+k&65535;if((mq(a,l)|0)!=0){m=0;i=d;return m|0}lQ(a,l,k&65535,b[h>>1]|0);h=a+268|0;c[h>>2]=(c[h>>2]|0)+8;m=c[a+192>>2]|0;i=d;return m|0}h=j&7;k=j>>>9&7;if((j&8|0)==0){n=k;o=h}else{n=k|32;o=h|32}if((b5[c[20008+(o<<2)>>2]&127](a,o,17,16)|0)!=0){m=0;i=d;return m|0}if((mn(a,f)|0)!=0){m=0;i=d;return m|0}if((b5[c[20008+(n<<2)>>2]&127](a,n,17,16)|0)!=0){m=0;i=d;return m|0}if((mn(a,g)|0)!=0){m=0;i=d;return m|0}n=((b[g>>1]|0)+(b[f>>1]|0)&65535)+((e[a+148>>1]|0)>>>4&1)&65535;if((mq(a,n)|0)!=0){m=0;i=d;return m|0}lT(a,n,b[f>>1]|0,b[g>>1]|0);g=a+268|0;c[g>>2]=(c[g>>2]|0)+8;m=c[a+192>>2]|0;i=d;return m|0}function k1(a){a=a|0;var b=0,d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+24|0;d=b|0;f=b+8|0;g=b+16|0;h=e[a+196>>1]|0;if((h&48|0)!=0){j=c[a+80+((h>>>9&7)<<2)>>2]|0;k=h&63;if((b5[c[20008+(k<<2)>>2]&127](a,k,508,32)|0)!=0){l=0;i=b;return l|0}if((mo(a,g)|0)!=0){l=0;i=b;return l|0}k=(c[g>>2]|0)+j|0;if((mr(a,k)|0)!=0){l=0;i=b;return l|0}lR(a,k,j,c[g>>2]|0);g=a+268|0;c[g>>2]=(c[g>>2]|0)+12;l=c[a+192>>2]|0;i=b;return l|0}g=h&7;j=h>>>9&7;if((h&8|0)==0){m=j;n=g}else{m=j|32;n=g|32}if((b5[c[20008+(n<<2)>>2]&127](a,n,17,32)|0)!=0){l=0;i=b;return l|0}if((mo(a,d)|0)!=0){l=0;i=b;return l|0}if((b5[c[20008+(m<<2)>>2]&127](a,m,17,32)|0)!=0){l=0;i=b;return l|0}if((mo(a,f)|0)!=0){l=0;i=b;return l|0}m=(c[f>>2]|0)+(c[d>>2]|0)+((e[a+148>>1]|0)>>>4&1)|0;if((mr(a,m)|0)!=0){l=0;i=b;return l|0}lU(a,m,c[d>>2]|0,c[f>>2]|0);f=a+268|0;c[f>>2]=(c[f>>2]|0)+12;l=c[a+192>>2]|0;i=b;return l|0}function k2(a){a=a|0;var b=0,d=0,f=0,g=0,h=0;b=i;i=i+8|0;d=b|0;f=e[a+196>>1]|0;g=f&63;if((b5[c[20008+(g<<2)>>2]&127](a,g,4095,32)|0)!=0){h=0;i=b;return h|0}if((mo(a,d)|0)!=0){h=0;i=b;return h|0}g=a+112+((f>>>9&7)<<2)|0;c[g>>2]=(c[d>>2]|0)+(c[g>>2]|0);g=a+268|0;c[g>>2]=(c[g>>2]|0)+6;h=c[a+192>>2]|0;i=b;return h|0}function k3(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;d=e[a+196>>1]|0;f=d>>>3&3;if((f|0)==3){g=a+80+((d&7)<<2)|0;h=c[g>>2]|0;i=h&255;j=d>>>9&7;if((d&32|0)==0){k=(j|0)==0?8:j}else{k=c[a+80+(j<<2)>>2]&63}j=k&7;L1549:do{if((j|0)==0){do{if((k|0)!=0){if((h&128|0)==0){break}l=a+148|0;b[l>>1]=b[l>>1]|1;m=i;break L1549}}while(0);l=a+148|0;b[l>>1]=b[l>>1]&-2;m=i}else{l=h&255;n=l<<8-j|l>>>(j>>>0);l=n&255;o=a+148|0;p=b[o>>1]|0;if((n&128|0)==0){b[o>>1]=p&-2;m=l;break}else{b[o>>1]=p|1;m=l;break}}}while(0);c[g>>2]=c[g>>2]&-256|m&255;lM(a,14,m);m=a+268|0;c[m>>2]=(k<<1)+6+(c[m>>2]|0);q=1;return q|0}else if((f|0)==1){m=a+80+((d&7)<<2)|0;k=c[m>>2]|0;g=d>>>9&7;do{if((d&32|0)==0){r=(g|0)==0?8:g;s=1246}else{j=c[a+80+(g<<2)>>2]&63;if((j|0)!=0){r=j;s=1246;break}j=a+148|0;b[j>>1]=b[j>>1]&-2;t=k&255;u=0}}while(0);L1566:do{if((s|0)==1246){if(r>>>0<8){g=k&255;j=g>>>(r>>>0)&255;h=a+148|0;i=b[h>>1]|0;if((1<<r-1&g|0)==0){b[h>>1]=i&-18;t=j;u=r;break}else{b[h>>1]=i|17;t=j;u=r;break}}do{if((r|0)==8){if((k&128|0)==0){break}j=a+148|0;b[j>>1]=b[j>>1]|17;t=0;u=8;break L1566}}while(0);j=a+148|0;b[j>>1]=b[j>>1]&-18;t=0;u=r}}while(0);c[m>>2]=c[m>>2]&-256|t&255;lM(a,14,t);t=a+268|0;c[t>>2]=(u<<1)+6+(c[t>>2]|0);q=1;return q|0}else if((f|0)==2){t=a+80+((d&7)<<2)|0;u=c[t>>2]|0;m=u&255;r=a+148|0;k=(e[r>>1]|0)>>>4;j=d>>>9&7;if((d&32|0)==0){v=(j|0)==0?8:j;w=k&1;s=1258}else{i=c[a+80+(j<<2)>>2]&63;j=k&1;if((i|0)==0){x=m;y=j;z=0}else{v=i;w=j;s=1258}}if((s|0)==1258){j=0;i=m;m=w;while(1){w=(i&65535)>>>1|m<<7;k=j+1|0;h=i&1;if(k>>>0<v>>>0){j=k;i=w;m=h}else{x=w;y=h;z=v;break}}}c[t>>2]=x&255|u&-256;lM(a,14,x&255);x=b[r>>1]|0;b[r>>1]=y<<16>>16==0?x&-18:x|17;x=a+268|0;c[x>>2]=(z<<1)+6+(c[x>>2]|0);q=1;return q|0}else if((f|0)==0){f=d&7;x=d>>>9&7;do{if((d&32|0)==0){z=a+80+(f<<2)|0;A=(x|0)==0?8:x;B=z;C=c[z>>2]|0;s=1234}else{z=c[a+80+(x<<2)>>2]&63;y=a+80+(f<<2)|0;r=c[y>>2]|0;if((z|0)!=0){A=z;B=y;C=r;s=1234;break}z=a+148|0;b[z>>1]=b[z>>1]&-2;D=r&255;E=0;F=y}}while(0);do{if((s|0)==1234){f=C&255;x=(C&128|0)!=0;if(A>>>0<8){d=(x?f|65280:f)>>>(A>>>0)&255;y=a+148|0;r=b[y>>1]|0;if((1<<A-1&f|0)==0){b[y>>1]=r&-18;D=d;E=A;F=B;break}else{b[y>>1]=r|17;D=d;E=A;F=B;break}}else{d=a+148|0;r=b[d>>1]|0;if(x){b[d>>1]=r|17;D=-1;E=A;F=B;break}else{b[d>>1]=r&-18;D=0;E=A;F=B;break}}}}while(0);c[F>>2]=c[F>>2]&-256|D&255;lM(a,14,D);D=a+268|0;c[D>>2]=(E<<1)+6+(c[D>>2]|0);q=1;return q|0}else{iA(a);D=a+268|0;c[D>>2]=(c[D>>2]|0)+2;q=0;return q|0}return 0}function k4(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=e[a+196>>1]|0;f=d>>>3&3;if((f|0)==0){g=a+80+((d&7)<<2)|0;h=c[g>>2]|0;i=d>>>9&7;do{if((d&32|0)==0){j=(i|0)==0?8:i;k=(h&32768|0)!=0;l=1286}else{m=c[a+80+(i<<2)>>2]&63;if((m|0)==0){n=a+148|0;b[n>>1]=b[n>>1]&-2;o=h&65535;p=0;break}n=(h&32768|0)!=0;if(m>>>0<16){j=m;k=n;l=1286;break}q=a+148|0;r=b[q>>1]|0;if(n){b[q>>1]=r|17;o=-1;p=m;break}else{b[q>>1]=r&-18;o=0;p=m;break}}}while(0);do{if((l|0)==1286){i=h&65535;m=(k?h|-65536:i)>>>(j>>>0)&65535;r=a+148|0;q=b[r>>1]|0;if((1<<j-1&i|0)==0){b[r>>1]=q&-18;o=m;p=j;break}else{b[r>>1]=q|17;o=m;p=j;break}}}while(0);c[g>>2]=c[g>>2]&-65536|o&65535;lN(a,14,o);o=a+268|0;c[o>>2]=(p<<1)+6+(c[o>>2]|0);s=1;return s|0}else if((f|0)==2){o=a+80+((d&7)<<2)|0;p=c[o>>2]|0;g=p&65535;j=d>>>9&7;if((d&32|0)==0){h=a+148|0;t=(j|0)==0?8:j;u=h;v=(e[h>>1]|0)>>>4;l=1309}else{h=c[a+80+(j<<2)>>2]&63;j=a+148|0;k=(e[j>>1]|0)>>>4;if((h|0)==0){w=k;x=g;y=0;z=j}else{t=h;u=j;v=k;l=1309}}if((l|0)==1309){k=v;v=0;j=g;while(1){g=k<<15|(j&65535)>>>1;h=v+1|0;if(h>>>0<t>>>0){k=j;v=h;j=g}else{w=j;x=g;y=t;z=u;break}}}c[o>>2]=x&65535|p&-65536;lN(a,14,x);x=b[z>>1]|0;b[z>>1]=(w&1)==0?x&-18:x|17;x=a+268|0;c[x>>2]=(y<<1)+6+(c[x>>2]|0);s=1;return s|0}else if((f|0)==3){x=a+80+((d&7)<<2)|0;y=c[x>>2]|0;w=y&65535;z=d>>>9&7;if((d&32|0)==0){A=(z|0)==0?8:z}else{A=c[a+80+(z<<2)>>2]&63}L1643:do{if((A&15|0)==0){do{if((A|0)!=0){if((y&32768|0)==0){break}z=a+148|0;b[z>>1]=b[z>>1]|1;B=w;break L1643}}while(0);z=a+148|0;b[z>>1]=b[z>>1]&-2;B=w}else{z=y&65535;p=z<<16-A|z>>>(A>>>0);z=p&65535;o=a+148|0;u=b[o>>1]|0;if((p&32768|0)==0){b[o>>1]=u&-2;B=z;break}else{b[o>>1]=u|1;B=z;break}}}while(0);c[x>>2]=c[x>>2]&-65536|B&65535;lN(a,14,B);B=a+268|0;c[B>>2]=(A<<1)+6+(c[B>>2]|0);s=1;return s|0}else if((f|0)==1){f=a+80+((d&7)<<2)|0;B=c[f>>2]|0;A=d>>>9&7;L1658:do{if((d&32|0)==0){C=(A|0)==0?8:A;l=1298}else{x=c[a+80+(A<<2)>>2]&63;if((x|0)==0){y=a+148|0;b[y>>1]=b[y>>1]&-2;D=B&65535;E=0;break}if(x>>>0<16){C=x;l=1298;break}do{if((x|0)==16){if((B&32768|0)==0){break}y=a+148|0;b[y>>1]=b[y>>1]|17;D=0;E=16;break L1658}}while(0);y=a+148|0;b[y>>1]=b[y>>1]&-18;D=0;E=x}}while(0);do{if((l|0)==1298){A=B&65535;d=A>>>(C>>>0)&65535;y=a+148|0;w=b[y>>1]|0;if((1<<C-1&A|0)==0){b[y>>1]=w&-18;D=d;E=C;break}else{b[y>>1]=w|17;D=d;E=C;break}}}while(0);c[f>>2]=c[f>>2]&-65536|D&65535;lN(a,14,D);D=a+268|0;c[D>>2]=(E<<1)+6+(c[D>>2]|0);s=1;return s|0}else{iA(a);D=a+268|0;c[D>>2]=(c[D>>2]|0)+2;s=0;return s|0}return 0}function k5(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;d=e[a+196>>1]|0;f=d>>>3&3;if((f|0)==3){g=a+80+((d&7)<<2)|0;h=c[g>>2]|0;i=d>>>9&7;if((d&32|0)==0){j=(i|0)==0?8:i}else{j=c[a+80+(i<<2)>>2]&63}i=j&31;do{if((i|0)==0){k=a+148|0;l=b[k>>1]|0;if((j|0)!=0&(h|0)<0){b[k>>1]=l|1;m=h;break}else{b[k>>1]=l&-2;m=h;break}}else{l=h<<32-i|h>>>(i>>>0);k=a+148|0;n=b[k>>1]|0;if((l|0)<0){b[k>>1]=n|1;m=l;break}else{b[k>>1]=n&-2;m=l;break}}}while(0);c[g>>2]=m;lO(a,14,m);m=a+268|0;c[m>>2]=(j<<1)+8+(c[m>>2]|0);o=1;return o|0}else if((f|0)==1){m=a+80+((d&7)<<2)|0;j=c[m>>2]|0;g=d>>>9&7;do{if((d&32|0)==0){p=(g|0)==0?8:g;q=1351}else{i=c[a+80+(g<<2)>>2]&63;if((i|0)==0){h=a+148|0;b[h>>1]=b[h>>1]&-2;r=j;s=0;break}if(i>>>0<32){p=i;q=1351;break}h=a+148|0;l=b[h>>1]|0;if((i|0)==32&(j|0)<0){b[h>>1]=l|17;r=0;s=32;break}else{b[h>>1]=l&-18;r=0;s=i;break}}}while(0);do{if((q|0)==1351){g=j>>>(p>>>0);i=a+148|0;l=b[i>>1]|0;if((1<<p-1&j|0)==0){b[i>>1]=l&-18;r=g;s=p;break}else{b[i>>1]=l|17;r=g;s=p;break}}}while(0);c[m>>2]=r;lO(a,14,r);r=a+268|0;c[r>>2]=(s<<1)+8+(c[r>>2]|0);o=1;return o|0}else if((f|0)==2){r=a+80+((d&7)<<2)|0;s=c[r>>2]|0;m=d>>>9&7;if((d&32|0)==0){p=a+148|0;t=(m|0)==0?8:m;u=p;v=(e[p>>1]|0)>>>4&1;q=1361}else{p=c[a+80+(m<<2)>>2]&63;m=a+148|0;j=(e[m>>1]|0)>>>4&1;if((p|0)==0){w=j;x=s;y=0;z=m}else{t=p;u=m;v=j;q=1361}}if((q|0)==1361){j=v;v=0;m=s;while(1){s=m&1;p=j<<31|m>>>1;g=v+1|0;if(g>>>0<t>>>0){j=s;v=g;m=p}else{w=s;x=p;y=t;z=u;break}}}c[r>>2]=x;lO(a,14,x);x=b[z>>1]|0;b[z>>1]=(w|0)==0?x&-18:x|17;x=a+268|0;c[x>>2]=(y<<1)+8+(c[x>>2]|0);o=1;return o|0}else if((f|0)==0){f=a+80+((d&7)<<2)|0;x=c[f>>2]|0;y=d>>>9&7;do{if((d&32|0)==0){w=(y|0)==0?8:y;z=x>>>(w>>>0);if((x|0)<0){A=w;B=z;q=1338}else{C=z;D=w;q=1339}}else{w=c[a+80+(y<<2)>>2]&63;if((w|0)==0){z=a+148|0;b[z>>1]=b[z>>1]&-2;E=x;F=0;break}z=(x|0)<0;if(w>>>0<32){r=x>>>(w>>>0);if(z){A=w;B=r;q=1338;break}else{C=r;D=w;q=1339;break}}r=a+148|0;u=b[r>>1]|0;if(z){b[r>>1]=u|17;E=-1;F=w;break}else{b[r>>1]=u&-18;E=0;F=w;break}}}while(0);if((q|0)==1338){C=-1<<32-A|B;D=A;q=1339}do{if((q|0)==1339){A=a+148|0;B=b[A>>1]|0;if((1<<D-1&x|0)==0){b[A>>1]=B&-18;E=C;F=D;break}else{b[A>>1]=B|17;E=C;F=D;break}}}while(0);c[f>>2]=E;lO(a,14,E);E=a+268|0;c[E>>2]=(F<<1)+8+(c[E>>2]|0);o=1;return o|0}else{iA(a);E=a+268|0;c[E>>2]=(c[E>>2]|0)+2;o=0;return o|0}return 0}function k6(a){a=a|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+8|0;e=d|0;f=b[a+196>>1]&63;if((b5[c[20008+(f<<2)>>2]&127](a,f,508,16)|0)!=0){g=0;i=d;return g|0}if((mn(a,e)|0)!=0){g=0;i=d;return g|0}f=b[e>>1]|0;h=(f&65535)>>>1|f&-32768;if((mq(a,h)|0)!=0){g=0;i=d;return g|0}lN(a,14,h);h=a+148|0;f=b[h>>1]|0;b[h>>1]=(b[e>>1]&1)==0?f&-18:f|17;f=a+268|0;c[f>>2]=(c[f>>2]|0)+8;g=c[a+192>>2]|0;i=d;return g|0}function k7(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;d=e[a+196>>1]|0;f=d>>>3&3;if((f|0)==3){g=a+80+((d&7)<<2)|0;h=c[g>>2]|0;i=h&255;j=d>>>9&7;if((d&32|0)==0){k=(j|0)==0?8:j}else{k=c[a+80+(j<<2)>>2]&63}j=k&7;L1766:do{if((j|0)==0){do{if((k|0)!=0){if((h&1|0)==0){break}l=a+148|0;b[l>>1]=b[l>>1]|1;m=i;break L1766}}while(0);l=a+148|0;b[l>>1]=b[l>>1]&-2;m=i}else{l=h&255;n=l>>>((8-j|0)>>>0)|l<<j;l=n&255;o=a+148|0;p=b[o>>1]|0;if((n&1|0)==0){b[o>>1]=p&-2;m=l;break}else{b[o>>1]=p|1;m=l;break}}}while(0);c[g>>2]=c[g>>2]&-256|m&255;lM(a,14,m);m=a+268|0;c[m>>2]=(k<<1)+6+(c[m>>2]|0);q=1;return q|0}else if((f|0)==1){m=a+80+((d&7)<<2)|0;k=c[m>>2]|0;g=d>>>9&7;do{if((d&32|0)==0){r=(g|0)==0?8:g;s=1412}else{j=c[a+80+(g<<2)>>2]&63;if((j|0)!=0){r=j;s=1412;break}j=a+148|0;b[j>>1]=b[j>>1]&-2;t=k&255;u=0}}while(0);L1783:do{if((s|0)==1412){if(r>>>0<8){g=k&255;j=g<<r&255;h=a+148|0;i=b[h>>1]|0;if((1<<8-r&g|0)==0){b[h>>1]=i&-18;t=j;u=r;break}else{b[h>>1]=i|17;t=j;u=r;break}}do{if((r|0)==8){if((k&1|0)==0){break}j=a+148|0;b[j>>1]=b[j>>1]|17;t=0;u=8;break L1783}}while(0);j=a+148|0;b[j>>1]=b[j>>1]&-18;t=0;u=r}}while(0);c[m>>2]=c[m>>2]&-256|t&255;lM(a,14,t);t=a+268|0;c[t>>2]=(u<<1)+6+(c[t>>2]|0);q=1;return q|0}else if((f|0)==2){t=a+80+((d&7)<<2)|0;u=c[t>>2]|0;m=u&255;r=d>>>9&7;if((d&32|0)==0){k=a+148|0;v=(r|0)==0?8:r;w=k;x=(e[k>>1]|0)>>>4&1;s=1424}else{k=c[a+80+(r<<2)>>2]&63;r=a+148|0;j=(e[r>>1]|0)>>>4&1;if((k|0)==0){y=m;z=j;A=0;B=r}else{v=k;w=r;x=j;s=1424}}if((s|0)==1424){j=0;r=m;m=x;while(1){x=r<<1|m;k=j+1|0;i=(r&65535)>>>7&1;if(k>>>0<v>>>0){j=k;r=x;m=i}else{y=x;z=i;A=v;B=w;break}}}c[t>>2]=y&255|u&-256;lM(a,14,y&255);y=b[B>>1]|0;b[B>>1]=z<<16>>16==0?y&-18:y|17;y=a+268|0;c[y>>2]=(A<<1)+6+(c[y>>2]|0);q=1;return q|0}else if((f|0)==0){f=a+80+((d&7)<<2)|0;y=c[f>>2]|0;A=d>>>9&7;do{if((d&32|0)==0){C=(A|0)==0?8:A;s=1396}else{z=c[a+80+(A<<2)>>2]&63;if((z|0)!=0){C=z;s=1396;break}z=a+148|0;b[z>>1]=b[z>>1]&-4;D=y&255;E=0}}while(0);do{if((s|0)==1396){if(C>>>0<8){A=y&255;d=A<<C&255;z=a+148|0;B=b[z>>1]|0;u=(1<<8-C&A|0)==0?B&-18:B|17;b[z>>1]=u;B=255<<7-C&255;A=B&y;if((A|0)==0|(A|0)==(B|0)){b[z>>1]=u&-3;D=d;E=C;break}else{b[z>>1]=u|2;D=d;E=C;break}}do{if((C|0)==8){if((y&1|0)==0){s=1403;break}d=a+148|0;u=b[d>>1]|17;b[d>>1]=u;F=u}else{s=1403}}while(0);if((s|0)==1403){u=a+148|0;d=b[u>>1]&-18;b[u>>1]=d;F=d}d=a+148|0;if((y&255|0)==0){b[d>>1]=F&-3;D=0;E=C;break}else{b[d>>1]=F|2;D=0;E=C;break}}}while(0);c[f>>2]=c[f>>2]&-256|D&255;lM(a,12,D);D=a+268|0;c[D>>2]=(E<<1)+6+(c[D>>2]|0);q=1;return q|0}else{iA(a);D=a+268|0;c[D>>2]=(c[D>>2]|0)+2;q=0;return q|0}return 0}function k8(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;d=e[a+196>>1]|0;f=d>>>3&3;if((f|0)==0){g=a+80+((d&7)<<2)|0;h=c[g>>2]|0;i=d>>>9&7;do{if((d&32|0)==0){j=(i|0)==0?8:i;k=1452}else{l=c[a+80+(i<<2)>>2]&63;if((l|0)==0){m=a+148|0;b[m>>1]=b[m>>1]&-4;n=h&65535;o=0;break}if(l>>>0<16){j=l;k=1452;break}do{if((l|0)==16){if((h&1|0)==0){k=1458;break}m=a+148|0;p=b[m>>1]|17;b[m>>1]=p;q=p}else{k=1458}}while(0);if((k|0)==1458){p=a+148|0;m=b[p>>1]&-18;b[p>>1]=m;q=m}m=a+148|0;if((h&65535|0)==0){b[m>>1]=q&-3;n=0;o=l;break}else{b[m>>1]=q|2;n=0;o=l;break}}}while(0);do{if((k|0)==1452){q=h&65535;i=q<<j&65535;m=a+148|0;p=b[m>>1]|0;r=(1<<16-j&q|0)==0?p&-18:p|17;b[m>>1]=r;p=65535<<15-j&65535;q=p&h;if((q|0)==0|(q|0)==(p|0)){b[m>>1]=r&-3;n=i;o=j;break}else{b[m>>1]=r|2;n=i;o=j;break}}}while(0);c[g>>2]=c[g>>2]&-65536|n&65535;lN(a,12,n);n=a+268|0;c[n>>2]=(o<<1)+6+(c[n>>2]|0);s=1;return s|0}else if((f|0)==1){n=a+80+((d&7)<<2)|0;o=c[n>>2]|0;g=d>>>9&7;L1858:do{if((d&32|0)==0){t=(g|0)==0?8:g;k=1468}else{j=c[a+80+(g<<2)>>2]&63;if((j|0)==0){h=a+148|0;b[h>>1]=b[h>>1]&-2;u=o&65535;v=0;break}if(j>>>0<16){t=j;k=1468;break}do{if((j|0)==16){if((o&1|0)==0){break}h=a+148|0;b[h>>1]=b[h>>1]|17;u=0;v=16;break L1858}}while(0);l=a+148|0;b[l>>1]=b[l>>1]&-18;u=0;v=j}}while(0);do{if((k|0)==1468){g=o&65535;l=g<<t&65535;h=a+148|0;i=b[h>>1]|0;if((1<<16-t&g|0)==0){b[h>>1]=i&-18;u=l;v=t;break}else{b[h>>1]=i|17;u=l;v=t;break}}}while(0);c[n>>2]=c[n>>2]&-65536|u&65535;lN(a,14,u);u=a+268|0;c[u>>2]=(v<<1)+6+(c[u>>2]|0);s=1;return s|0}else if((f|0)==2){u=a+80+((d&7)<<2)|0;v=c[u>>2]|0;n=v&65535;t=d>>>9&7;if((d&32|0)==0){o=a+148|0;w=(t|0)==0?8:t;x=o;y=(e[o>>1]|0)>>>4&1;k=1479}else{o=c[a+80+(t<<2)>>2]&63;t=a+148|0;l=(e[t>>1]|0)>>>4&1;if((o|0)==0){z=l;A=n;B=0;C=t}else{w=o;x=t;y=l;k=1479}}if((k|0)==1479){k=y;y=0;l=n;while(1){n=(l&65535)>>>15;t=k|l<<1;o=y+1|0;if(o>>>0<w>>>0){k=n;y=o;l=t}else{z=n;A=t;B=w;C=x;break}}}c[u>>2]=A&65535|v&-65536;lN(a,14,A);A=b[C>>1]|0;b[C>>1]=z<<16>>16==0?A&-18:A|17;A=a+268|0;c[A>>2]=(B<<1)+6+(c[A>>2]|0);s=1;return s|0}else if((f|0)==3){f=a+80+((d&7)<<2)|0;A=c[f>>2]|0;B=A&65535;z=d>>>9&7;if((d&32|0)==0){D=(z|0)==0?8:z}else{D=c[a+80+(z<<2)>>2]&63}z=D&15;L1891:do{if((z|0)==0){do{if((D|0)!=0){if((A&1|0)==0){break}d=a+148|0;b[d>>1]=b[d>>1]|1;E=B;break L1891}}while(0);j=a+148|0;b[j>>1]=b[j>>1]&-2;E=B}else{j=A&65535;d=j>>>((16-z|0)>>>0)|j<<z;j=d&65535;C=a+148|0;v=b[C>>1]|0;if((d&1|0)==0){b[C>>1]=v&-2;E=j;break}else{b[C>>1]=v|1;E=j;break}}}while(0);c[f>>2]=c[f>>2]&-65536|E&65535;lN(a,14,E);E=a+268|0;c[E>>2]=(D<<1)+6+(c[E>>2]|0);s=1;return s|0}else{iA(a);E=a+268|0;c[E>>2]=(c[E>>2]|0)+2;s=0;return s|0}return 0}function k9(a){a=a|0;var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=e[a+196>>1]|0;f=d>>>3&3;if((f|0)==1){g=a+80+((d&7)<<2)|0;h=c[g>>2]|0;i=d>>>9&7;L1908:do{if((d&32|0)==0){j=(i|0)==0?8:i;k=1523}else{l=c[a+80+(i<<2)>>2]&63;if((l|0)==0){m=a+148|0;b[m>>1]=b[m>>1]&-2;n=h;o=0;break}if(l>>>0<32){j=l;k=1523;break}do{if((l|0)==32){if((h&1|0)==0){break}m=a+148|0;b[m>>1]=b[m>>1]|17;n=0;o=32;break L1908}}while(0);m=a+148|0;b[m>>1]=b[m>>1]&-18;n=0;o=l}}while(0);do{if((k|0)==1523){i=h<<j;m=a+148|0;p=b[m>>1]|0;if((1<<32-j&h|0)==0){b[m>>1]=p&-18;n=i;o=j;break}else{b[m>>1]=p|17;n=i;o=j;break}}}while(0);c[g>>2]=n;lO(a,14,n);n=a+268|0;c[n>>2]=(o<<1)+8+(c[n>>2]|0);q=1;return q|0}else if((f|0)==2){n=d>>>9&7;if((d&32|0)==0){r=(n|0)==0?8:n}else{r=c[a+80+(n<<2)>>2]&63}n=a+80+((d&7)<<2)|0;o=c[n>>2]|0;g=a+148|0;j=(e[g>>1]|0)>>>4&1;if((r|0)==0){s=j;t=o}else{h=j;j=0;i=o;while(1){o=i>>>31;p=h|i<<1;m=j+1|0;if(m>>>0<r>>>0){h=o;j=m;i=p}else{s=o;t=p;break}}}c[n>>2]=t;lO(a,14,t);t=b[g>>1]|0;b[g>>1]=(s|0)==0?t&-18:t|17;t=a+268|0;c[t>>2]=(r<<1)+8+(c[t>>2]|0);q=1;return q|0}else if((f|0)==0){t=a+80+((d&7)<<2)|0;r=c[t>>2]|0;s=d>>>9&7;do{if((d&32|0)==0){u=(s|0)==0?8:s;k=1507}else{g=c[a+80+(s<<2)>>2]&63;if((g|0)==0){n=a+148|0;b[n>>1]=b[n>>1]&-4;v=r;w=0;break}if(g>>>0<32){u=g;k=1507;break}do{if((g|0)==32){if((r&1|0)==0){k=1513;break}n=a+148|0;i=b[n>>1]|17;b[n>>1]=i;x=i}else{k=1513}}while(0);if((k|0)==1513){l=a+148|0;i=b[l>>1]&-18;b[l>>1]=i;x=i}i=a+148|0;if((r|0)==0){b[i>>1]=x&-3;v=0;w=g;break}else{b[i>>1]=x|2;v=0;w=g;break}}}while(0);do{if((k|0)==1507){x=r<<u;s=-1<<31-u;i=a+148|0;l=b[i>>1]|0;n=(1<<32-u&r|0)==0?l&-18:l|17;b[i>>1]=n;l=s&r;if((l|0)==0|(l|0)==(s|0)){b[i>>1]=n&-3;v=x;w=u;break}else{b[i>>1]=n|2;v=x;w=u;break}}}while(0);c[t>>2]=v;lO(a,12,v);v=a+268|0;c[v>>2]=(w<<1)+8+(c[v>>2]|0);q=1;return q|0}else if((f|0)==3){f=a+80+((d&7)<<2)|0;v=c[f>>2]|0;w=d>>>9&7;if((d&32|0)==0){y=(w|0)==0?8:w}else{y=c[a+80+(w<<2)>>2]&63}w=y&31;L1965:do{if((w|0)==0){do{if((y|0)!=0){if((v&1|0)==0){break}d=a+148|0;b[d>>1]=b[d>>1]|1;z=v;break L1965}}while(0);g=a+148|0;b[g>>1]=b[g>>1]&-2;z=v}else{g=v>>>((32-w|0)>>>0)|v<<w;d=a+148|0;t=b[d>>1]|0;if((g&1|0)==0){b[d>>1]=t&-2;z=g;break}else{b[d>>1]=t|1;z=g;break}}}while(0);c[f>>2]=z;lO(a,14,z);z=a+268|0;c[z>>2]=(y<<1)+8+(c[z>>2]|0);q=1;return q|0}else{iA(a);z=a+268|0;c[z>>2]=(c[z>>2]|0)+2;q=0;return q|0}return 0}function la(a){a=a|0;var d=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+8|0;f=d|0;g=b[a+196>>1]&63;if((b5[c[20008+(g<<2)>>2]&127](a,g,508,16)|0)!=0){h=0;i=d;return h|0}if((mn(a,f)|0)!=0){h=0;i=d;return h|0}g=(e[f>>1]|0)<<1;j=g&65535;if((mq(a,j)|0)!=0){h=0;i=d;return h|0}lN(a,12,j);j=b[f>>1]|0;f=a+148|0;k=b[f>>1]|0;l=j<<16>>16<0?k|17:k&-18;b[f>>1]=((j&65535^g)&32768|0)==0?l&-3:l|2;l=a+268|0;c[l>>2]=(c[l>>2]|0)+8;h=c[a+192>>2]|0;i=d;return h|0}function lb(a){a=a|0;var d=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;f=d|0;g=b[a+196>>1]&63;if((b5[c[20008+(g<<2)>>2]&127](a,g,508,16)|0)!=0){h=0;i=d;return h|0}if((mn(a,f)|0)!=0){h=0;i=d;return h|0}g=(e[f>>1]|0)>>>1;if((mq(a,g)|0)!=0){h=0;i=d;return h|0}lN(a,14,g);g=a+148|0;j=b[g>>1]|0;b[g>>1]=(b[f>>1]&1)==0?j&-18:j|17;j=a+268|0;c[j>>2]=(c[j>>2]|0)+8;h=c[a+192>>2]|0;i=d;return h|0}function lc(a){a=a|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+8|0;e=d|0;f=b[a+196>>1]&63;if((b5[c[20008+(f<<2)>>2]&127](a,f,508,16)|0)!=0){g=0;i=d;return g|0}if((mn(a,e)|0)!=0){g=0;i=d;return g|0}f=b[e>>1]<<1;if((mq(a,f)|0)!=0){g=0;i=d;return g|0}lN(a,14,f);f=a+148|0;h=b[f>>1]|0;b[f>>1]=(b[e>>1]|0)<0?h|17:h&-18;h=a+268|0;c[h>>2]=(c[h>>2]|0)+8;g=c[a+192>>2]|0;i=d;return g|0}function ld(a){a=a|0;var d=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;f=d|0;g=b[a+196>>1]&63;if((b5[c[20008+(g<<2)>>2]&127](a,g,508,16)|0)!=0){h=0;i=d;return h|0}if((mn(a,f)|0)!=0){h=0;i=d;return h|0}g=a+148|0;j=(e[f>>1]|0)>>>1|(e[g>>1]|0)>>>4<<15;if((mq(a,j)|0)!=0){h=0;i=d;return h|0}lN(a,14,j);j=b[g>>1]|0;b[g>>1]=(b[f>>1]&1)==0?j&-18:j|17;j=a+268|0;c[j>>2]=(c[j>>2]|0)+8;h=c[a+192>>2]|0;i=d;return h|0}function le(a){a=a|0;var d=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;f=d|0;g=b[a+196>>1]&63;if((b5[c[20008+(g<<2)>>2]&127](a,g,508,16)|0)!=0){h=0;i=d;return h|0}if((mn(a,f)|0)!=0){h=0;i=d;return h|0}g=a+148|0;j=b[f>>1]<<1|(e[g>>1]|0)>>>4&1;if((mq(a,j)|0)!=0){h=0;i=d;return h|0}lN(a,14,j);j=b[g>>1]|0;b[g>>1]=(b[f>>1]|0)<0?j|17:j&-18;j=a+268|0;c[j>>2]=(c[j>>2]|0)+8;h=c[a+192>>2]|0;i=d;return h|0}function lf(a){a=a|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+8|0;e=d|0;f=b[a+196>>1]&63;if((b5[c[20008+(f<<2)>>2]&127](a,f,508,16)|0)!=0){g=0;i=d;return g|0}if((mn(a,e)|0)!=0){g=0;i=d;return g|0}f=b[e>>1]|0;h=(f&65535)>>>1|f<<15;if((mq(a,h)|0)!=0){g=0;i=d;return g|0}lN(a,14,h);h=a+148|0;f=b[h>>1]|0;b[h>>1]=(b[e>>1]&1)==0?f&-2:f|1;f=a+268|0;c[f>>2]=(c[f>>2]|0)+8;g=c[a+192>>2]|0;i=d;return g|0}function lg(a){a=a|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+8|0;e=d|0;f=b[a+196>>1]&63;if((b5[c[20008+(f<<2)>>2]&127](a,f,508,16)|0)!=0){g=0;i=d;return g|0}if((mn(a,e)|0)!=0){g=0;i=d;return g|0}f=b[e>>1]|0;e=f<<16>>16==0?(f&65535)>>>15:1;if((mq(a,e)|0)!=0){g=0;i=d;return g|0}lN(a,14,e);f=a+148|0;h=b[f>>1]|0;b[f>>1]=e<<16>>16==0?h&-2:h|1;h=a+268|0;c[h>>2]=(c[h>>2]|0)+8;g=c[a+192>>2]|0;i=d;return g|0}function lh(a){a=a|0;b[a+186>>1]=b[a+196>>1]|0;iG(a);return 0}function li(a){a=a|0;var b=0,d=0;iy(a);b=0;do{d=c[24360+(b<<2)>>2]|0;if((d|0)!=0){c[a+296+(b<<2)>>2]=d}b=b+1|0;}while(b>>>0<1024);c[a+4392>>2]=386;return}function lj(a){a=a|0;var d=0,e=0,f=0;d=a+80+((b[a+196>>1]&7)<<2)|0;e=c[d>>2]|0;f=(e&128|0)!=0?e|-256:e&255;c[d>>2]=f;lO(a,15,f);f=a+268|0;c[f>>2]=(c[f>>2]|0)+4;return 1}function lk(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=f+196|0;h=(e[g>>1]|0)>>>9&3;i=(c[f+144>>2]|0)+2&16777215;j=i+1|0;k=f+36|0;if(j>>>0<(c[k>>2]|0)>>>0){l=c[f+32>>2]|0;m=(d[l+i|0]|0)<<8|(d[l+j|0]|0)}else{m=b6[c[f+12>>2]&63](c[f+4>>2]|0,i)|0}i=f+198|0;b[i>>1]=m;j=f+192|0;c[j>>2]=2;if((m&2047)!=0){iA(f);m=f+268|0;c[m>>2]=(c[m>>2]|0)+2;n=0;return n|0}m=b[g>>1]&63;if((b5[c[20008+(m<<2)>>2]&127](f,m,2020,8)|0)!=0){n=0;return n|0}if((c[f+228>>2]|0)!=2){iA(f);m=f+268|0;c[m>>2]=(c[m>>2]|0)+2;n=0;return n|0}m=(h|0)==0;do{if(m){g=f+232|0;l=c[g>>2]|0;o=l&16777215;p=c[k>>2]|0;if(o>>>0<p>>>0){q=a[(c[f+32>>2]|0)+o|0]|0;r=l;s=p}else{p=b6[c[f+8>>2]&63](c[f+4>>2]|0,o)|0;q=p;r=c[g>>2]|0;s=c[k>>2]|0}g=q&255;p=r+1&16777215;if(p>>>0<s>>>0){t=a[(c[f+32>>2]|0)+p|0]|0}else{t=b6[c[f+8>>2]&63](c[f+4>>2]|0,p)|0}p=t&255;u=(p&128|0)!=0?p|-256:p;v=(g&128|0)!=0?g|-256:g}else{g=f+232|0;p=c[g>>2]|0;o=p&16777215;if((h|0)!=1){l=o+3|0;w=c[k>>2]|0;if(l>>>0<w>>>0){x=c[f+32>>2]|0;y=(((d[x+o|0]|0)<<8|(d[x+(o+1)|0]|0))<<8|(d[x+(o+2)|0]|0))<<8|(d[x+l|0]|0);z=p;A=w}else{w=b6[c[f+16>>2]&63](c[f+4>>2]|0,o)|0;y=w;z=c[g>>2]|0;A=c[k>>2]|0}w=z+4&16777215;l=w+3|0;if(l>>>0<A>>>0){x=c[f+32>>2]|0;u=(((d[x+w|0]|0)<<8|(d[x+(w+1)|0]|0))<<8|(d[x+(w+2)|0]|0))<<8|(d[x+l|0]|0);v=y;break}else{u=b6[c[f+16>>2]&63](c[f+4>>2]|0,w)|0;v=y;break}}w=o+1|0;l=c[k>>2]|0;if(w>>>0<l>>>0){x=c[f+32>>2]|0;B=(d[x+o|0]|0)<<8|(d[x+w|0]|0);C=p;D=l}else{l=b6[c[f+12>>2]&63](c[f+4>>2]|0,o)|0;B=l;C=c[g>>2]|0;D=c[k>>2]|0}g=B&65535;l=C+2&16777215;o=l+1|0;if(o>>>0<D>>>0){p=c[f+32>>2]|0;E=(d[p+l|0]|0)<<8|(d[p+o|0]|0)}else{E=b6[c[f+12>>2]&63](c[f+4>>2]|0,l)|0}l=E&65535;u=(l&32768|0)!=0?l|-65536:l;v=(g&32768|0)!=0?g|-65536:g}}while(0);E=b[i>>1]|0;i=E&65535;D=i>>>12&7;do{if((i&32768|0)==0){C=c[f+80+(D<<2)>>2]|0;if(m){F=(C&128|0)!=0?C|-256:C&255;break}if((h|0)!=1){F=C;break}F=(C&32768|0)!=0?C|-65536:C&65535}else{F=c[f+112+(D<<2)>>2]|0}}while(0);D=F^-2147483648;if(D>>>0<(v^-2147483648)>>>0){G=1}else{G=D>>>0>(u^-2147483648)>>>0}D=f+148|0;h=b[D>>1]|0;m=(F|0)==(v|0)|(F|0)==(u|0)?h|4:h&-5;b[D>>1]=G?m|1:m&-2;m=f+268|0;c[m>>2]=(c[m>>2]|0)+14;if((E&2048)==0|G^1){n=c[j>>2]|0;return n|0}else{iC(f);n=0;return n|0}return 0}function ll(a){a=a|0;var d=0,f=0,g=0,h=0,j=0;d=i;i=i+8|0;f=d|0;g=a+196|0;h=b[g>>1]&63;if((b5[c[20008+(h<<2)>>2]&127](a,h,4093,32)|0)!=0){j=0;i=d;return j|0}if((mo(a,f)|0)!=0){j=0;i=d;return j|0}h=c[a+80+(((e[g>>1]|0)>>>9&7)<<2)>>2]|0;do{if((h|0)<0){g=a+148|0;b[g>>1]=b[g>>1]|8}else{g=c[f>>2]|0;if((g|0)<0|h>>>0>g>>>0){g=a+148|0;b[g>>1]=b[g>>1]&-9;break}g=a+268|0;c[g>>2]=(c[g>>2]|0)+14;j=c[a+192>>2]|0;i=d;return j|0}}while(0);iC(a);j=0;i=d;return j|0}function lm(d){d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+8|0;f=e|0;g=b[d+196>>1]&63;if((b5[c[20008+(g<<2)>>2]&127](d,g,4093,8)|0)!=0){h=0;i=e;return h|0}if((mm(d,f)|0)!=0){h=0;i=e;return h|0}lM(d,15,a[f]|0);f=d+268|0;c[f>>2]=(c[f>>2]|0)+8;h=c[d+192>>2]|0;i=e;return h|0}function ln(a){a=a|0;var d=0,e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;f=b[a+196>>1]&63;if((b5[c[20008+(f<<2)>>2]&127](a,f,4095,16)|0)!=0){g=0;i=d;return g|0}if((mn(a,e)|0)!=0){g=0;i=d;return g|0}lN(a,15,b[e>>1]|0);e=a+268|0;c[e>>2]=(c[e>>2]|0)+8;g=c[a+192>>2]|0;i=d;return g|0}function lo(a){a=a|0;var d=0,e=0,f=0,g=0;d=i;i=i+8|0;e=d|0;f=b[a+196>>1]&63;if((b5[c[20008+(f<<2)>>2]&127](a,f,4095,32)|0)!=0){g=0;i=d;return g|0}if((mo(a,e)|0)!=0){g=0;i=d;return g|0}lO(a,15,c[e>>2]|0);e=a+268|0;c[e>>2]=(c[e>>2]|0)+8;g=c[a+192>>2]|0;i=d;return g|0}function lp(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;i=i+8|0;f=e|0;g=(c[a+144>>2]|0)+2&16777215;h=g+1|0;if(h>>>0<(c[a+36>>2]|0)>>>0){j=c[a+32>>2]|0;k=(d[j+g|0]|0)<<8|(d[j+h|0]|0)}else{k=b6[c[a+12>>2]&63](c[a+4>>2]|0,g)|0}g=a+198|0;b[g>>1]=k;h=a+192|0;c[h>>2]=2;j=k&65535;if((j&33544|0)!=0){iA(a);k=a+268|0;c[k>>2]=(c[k>>2]|0)+2;l=0;i=e;return l|0}k=(j&2048|0)!=0;m=j&7;n=b[a+196>>1]&63;if((b5[c[20008+(n<<2)>>2]&127](a,n,4093,32)|0)!=0){l=0;i=e;return l|0}if((mo(a,f)|0)!=0){l=0;i=e;return l|0}n=c[f>>2]|0;f=0;o=a+80+((j>>>12&7)<<2)|0;j=c[o>>2]|0;p=0;if(k){q=(n&-2147483648|0)==0&(f&0|0)==0;r=(j&-2147483648|0)==0&(p&0|0)==0;s=r?p:p|-1;t=r?j:j|0;u=q?f:f|-1;v=q?n:n|0}else{s=p;t=j;u=f;v=n}n=vp(t,s,v,u)|0;u=n;v=G;s=v;c[o>>2]=u;do{if((b[g>>1]&1024)==0){o=a+148|0;t=b[o>>1]|0;f=(s|0)<0?t|8:t&-9;t=(v|n|0)==0?f|4:f&-5;b[o>>1]=t;if((s|0)==((k&(u|0)<0)<<31>>31|0)){f=t&-3;b[o>>1]=f;w=f;break}else{f=t|2;b[o>>1]=f;w=f;break}}else{c[a+80+(m<<2)>>2]=s;f=a+148|0;o=b[f>>1]|0;t=(s|0)<0?o|8:o&-9;o=((v|n|0)==0?t|4:t&-7)&-3;b[f>>1]=o;w=o}}while(0);b[a+148>>1]=w&-2;w=a+268|0;c[w>>2]=(c[w>>2]|0)+74;l=c[h>>2]|0;i=e;return l|0}function lq(a){a=a|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0;e=i;i=i+8|0;f=e|0;g=(c[a+144>>2]|0)+2&16777215;h=g+1|0;if(h>>>0<(c[a+36>>2]|0)>>>0){j=c[a+32>>2]|0;k=(d[j+g|0]|0)<<8|(d[j+h|0]|0)}else{k=b6[c[a+12>>2]&63](c[a+4>>2]|0,g)|0}g=a+198|0;b[g>>1]=k;h=a+192|0;c[h>>2]=2;j=k&65535;if((j&33544|0)!=0){iA(a);k=a+268|0;c[k>>2]=(c[k>>2]|0)+2;l=0;i=e;return l|0}k=(j&2048|0)!=0;m=j>>>12&7;n=j&7;j=b[a+196>>1]&63;if((b5[c[20008+(j<<2)>>2]&127](a,j,4093,32)|0)!=0){l=0;i=e;return l|0}if((mo(a,f)|0)!=0){l=0;i=e;return l|0}j=a+80+(m<<2)|0;o=c[j>>2]|0;p=c[f>>2]|0;if((p|0)==0){iB(a);l=0;i=e;return l|0}if(k){if((p|0)<0){q=-p|0;c[f>>2]=q;r=q}else{r=p}s=p>>>31;t=(o|0)<0?-o|0:o;u=o>>>31;v=r}else{s=0;t=o;u=0;v=p}L2218:do{if((b[g>>1]&1024)==0){w=u;x=(t>>>0)/(v>>>0)|0;y=(t>>>0)%(v>>>0)|0;z=1749}else{p=c[a+80+(n<<2)>>2]|0;do{if(k){r=p>>>31;if((p|0)>=0){A=p;B=o;C=r;break}A=((o|0)==0)+~p|0;B=-o|0;C=r}else{A=p;B=o;C=u}}while(0);p=B|0;r=A|0;q=v;f=0;D=vq(p,r,q,f)|0;E=G;F=D;H=vr(p,r,q,f)|0;f=H;do{if(k){H=0;if(E>>>0>H>>>0|E>>>0==H>>>0&D>>>0>-2147483648>>>0){break}if(!((D|0)==(-2147483648|0)&(E|0)==0&(s|0)==(C|0))){w=C;x=F;y=f;z=1749;break L2218}}else{H=1;if(E>>>0<H>>>0|E>>>0==H>>>0&D>>>0<0>>>0){w=C;x=F;y=f;z=1749;break L2218}}}while(0);f=a+148|0;b[f>>1]=b[f>>1]|2}}while(0);if((z|0)==1749){z=(s|0)==(w|0)?x:-x|0;c[j>>2]=z;if((n|0)!=(m|0)){c[a+80+(n<<2)>>2]=(w|0)==0?y:-y|0}lO(a,15,z)}z=a+268|0;c[z>>2]=(c[z>>2]|0)+144;l=c[h>>2]|0;i=e;return l|0}function lr(a){a=a|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=e[a+196>>1]|0;g=(f&128|0)!=0?f|-256:f&255;if((g|0)==0){f=a+144|0;h=(c[f>>2]|0)+2&16777215;i=h+1|0;if(i>>>0<(c[a+36>>2]|0)>>>0){j=c[a+32>>2]|0;k=(d[j+h|0]|0)<<8|(d[j+i|0]|0)}else{k=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0}b[a+198>>1]=k;c[a+192>>2]=2;h=k&65535;l=(h&32768|0)!=0?h|-65536:h;m=f;n=c[m>>2]|0;o=l+2|0;p=o+n|0;c[m>>2]=p;q=a+268|0;r=c[q>>2]|0;s=r+10|0;c[q>>2]=s;return 0}f=a+144|0;if((g&255|0)!=255){l=g;m=f;n=c[m>>2]|0;o=l+2|0;p=o+n|0;c[m>>2]=p;q=a+268|0;r=c[q>>2]|0;s=r+10|0;c[q>>2]=s;return 0}g=c[f>>2]|0;h=g+2&16777215;k=h+1|0;i=a+36|0;j=c[i>>2]|0;if(k>>>0<j>>>0){t=c[a+32>>2]|0;u=(d[t+h|0]|0)<<8|(d[t+k|0]|0);v=g;w=j}else{j=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0;u=j;v=c[f>>2]|0;w=c[i>>2]|0}i=a+198|0;b[i>>1]=u;j=a+192|0;c[j>>2]=2;h=v+4&16777215;v=h+1|0;if(v>>>0<w>>>0){w=c[a+32>>2]|0;x=(d[w+h|0]|0)<<8|(d[w+v|0]|0);y=u}else{u=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0;x=u;y=b[i>>1]|0}b[a+200>>1]=x;c[j>>2]=3;l=(y&65535)<<16|x&65535;m=f;n=c[m>>2]|0;o=l+2|0;p=o+n|0;c[m>>2]=p;q=a+268|0;r=c[q>>2]|0;s=r+10|0;c[q>>2]=s;return 0}function ls(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=e[f+196>>1]|0;h=(g&128|0)!=0?g|-256:g&255;do{if((h|0)==0){g=f+144|0;i=(c[g>>2]|0)+2&16777215;j=i+1|0;k=f+36|0;if(j>>>0<(c[k>>2]|0)>>>0){l=c[f+32>>2]|0;m=(d[l+i|0]|0)<<8|(d[l+j|0]|0)}else{m=b6[c[f+12>>2]&63](c[f+4>>2]|0,i)|0}b[f+198>>1]=m;c[f+192>>2]=2;i=m&65535;n=(i&32768|0)!=0?i|-65536:i;o=4;p=g;q=k}else{if((h&255|0)!=255){n=h;o=c[f+192>>2]<<1;p=f+144|0;q=f+36|0;break}k=f+144|0;g=c[k>>2]|0;i=g+2&16777215;j=i+1|0;l=f+36|0;r=c[l>>2]|0;if(j>>>0<r>>>0){s=c[f+32>>2]|0;t=(d[s+i|0]|0)<<8|(d[s+j|0]|0);u=g;v=r}else{r=b6[c[f+12>>2]&63](c[f+4>>2]|0,i)|0;t=r;u=c[k>>2]|0;v=c[l>>2]|0}r=f+198|0;b[r>>1]=t;i=f+192|0;c[i>>2]=2;g=u+4&16777215;j=g+1|0;if(j>>>0<v>>>0){s=c[f+32>>2]|0;w=(d[s+g|0]|0)<<8|(d[s+j|0]|0);x=t}else{j=b6[c[f+12>>2]&63](c[f+4>>2]|0,g)|0;w=j;x=b[r>>1]|0}b[f+200>>1]=w;c[i>>2]=3;n=(x&65535)<<16|w&65535;o=6;p=k;q=l}}while(0);w=o+(c[p>>2]|0)|0;o=f+140|0;x=(c[o>>2]|0)-4|0;t=x&16777215;v=t+3|0;if(v>>>0<(c[q>>2]|0)>>>0){q=f+32|0;a[(c[q>>2]|0)+t|0]=w>>>24&255;a[(c[q>>2]|0)+(t+1)|0]=w>>>16&255;a[(c[q>>2]|0)+(t+2)|0]=w>>>8&255;a[(c[q>>2]|0)+v|0]=w&255;c[o>>2]=x;y=c[p>>2]|0;z=n+2|0;A=z+y|0;c[p>>2]=A;B=f+268|0;C=c[B>>2]|0;D=C+18|0;c[B>>2]=D;return 0}else{b3[c[f+28>>2]&63](c[f+4>>2]|0,t,w);c[o>>2]=x;y=c[p>>2]|0;z=n+2|0;A=z+y|0;c[p>>2]=A;B=f+268|0;C=c[B>>2]|0;D=C+18|0;c[B>>2]=D;return 0}return 0}function lt(a){a=a|0;var b=0,c=0;b=e[a+148>>1]|0;if((b&1|0)==0){c=b>>>2&1^1}else{c=0}return l$(a,c)|0}function lu(a){a=a|0;var b=0,c=0;b=e[a+148>>1]|0;if((b&1|0)==0){c=b>>>2&1}else{c=1}return l$(a,c)|0}function lv(a){a=a|0;return l$(a,(b[a+148>>1]&1^1)&65535)|0}function lw(a){a=a|0;return l$(a,b[a+148>>1]&1)|0}function lx(a){a=a|0;return l$(a,((e[a+148>>1]|0)>>>2&1^1)&65535)|0}function ly(a){a=a|0;return l$(a,(e[a+148>>1]|0)>>>2&1)|0}function lz(a){a=a|0;return l$(a,((e[a+148>>1]|0)>>>1&1^1)&65535)|0}function lA(a){a=a|0;return l$(a,(e[a+148>>1]|0)>>>1&1)|0}function lB(a){a=a|0;return l$(a,((e[a+148>>1]|0)>>>3&1^1)&65535)|0}function lC(a){a=a|0;return l$(a,(e[a+148>>1]|0)>>>3&1)|0}function lD(a){a=a|0;var b=0;b=e[a+148>>1]|0;return l$(a,(b>>>3^b>>>1)&1^1)|0}function lE(a){a=a|0;var b=0;b=e[a+148>>1]|0;return l$(a,(b>>>3^b>>>1)&1)|0}function lF(a){a=a|0;var b=0,c=0;b=e[a+148>>1]|0;if(((b>>>3^b>>>1)&1|0)==0){c=b>>>2&1^1}else{c=0}return l$(a,c)|0}function lG(a){a=a|0;var b=0,c=0;b=e[a+148>>1]|0;if(((b>>>3^b>>>1)&1|0)==0){c=b>>>2&1}else{c=1}return l$(a,c)|0}function lH(a){a=a|0;var b=0,d=0,e=0;b=i;i=i+8|0;d=b|0;if((lZ(a,d,2021)|0)==0){lO(a,15,c[d>>2]<<32-(c[a+240>>2]|0));e=c[a+192>>2]|0;i=b;return e|0}else{iA(a);d=a+268|0;c[d>>2]=(c[d>>2]|0)+2;e=0;i=b;return e|0}return 0}function lI(a){a=a|0;var b=0,d=0,f=0,g=0,h=0,j=0;b=i;i=i+8|0;d=b|0;if((lZ(a,d,2021)|0)==0){f=(e[a+198>>1]|0)>>>12&7;g=a+240|0;h=-1>>>((32-(c[g>>2]|0)|0)>>>0)&c[d>>2];c[d>>2]=h;c[a+80+(f<<2)>>2]=h;lO(a,15,h<<32-(c[g>>2]|0));j=c[a+192>>2]|0;i=b;return j|0}else{iA(a);g=a+268|0;c[g>>2]=(c[g>>2]|0)+2;j=0;i=b;return j|0}return 0}function lJ(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;i=i+8|0;d=b|0;if((lZ(a,d,485)|0)!=0){iA(a);e=a+268|0;c[e>>2]=(c[e>>2]|0)+2;f=0;i=b;return f|0}e=c[d>>2]|0;if((l_(a,~e)|0)==0){lO(a,15,e<<32-(c[a+240>>2]|0));f=c[a+192>>2]|0;i=b;return f|0}else{iA(a);e=a+268|0;c[e>>2]=(c[e>>2]|0)+2;f=0;i=b;return f|0}return 0}function lK(a){a=a|0;var b=0,d=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+8|0;d=b|0;if((lZ(a,d,2021)|0)!=0){iA(a);f=a+268|0;c[f>>2]=(c[f>>2]|0)+2;g=0;i=b;return g|0}f=(e[a+198>>1]|0)>>>12&7;h=a+240|0;j=32-(c[h>>2]|0)|0;k=-1>>>(j>>>0);l=c[d>>2]|0;if((-2147483648>>>(j>>>0)&l|0)==0){m=k&l}else{m=l|~k}c[d>>2]=m;c[a+80+(f<<2)>>2]=m;lO(a,15,m<<32-(c[h>>2]|0));g=c[a+192>>2]|0;i=b;return g|0}function lL(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;i=i+8|0;d=b|0;if((lZ(a,d,485)|0)!=0){iA(a);e=a+268|0;c[e>>2]=(c[e>>2]|0)+2;f=0;i=b;return f|0}if((l_(a,0)|0)==0){lO(a,15,c[d>>2]<<32-(c[a+240>>2]|0));f=c[a+192>>2]|0;i=b;return f|0}else{iA(a);d=a+268|0;c[d>>2]=(c[d>>2]|0)+2;f=0;i=b;return f|0}return 0}function lM(a,c,d){a=a|0;c=c|0;d=d|0;var f=0;if(d<<24>>24==0){f=4}else{f=d<<24>>24<0?8:0}d=c&255;c=a+148|0;b[c>>1]=((e[c>>1]|0)&(d^65535)|f&d)&65535;return}function lN(a,c,d){a=a|0;c=c|0;d=d|0;var f=0;if(d<<16>>16==0){f=4}else{f=d<<16>>16<0?8:0}d=c&255;c=a+148|0;b[c>>1]=((e[c>>1]|0)&(d^65535)|f&d)&65535;return}function lO(a,c,d){a=a|0;c=c|0;d=d|0;var f=0;if((d|0)==0){f=4}else{f=d>>31&8}d=c&255;c=a+148|0;b[c>>1]=((e[c>>1]|0)&(d^65535)|f&d)&65535;return}function lP(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=a+148|0;a=b[f>>1]|0;g=c<<24>>24==0?a|4:a&-5;b[f>>1]=g;a=(d&255)>>>7;d=(e&255)>>>7;do{if(c<<24>>24>-1){e=(d|a|0)==0?0:17;if((d&a|0)==0){h=e;break}h=e|2}else{e=(d&a|0)==0?8:25;if((d|a|0)!=0){h=e;break}h=e|2}}while(0);b[f>>1]=g&-28|h;return}function lQ(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=a+148|0;a=b[f>>1]|0;g=c<<16>>16==0?a|4:a&-5;b[f>>1]=g;a=(d&65535)>>>15;d=(e&65535)>>>15;do{if(c<<16>>16>-1){e=(d|a|0)==0?0:17;if((d&a|0)==0){h=e;break}h=e|2}else{e=(d&a|0)==0?8:25;if((d|a|0)!=0){h=e;break}h=e|2}}while(0);b[f>>1]=g&-28|h;return}function lR(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=a+148|0;a=b[f>>1]|0;g=(c|0)==0?a|4:a&-5;b[f>>1]=g;a=d>>>31;d=e>>>31;do{if((c|0)>-1){e=(d|a|0)==0?0:17;if((d&a|0)==0){h=e;break}h=e|2}else{e=(d&a|0)==0?8:25;if((d|a|0)!=0){h=e;break}h=e|2}}while(0);b[f>>1]=g&-28|h;return}function lS(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=(d&255)>>>7;d=(e&255)>>>7;do{if(c<<24>>24>-1){e=(d|f|0)==0?0:17;if((d&f|0)==0){g=e;break}g=e|2}else{e=(d&f|0)==0?8:25;if((d|f|0)!=0){g=e;break}g=e|2}}while(0);f=a+148|0;a=b[f>>1]&-28|g;b[f>>1]=c<<24>>24==0?a:a&-5;return}function lT(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=(d&65535)>>>15;d=(e&65535)>>>15;do{if(c<<16>>16>-1){e=(d|f|0)==0?0:17;if((d&f|0)==0){g=e;break}g=e|2}else{e=(d&f|0)==0?8:25;if((d|f|0)!=0){g=e;break}g=e|2}}while(0);f=a+148|0;a=b[f>>1]&-28|g;b[f>>1]=c<<16>>16==0?a:a&-5;return}function lU(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=d>>>31;d=e>>>31;do{if((c|0)>-1){e=(d|f|0)==0?0:17;if((d&f|0)==0){g=e;break}g=e|2}else{e=(d&f|0)==0?8:25;if((d|f|0)!=0){g=e;break}g=e|2}}while(0);f=a+148|0;a=b[f>>1]&-28|g;b[f>>1]=(c|0)==0?a:a&-5;return}function lV(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=d<<24>>24<0;d=e<<24>>24>-1;do{if(c<<24>>24>-1){e=f&d?17:0;if(f|d){g=e;break}g=e|2}else{e=f|d?25:8;if(!(f&d)){g=e;break}g=e|2}}while(0);d=a+148|0;a=b[d>>1]&-16|g&15;b[d>>1]=c<<24>>24==0?a|4:a;return}function lW(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=d<<16>>16<0;d=e<<16>>16>-1;do{if(c<<16>>16>-1){e=f&d?17:0;if(f|d){g=e;break}g=e|2}else{e=f|d?25:8;if(!(f&d)){g=e;break}g=e|2}}while(0);d=a+148|0;a=b[d>>1]&-16|g&15;b[d>>1]=c<<16>>16==0?a|4:a;return}function lX(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;i=i+8|0;d=b|0;if((lZ(a,d,485)|0)!=0){iA(a);e=a+268|0;c[e>>2]=(c[e>>2]|0)+2;f=0;i=b;return f|0}if((l_(a,-1)|0)==0){lO(a,15,c[d>>2]<<32-(c[a+240>>2]|0));f=c[a+192>>2]|0;i=b;return f|0}else{iA(a);d=a+268|0;c[d>>2]=(c[d>>2]|0)+2;f=0;i=b;return f|0}return 0}function lY(a){a=a|0;var b=0,d=0,f=0,g=0;b=i;i=i+8|0;d=b|0;if((lZ(a,d,2021)|0)!=0){iA(a);f=a+268|0;c[f>>2]=(c[f>>2]|0)+2;g=0;i=b;return g|0}f=c[a+80+(((e[a+198>>1]|0)>>>12&7)<<2)>>2]|0;c[d>>2]=f;if((l_(a,f)|0)==0){lO(a,15,f<<32-(c[a+240>>2]|0));g=c[a+192>>2]|0;i=b;return g|0}else{iA(a);f=a+268|0;c[f>>2]=(c[f>>2]|0)+2;g=0;i=b;return g|0}return 0}function lZ(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;h=(c[e+144>>2]|0)+2&16777215;i=h+1|0;j=e+36|0;if(i>>>0<(c[j>>2]|0)>>>0){k=c[e+32>>2]|0;l=(d[k+h|0]|0)<<8|(d[k+i|0]|0)}else{l=b6[c[e+12>>2]&63](c[e+4>>2]|0,h)|0}b[e+198>>1]=l;c[e+192>>2]=2;h=l&65535;i=h>>>6;if((h&2048|0)==0){m=i&31}else{m=c[e+80+((i&7)<<2)>>2]|0}if((l&32)==0){n=h}else{n=c[e+80+((h&7)<<2)>>2]|0}h=n&31;n=(h|0)==0?32:h;h=b[e+196>>1]&63;if((b5[c[20008+(h<<2)>>2]&127](e,h,g,8)|0)!=0){o=1;return o|0}g=e+236|0;c[g>>2]=m;h=e+240|0;c[h>>2]=n;l=c[e+228>>2]|0;do{if((l|0)==1){i=c[e+80+((c[e+232>>2]&7)<<2)>>2]|0;k=m+n&31;if((k|0)==0){p=i}else{p=i>>>((32-k|0)>>>0)|i<<k}c[f>>2]=p}else if((l|0)==2){k=c[e+232>>2]|0;i=m>>>3;c[f>>2]=0;q=c[h>>2]|0;if((q|0)==0){break}r=e+32|0;s=e+8|0;t=e+4|0;u=q;q=e+244|0;v=((m|0)<0?i|-536870912:i)+k|0;k=c[g>>2]|0;while(1){i=k&7;w=8-i|0;x=w>>>0>u>>>0?u:w;y=w-x|0;w=v&16777215;if(w>>>0<(c[j>>2]|0)>>>0){z=a[(c[r>>2]|0)+w|0]|0}else{z=b6[c[s>>2]&63](c[t>>2]|0,w)|0}a[q]=z;c[f>>2]=(255<<y&255>>>(i>>>0)&(z&255))>>>(y>>>0)|c[f>>2]<<x;if((u|0)==(x|0)){break}else{u=u-x|0;q=q+1|0;v=v+1|0;k=x+i|0}}}else{o=1;return o|0}}while(0);f=e+268|0;c[f>>2]=(c[f>>2]|0)+18;o=0;return o|0}function l_(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=c[b+228>>2]|0;if((f|0)==2){g=c[b+236>>2]|0;h=g>>>3;i=c[b+240>>2]|0;if((i|0)==0){j=0;return j|0}k=b+36|0;l=b+32|0;m=b+20|0;n=b+4|0;o=i;i=b+244|0;p=(c[b+232>>2]|0)+((g|0)<0?h|-536870912:h)|0;h=g;while(1){g=h&7;q=8-g|0;r=q>>>0>o>>>0?o:q;s=q-r|0;q=255<<s&255>>>(g>>>0);t=o-r|0;u=((q^255)&(d[i]|0)|e>>>((t-s|0)>>>0)&q)&255;q=p&16777215;if(q>>>0<(c[k>>2]|0)>>>0){a[(c[l>>2]|0)+q|0]=u}else{b3[c[m>>2]&63](c[n>>2]|0,q,u)}if((o|0)==(r|0)){j=0;break}else{o=t;i=i+1|0;p=p+1|0;h=r+g|0}}return j|0}else if((f|0)==1){f=b+80+((c[b+232>>2]&7)<<2)|0;h=32-(c[b+240>>2]|0)|0;p=-1>>>(h>>>0);i=h-(c[b+236>>2]|0)&31;if((i|0)==0){v=p;w=e}else{b=32-i|0;v=p>>>(b>>>0)|p<<i;w=e>>>(b>>>0)|e<<i}c[f>>2]=c[f>>2]&~v|v&w;j=0;return j|0}else{j=1;return j|0}return 0}function l$(a,f){a=a|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=a+196|0;h=e[g>>1]|0;i=(h&128|0)!=0?h|-256:h&255;do{if((i|0)==0){h=(c[a+144>>2]|0)+2&16777215;j=h+1|0;if(j>>>0<(c[a+36>>2]|0)>>>0){k=c[a+32>>2]|0;l=(d[k+h|0]|0)<<8|(d[k+j|0]|0)}else{l=b6[c[a+12>>2]&63](c[a+4>>2]|0,h)|0}b[a+198>>1]=l;c[a+192>>2]=2;h=l&65535;m=(h&32768|0)!=0?h|-65536:h}else{if((i&255|0)!=255){m=i;break}h=a+144|0;j=c[h>>2]|0;k=j+2&16777215;n=k+1|0;o=a+36|0;p=c[o>>2]|0;if(n>>>0<p>>>0){q=c[a+32>>2]|0;r=(d[q+k|0]|0)<<8|(d[q+n|0]|0);s=j;t=p}else{p=b6[c[a+12>>2]&63](c[a+4>>2]|0,k)|0;r=p;s=c[h>>2]|0;t=c[o>>2]|0}o=a+198|0;b[o>>1]=r;h=a+192|0;c[h>>2]=2;p=s+4&16777215;k=p+1|0;if(k>>>0<t>>>0){j=c[a+32>>2]|0;u=(d[j+p|0]|0)<<8|(d[j+k|0]|0);v=r}else{k=b6[c[a+12>>2]&63](c[a+4>>2]|0,p)|0;u=k;v=b[o>>1]|0}b[a+200>>1]=u;c[h>>2]=3;m=(v&65535)<<16|u&65535}}while(0);if((f|0)==0){f=a+268|0;c[f>>2]=((b[g>>1]&255)==0?12:8)+(c[f>>2]|0);w=c[a+192>>2]|0;return w|0}else{f=a+144|0;c[f>>2]=m+2+(c[f>>2]|0);f=a+268|0;c[f>>2]=(c[f>>2]|0)+10;w=0;return w|0}return 0}function l0(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=(d|0)<0;d=(e|0)>-1;do{if((c|0)>-1){e=f&d?17:0;if(f|d){g=e;break}g=e|2}else{e=f|d?25:8;if(!(f&d)){g=e;break}g=e|2}}while(0);d=a+148|0;a=b[d>>1]&-16|g&15;b[d>>1]=(c|0)==0?a|4:a;return}function l1(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=d<<24>>24<0;d=e<<24>>24>-1;do{if(c<<24>>24>-1){e=f&d?17:0;if(f|d){g=e;break}g=e|2}else{e=f|d?25:8;if(!(f&d)){g=e;break}g=e|2}}while(0);d=a+148|0;a=b[d>>1]&-32|g&31;b[d>>1]=c<<24>>24==0?a|4:a;return}function l2(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=d<<16>>16<0;d=e<<16>>16>-1;do{if(c<<16>>16>-1){e=f&d?17:0;if(f|d){g=e;break}g=e|2}else{e=f|d?25:8;if(!(f&d)){g=e;break}g=e|2}}while(0);d=a+148|0;a=b[d>>1]&-32|g&31;b[d>>1]=c<<16>>16==0?a|4:a;return}function l3(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=(d|0)<0;d=(e|0)>-1;do{if((c|0)>-1){e=f&d?17:0;if(f|d){g=e;break}g=e|2}else{e=f|d?25:8;if(!(f&d)){g=e;break}g=e|2}}while(0);d=a+148|0;a=b[d>>1]&-32|g&31;b[d>>1]=(c|0)==0?a|4:a;return}function l4(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=d<<24>>24<0;d=e<<24>>24>-1;do{if(c<<24>>24>-1){e=f&d?17:0;if(f|d){g=e;break}g=e|2}else{e=f|d?25:8;if(!(f&d)){g=e;break}g=e|2}}while(0);d=a+148|0;a=b[d>>1]&-28|g&27;b[d>>1]=c<<24>>24==0?a:a&-5;return}function l5(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=d<<16>>16<0;d=e<<16>>16>-1;do{if(c<<16>>16>-1){e=f&d?17:0;if(f|d){g=e;break}g=e|2}else{e=f|d?25:8;if(!(f&d)){g=e;break}g=e|2}}while(0);d=a+148|0;a=b[d>>1]&-28|g&27;b[d>>1]=c<<16>>16==0?a:a&-5;return}function l6(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=(d|0)<0;d=(e|0)>-1;do{if((c|0)>-1){e=f&d?17:0;if(f|d){g=e;break}g=e|2}else{e=f|d?25:8;if(!(f&d)){g=e;break}g=e|2}}while(0);d=a+148|0;a=b[d>>1]&-28|g&27;b[d>>1]=(c|0)==0?a:a&-5;return}function l7(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;if((d&1|0)==0){iA(a);f=1;return f|0}else{c[a+228>>2]=1;c[a+232>>2]=b&7;f=0;return f|0}return 0}function l8(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;if((d&2|0)==0){iA(a);f=1;return f|0}else{c[a+228>>2]=1;c[a+232>>2]=b&7|8;f=0;return f|0}return 0}function l9(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;if((d&4|0)==0){iA(a);f=1;return f|0}else{c[a+228>>2]=2;c[a+232>>2]=c[a+112+((b&7)<<2)>>2];f=0;return f|0}return 0}function ma(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;if((d&8|0)==0){iA(a);f=1;return f|0}else{c[a+228>>2]=2;d=a+112+((b&7)<<2)|0;b=c[d>>2]|0;c[a+232>>2]=b;c[d>>2]=b+(e>>>3);f=0;return f|0}return 0}function mb(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;if((d&8|0)==0){iA(a);f=1;return f|0}else{c[a+228>>2]=2;d=a+140|0;b=c[d>>2]|0;c[a+232>>2]=b;c[d>>2]=b+((e|0)==8?2:e>>>3);f=0;return f|0}return 0}function mc(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;if((d&16|0)==0){iA(a);f=1;return f|0}else{c[a+228>>2]=2;d=a+112+((b&7)<<2)|0;b=(c[d>>2]|0)-(e>>>3)|0;c[a+232>>2]=b;c[d>>2]=b;b=a+268|0;c[b>>2]=(c[b>>2]|0)+2;f=0;return f|0}return 0}function md(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;if((d&16|0)==0){iA(a);f=1;return f|0}else{c[a+228>>2]=2;d=a+140|0;b=(c[d>>2]|0)-((e|0)==8?2:e>>>3)|0;c[a+232>>2]=b;c[d>>2]=b;b=a+268|0;c[b>>2]=(c[b>>2]|0)+2;f=0;return f|0}return 0}function me(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;if((g&32|0)==0){iA(a);i=1;return i|0}c[a+228>>2]=2;g=a+192|0;h=c[g>>2]|0;j=(h<<1)+(c[a+144>>2]|0)&16777215;k=j+1|0;if(k>>>0<(c[a+36>>2]|0)>>>0){l=c[a+32>>2]|0;m=(d[l+j|0]|0)<<8|(d[l+k|0]|0);n=h}else{k=b6[c[a+12>>2]&63](c[a+4>>2]|0,j)|0;m=k;n=c[g>>2]|0}b[a+196+(n<<1)>>1]=m;c[g>>2]=(c[g>>2]|0)+1;g=e[a+196+(h<<1)>>1]|0;c[a+232>>2]=((g&32768|0)!=0?g|-65536:g)+(c[a+112+((f&7)<<2)>>2]|0);f=a+268|0;c[f>>2]=(c[f>>2]|0)+4;i=0;return i|0}function mf(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((f&64|0)==0){iA(a);h=1;return h|0}c[a+228>>2]=2;f=a+192|0;g=c[f>>2]|0;i=a+196+(g<<1)|0;j=(g<<1)+(c[a+144>>2]|0)&16777215;k=j+1|0;if(k>>>0<(c[a+36>>2]|0)>>>0){l=c[a+32>>2]|0;m=(d[l+j|0]|0)<<8|(d[l+k|0]|0);n=g}else{g=b6[c[a+12>>2]&63](c[a+4>>2]|0,j)|0;m=g;n=c[f>>2]|0}b[a+196+(n<<1)>>1]=m;c[f>>2]=(c[f>>2]|0)+1;f=c[a+112+((e&7)<<2)>>2]|0;e=a+232|0;c[e>>2]=f;m=b[i>>1]|0;do{if((c[a>>2]&4|0)==0){o=0}else{n=m&65535;if((n&256|0)==0){o=n>>>9&3;break}h=mx(a,i)|0;return h|0}}while(0);n=m&65535;m=((n&128|0)!=0?n|-256:n&255)+f|0;c[e>>2]=m;f=b[i>>1]|0;i=f&65535;n=i>>>12&7;if((i&32768|0)==0){p=a+80+(n<<2)|0}else{p=a+112+(n<<2)|0}n=c[p>>2]|0;if((f&2048)==0){q=(n&32768|0)!=0?n|-65536:n&65535}else{q=n}c[e>>2]=m+(q<<o);o=a+268|0;c[o>>2]=(c[o>>2]|0)+6;h=0;return h|0}function mg(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((g&128|0)==0){iA(a);i=1;return i|0}c[a+228>>2]=2;g=a+192|0;h=c[g>>2]|0;f=(h<<1)+(c[a+144>>2]|0)&16777215;j=f+1|0;if(j>>>0<(c[a+36>>2]|0)>>>0){k=c[a+32>>2]|0;l=(d[k+f|0]|0)<<8|(d[k+j|0]|0);m=h}else{j=b6[c[a+12>>2]&63](c[a+4>>2]|0,f)|0;l=j;m=c[g>>2]|0}b[a+196+(m<<1)>>1]=l;c[g>>2]=(c[g>>2]|0)+1;g=e[a+196+(h<<1)>>1]|0;c[a+232>>2]=(g&32768|0)!=0?g|-65536:g;g=a+268|0;c[g>>2]=(c[g>>2]|0)+4;i=0;return i|0}function mh(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((g&256|0)==0){iA(a);i=1;return i|0}c[a+228>>2]=2;g=a+192|0;h=c[g>>2]|0;f=a+144|0;j=(h<<1)+(c[f>>2]|0)&16777215;k=j+1|0;l=a+36|0;if(k>>>0<(c[l>>2]|0)>>>0){m=c[a+32>>2]|0;n=(d[m+j|0]|0)<<8|(d[m+k|0]|0);o=h}else{k=b6[c[a+12>>2]&63](c[a+4>>2]|0,j)|0;n=k;o=c[g>>2]|0}b[a+196+(o<<1)>>1]=n;n=(c[g>>2]|0)+1|0;c[g>>2]=n;o=(n<<1)+(c[f>>2]|0)&16777215;f=o+1|0;if(f>>>0<(c[l>>2]|0)>>>0){l=c[a+32>>2]|0;p=(d[l+o|0]|0)<<8|(d[l+f|0]|0);q=n}else{n=b6[c[a+12>>2]&63](c[a+4>>2]|0,o)|0;p=n;q=c[g>>2]|0}b[a+196+(q<<1)>>1]=p;c[g>>2]=(c[g>>2]|0)+1;c[a+232>>2]=(e[a+196+(h<<1)>>1]|0)<<16|(e[a+196+(h+1<<1)>>1]|0);h=a+268|0;c[h>>2]=(c[h>>2]|0)+8;i=0;return i|0}function mi(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;if((g&512|0)==0){iA(a);i=1;return i|0}c[a+228>>2]=2;g=a+192|0;h=c[g>>2]|0;f=(h<<1)+(c[a+144>>2]|0)|0;j=a+232|0;c[j>>2]=f;k=f&16777215;f=k+1|0;if(f>>>0<(c[a+36>>2]|0)>>>0){l=c[a+32>>2]|0;m=(d[l+k|0]|0)<<8|(d[l+f|0]|0);n=h}else{f=b6[c[a+12>>2]&63](c[a+4>>2]|0,k)|0;m=f;n=c[g>>2]|0}b[a+196+(n<<1)>>1]=m;c[g>>2]=(c[g>>2]|0)+1;g=e[a+196+(h<<1)>>1]|0;c[j>>2]=((g&32768|0)!=0?g|-65536:g)+(c[j>>2]|0);j=a+268|0;c[j>>2]=(c[j>>2]|0)+4;i=0;return i|0}function mj(a,e,f,g){a=a|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((f&1024|0)==0){iA(a);h=1;return h|0}c[a+228>>2]=2;f=a+192|0;g=c[f>>2]|0;e=(g<<1)+(c[a+144>>2]|0)|0;i=a+232|0;c[i>>2]=e;j=a+196+(g<<1)|0;k=e&16777215;e=k+1|0;if(e>>>0<(c[a+36>>2]|0)>>>0){l=c[a+32>>2]|0;m=(d[l+k|0]|0)<<8|(d[l+e|0]|0);n=g}else{g=b6[c[a+12>>2]&63](c[a+4>>2]|0,k)|0;m=g;n=c[f>>2]|0}b[a+196+(n<<1)>>1]=m;c[f>>2]=(c[f>>2]|0)+1;f=b[j>>1]|0;do{if((c[a>>2]&4|0)==0){o=0}else{m=f&65535;if((m&256|0)==0){o=m>>>9&3;break}h=mx(a,j)|0;return h|0}}while(0);m=f&65535;f=((m&128|0)!=0?m|-256:m&255)+(c[i>>2]|0)|0;c[i>>2]=f;m=b[j>>1]|0;j=m&65535;n=j>>>12&7;if((j&32768|0)==0){p=a+80+(n<<2)|0}else{p=a+112+(n<<2)|0}n=c[p>>2]|0;if((m&2048)==0){q=(n&32768|0)!=0?n|-65536:n&65535}else{q=n}c[i>>2]=f+(q<<o);o=a+268|0;c[o>>2]=(c[o>>2]|0)+6;h=0;return h|0}function mk(a,f,g,h){a=a|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;if((g&2048|0)==0){iA(a);i=1;return i|0}c[a+228>>2]=0;g=a+192|0;f=c[g>>2]|0;j=a+196+(f<<1)|0;if((h|0)==32){k=a+144|0;l=(c[k>>2]|0)+(f<<1)&16777215;m=l+1|0;n=a+36|0;if(m>>>0<(c[n>>2]|0)>>>0){o=c[a+32>>2]|0;p=(d[o+l|0]|0)<<8|(d[o+m|0]|0);q=f}else{m=b6[c[a+12>>2]&63](c[a+4>>2]|0,l)|0;p=m;q=c[g>>2]|0}b[a+196+(q<<1)>>1]=p;p=(c[g>>2]|0)+1|0;c[g>>2]=p;q=(p<<1)+(c[k>>2]|0)&16777215;k=q+1|0;if(k>>>0<(c[n>>2]|0)>>>0){n=c[a+32>>2]|0;r=(d[n+q|0]|0)<<8|(d[n+k|0]|0);s=p}else{p=b6[c[a+12>>2]&63](c[a+4>>2]|0,q)|0;r=p;s=c[g>>2]|0}b[a+196+(s<<1)>>1]=r;c[g>>2]=(c[g>>2]|0)+1;c[a+232>>2]=(e[j>>1]|0)<<16|(e[a+196+(f+1<<1)>>1]|0);r=a+268|0;c[r>>2]=(c[r>>2]|0)+8;i=0;return i|0}else{r=(c[a+144>>2]|0)+(f<<1)&16777215;s=r+1|0;if(s>>>0<(c[a+36>>2]|0)>>>0){p=c[a+32>>2]|0;t=(d[p+r|0]|0)<<8|(d[p+s|0]|0);u=f}else{f=b6[c[a+12>>2]&63](c[a+4>>2]|0,r)|0;t=f;u=c[g>>2]|0}b[a+196+(u<<1)>>1]=t;c[g>>2]=(c[g>>2]|0)+1;g=e[j>>1]|0;if((h|0)==16){c[a+232>>2]=g;h=a+268|0;c[h>>2]=(c[h>>2]|0)+4;i=0;return i|0}else{c[a+232>>2]=g&255;g=a+268|0;c[g>>2]=(c[g>>2]|0)+4;i=0;return i|0}}return 0}function ml(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;iA(a);return 1}function mm(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=c[b+228>>2]|0;if((e|0)==2){f=c[b+232>>2]&16777215;if(f>>>0<(c[b+36>>2]|0)>>>0){g=a[(c[b+32>>2]|0)+f|0]|0}else{g=b6[c[b+8>>2]&63](c[b+4>>2]|0,f)|0}a[d]=g;g=b+268|0;c[g>>2]=(c[g>>2]|0)+4;h=0;return h|0}else if((e|0)==1){g=c[b+232>>2]|0;if(g>>>0<8){a[d]=c[b+80+((g&7)<<2)>>2]&255;h=0;return h|0}else{iA(b);h=1;return h|0}}else if((e|0)==0){a[d]=c[b+232>>2]&255;h=0;return h|0}else{iA(b);h=1;return h|0}return 0}function mn(a,e){a=a|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c[a+228>>2]|0;if((f|0)==2){g=c[a+232>>2]|0;do{if((g&1|0)!=0){if((c[a>>2]&1|0)!=0){break}iw(a,g,1,0);h=1;return h|0}}while(0);i=g&16777215;g=i+1|0;if(g>>>0<(c[a+36>>2]|0)>>>0){j=c[a+32>>2]|0;k=(d[j+i|0]|0)<<8|(d[j+g|0]|0)}else{k=b6[c[a+12>>2]&63](c[a+4>>2]|0,i)|0}b[e>>1]=k;k=a+268|0;c[k>>2]=(c[k>>2]|0)+4;h=0;return h|0}else if((f|0)==0){b[e>>1]=c[a+232>>2]&65535;h=0;return h|0}else if((f|0)==1){f=c[a+232>>2]|0;do{if(f>>>0<8){l=a+80+((f&7)<<2)|0}else{if(f>>>0<16){l=a+112+((f&7)<<2)|0;break}iA(a);h=1;return h|0}}while(0);b[e>>1]=c[l>>2]&65535;h=0;return h|0}else{iA(a);h=1;return h|0}return 0}function mo(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c[a+228>>2]|0;if((e|0)==1){f=c[a+232>>2]|0;do{if(f>>>0<8){g=a+80+((f&7)<<2)|0}else{if(f>>>0<16){g=a+112+((f&7)<<2)|0;break}iA(a);h=1;return h|0}}while(0);c[b>>2]=c[g>>2];h=0;return h|0}else if((e|0)==2){g=c[a+232>>2]|0;do{if((g&1|0)!=0){if((c[a>>2]&1|0)!=0){break}iw(a,g,1,0);h=1;return h|0}}while(0);f=g&16777215;g=f+3|0;if(g>>>0<(c[a+36>>2]|0)>>>0){i=c[a+32>>2]|0;j=(((d[i+f|0]|0)<<8|(d[i+(f+1)|0]|0))<<8|(d[i+(f+2)|0]|0))<<8|(d[i+g|0]|0)}else{j=b6[c[a+16>>2]&63](c[a+4>>2]|0,f)|0}c[b>>2]=j;j=a+268|0;c[j>>2]=(c[j>>2]|0)+8;h=0;return h|0}else if((e|0)==0){c[b>>2]=c[a+232>>2];h=0;return h|0}else{iA(a);h=1;return h|0}return 0}function mp(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=c[b+228>>2]|0;if((e|0)==0){iA(b);f=1;return f|0}else if((e|0)==1){g=c[b+232>>2]|0;if(g>>>0<8){h=b+80+((g&7)<<2)|0;c[h>>2]=c[h>>2]&-256|d&255;f=0;return f|0}else{iA(b);f=1;return f|0}}else if((e|0)==2){e=c[b+232>>2]&16777215;if(e>>>0<(c[b+36>>2]|0)>>>0){a[(c[b+32>>2]|0)+e|0]=d}else{b3[c[b+20>>2]&63](c[b+4>>2]|0,e,d)}d=b+268|0;c[d>>2]=(c[d>>2]|0)+4;f=0;return f|0}else{iA(b);f=1;return f|0}return 0}function mq(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=c[b+228>>2]|0;if((e|0)==1){f=c[b+232>>2]|0;if(f>>>0<8){g=b+80+((f&7)<<2)|0;c[g>>2]=c[g>>2]&-65536|d&65535;h=0;return h|0}if(f>>>0<16){g=d&65535;c[b+112+((f&7)<<2)>>2]=(g&32768|0)==0?g:g|-65536;h=0;return h|0}else{iA(b);h=1;return h|0}}else if((e|0)==2){g=c[b+232>>2]|0;do{if((g&1|0)!=0){if((c[b>>2]&1|0)!=0){break}iw(b,g,1,1);h=1;return h|0}}while(0);f=g&16777215;g=f+1|0;if(g>>>0<(c[b+36>>2]|0)>>>0){i=b+32|0;a[(c[i>>2]|0)+f|0]=(d&65535)>>>8&255;a[(c[i>>2]|0)+g|0]=d&255}else{b3[c[b+24>>2]&63](c[b+4>>2]|0,f,d)}d=b+268|0;c[d>>2]=(c[d>>2]|0)+4;h=0;return h|0}else if((e|0)==0){iA(b);h=1;return h|0}else{iA(b);h=1;return h|0}return 0}function mr(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=c[b+228>>2]|0;if((e|0)==0){iA(b);f=1;return f|0}else if((e|0)==1){g=c[b+232>>2]|0;if(g>>>0<8){c[b+80+((g&7)<<2)>>2]=d;f=0;return f|0}if(g>>>0<16){c[b+112+((g&7)<<2)>>2]=d;f=0;return f|0}else{iA(b);f=1;return f|0}}else if((e|0)==2){e=c[b+232>>2]|0;do{if((e&1|0)!=0){if((c[b>>2]&1|0)!=0){break}iw(b,e,1,1);f=1;return f|0}}while(0);g=e&16777215;e=g+3|0;if(e>>>0<(c[b+36>>2]|0)>>>0){h=b+32|0;a[(c[h>>2]|0)+g|0]=d>>>24&255;a[(c[h>>2]|0)+(g+1)|0]=d>>>16&255;a[(c[h>>2]|0)+(g+2)|0]=d>>>8&255;a[(c[h>>2]|0)+e|0]=d&255}else{b3[c[b+28>>2]&63](c[b+4>>2]|0,g,d)}d=b+268|0;c[d>>2]=(c[d>>2]|0)+8;f=0;return f|0}else{iA(b);f=1;return f|0}return 0}function ms(a,b,d){a=a|0;b=b|0;d=d|0;c[a+36>>2]=b;c[a+40>>2]=d;return}function mt(a,b,d){a=a|0;b=b|0;d=d|0;c[a+48>>2]=b;c[a+52>>2]=d;return}function mu(a,b,d){a=a|0;b=b|0;d=d|0;c[a+60>>2]=b;c[a+64>>2]=d;return}function mv(a,b,d){a=a|0;b=b|0;d=d|0;c[a+72>>2]=b;c[a+76>>2]=d;return}function mw(a,b,d){a=a|0;b=b|0;d=d|0;c[a+80>>2]=b;c[a+84>>2]=d;return}function mx(a,f){a=a|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=b[f>>1]|0;h=g&65535;i=(h&64|0)!=0;if((h&128|0)==0){j=g}else{c[a+232>>2]=0;j=b[f>>1]|0}g=j&65535;h=g>>>9&3;do{if(i){k=0}else{l=g>>>12&7;if((g&32768|0)==0){m=a+80+(l<<2)|0}else{m=a+112+(l<<2)|0}l=c[m>>2]|0;if((j&2048)!=0){k=l;break}k=(l&32768|0)!=0?l|-65536:l&65535}}while(0);j=g>>>4&3;if((j|0)==2){g=a+192|0;m=c[g>>2]|0;l=(m<<1)+(c[a+144>>2]|0)&16777215;n=l+1|0;if(n>>>0<(c[a+36>>2]|0)>>>0){o=c[a+32>>2]|0;p=(d[o+l|0]|0)<<8|(d[o+n|0]|0);q=m}else{m=b6[c[a+12>>2]&63](c[a+4>>2]|0,l)|0;p=m;q=c[g>>2]|0}b[a+196+(q<<1)>>1]=p;c[g>>2]=(c[g>>2]|0)+1;g=e[f+2>>1]|0;r=(g&32768|0)!=0?g|-65536:g}else if((j|0)==3){g=a+144|0;p=a+192|0;q=c[p>>2]|0;m=(q<<1)+(c[g>>2]|0)&16777215;l=m+1|0;n=a+36|0;if(l>>>0<(c[n>>2]|0)>>>0){o=c[a+32>>2]|0;s=(d[o+m|0]|0)<<8|(d[o+l|0]|0);t=q}else{q=b6[c[a+12>>2]&63](c[a+4>>2]|0,m)|0;s=q;t=c[p>>2]|0}b[a+196+(t<<1)>>1]=s;s=(c[p>>2]|0)+1|0;c[p>>2]=s;t=(s<<1)+(c[g>>2]|0)&16777215;g=t+1|0;if(g>>>0<(c[n>>2]|0)>>>0){n=c[a+32>>2]|0;u=(d[n+t|0]|0)<<8|(d[n+g|0]|0);v=s}else{s=b6[c[a+12>>2]&63](c[a+4>>2]|0,t)|0;u=s;v=c[p>>2]|0}b[a+196+(v<<1)>>1]=u;c[p>>2]=(c[p>>2]|0)+1;r=(e[f+2>>1]|0)<<16|(e[f+4>>1]|0)}else if((j|0)==0){iA(a);w=1;return w|0}else{r=0}j=e[f>>1]|0;if((j&7|0)==0){p=a+232|0;c[p>>2]=r+(k<<h)+(c[p>>2]|0);w=0;return w|0}p=a+192|0;u=c[p>>2]|0;v=a+196+(u<<1)|0;s=j&3;if((s|0)==3){j=a+144|0;t=(c[j>>2]|0)+(u<<1)&16777215;g=t+1|0;n=a+36|0;if(g>>>0<(c[n>>2]|0)>>>0){q=c[a+32>>2]|0;x=(d[q+t|0]|0)<<8|(d[q+g|0]|0);y=u}else{g=b6[c[a+12>>2]&63](c[a+4>>2]|0,t)|0;x=g;y=c[p>>2]|0}b[a+196+(y<<1)>>1]=x;x=(c[p>>2]|0)+1|0;c[p>>2]=x;y=(x<<1)+(c[j>>2]|0)&16777215;j=y+1|0;if(j>>>0<(c[n>>2]|0)>>>0){n=c[a+32>>2]|0;z=(d[n+y|0]|0)<<8|(d[n+j|0]|0);A=x}else{x=b6[c[a+12>>2]&63](c[a+4>>2]|0,y)|0;z=x;A=c[p>>2]|0}b[a+196+(A<<1)>>1]=z;c[p>>2]=(c[p>>2]|0)+1;B=(e[v>>1]|0)<<16|(e[a+196+(u+1<<1)>>1]|0)}else if((s|0)==0){iA(a);w=1;return w|0}else if((s|0)==2){s=(c[a+144>>2]|0)+(u<<1)&16777215;z=s+1|0;if(z>>>0<(c[a+36>>2]|0)>>>0){A=c[a+32>>2]|0;C=(d[A+s|0]|0)<<8|(d[A+z|0]|0);D=u}else{u=b6[c[a+12>>2]&63](c[a+4>>2]|0,s)|0;C=u;D=c[p>>2]|0}b[a+196+(D<<1)>>1]=C;c[p>>2]=(c[p>>2]|0)+1;p=e[v>>1]|0;B=(p&32768|0)!=0?p|-65536:p}else{B=0}if((b[f>>1]&4)==0){f=a+232|0;p=r+(k<<h)+(c[f>>2]|0)&16777215;v=p+3|0;if(v>>>0<(c[a+36>>2]|0)>>>0){C=c[a+32>>2]|0;E=(((d[C+p|0]|0)<<8|(d[C+(p+1)|0]|0))<<8|(d[C+(p+2)|0]|0))<<8|(d[C+v|0]|0)}else{E=b6[c[a+16>>2]&63](c[a+4>>2]|0,p)|0}c[f>>2]=E+B;w=0;return w|0}if(i){iA(a);w=1;return w|0}i=a+232|0;E=(c[i>>2]|0)+r&16777215;r=E+3|0;if(r>>>0<(c[a+36>>2]|0)>>>0){f=c[a+32>>2]|0;F=(((d[f+E|0]|0)<<8|(d[f+(E+1)|0]|0))<<8|(d[f+(E+2)|0]|0))<<8|(d[f+r|0]|0)}else{F=b6[c[a+16>>2]&63](c[a+4>>2]|0,E)|0}c[i>>2]=B+(k<<h)+F;w=0;return w|0}function my(b,d){b=b|0;d=d|0;c[b>>2]=d;c[b+48>>2]=0;c[b+52>>2]=0;a[b+56|0]=0;c[b+60>>2]=0;c[b+64>>2]=0;a[b+68|0]=0;u6(b+4|0,0,41);u6(b+72|0,0,17);return}function mz(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0;if((a[b+12|0]&28)!=28){e=0;return e|0}f=b+10|0;g=d[f]|0;h=g>>>7;i=h&255;a[f]=(g<<1|h)&255;h=b+11|0;g=(a[h]|0)+1&7;a[h]=g;if(g<<24>>24!=0){e=i;return e|0}g=b+14|0;h=a[g]|0;f=h&123|4;j=(f&a[b+15|0])<<24>>24==0?f:h|-124;a[g]=j;g=(j&255)>>>7;j=b+88|0;if((a[j]|0)==g<<24>>24){e=i;return e|0}a[j]=g;j=c[b+84>>2]|0;if((j|0)==0){e=i;return e|0}b1[j&511](c[b+80>>2]|0,g);e=i;return e|0}function mA(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a[b+12|0]&28)!=12){return}e=b+10|0;a[e]=a[e]<<1|d<<24>>24!=0;d=b+11|0;e=(a[d]|0)+1&7;a[d]=e;d=b+14|0;do{if(e<<24>>24==0){f=a[d]|0;g=f&123|4;h=b+15|0;i=(g&a[h])<<24>>24==0?g:f|-124;a[d]=i;f=(i&255)>>>7;i=b+88|0;if((a[i]|0)==f<<24>>24){j=h;k=i;break}a[i]=f;g=c[b+84>>2]|0;if((g|0)==0){j=h;k=i;break}b1[g&511](c[b+80>>2]|0,f);j=h;k=i}else{j=b+15|0;k=b+88|0}}while(0);e=a[d]|0;i=e&111|16;h=(i&a[j])<<24>>24==0?i:e|-112;a[d]=h;d=(h&255)>>>7;if((a[k]|0)==d<<24>>24){return}a[k]=d;k=c[b+84>>2]|0;if((k|0)==0){return}b1[k&511](c[b+80>>2]|0,d);return}function mB(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=b+32|0;f=(a[e]|0)!=0;g=d<<24>>24!=0;a[e]=g&1;if(!(f^g)){return}if((g&1|0)!=(a[b+13|0]&1|0)){return}g=b+14|0;f=a[g]|0;e=f&125|2;d=(e&a[b+15|0])<<24>>24==0?e:f|-126;a[g]=d;g=(d&255)>>>7;d=b+88|0;if((a[d]|0)==g<<24>>24){return}a[d]=g;d=c[b+84>>2]|0;if((d|0)==0){return}b1[d&511](c[b+80>>2]|0,g);return}function mC(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=b+33|0;g=a[f]|0;h=e<<24>>24!=0;a[f]=h&1;f=d[b+13|0]|0;if((f&8|0)!=0){return}if(!(g<<24>>24!=0^h)){return}if(h^(f&4|0)!=0){return}f=b+14|0;h=a[f]|0;g=h&126|1;e=(g&a[b+15|0])<<24>>24==0?g:h|-127;a[f]=e;f=(e&255)>>>7;e=b+88|0;if((a[e]|0)==f<<24>>24){return}a[e]=f;e=c[b+84>>2]|0;if((e|0)==0){return}b1[e&511](c[b+80>>2]|0,f);return}function mD(b,d){b=b|0;d=d|0;var e=0,f=0;a[b+6|0]=d;e=a[b+8|0]|0;f=c[b+40>>2]|0;if((f|0)==0){return}b1[f&511](c[b+36>>2]|0,a[b+4|0]&e|~e&d);return}function mE(b,d){b=b|0;d=d|0;var e=0,f=0;a[b+7|0]=d;e=a[b+9|0]|0;f=c[b+52>>2]|0;if((f|0)==0){return}b1[f&511](c[b+48>>2]|0,a[b+5|0]&e|~e&d);return}function mF(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;if((a[b+12|0]&28)!=12){return}a[b+10|0]=d;a[b+11|0]=0;d=b+14|0;e=a[d]|0;f=e&123|4;g=(f&a[b+15|0])<<24>>24==0?f:e|-124;a[d]=g;d=(g&255)>>>7;g=b+88|0;if((a[g]|0)==d<<24>>24){return}a[g]=d;g=c[b+84>>2]|0;if((g|0)==0){return}b1[g&511](c[b+80>>2]|0,d);return}function mG(d,f){d=d|0;f=f|0;var g=0,h=0,i=0,j=0;g=f>>>((c[d>>2]|0)>>>0);if((g|0)==11){h=a[d+12|0]|0;return h|0}else if((g|0)==12){h=a[d+13|0]|0;return h|0}else if((g|0)==13){h=a[d+14|0]|0;return h|0}else if((g|0)==14){h=a[d+15|0]|-128;return h|0}else if((g|0)==4){f=d+14|0;i=a[f]&63;j=(a[d+15|0]&i)<<24>>24==0?i:i|-128;a[f]=j;f=(j&255)>>>7;j=d+88|0;do{if((a[j]|0)!=f<<24>>24){a[j]=f;i=c[d+84>>2]|0;if((i|0)==0){break}b1[i&511](c[d+80>>2]|0,f)}}while(0);h=b[d+18>>1]&255;return h|0}else if((g|0)==5){h=(e[d+18>>1]|0)>>>8&255;return h|0}else if((g|0)==3){h=a[d+8|0]|0;return h|0}else if((g|0)==10){f=d+14|0;j=a[f]&123;i=(a[d+15|0]&j)<<24>>24==0?j:j|-128;a[f]=i;f=(i&255)>>>7;i=d+88|0;do{if((a[i]|0)!=f<<24>>24){a[i]=f;j=c[d+84>>2]|0;if((j|0)==0){break}b1[j&511](c[d+80>>2]|0,f)}}while(0);a[d+11|0]=0;h=a[d+10|0]|0;return h|0}else if((g|0)==6){h=b[d+16>>1]&255;return h|0}else if((g|0)==7){h=(e[d+16>>1]|0)>>>8&255;return h|0}else if((g|0)==15){f=a[d+8|0]|0;h=a[d+6|0]&~f|f&a[d+4|0];return h|0}else if((g|0)==1){f=d+14|0;i=a[f]&124;j=(a[d+15|0]&i)<<24>>24==0?i:i|-128;a[f]=j;f=(j&255)>>>7;j=d+88|0;do{if((a[j]|0)!=f<<24>>24){a[j]=f;i=c[d+84>>2]|0;if((i|0)==0){break}b1[i&511](c[d+80>>2]|0,f)}}while(0);f=a[d+8|0]|0;h=a[d+6|0]&~f|f&a[d+4|0];return h|0}else if((g|0)==9){h=(e[d+26>>1]|0)>>>8&255;return h|0}else if((g|0)==2){h=a[d+9|0]|0;return h|0}else if((g|0)==0){f=d+14|0;j=a[f]&103;i=(a[d+15|0]&j)<<24>>24==0?j:j|-128;a[f]=i;f=(i&255)>>>7;i=d+88|0;do{if((a[i]|0)!=f<<24>>24){a[i]=f;j=c[d+84>>2]|0;if((j|0)==0){break}b1[j&511](c[d+80>>2]|0,f)}}while(0);f=a[d+9|0]|0;h=a[d+7|0]&~f|f&a[d+5|0];return h|0}else if((g|0)==8){g=d+14|0;f=a[g]&95;i=(a[d+15|0]&f)<<24>>24==0?f:f|-128;a[g]=i;g=(i&255)>>>7;i=d+88|0;do{if((a[i]|0)!=g<<24>>24){a[i]=g;f=c[d+84>>2]|0;if((f|0)==0){break}b1[f&511](c[d+80>>2]|0,g)}}while(0);h=b[d+26>>1]&255;return h|0}else{h=-86;return h|0}return 0}function mH(a,b){a=a|0;b=b|0;return(mG(a,b)|0)&255|0}function mI(a,b){a=a|0;b=b|0;return(mG(a,b)|0)&255|0}function mJ(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=f>>>((c[e>>2]|0)>>>0);if((h|0)==14){f=g&127;if(g<<24>>24>-1){i=e+15|0;j=a[i]&(f^127);a[i]=j;k=j}else{j=e+15|0;i=a[j]|f;a[j]=i;k=i}i=e+14|0;j=a[i]|0;f=j&127;l=(f&k)<<24>>24==0?f:j|-128;a[i]=l;i=(l&255)>>>7;l=e+88|0;if((a[l]|0)==i<<24>>24){return}a[l]=i;l=c[e+84>>2]|0;if((l|0)==0){return}b1[l&511](c[e+80>>2]|0,i);return}else if((h|0)==12){a[e+13|0]=g;i=d[e+12|0]|0;do{if((i&28|0)==0){m=(g&-32)<<24>>24!=-64|0}else{if((i&16|0)==0){m=1;break}m=a[e+10|0]&1}}while(0);i=e+68|0;if(m<<24>>24==(a[i]|0)){return}a[i]=m;i=c[e+64>>2]|0;if((i|0)==0){return}b1[i&511](c[e+60>>2]|0,m);return}else if((h|0)==5){m=e+16|0;i=b[m>>1]&255|(g&255)<<8;b[m>>1]=i;b[e+18>>1]=i;if((a[e+12|0]&64)==0){c[e+20>>2]=1}i=e+14|0;m=a[i]&63;l=(a[e+15|0]&m)<<24>>24==0?m:m|-128;a[i]=l;i=(l&255)>>>7;l=e+88|0;if((a[l]|0)==i<<24>>24){return}a[l]=i;l=c[e+84>>2]|0;if((l|0)==0){return}b1[l&511](c[e+80>>2]|0,i);return}else if((h|0)==0){a[e+5|0]=g;i=a[e+9|0]|0;l=c[e+52>>2]|0;if((l|0)!=0){b1[l&511](c[e+48>>2]|0,a[e+7|0]&~i|i&g)}i=e+14|0;l=a[i]&103;m=(a[e+15|0]&l)<<24>>24==0?l:l|-128;a[i]=m;i=(m&255)>>>7;m=e+88|0;if((a[m]|0)==i<<24>>24){return}a[m]=i;m=c[e+84>>2]|0;if((m|0)==0){return}b1[m&511](c[e+80>>2]|0,i);return}else if((h|0)==10){i=e+14|0;m=a[i]&123;l=e+15|0;j=(a[l]&m)<<24>>24==0?m:m|-128;a[i]=j;m=(j&255)>>>7;j=e+88|0;do{if((a[j]|0)!=m<<24>>24){a[j]=m;f=c[e+84>>2]|0;if((f|0)==0){break}b1[f&511](c[e+80>>2]|0,m)}}while(0);a[e+10|0]=g;a[e+11|0]=0;if((a[e+12|0]&28)!=28){return}m=c[e+76>>2]|0;if((m|0)==0){return}b1[m&511](c[e+72>>2]|0,g);m=a[i]|0;f=m&123|4;k=(f&a[l])<<24>>24==0?f:m|-124;a[i]=k;i=(k&255)>>>7;if((a[j]|0)==i<<24>>24){return}a[j]=i;j=c[e+84>>2]|0;if((j|0)==0){return}b1[j&511](c[e+80>>2]|0,i);return}else if((h|0)==3){a[e+8|0]=g;i=c[e+40>>2]|0;if((i|0)==0){return}b1[i&511](c[e+36>>2]|0,a[e+6|0]&~g|a[e+4|0]&g);return}else if((h|0)==4){i=e+16|0;b[i>>1]=b[i>>1]&-256|g&255;return}else if((h|0)==6){i=e+16|0;b[i>>1]=b[i>>1]&-256|g&255;return}else if((h|0)==7){i=e+16|0;b[i>>1]=b[i>>1]&255|(g&255)<<8;return}else if((h|0)==13){i=e+14|0;j=a[i]&(g^127);k=j&127;m=(k&a[e+15|0])<<24>>24==0?k:j|-128;a[i]=m;i=(m&255)>>>7;m=e+88|0;if((a[m]|0)==i<<24>>24){return}a[m]=i;m=c[e+84>>2]|0;if((m|0)==0){return}b1[m&511](c[e+80>>2]|0,i);return}else if((h|0)==9){i=e+24|0;m=b[i>>1]&255|(g&255)<<8;b[i>>1]=m;b[e+26>>1]=m;if((a[e+12|0]&32)==0){c[e+28>>2]=1}m=e+14|0;i=a[m]&95;j=(a[e+15|0]&i)<<24>>24==0?i:i|-128;a[m]=j;m=(j&255)>>>7;j=e+88|0;if((a[j]|0)==m<<24>>24){return}a[j]=m;j=c[e+84>>2]|0;if((j|0)==0){return}b1[j&511](c[e+80>>2]|0,m);return}else if((h|0)==11){a[e+12|0]=g;if((g&28)==0){a[e+11|0]=0}m=g&255;do{if((m&28|0)==0){n=(a[e+13|0]&-32)<<24>>24!=-64|0}else{if((m&16|0)==0){n=1;break}n=a[e+10|0]&1}}while(0);m=e+68|0;if(n<<24>>24==(a[m]|0)){return}a[m]=n;m=c[e+64>>2]|0;if((m|0)==0){return}b1[m&511](c[e+60>>2]|0,n);return}else if((h|0)==2){a[e+9|0]=g;n=c[e+52>>2]|0;if((n|0)==0){return}b1[n&511](c[e+48>>2]|0,a[e+7|0]&~g|a[e+5|0]&g);return}else if((h|0)==1){a[e+4|0]=g;n=a[e+8|0]|0;m=c[e+40>>2]|0;if((m|0)!=0){b1[m&511](c[e+36>>2]|0,a[e+6|0]&~n|n&g)}n=e+14|0;m=a[n]&124;j=(a[e+15|0]&m)<<24>>24==0?m:m|-128;a[n]=j;n=(j&255)>>>7;j=e+88|0;if((a[j]|0)==n<<24>>24){return}a[j]=n;j=c[e+84>>2]|0;if((j|0)==0){return}b1[j&511](c[e+80>>2]|0,n);return}else if((h|0)==8){n=e+24|0;b[n>>1]=b[n>>1]&-256|g&255;return}else if((h|0)==15){a[e+4|0]=g;h=a[e+8|0]|0;n=c[e+40>>2]|0;if((n|0)!=0){b1[n&511](c[e+36>>2]|0,a[e+6|0]&~h|h&g)}g=e+14|0;h=a[g]&124;n=(a[e+15|0]&h)<<24>>24==0?h:h|-128;a[g]=n;g=(n&255)>>>7;n=e+88|0;if((a[n]|0)==g<<24>>24){return}a[n]=g;n=c[e+84>>2]|0;if((n|0)==0){return}b1[n&511](c[e+80>>2]|0,g);return}else{return}}function mK(a,b,c){a=a|0;b=b|0;c=c|0;mJ(a,b,c&255);return}function mL(a,b,c){a=a|0;b=b|0;c=c|0;mJ(a,b,c&255);return}function mM(a,b,d){a=a|0;b=b|0;d=d|0;c[a+1288>>2]=b;c[a+1292>>2]=d;return}function mN(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;if(b>>>0>=2){return}c[a+4+(b*640|0)+608>>2]=d;c[a+4+(b*640|0)+612>>2]=e;return}function mO(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;if(b>>>0>=2){return}c[a+4+(b*640|0)+616>>2]=d;c[a+4+(b*640|0)+620>>2]=e;return}function mP(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;if(b>>>0>=2){return}c[a+4+(b*640|0)+624>>2]=d;c[a+4+(b*640|0)+628>>2]=e;return}function mQ(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;if(b>>>0>=2){return}c[a+4+(b*640|0)+632>>2]=d;c[a+4+(b*640|0)+636>>2]=e;return}function mR(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;if(b>>>0>1){return}c[a+4+(b*640|0)+60>>2]=0;c[a+4+(b*640|0)+64>>2]=(d|0)==0?1:d;c[a+4+(b*640|0)+68>>2]=0;c[a+4+(b*640|0)+72>>2]=(e|0)==0?1:e;return}function mS(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[a+1284>>2]=b;c[a+80>>2]=d;c[a+720>>2]=e;return}function mT(b){b=b|0;var d=0,e=0,f=0,g=0;a[b+4|0]=0;d=b+5|0;a[d]=0;e=b+14|0;u6(b+8|0,0,24);f=c[b+40>>2]|0;if((f|0)==0){g=0}else{b1[f&511](c[b+36>>2]|0,a[b+6|0]|0);g=a[b+9|0]|0}f=c[b+52>>2]|0;if((f|0)!=0){b1[f&511](c[b+48>>2]|0,a[b+7|0]&~g|a[d]&g)}g=a[e]|0;d=g&127;f=(a[b+15|0]&d)<<24>>24==0?d:g|-128;a[e]=f;e=(f&255)>>>7;f=b+88|0;if((a[f]|0)==e<<24>>24){return}a[f]=e;f=c[b+84>>2]|0;if((f|0)==0){return}b1[f&511](c[b+80>>2]|0,e);return}function mU(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=d+18|0;g=b[f>>1]|0;h=g&65535;do{if(h>>>0>e>>>0|g<<16>>16==0){b[f>>1]=h-e&65535}else{if((a[d+12|0]&64)==0){b[f>>1]=h-e&65535;i=d+20|0;if((c[i>>2]|0)==0){break}c[i>>2]=0;i=d+14|0;j=a[i]|0;k=j&63|64;l=(k&a[d+15|0])<<24>>24==0?k:j|-64;a[i]=l;i=(l&255)>>>7;l=d+88|0;if((a[l]|0)==i<<24>>24){break}a[l]=i;l=c[d+84>>2]|0;if((l|0)==0){break}b1[l&511](c[d+80>>2]|0,i);break}i=e-h|0;l=d+14|0;j=a[l]|0;k=j&63|64;m=(k&a[d+15|0])<<24>>24==0?k:j|-64;a[l]=m;l=(m&255)>>>7;m=d+88|0;do{if((a[m]|0)!=l<<24>>24){a[m]=l;j=c[d+84>>2]|0;if((j|0)==0){break}b1[j&511](c[d+80>>2]|0,l)}}while(0);l=b[d+16>>1]|0;if(l<<16>>16==0){n=i&65535;o=0}else{m=l&65535;n=(i>>>0)%(m>>>0)|0;o=m}b[f>>1]=o-n&65535}}while(0);n=d+26|0;o=b[n>>1]|0;f=o&65535;if(f>>>0>e>>>0|o<<16>>16==0){b[n>>1]=f-e&65535;return}if((a[d+12|0]&32)!=0){return}b[n>>1]=f-e&65535;e=d+28|0;if((c[e>>2]|0)==0){return}c[e>>2]=0;e=d+14|0;f=a[e]|0;n=f&95|32;o=(n&a[d+15|0])<<24>>24==0?n:f|-96;a[e]=o;e=(o&255)>>>7;o=d+88|0;if((a[o]|0)==e<<24>>24){return}a[o]=e;o=c[d+84>>2]|0;if((o|0)==0){return}b1[o&511](c[d+80>>2]|0,e);return}function mV(b){b=b|0;c[b>>2]=0;c[b+1284>>2]=0;a[b+38|0]=1;a[b+39|0]=1;c[b+56>>2]=0;c[b+60>>2]=16384;c[b+64>>2]=0;c[b+68>>2]=1;c[b+72>>2]=0;c[b+76>>2]=1;c[b+80>>2]=0;c[b+84>>2]=0;c[b+88>>2]=0;c[b+348>>2]=0;c[b+352>>2]=0;u6(b+612|0,0,32);a[b+678|0]=1;a[b+679|0]=1;c[b+696>>2]=0;c[b+700>>2]=16384;c[b+704>>2]=0;c[b+708>>2]=1;c[b+712>>2]=0;c[b+716>>2]=1;c[b+720>>2]=0;c[b+724>>2]=0;c[b+728>>2]=0;c[b+988>>2]=0;c[b+992>>2]=0;u6(b+1252|0,0,32);c[b+1288>>2]=0;c[b+1292>>2]=0;a[b+1296|0]=0;return}function mW(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=d&1;do{if((e|0)==13){a[b+4+(g*640|0)+13|0]=f;nf(b,g)}else if((e|0)==14){a[b+4+(g*640|0)+14|0]=f;nf(b,g)}else if((e|0)==8){d=b+4+(g*640|0)+8|0;a[d]=f;h=b+4+(g*640|0)+16|0;a[h]=a[h]&-5;i=b+4+(g*640|0)+34|0;a[i]=0;j=b+23|0;k=a[j]&((g|0)==0?-17:-3);a[j]=k;do{if((a[b+13|0]&8)==0){j=b+1296|0;if((a[j]|0)==0){break}a[j]=0;j=c[b+1292>>2]|0;if((j|0)==0){break}b1[j&511](c[b+1288>>2]|0,0)}else{j=k<<24>>24!=0|0;l=b+1296|0;if((a[l]|0)==j<<24>>24){break}a[l]=j;l=c[b+1292>>2]|0;if((l|0)==0){break}b1[l&511](c[b+1288>>2]|0,j)}}while(0);k=b+4+(g*640|0)+68|0;j=c[k>>2]|0;if((j|0)==0){m=2704;break}l=b+4+(g*640|0)+80|0;n=c[l>>2]|0;if((n+1&255|0)==(c[b+4+(g*640|0)+84>>2]|0)){m=2704;break}if((a[i]|0)!=0){a[h]=a[h]|64;m=2704;break}c[k>>2]=j-1;j=a[d]|0;a[b+4+(g*640|0)+88+n|0]=j;c[l>>2]=(c[l>>2]|0)+1&255;l=c[b+4+(g*640|0)+620>>2]|0;if((l|0)!=0){b1[l&511](c[b+4+(g*640|0)+616>>2]|0,j)}a[h]=a[h]|4;a[i]=1;ne(b,g,2);m=2704}else if((e|0)==15){a[b+4+(g*640|0)+15|0]=f;a[b+4+(g*640|0)+31|0]=f}else if((e|0)==9){j=b+13|0;l=a[j]|0;a[j]=f;a[b+653|0]=f;if((f&8&(l^8))<<24>>24==0){break}ne(b,0,0);ne(b,1,0);m=2704}else if((e|0)==12){a[b+4+(g*640|0)+12|0]=f;nf(b,g)}else if((e|0)==3){a[b+4+(g*640|0)+3|0]=f;if((f&16)==0){break}l=b+4+(g*640|0)+16|0;a[l]=a[l]|16;m=2704}else if((e|0)==2){a[b+6|0]=f;a[b+646|0]=f;a[b+22|0]=f;a[b+662|0]=f}else if((e|0)==4){a[b+4+(g*640|0)+4|0]=f;nf(b,g)}else if((e|0)==1){a[b+4+(g*640|0)+1|0]=f;ne(b,g,0)}else if((e|0)==10){a[b+4+(g*640|0)+10|0]=f}else if((e|0)==0){a[b+4+(g*640|0)|0]=f;l=f&255;j=l&7;n=b|0;c[n>>2]=j;k=l>>>3&7;if((k|0)==2){l=b+23|0;o=a[l]&((g|0)==0?-9:-2);a[l]=o;a[b+4+(g*640|0)+32|0]=0;if((a[b+13|0]&8)!=0){l=o<<24>>24!=0|0;o=b+1296|0;if((a[o]|0)==l<<24>>24){m=2704;break}a[o]=l;o=c[b+1292>>2]|0;if((o|0)==0){m=2704;break}b1[o&511](c[b+1288>>2]|0,l);m=2704;break}l=b+1296|0;if((a[l]|0)==0){return}a[l]=0;l=c[b+1292>>2]|0;if((l|0)==0){m=2704;break}b1[l&511](c[b+1288>>2]|0,0);m=2704;break}else if((k|0)==5){l=b+23|0;o=a[l]&((g|0)==0?-17:-3);a[l]=o;if((a[b+13|0]&8)==0){l=b+1296|0;if((a[l]|0)==0){m=2704;break}a[l]=0;l=c[b+1292>>2]|0;if((l|0)==0){m=2704;break}b1[l&511](c[b+1288>>2]|0,0);m=2704;break}else{l=o<<24>>24!=0|0;o=b+1296|0;if((a[o]|0)==l<<24>>24){m=2704;break}a[o]=l;o=c[b+1292>>2]|0;if((o|0)==0){m=2704;break}b1[o&511](c[b+1288>>2]|0,l);m=2704;break}}else if((k|0)==1){c[n>>2]=j|8;return}else{return}}else if((e|0)==11){a[b+4+(g*640|0)+11|0]=f}else if((e|0)==5){j=b+4+(g*640|0)+5|0;n=a[j]|0;a[j]=f;do{if(((n^f)&2)!=0){j=c[b+4+(g*640|0)+628>>2]|0;if((j|0)==0){break}b1[j&511](c[b+4+(g*640|0)+624>>2]|0,(f&255)>>>1&1)}}while(0);nf(b,g);m=2704}else{a[(e&15)+(b+4+(g*640|0))|0]=f;m=2704}}while(0);do{if((m|0)==2704){if((e|0)!=0){break}return}}while(0);c[b>>2]=0;return}function mX(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0;f=d&1;d=b+4+(f*640|0)+344|0;g=c[d>>2]|0;if((g+1&255|0)==(c[b+4+(f*640|0)+348>>2]|0)){return}a[b+4+(f*640|0)+352+g|0]=e;c[d>>2]=(c[d>>2]|0)+1&255;return}function mY(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=d&1;d=b+4+(e*640|0)+84|0;f=c[d>>2]|0;if((c[b+4+(e*640|0)+80>>2]|0)==(f|0)){g=0;return g|0}h=a[b+4+(e*640|0)+88+f|0]|0;c[d>>2]=f+1&255;g=h;return g|0}function mZ(a,b){a=a|0;b=b|0;var d=0;d=b&1;return((c[a+4+(d*640|0)+344>>2]|0)+1&255|0)==(c[a+4+(d*640|0)+348>>2]|0)|0}function m_(a,b){a=a|0;b=b|0;var d=0;d=b&1;return(c[a+4+(d*640|0)+80>>2]|0)==(c[a+4+(d*640|0)+84>>2]|0)|0}function m$(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=e&1;do{if((f|0)==8){e=b+4+(g*640|0)+24|0;h=a[e]|0;i=b+4+(g*640|0)+16|0;a[i]=a[i]&-2;j=b+4+(g*640|0)+35|0;a[j]=1;k=b+23|0;l=a[k]&((g|0)==0?-33:-5);a[k]=l;do{if((a[b+13|0]&8)==0){k=b+1296|0;if((a[k]|0)==0){break}a[k]=0;k=c[b+1292>>2]|0;if((k|0)==0){break}b1[k&511](c[b+1288>>2]|0,0)}else{k=l<<24>>24!=0|0;m=b+1296|0;if((a[m]|0)==k<<24>>24){break}a[m]=k;m=c[b+1292>>2]|0;if((m|0)==0){break}b1[m&511](c[b+1288>>2]|0,k)}}while(0);l=b+4+(g*640|0)+348|0;k=c[l>>2]|0;if((c[b+4+(g*640|0)+344>>2]|0)==(k|0)){n=h;break}m=b+4+(g*640|0)+60|0;o=c[m>>2]|0;if((o|0)==0){n=h;break}if((a[j]|0)==0){n=h;break}c[m>>2]=o-1;a[e]=a[b+4+(g*640|0)+352+k|0]|0;c[l>>2]=k+1&255;k=c[b+4+(g*640|0)+612>>2]|0;if((k|0)!=0){b1[k&511](c[b+4+(g*640|0)+608>>2]|0,1)}a[i]=a[i]|1;a[j]=0;ne(b,g,4);n=h}else if((f|0)==2){k=a[b+22|0]|0;if((g|0)==0){n=k;break}l=d[b+23|0]|0;do{if((l&32|0)==0){if((l&16|0)!=0){p=24;break}if((l&8|0)!=0){p=90;break}if((l&4|0)!=0){p=36;break}if((l&2|0)!=0){p=0;break}p=(l&1|0)==0?102:66}else{p=60}}while(0);l=k&255;if((a[b+13|0]&16)==0){n=(p&14|l&241)&255;break}else{n=(p|l)&112;break}}else if((f|0)==0){l=a[b+4+(g*640|0)+32|0]|0;n=a[b+4+(g*640|0)+33|0]&l|a[b+4+(g*640|0)+16|0]&~l}else if((f|0)==3){if((g|0)!=0){n=0;break}n=a[b+23|0]|0}else{n=a[(f&15)+(b+4+(g*640|0)+16)|0]|0}}while(0);c[b>>2]=0;return n|0}function m0(a){a=a|0;return m$(a,0,c[a>>2]|0)|0}function m1(a){a=a|0;return m$(a,1,c[a>>2]|0)|0}function m2(a,b){a=a|0;b=b|0;mW(a,0,c[a>>2]|0,b);return}function m3(a,b){a=a|0;b=b|0;mW(a,1,c[a>>2]|0,b);return}function m4(a){a=a|0;return m$(a,0,8)|0}function m5(a){a=a|0;return m$(a,1,8)|0}function m6(a,b){a=a|0;b=b|0;mW(a,0,8,b);return}function m7(a,b){a=a|0;b=b|0;mW(a,1,8,b);return}function m8(b,c){b=b|0;c=c|0;var d=0,e=0,f=0;d=b+20|0;e=a[d]|0;f=c<<24>>24==0?e|8:e&-9;a[d]=f;if((a[b+19|0]&-6&(f^e))<<24>>24==0){return}ne(b,0,1);return}function m9(b,c){b=b|0;c=c|0;var d=0,e=0,f=0;d=b+660|0;e=a[d]|0;f=c<<24>>24==0?e|8:e&-9;a[d]=f;if((a[b+659|0]&-6&(f^e))<<24>>24==0){return}ne(b,1,1);return}function na(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=c&1;c=b+4+(e*640|0)+16|0;f=a[c]|0;g=d<<24>>24==0?f|32:f&-33;a[c]=g;if((a[b+4+(e*640|0)+15|0]&-6&(g^f))<<24>>24==0){return}ne(b,e,1);return}function nb(b){b=b|0;var d=0;c[b>>2]=0;d=0;do{a[b+20+d|0]=0;a[b+4+d|0]=0;a[b+660+d|0]=0;a[b+644+d|0]=0;d=d+1|0;}while(d>>>0<16);d=b+20|0;a[d]=a[d]|4;d=b+21|0;a[d]=a[d]|1;a[b+36|0]=0;c[b+84>>2]=0;c[b+88>>2]=0;c[b+348>>2]=0;c[b+352>>2]=0;u6(b+40|0,0,16);d=b+660|0;a[d]=a[d]|4;d=b+661|0;a[d]=a[d]|1;a[b+676|0]=0;c[b+724>>2]=0;c[b+728>>2]=0;c[b+988>>2]=0;c[b+992>>2]=0;u6(b+680|0,0,16);d=c[b+632>>2]|0;if((d|0)!=0){b1[d&511](c[b+628>>2]|0,0)}d=c[b+1272>>2]|0;if((d|0)!=0){b1[d&511](c[b+1268>>2]|0,0)}d=b+1296|0;if((a[d]|0)==0){return}a[d]=0;d=c[b+1292>>2]|0;if((d|0)==0){return}b1[d&511](c[b+1288>>2]|0,0);return}function nc(a,b){a=a|0;b=b|0;nd(a,0,b);nd(a,1,b);return}function nd(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b+4+(d*640|0)+52|0;g=c[f>>2]|0;if(g>>>0>e>>>0){c[f>>2]=g-e;return}h=e-g|0;g=c[b+4+(d*640|0)+56>>2]|0;if(h>>>0>g>>>0){i=(h>>>0)%(g>>>0)|0}else{i=h}c[f>>2]=g-i;i=c[b+4+(d*640|0)+64>>2]|0;g=b+4+(d*640|0)+60|0;c[g>>2]=i;f=c[b+4+(d*640|0)+72>>2]|0;h=b+4+(d*640|0)+68|0;c[h>>2]=f;e=b+4+(d*640|0)+348|0;j=c[e>>2]|0;do{if((c[b+4+(d*640|0)+344>>2]|0)==(j|0)|(i|0)==0){k=f}else{l=b+4+(d*640|0)+35|0;if((a[l]|0)==0){k=f;break}c[g>>2]=i-1;a[b+4+(d*640|0)+24|0]=a[b+4+(d*640|0)+352+j|0]|0;c[e>>2]=j+1&255;m=c[b+4+(d*640|0)+612>>2]|0;if((m|0)!=0){b1[m&511](c[b+4+(d*640|0)+608>>2]|0,1)}m=b+4+(d*640|0)+16|0;a[m]=a[m]|1;a[l]=0;ne(b,d,4);k=c[h>>2]|0}}while(0);if((k|0)==0){return}j=b+4+(d*640|0)+80|0;e=c[j>>2]|0;if((e+1&255|0)==(c[b+4+(d*640|0)+84>>2]|0)){return}i=b+4+(d*640|0)+34|0;if((a[i]|0)!=0){g=b+4+(d*640|0)+16|0;a[g]=a[g]|64;return}c[h>>2]=k-1;k=a[b+4+(d*640|0)+8|0]|0;a[b+4+(d*640|0)+88+e|0]=k;c[j>>2]=(c[j>>2]|0)+1&255;j=c[b+4+(d*640|0)+620>>2]|0;if((j|0)!=0){b1[j&511](c[b+4+(d*640|0)+616>>2]|0,k)}k=b+4+(d*640|0)+16|0;a[k]=a[k]|4;a[i]=1;ne(b,d,2);return}function ne(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=e&255;do{if((f&1|0)!=0){if((a[b+4+(d*640|0)+1|0]&1)==0){break}e=b+23|0;a[e]=a[e]|((d|0)==0?8:1);a[b+4+(d*640|0)+32|0]=a[b+4+(d*640|0)+15|0]|0;a[b+4+(d*640|0)+33|0]=a[b+4+(d*640|0)+16|0]|0}}while(0);do{if((f&2|0)!=0){if((a[b+4+(d*640|0)+1|0]&2)==0){break}e=b+23|0;a[e]=a[e]|((d|0)==0?16:2)}}while(0);do{if((f&4|0)!=0){if((a[b+4+(d*640|0)+1|0]&24)!=16){break}e=b+23|0;a[e]=a[e]|((d|0)==0?32:4)}}while(0);if((a[b+13|0]&8)==0){d=b+1296|0;if((a[d]|0)==0){return}a[d]=0;d=c[b+1292>>2]|0;if((d|0)==0){return}b1[d&511](c[b+1288>>2]|0,0);return}else{d=(a[b+23|0]|0)!=0|0;f=b+1296|0;if((a[f]|0)==d<<24>>24){return}a[f]=d;f=c[b+1292>>2]|0;if((f|0)==0){return}b1[f&511](c[b+1288>>2]|0,d);return}}function nf(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=(d[a+4+(b*640|0)+5|0]|0)>>>5&3;if((e|0)==3){f=8}else if((e|0)==0){f=5}else if((e|0)==1){f=7}else if((e|0)==2){f=6}else{f=0}c[a+4+(b*640|0)+44>>2]=f;e=d[a+4+(b*640|0)+4|0]|0;g=e&3;if((g|0)==0|(g|0)==1){h=g}else if((g|0)==2){h=0}else if((g|0)==3){h=2}else{h=0}c[a+4+(b*640|0)+40>>2]=h;g=e>>>2&3;if((g|0)==1){i=2}else if((g|0)==3){i=4}else if((g|0)==2){i=3}else{i=0}c[a+4+(b*640|0)+48>>2]=i;g=e>>>6;if((g|0)==0){j=2}else if((g|0)==1){j=32}else if((g|0)==3){j=128}else if((g|0)==2){j=64}else{j=0}g=(i|0)==0?2:j;j=d[a+4+(b*640|0)+14|0]|0;if((j&1|0)==0){c[a+4+(b*640|0)+56>>2]=16384;k=0}else{if((j&2|0)==0){l=a+4+(b*640|0)+76|0}else{l=a+1284|0}j=c[l>>2]|0;l=ac(((d[a+4+(b*640|0)+13|0]|0)<<8|(d[a+4+(b*640|0)+12|0]|0))+2|0,g)|0;c[a+4+(b*640|0)+56>>2]=(ac(l,f+1+i|0)|0)+((h|0)==0?0:l);k=(j>>>0)/(l>>>0)|0}c[a+4+(b*640|0)+36>>2]=k;l=c[a+4+(b*640|0)+636>>2]|0;if((l|0)==0){return}b$[l&3](c[a+4+(b*640|0)+632>>2]|0,k,h,f,i);return}function ng(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=u0(48)|0;g=f;if((f|0)==0){h=0;return h|0}do{if((e|0)==0){c[f+44>>2]=0;i=0}else{j=u0(d+16|0)|0;c[f+44>>2]=j;if((j|0)!=0){i=j;break}u1(f);h=0;return h|0}}while(0);u6(f|0,0,24);c[f+24>>2]=f;a[f+28|0]=1;a[f+29|0]=0;a[f+30|0]=(i|0)!=0|0;c[f+32>>2]=b;c[f+36>>2]=b-1+d;c[f+40>>2]=d;h=g;return h|0}function nh(a,b){a=a|0;b=b|0;return 0}function ni(a,b){a=a|0;b=b|0;return 0}function nj(a,b){a=a|0;b=b|0;return 0}function nk(a,b,c){a=a|0;b=b|0;c=c|0;return}function nl(a,b,c){a=a|0;b=b|0;c=c|0;return}function nm(a,b,c){a=a|0;b=b|0;c=c|0;return}function nn(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;c[a+24>>2]=b;b=a|0;c[b>>2]=d;j=a+4|0;c[j>>2]=e;k=a+8|0;c[k>>2]=f;l=a+12|0;c[l>>2]=g;m=a+16|0;c[m>>2]=h;n=a+20|0;c[n>>2]=i;if((c[a+44>>2]|0)!=0){return}if((d|0)==0){c[b>>2]=20}if((e|0)==0){c[j>>2]=42}if((f|0)==0){c[k>>2]=6}if((g|0)==0){c[l>>2]=8}if((h|0)==0){c[m>>2]=6}if((i|0)!=0){return}c[n>>2]=20;return}function no(a){a=a|0;return c[a+44>>2]|0}function np(b,c){b=b|0;c=c|0;a[b+29|0]=(c|0)!=0|0;return}function nq(a){a=a|0;return c[a+32>>2]|0}function nr(a,b){a=a|0;b=b|0;c[a+32>>2]=b;c[a+36>>2]=b-1+(c[a+40>>2]|0);return}function ns(a){a=a|0;return c[a+40>>2]|0}function nt(a,b){a=a|0;b=b|0;c[a+40>>2]=b;c[a+36>>2]=b-1+(c[a+32>>2]|0);return}function nu(b,c,d){b=b|0;c=c|0;d=d|0;a[b+c|0]=(d&65535)>>>8&255;a[b+(c+1)|0]=d&255;return}function nv(b,c,d){b=b|0;c=c|0;d=d|0;a[b+c|0]=d>>>24&255;a[b+(c+1)|0]=d>>>16&255;a[b+(c+2)|0]=d>>>8&255;a[b+(c+3)|0]=d&255;return}function nw(a,b){a=a|0;b=b|0;var e=0;e=c[a+44>>2]|0;return(((d[e+b|0]|0)<<8|(d[e+(b+1)|0]|0))<<8|(d[e+(b+2)|0]|0))<<8|(d[e+(b+3)|0]|0)|0}function nx(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;c[a+24>>2]=b;c[a+28>>2]=d;c[a+32>>2]=e;c[a+36>>2]=f;c[a+40>>2]=g;c[a+44>>2]=h;c[a+48>>2]=i;return}function ny(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=b+8|0;f=c[e>>2]|0;do{if((f|0)!=0){g=c[f>>2]|0;if((a[g+28|0]|0)==0){break}if((c[g+32>>2]|0)>>>0>d>>>0){break}if((c[g+36>>2]|0)>>>0<d>>>0){break}else{h=g}return h|0}}while(0);f=c[b>>2]|0;if((f|0)==0){h=0;return h|0}g=0;i=c[b+4>>2]|0;L3610:while(1){j=c[i>>2]|0;do{if((a[j+28|0]|0)!=0){if((c[j+32>>2]|0)>>>0>d>>>0){break}if((c[j+36>>2]|0)>>>0>=d>>>0){break L3610}}}while(0);b=g+1|0;if(b>>>0<f>>>0){g=b;i=i+8|0}else{h=0;k=2919;break}}if((k|0)==2919){return h|0}c[e>>2]=i;h=j;return h|0}function nz(b){b=b|0;var c=0,d=0,e=0,f=0;c=u0(48)|0;if((c|0)==0){d=0;return d|0}e=c;f=b;u7(c|0,f|0,48)|0;a[c+30|0]=0;a[c+28|0]=1;d=e;return d|0}function nA(a,b){a=a|0;b=b|0;var d=0;d=c[a+44>>2]|0;if((d|0)==0){return}u6(d|0,b|0,c[a+40>>2]|0);return}function nB(){var a=0,b=0;a=u0(56)|0;if((a|0)==0){b=0;return b|0}u6(a|0,0,52);c[a+52>>2]=-1;b=a;return b|0}function nC(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=b|0;if((c[f>>2]|0)==0){i=e;return}g=b+4|0;b=0;do{h=c[(c[g>>2]|0)+(b<<3)>>2]|0;j=c[h+32>>2]|0;k=c[h+36>>2]|0;l=c[h+40>>2]|0;m=(a[h+29|0]|0)!=0|0;bN(d|0,53776,(x=i,i=i+40|0,c[x>>2]=b,c[x+8>>2]=j,c[x+16>>2]=k,c[x+24>>2]=l,c[x+32>>2]=m,x)|0)|0;b=b+1|0;}while(b>>>0<(c[f>>2]|0)>>>0);i=e;return}function nD(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;if((b|0)==0){return}e=a+4|0;f=a|0;g=u2(c[e>>2]|0,(c[f>>2]<<3)+8|0)|0;h=g;if((g|0)==0){return}c[e>>2]=h;e=c[f>>2]|0;c[f>>2]=e+1;c[h+(e<<3)>>2]=b;c[h+(e<<3)+4>>2]=(d|0)!=0;u6(a+8|0,0,16);return}function nE(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[a+4>>2]|0;e=a|0;f=c[e>>2]|0;if((f|0)==0){g=0}else{h=0;i=0;j=f;while(1){f=d+(i<<3)|0;if((c[f>>2]|0)==(b|0)){k=h;l=j}else{m=f;f=d+(h<<3)|0;n=c[m+4>>2]|0;c[f>>2]=c[m>>2];c[f+4>>2]=n;k=h+1|0;l=c[e>>2]|0}n=i+1|0;if(n>>>0<l>>>0){h=k;i=n;j=l}else{g=k;break}}}c[e>>2]=g;u6(a+8|0,0,16);return}function nF(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b+12|0;f=c[e>>2]|0;do{if((f|0)==0){g=2960}else{h=c[f>>2]|0;if((a[h+28|0]|0)==0){g=2960;break}if((c[h+32>>2]|0)>>>0>d>>>0){g=2960;break}if((c[h+36>>2]|0)>>>0<d>>>0){g=2960}else{i=h;g=2967}}}while(0);L3663:do{if((g|0)==2960){f=c[b>>2]|0;if((f|0)==0){break}h=0;j=c[b+4>>2]|0;L3666:while(1){k=c[j>>2]|0;do{if((a[k+28|0]|0)!=0){if((c[k+32>>2]|0)>>>0>d>>>0){break}if((c[k+36>>2]|0)>>>0>=d>>>0){break L3666}}}while(0);l=h+1|0;if(l>>>0<f>>>0){h=l;j=j+8|0}else{break L3663}}c[e>>2]=j;i=k;g=2967}}while(0);do{if((g|0)==2967){if((i|0)==0){break}k=d-(c[i+32>>2]|0)|0;e=c[i>>2]|0;if((e|0)==0){m=a[(c[i+44>>2]|0)+k|0]|0;return m|0}else{m=b6[e&63](c[i+24>>2]|0,k)|0;return m|0}}}while(0);i=c[b+28>>2]|0;if((i|0)==0){m=c[b+52>>2]&255;return m|0}else{m=b6[i&63](c[b+24>>2]|0,d)|0;return m|0}return 0}function nG(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b+12|0;g=c[f>>2]|0;do{if((g|0)==0){h=2983}else{i=c[g>>2]|0;if((a[i+28|0]|0)==0){h=2983;break}if((c[i+32>>2]|0)>>>0>e>>>0){h=2983;break}if((c[i+36>>2]|0)>>>0<e>>>0){h=2983}else{j=i;h=2990}}}while(0);L3692:do{if((h|0)==2983){g=c[b>>2]|0;if((g|0)==0){break}i=0;k=c[b+4>>2]|0;L3695:while(1){l=c[k>>2]|0;do{if((a[l+28|0]|0)!=0){if((c[l+32>>2]|0)>>>0>e>>>0){break}if((c[l+36>>2]|0)>>>0>=e>>>0){break L3695}}}while(0);m=i+1|0;if(m>>>0<g>>>0){i=m;k=k+8|0}else{break L3692}}c[f>>2]=k;j=l;h=2990}}while(0);do{if((h|0)==2990){if((j|0)==0){break}l=e+1|0;if(l>>>0>(c[j+36>>2]|0)>>>0){f=((nF(b,e)|0)&255)<<8;n=f|(nF(b,l)|0)&255;return n|0}l=e-(c[j+32>>2]|0)|0;f=c[j+4>>2]|0;if((f|0)==0){i=c[j+44>>2]|0;n=d[i+l|0]<<8|d[i+(l+1)|0];return n|0}else{n=b6[f&63](c[j+24>>2]|0,l)|0;return n|0}}}while(0);j=c[b+32>>2]|0;if((j|0)==0){n=c[b+52>>2]&65535;return n|0}else{n=b6[j&63](c[b+24>>2]|0,e)|0;return n|0}return 0}function nH(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b+12|0;g=c[f>>2]|0;do{if((g|0)==0){h=3009}else{i=c[g>>2]|0;if((a[i+28|0]|0)==0){h=3009;break}if((c[i+32>>2]|0)>>>0>e>>>0){h=3009;break}if((c[i+36>>2]|0)>>>0<e>>>0){h=3009}else{j=i;h=3016}}}while(0);L3725:do{if((h|0)==3009){g=c[b>>2]|0;if((g|0)==0){break}i=0;k=c[b+4>>2]|0;L3728:while(1){l=c[k>>2]|0;do{if((a[l+28|0]|0)!=0){if((c[l+32>>2]|0)>>>0>e>>>0){break}if((c[l+36>>2]|0)>>>0>=e>>>0){break L3728}}}while(0);m=i+1|0;if(m>>>0<g>>>0){i=m;k=k+8|0}else{break L3725}}c[f>>2]=k;j=l;h=3016}}while(0);do{if((h|0)==3016){if((j|0)==0){break}l=e+3|0;if(l>>>0>(c[j+36>>2]|0)>>>0){f=((nF(b,e)|0)&255)<<24;i=((nF(b,e+1|0)|0)&255)<<16|f;f=i|((nF(b,e+2|0)|0)&255)<<8;n=f|(nF(b,l)|0)&255;return n|0}l=e-(c[j+32>>2]|0)|0;f=c[j+8>>2]|0;if((f|0)==0){i=c[j+44>>2]|0;n=d[i+(l+1)|0]<<16|d[i+l|0]<<24|d[i+(l+2)|0]<<8|d[i+(l+3)|0];return n|0}else{n=b6[f&63](c[j+24>>2]|0,l)|0;return n|0}}}while(0);j=c[b+36>>2]|0;if((j|0)==0){n=c[b+52>>2]|0;return n|0}else{n=b6[j&63](c[b+24>>2]|0,e)|0;return n|0}return 0}function nI(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b+8|0;g=c[f>>2]|0;do{if((g|0)==0){h=3035}else{i=c[g>>2]|0;if((a[i+28|0]|0)==0){h=3035;break}if((c[i+32>>2]|0)>>>0>d>>>0){h=3035;break}if((c[i+36>>2]|0)>>>0<d>>>0){h=3035}else{j=i;h=3042}}}while(0);L3758:do{if((h|0)==3035){g=c[b>>2]|0;if((g|0)==0){break}i=0;k=c[b+4>>2]|0;L3761:while(1){l=c[k>>2]|0;do{if((a[l+28|0]|0)!=0){if((c[l+32>>2]|0)>>>0>d>>>0){break}if((c[l+36>>2]|0)>>>0>=d>>>0){break L3761}}}while(0);m=i+1|0;if(m>>>0<g>>>0){i=m;k=k+8|0}else{break L3758}}c[f>>2]=k;j=l;h=3042}}while(0);do{if((h|0)==3042){if((j|0)==0){break}l=d-(c[j+32>>2]|0)|0;f=c[j+12>>2]|0;if((f|0)==0){a[(c[j+44>>2]|0)+l|0]=e;return}else{b3[f&63](c[j+24>>2]|0,l,e);return}}}while(0);j=c[b+40>>2]|0;if((j|0)==0){return}b3[j&63](c[b+24>>2]|0,d,e);return}function nJ(a,b){a=a|0;b=b|0;c[a+76>>2]=b;return}function nK(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b+16|0;g=c[f>>2]|0;do{if((g|0)==0){h=3058}else{i=c[g>>2]|0;if((a[i+28|0]|0)==0){h=3058;break}if((c[i+32>>2]|0)>>>0>d>>>0){h=3058;break}if((c[i+36>>2]|0)>>>0<d>>>0){h=3058}else{j=i;h=3065}}}while(0);L3787:do{if((h|0)==3058){g=c[b>>2]|0;if((g|0)==0){break}i=0;k=c[b+4>>2]|0;L3790:while(1){l=c[k>>2]|0;do{if((a[l+28|0]|0)!=0){if((c[l+32>>2]|0)>>>0>d>>>0){break}if((c[l+36>>2]|0)>>>0>=d>>>0){break L3790}}}while(0);m=i+1|0;if(m>>>0<g>>>0){i=m;k=k+8|0}else{break L3787}}c[f>>2]=k;j=l;h=3065}}while(0);do{if((h|0)==3065){if((j|0)==0){break}if((a[j+29|0]|0)!=0){return}l=d-(c[j+32>>2]|0)|0;f=c[j+12>>2]|0;if((f|0)==0){a[(c[j+44>>2]|0)+l|0]=e;return}else{b3[f&63](c[j+24>>2]|0,l,e);return}}}while(0);j=c[b+40>>2]|0;if((j|0)==0){return}b3[j&63](c[b+24>>2]|0,d,e);return}function nL(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b+16|0;g=c[f>>2]|0;do{if((g|0)==0){h=3082}else{i=c[g>>2]|0;if((a[i+28|0]|0)==0){h=3082;break}if((c[i+32>>2]|0)>>>0>d>>>0){h=3082;break}if((c[i+36>>2]|0)>>>0<d>>>0){h=3082}else{j=i;h=3089}}}while(0);L3818:do{if((h|0)==3082){g=c[b>>2]|0;if((g|0)==0){break}i=0;k=c[b+4>>2]|0;L3821:while(1){l=c[k>>2]|0;do{if((a[l+28|0]|0)!=0){if((c[l+32>>2]|0)>>>0>d>>>0){break}if((c[l+36>>2]|0)>>>0>=d>>>0){break L3821}}}while(0);m=i+1|0;if(m>>>0<g>>>0){i=m;k=k+8|0}else{break L3818}}c[f>>2]=k;j=l;h=3089}}while(0);do{if((h|0)==3089){if((j|0)==0){break}l=d+1|0;if(l>>>0>(c[j+36>>2]|0)>>>0){nK(b,d,(e&65535)>>>8&255);nK(b,l,e&255);return}if((a[j+29|0]|0)!=0){return}l=d-(c[j+32>>2]|0)|0;f=c[j+16>>2]|0;if((f|0)==0){i=j+44|0;a[(c[i>>2]|0)+l|0]=(e&65535)>>>8&255;a[(c[i>>2]|0)+(l+1)|0]=e&255;return}else{b3[f&63](c[j+24>>2]|0,l,e);return}}}while(0);j=c[b+44>>2]|0;if((j|0)==0){return}b3[j&63](c[b+24>>2]|0,d,e);return}function nM(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b+16|0;g=c[f>>2]|0;do{if((g|0)==0){h=3109}else{i=c[g>>2]|0;if((a[i+28|0]|0)==0){h=3109;break}if((c[i+32>>2]|0)>>>0>d>>>0){h=3109;break}if((c[i+36>>2]|0)>>>0<d>>>0){h=3109}else{j=i;h=3116}}}while(0);L3853:do{if((h|0)==3109){g=c[b>>2]|0;if((g|0)==0){break}i=0;k=c[b+4>>2]|0;L3856:while(1){l=c[k>>2]|0;do{if((a[l+28|0]|0)!=0){if((c[l+32>>2]|0)>>>0>d>>>0){break}if((c[l+36>>2]|0)>>>0>=d>>>0){break L3856}}}while(0);m=i+1|0;if(m>>>0<g>>>0){i=m;k=k+8|0}else{break L3853}}c[f>>2]=k;j=l;h=3116}}while(0);do{if((h|0)==3116){if((j|0)==0){break}l=d+3|0;if(l>>>0>(c[j+36>>2]|0)>>>0){nK(b,d,e>>>24&255);nK(b,d+1|0,e>>>16&255);nK(b,d+2|0,e>>>8&255);nK(b,l,e&255);return}if((a[j+29|0]|0)!=0){return}l=d-(c[j+32>>2]|0)|0;f=c[j+20>>2]|0;if((f|0)==0){i=j+44|0;a[(c[i>>2]|0)+l|0]=e>>>24&255;a[(c[i>>2]|0)+(l+1)|0]=e>>>16&255;a[(c[i>>2]|0)+(l+2)|0]=e>>>8&255;a[(c[i>>2]|0)+(l+3)|0]=e&255;return}else{b3[f&63](c[j+24>>2]|0,l,e);return}}}while(0);j=c[b+48>>2]|0;if((j|0)==0){return}b3[j&63](c[b+24>>2]|0,d,e);return}function nN(a,b,d,f,g,h,i){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;j=c[a+68>>2]|0;if((j|0)==0){c[d>>2]=0;k=1;return k|0}a=qp(j,f,g,h,i)|0;if((a|0)==0){c[d>>2]=0;k=1;return k|0}i=a+20|0;h=p1(a,c[i>>2]|0)|0;if((h|0)==0){c[i>>2]=0;l=a}else{l=h}h=c[d>>2]|0;g=e[l+10>>1]|0;if(h>>>0>g>>>0){c[d>>2]=g;m=32;n=g}else{m=0;n=h}if((n|0)!=0){h=c[l+24>>2]|0;u7(b|0,h|0,n)|0}n=c[l+12>>2]|0;l=(n&8|0)==0?m:m|2;m=(n&1|0)==0?l:l|4;l=(n&2|0)==0?m:m|8;m=(n&4|0)==0?l:l|16;if((c[a>>2]|0)==0){k=m;return k|0}c[i>>2]=(c[i>>2]|0)+1;k=m;return k|0}function nO(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;u6(b|0,0,d|0);i=c[a+68>>2]|0;if((i|0)==0){j=0;return j|0}a=qp(i,e,f,g,h)|0;if((a|0)==0){j=0;return j|0}h=a+20|0;g=p1(a,c[h>>2]|0)|0;if((g|0)==0){c[h>>2]=0;k=a}else{k=g}j=qj(k,b,d)|0;return j|0}function nP(b,d,f,g,h,i,j){b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0;k=c[b+68>>2]|0;if((k|0)==0){c[f>>2]=0;l=1;return l|0}if((a[b+56|0]|0)!=0){l=64;return l|0}m=qp(k,g,h,i,j)|0;if((m|0)==0){c[f>>2]=0;l=1;return l|0}j=m+12|0;if((c[j>>2]&8|0)!=0){l=2;return l|0}a[b+72|0]=1;b=c[f>>2]|0;i=e[m+10>>1]|0;if(b>>>0>i>>>0){c[f>>2]=i;n=32;o=i}else{n=0;o=b}if((o|0)!=0){b=c[m+24>>2]|0;u7(b|0,d|0,o)|0}c[j>>2]=c[j>>2]&-3;j=m|0;o=c[j>>2]|0;if((o|0)==0){l=n;return l|0}qi(o);c[j>>2]=0;c[m+20>>2]=0;l=n;return l|0}function nQ(b,d,e,f,g,h,i){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=c[b+68>>2]|0;do{if((j|0)==0){k=0}else{if((a[b+56|0]|0)!=0){k=0;break}l=qp(j,f,g,h,i)|0;if((l|0)==0){k=0;break}a[b+72|0]=1;k=qa(l,d,e)|0}}while(0);return k|0}function nR(b){b=b|0;var d=0,e=0;d=c[b+68>>2]|0;if((d|0)==0){e=1;return e|0}if((a[b+56|0]|0)!=0){e=1;return e|0}qu(d);c[b+28>>2]=0;a[b+72|0]=1;e=0;return e|0}function nS(b,d,e,f,g,h,i,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=c[b+68>>2]|0;if((k|0)==0){l=1;return l|0}if((a[b+56|0]|0)!=0){l=1;return l|0}m=qx(k,d,e,1)|0;if((m|0)==0){l=1;return l|0}a[b+72|0]=1;e=qh(f,g,h,i)|0;if((e|0)==0){l=1;return l|0}p2(e,j);if((qm(m,e)|0)==0){p5(e,c[b+76>>2]|0);m=b+28|0;c[m>>2]=(c[m>>2]|0)+1;l=0;return l|0}else{qi(e);l=1;return l|0}return 0}function nT(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=u0(88)|0;if((h|0)==0){i=0;return i|0}j=h;oh(j,h,0,0,0,0);n2(j,6);n4(j,g);c[h+4>>2]=50;c[h+8>>2]=20;c[h+12>>2]=2;c[h+20>>2]=64;a[h+72|0]=0;c[h+76>>2]=2;c[h+80>>2]=f;c[h+84>>2]=0;g=qd(d,f)|0;c[h+68>>2]=g;if((g|0)==0){nU(j);i=0;return i|0}h=b[g>>1]|0;f=h&65535;if(h<<16>>16==0){i=j;return i|0}h=c[g+4>>2]|0;g=0;d=0;k=0;while(1){l=c[h+(k<<2)>>2]|0;m=b[l+2>>1]|0;n=m&65535;o=n+g|0;if(m<<16>>16==0){p=d}else{m=c[l+4>>2]|0;l=d;q=0;while(1){r=(e[(c[m+(q<<2)>>2]|0)+2>>1]|0)+l|0;s=q+1|0;if(s>>>0<n>>>0){l=r;q=s}else{p=r;break}}}q=k+1|0;if(q>>>0<f>>>0){g=o;d=p;k=q}else{break}}if((o|0)==0|(p|0)==0){i=j;return i|0}k=(((((o>>>0)/(f>>>0)|0)>>>1)+o|0)>>>0)/(f>>>0)|0;d=(((((p>>>0)/(o>>>0)|0)>>>1)+p|0)>>>0)/(o>>>0)|0;if((n5(j,p,f,k,d)|0)!=0){i=j;return i|0}n6(j,f,k,d);i=j;return i|0}function nU(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=c[b+64>>2]|0;L4000:do{if((a[e+72|0]|0)!=0){f=c[q>>2]|0;g=b+24|0;h=c[g>>2]|0;bN(f|0,40640,(x=i,i=i+8|0,c[x>>2]=h,x)|0)|0;h=e+84|0;do{if((c[h>>2]|0)!=0){f=e+68|0;if((c[f>>2]|0)==0){break}if((n3(e)|0)!=0){break}if((qg(c[h>>2]|0,c[f>>2]|0,c[e+80>>2]|0)|0)==0){break L4000}}}while(0);h=c[q>>2]|0;f=c[g>>2]|0;bN(h|0,37496,(x=i,i=i+8|0,c[x>>2]=f,x)|0)|0}}while(0);b=c[e+68>>2]|0;if((b|0)==0){j=e+84|0;k=j;l=c[k>>2]|0;u1(l);u1(e);i=d;return}qt(b);j=e+84|0;k=j;l=c[k>>2]|0;u1(l);u1(e);i=d;return}function nV(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+32|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=c[a+64>>2]|0;a=l;m=l+68|0;if((e|0)==0){n=0;i=f;return n|0}else{o=d;p=e;q=b}while(1){if((qy(c[m>>2]|0,o,g,h,j)|0)!=0){n=1;r=3241;break}c[k>>2]=512;b=(nN(a,q,k,c[g>>2]|0,c[h>>2]|0,c[j>>2]|0,1)|0)==0;if(!(b&(c[k>>2]|0)==512)){n=1;r=3239;break}b=p-1|0;if((b|0)==0){n=0;r=3240;break}else{o=o+1|0;p=b;q=q+512|0}}if((r|0)==3240){i=f;return n|0}else if((r|0)==3241){i=f;return n|0}else if((r|0)==3239){i=f;return n|0}return 0}function nW(a,b){a=a|0;b=b|0;return(((d[a+b|0]|0)<<8|(d[a+(b+1)|0]|0))<<8|(d[a+(b+2)|0]|0))<<8|(d[a+(b+3)|0]|0)|0}function nX(b,c,d){b=b|0;c=c|0;d=d|0;a[b+c|0]=d>>>24&255;a[b+(c+1)|0]=d>>>16&255;a[b+(c+2)|0]=d>>>8&255;a[b+(c+3)|0]=d&255;return}function nY(a,b){a=a|0;b=b|0;return(((d[a+(b+3)|0]|0)<<8|(d[a+(b+2)|0]|0))<<8|(d[a+(b+1)|0]|0))<<8|(d[a+b|0]|0)|0}function nZ(a,b){a=a|0;b=b|0;var c=0,e=0,f=0,g=0,h=0,i=0,j=0;c=d[a+(b+7)|0]|0;e=c<<8|0>>>24|(d[a+(b+6)|0]|0);f=e<<8|0>>>24|(d[a+(b+5)|0]|0);g=f<<8|0>>>24|(d[a+(b+4)|0]|0);h=g<<8|0>>>24|(d[a+(b+3)|0]|0);i=h<<8|0>>>24|(d[a+(b+2)|0]|0);j=i<<8|0>>>24|(d[a+(b+1)|0]|0);return(G=((((((0<<8|c>>>24)<<8|e>>>24)<<8|f>>>24)<<8|g>>>24)<<8|h>>>24)<<8|i>>>24)<<8|j>>>24|0,j<<8|0>>>24|(d[a+b|0]|0))|0}function n_(b,c,d){b=b|0;c=c|0;d=d|0;a[b+c|0]=d&255;a[b+(c+1)|0]=d>>>8&255;a[b+(c+2)|0]=d>>>16&255;a[b+(c+3)|0]=d>>>24&255;return}function n$(b,c,d,e){b=b|0;c=c|0;d=d|0;e=e|0;a[b+c|0]=d&255;a[b+(c+1)|0]=(d>>>8|e<<24)&255;a[b+(c+2)|0]=(d>>>16|e<<16)&255;a[b+(c+3)|0]=(d>>>24|e<<8)&255;a[b+(c+4)|0]=e&255;a[b+(c+5)|0]=(e>>>8|0<<24)&255;a[b+(c+6)|0]=(e>>>16|0<<16)&255;a[b+(c+7)|0]=(e>>>24|0<<8)&255;return}function n0(a,b){a=a|0;b=b|0;c[a+24>>2]=b;return}function n1(a){a=a|0;return c[a>>2]|0}function n2(a,b){a=a|0;b=b|0;c[a>>2]=b;return}function n3(b){b=b|0;return(a[b+56|0]|0)!=0|0}function n4(b,c){b=b|0;c=c|0;a[b+56|0]=(c|0)!=0|0;return}function n5(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;do{if((b|0)==0){g=ac(ac(e,d)|0,f)|0;if((g|0)==0){h=1}else{i=g;break}return h|0}else{i=b}}while(0);do{if((d|0)==0){b=(f|0)==0?63:f;g=(e|0)==0?16:e;j=b;k=(i>>>0)/((ac(b,g)|0)>>>0)|0;l=g}else{g=(f|0)==0;if((e|0)==0){b=g?63:f;j=b;k=d;l=(i>>>0)/((ac(b,d)|0)>>>0)|0;break}if(!g){j=f;k=d;l=e;break}j=(i>>>0)/((ac(e,d)|0)>>>0)|0;k=d;l=e}}while(0);c[a+28>>2]=i;c[a+32>>2]=k;c[a+36>>2]=l;c[a+40>>2]=j;h=0;return h|0}function n6(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[a+44>>2]=b;c[a+48>>2]=d;c[a+52>>2]=e;return}function n7(a){a=a|0;return c[a+24>>2]|0}function n8(a){a=a|0;return c[a+28>>2]|0}function n9(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;i=i+24|0;j=h|0;k=h+8|0;l=h+16|0;L4052:do{if((a[d+56|0]|0)==0){m=c[d+64>>2]|0;n=m+68|0;o=m+56|0;if((g|0)==0){p=0;break}q=m+72|0;m=f;r=g;s=e;while(1){if((qy(c[n>>2]|0,m,j,k,l)|0)!=0){p=1;break L4052}t=c[n>>2]|0;if((t|0)==0){p=1;break L4052}if((a[o]|0)!=0){p=1;break L4052}u=qp(t,c[j>>2]|0,c[k>>2]|0,c[l>>2]|0,1)|0;if((u|0)==0){p=1;break L4052}t=u+12|0;if((c[t>>2]&8|0)!=0){p=1;break L4052}a[q]=1;v=b[u+10>>1]|0;if((v&65535)<512){if(v<<16>>16==0){w=0;x=32}else{y=v&65535;z=32;A=3278}}else{y=512;z=0;A=3278}if((A|0)==3278){A=0;v=c[u+24>>2]|0;u7(v|0,s|0,y)|0;w=y;x=z}c[t>>2]=c[t>>2]&-3;t=u|0;v=c[t>>2]|0;if((v|0)!=0){qi(v);c[t>>2]=0;c[u+20>>2]=0}if(!((x|0)==0&(w|0)==512)){p=1;break L4052}u=r-1|0;if((u|0)==0){p=0;break}else{m=m+1|0;r=u;s=s+512|0}}}else{p=1}}while(0);i=h;return p|0}function oa(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;e=c[b+64>>2]|0;if((aQ(d|0,44176)|0)!=0){f=1;return f|0}d=e+84|0;if((c[d>>2]|0)==0){f=1;return f|0}b=e+68|0;if((c[b>>2]|0)==0){f=1;return f|0}if((n3(e)|0)!=0){f=1;return f|0}if((qg(c[d>>2]|0,c[b>>2]|0,c[e+80>>2]|0)|0)!=0){f=1;return f|0}a[e+72|0]=0;f=0;return f|0}function ob(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;do{if((b|0)==0){e=qe(a)|0;if((e|0)!=0){f=e;break}e=qc(a)|0;if((e|0)==0){g=0}else{f=e;break}return g|0}else{f=b}}while(0);do{if((d|0)==0){b=aZ(a|0,54384)|0;if((b|0)!=0){h=0;i=b;break}j=aZ(a|0,53384)|0;k=1;l=3304}else{j=aZ(a|0,53384)|0;k=d;l=3304}}while(0);do{if((l|0)==3304){if((j|0)==0){g=0}else{h=k;i=j;break}return g|0}}while(0);j=nT(i,f,h)|0;av(i|0)|0;if((j|0)==0){g=0;return g|0}i=c[j+64>>2]|0;h=u0((u8(a|0)|0)+1|0)|0;c[i+84>>2]=h;if((h|0)!=0){vb(h|0,a|0)|0}oj(j,a);g=j;return g|0}function oc(a){a=a|0;return qe(a)|0}function od(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=0;if(d>>>0>g>>>0|d>>>0==g>>>0&c>>>0>2147483647>>>0){h=1;return h|0}if((bR(a|0,c|0,0)|0)!=0){h=1;return h|0}c=bK(b|0,1,e|0,a|0)|0;a=c;g=0;if(!(g>>>0<f>>>0|g>>>0==f>>>0&a>>>0<e>>>0)){h=0;return h|0}d=vg(e,f,a,g)|0;u6(b+c|0,0,d|0);h=0;return h|0}function oe(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=0;if(d>>>0>g>>>0|d>>>0==g>>>0&c>>>0>2147483647>>>0){h=1;return h|0}if((bR(a|0,c|0,0)|0)!=0){h=1;return h|0}h=((aC(b|0,1,e|0,a|0)|0)!=(e|0)|0!=(f|0))&1;return h|0}function of(a,b){a=a|0;b=b|0;var d=0,e=0;if((bR(a|0,0,2)|0)!=0){d=1;return d|0}e=a0(a|0)|0;if((e|0)==-1){d=1;return d|0}c[b>>2]=e;c[b+4>>2]=(e|0)<0?-1:0;d=0;return d|0}function og(a,b,c){a=a|0;b=b|0;c=c|0;ay(a|0)|0;return(a8(aL(a|0)|0,b|0)|0)!=0|0}function oh(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;u6(b|0,0,28);if((e|0)==0){i=ac(ac(g,f)|0,h)|0;if((i|0)==0){j=h;k=g;l=f;m=0}else{n=i;o=3341}}else{n=e;o=3341}do{if((o|0)==3341){if((f|0)==0){e=(h|0)==0?63:h;i=(g|0)==0?16:g;j=e;k=i;l=(n>>>0)/((ac(e,i)|0)>>>0)|0;m=n;break}i=(h|0)==0;if((g|0)==0){e=i?63:h;j=e;k=(n>>>0)/((ac(e,f)|0)>>>0)|0;l=f;m=n;break}if(!i){j=h;k=g;l=f;m=n;break}j=(n>>>0)/((ac(g,f)|0)>>>0)|0;k=g;l=f;m=n}}while(0);c[b+28>>2]=m;c[b+32>>2]=l;c[b+36>>2]=k;c[b+40>>2]=j;c[b+44>>2]=l;c[b+48>>2]=k;c[b+52>>2]=j;a[b+56|0]=0;c[b+60>>2]=0;c[b+64>>2]=d;return}function oi(a){a=a|0;var b=0;if((a|0)==0){return}u1(c[a+60>>2]|0);b=c[a+4>>2]|0;if((b|0)==0){return}b0[b&127](a);return}function oj(a,b){a=a|0;b=b|0;var d=0;d=a+60|0;a=c[d>>2]|0;if((a|0)!=0){u1(a)}if((b|0)==0){c[d>>2]=0;return}a=u0((u8(b|0)|0)+1|0)|0;c[d>>2]=a;if((a|0)==0){return}vb(a|0,b|0)|0;return}function ok(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=a|0;e=c[d>>2]|0;if((e|0)==0){f=0;g=0;c[d>>2]=g;return f|0}h=a+4|0;a=0;i=0;j=0;k=e;while(1){e=c[h>>2]|0;l=c[e+(i<<2)>>2]|0;if((l|0)==(b|0)){m=j;n=1;o=k}else{c[e+(j<<2)>>2]=l;m=j+1|0;n=a;o=c[d>>2]|0}l=i+1|0;if(l>>>0<o>>>0){a=n;i=l;j=m;k=o}else{f=n;g=m;break}}c[d>>2]=g;return f|0}function ol(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=a+4|0;e=c[a>>2]|0;a=0;while(1){if(a>>>0>=e>>>0){f=0;g=3377;break}h=c[(c[d>>2]|0)+(a<<2)>>2]|0;if((c[h+24>>2]|0)==(b|0)){f=h;g=3378;break}else{a=a+1|0}}if((g|0)==3377){return f|0}else if((g|0)==3378){return f|0}return 0}function om(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;e=i;i=i+512|0;f=e|0;g=f|0;h=b+8|0;j=c[h>>2]|0;L4190:do{if((j|0)!=0){if((b5[j&127](b,g,0,1)|0)!=0){break}if((a[f+510|0]|0)!=85){break}if((a[f+511|0]|0)==-86){k=0;l=0;m=0;n=0}else{break}while(1){o=l<<4;do{if((a[f+(o+446)|0]&127)==0){p=d[f+(o+448)|0]|0;q=a[f+(o+447)|0]|0;r=p&63;s=((d[f+(o+457)|0]<<8|d[f+(o+456)|0])<<8|d[f+(o+455)|0])<<8|d[f+(o+454)|0];t=d[f+(o+452)|0]|0;u=t&63;v=((d[f+(o+461)|0]<<8|d[f+(o+460)|0])<<8|d[f+(o+459)|0])<<8|d[f+(o+458)|0];if((r|0)==0|(u|0)==0|(s|0)==0|(v|0)==0){w=n;x=m;y=k;break}z=r-1|0;r=u-1|0;u=s-1+v|0;if(!(s>>>0>z>>>0&u>>>0>r>>>0)){w=n;x=m;y=k;break}v=p<<2&768|d[f+(o+449)|0];p=0;A=u-r|0;r=0;u=t<<2&768|d[f+(o+453)|0];t=0;B=d[f+(o+451)|0]|0;C=0;D=vp(B,C,v,p)|0;E=G;F=vp(u,t,q&255,0)|0;q=G;if((D|0)==(F|0)&(E|0)==(q|0)){w=n;x=m;y=k;break}H=vp(u,t,s-z|0,0)|0;z=G;s=vp(A,r,v,p)|0;p=G;v=vg(D,E,F,q)|0;q=G;F=vg(s,p,H,z)|0;z=vn(F,G,v,q)|0;q=z;v=z|0;z=G&0;F=vp(v,z,u,t)|0;t=G;if((F|0)==0&(t|0)==0){I=k}else{u=vp(v,z,B,C)|0;C=vg(A,r,u,G)|0;u=vn(C,G,F,t)|0;t=u;if((t|0)==0){w=n;x=m;y=0;break}if((q|0)==0){w=n;x=m;y=t;break}else{I=t}}if(!((m|0)==0|(m|0)==(I|0))){break L4190}if((n|0)==0|(n|0)==(q|0)){w=q;x=I;y=I}else{break L4190}}else{w=n;x=m;y=k}}while(0);o=l+1|0;if(o>>>0<4){k=y;l=o;m=x;n=w}else{break}}if((x|0)==0|(w|0)==0){break}o=b+28|0;q=c[o>>2]|0;t=ac(w,x)|0;u=(q>>>0)/(t>>>0)|0;do{if((q|0)==0){F=ac(u,t)|0;if((F|0)!=0){J=F;break}i=e;return 0}else{J=q}}while(0);if((u|0)==0){K=(J>>>0)/(t>>>0)|0}else{K=u}c[o>>2]=J;c[b+32>>2]=K;c[b+36>>2]=x;c[b+40>>2]=w;i=e;return 0}}while(0);w=c[h>>2]|0;do{if((w|0)!=0){if((b5[w&127](b,g,0,1)|0)!=0){break}if((a[f+510|0]|0)!=85){break}if((a[f+511|0]|0)!=-86){break}if((d[f+12|0]<<8|d[f+11|0])<<16>>16!=512){break}x=d[f+27|0]<<8|d[f+26|0];K=x&65535;J=d[f+25|0]<<8|d[f+24|0];n=J&65535;if(x<<16>>16==0|(x&65535)>255){break}if(J<<16>>16==0|(J&65535)>255){break}J=b+28|0;x=c[J>>2]|0;m=ac(n,K)|0;l=(x>>>0)/(m>>>0)|0;do{if((x|0)==0){y=ac(l,m)|0;if((y|0)!=0){L=y;break}i=e;return 0}else{L=x}}while(0);if((l|0)==0){M=(L>>>0)/(m>>>0)|0}else{M=l}c[J>>2]=L;c[b+32>>2]=M;c[b+36>>2]=K;c[b+40>>2]=n;i=e;return 0}}while(0);M=c[h>>2]|0;do{if((M|0)!=0){if((b5[M&127](b,g,0,1)|0)!=0){break}if((d[f+508|0]<<8|d[f+509|0])<<16>>16==-9538){N=0;O=0}else{break}while(1){P=d[f+N|0]<<8^O;Q=d[f+(N|1)|0]|0;h=N+2|0;if(h>>>0<512){N=h;O=P^Q}else{break}}if((P|0)!=(Q|0)){break}if((((d[f+128|0]<<8|d[f+129|0])<<8|d[f+130|0])<<8|d[f+131|0]|0)!=1){break}if(((d[f+140|0]<<8|d[f+141|0])&65535)>8){break}n=d[f+422|0]<<8|d[f+423|0];K=n&65535;J=d[f+436|0]<<8|d[f+437|0];l=J&65535;m=d[f+438|0]<<8|d[f+439|0];h=m&65535;L=b+28|0;w=c[L>>2]|0;do{if((w|0)==0){x=ac(ac(l,K)|0,h)|0;if((x|0)!=0){R=x;break}i=e;return 0}else{R=w}}while(0);do{if(n<<16>>16==0){w=m<<16>>16==0?63:h;x=J<<16>>16==0?16:l;S=w;T=(R>>>0)/((ac(w,x)|0)>>>0)|0;U=x}else{x=m<<16>>16==0;if(J<<16>>16==0){w=x?63:h;S=w;T=K;U=(R>>>0)/((ac(w,K)|0)>>>0)|0;break}if(!x){S=h;T=K;U=l;break}S=(R>>>0)/((ac(l,K)|0)>>>0)|0;T=K;U=l}}while(0);c[L>>2]=R;c[b+32>>2]=T;c[b+36>>2]=U;c[b+40>>2]=S;i=e;return 0}}while(0);S=b+28|0;U=c[S>>2]|0;if((U|0)==320){c[S>>2]=320;c[b+32>>2]=40;c[b+36>>2]=1;c[b+40>>2]=8;i=e;return 0}else if((U|0)==360){c[S>>2]=360;c[b+32>>2]=40;c[b+36>>2]=1;c[b+40>>2]=9;i=e;return 0}else if((U|0)==640){c[S>>2]=640;c[b+32>>2]=40;c[b+36>>2]=2;c[b+40>>2]=8;i=e;return 0}else if((U|0)==720){c[S>>2]=720;c[b+32>>2]=40;c[b+36>>2]=2;c[b+40>>2]=9;i=e;return 0}else if((U|0)==800){c[S>>2]=800;c[b+32>>2]=40;c[b+36>>2]=2;c[b+40>>2]=10;i=e;return 0}else if((U|0)==1440){c[S>>2]=1440;c[b+32>>2]=80;c[b+36>>2]=2;c[b+40>>2]=9;i=e;return 0}else if((U|0)==1600){c[S>>2]=1600;c[b+32>>2]=80;c[b+36>>2]=2;c[b+40>>2]=10;i=e;return 0}else if((U|0)==2400){c[S>>2]=2400;c[b+32>>2]=80;c[b+36>>2]=2;c[b+40>>2]=15;i=e;return 0}else if((U|0)==2880){c[S>>2]=2880;c[b+32>>2]=80;c[b+36>>2]=2;c[b+40>>2]=18;i=e;return 0}else if((U|0)==5760){c[S>>2]=5760;c[b+32>>2]=80;c[b+36>>2]=2;c[b+40>>2]=36;i=e;return 0}else{T=b+32|0;R=c[T>>2]|0;f=b+36|0;Q=c[f>>2]|0;P=b+40|0;b=c[P>>2]|0;do{if((U|0)==0){O=ac(ac(Q,R)|0,b)|0;if((O|0)!=0){V=O;break}i=e;return 0}else{V=U}}while(0);do{if((R|0)==0){U=(b|0)==0?63:b;O=(Q|0)==0?16:Q;W=U;X=(V>>>0)/((ac(U,O)|0)>>>0)|0;Y=O}else{O=(b|0)==0;if((Q|0)==0){U=O?63:b;W=U;X=R;Y=(V>>>0)/((ac(U,R)|0)>>>0)|0;break}if(!O){W=b;X=R;Y=Q;break}W=(V>>>0)/((ac(Q,R)|0)>>>0)|0;X=R;Y=Q}}while(0);c[S>>2]=V;c[T>>2]=X;c[f>>2]=Y;c[P>>2]=W;i=e;return 0}return 0}function on(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if((oH(a)|0)!=0){e=oG(a,d)|0;return e|0}if((oR(a)|0)!=0){e=oM(a,d)|0;return e|0}if((oA(a)|0)!=0){e=oz(a,d)|0;return e|0}f=oc(a)|0;if((f|0)!=0){e=ob(a,f,d)|0;return e|0}f=qc(a)|0;if((f|0)==10|(f|0)==0){e=oU(a,b,c,d)|0;return e|0}else{e=ob(a,f,d)|0;return e|0}return 0}function oo(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=c[a+8>>2]|0;if((f|0)==0){g=1;return g|0}g=b5[f&127](a,b,d,e)|0;return g|0}function op(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=c[a+12>>2]|0;if((f|0)==0){g=1;return g|0}g=b5[f&127](a,b,d,e)|0;return g|0}function oq(){var a=0,b=0;a=u0(8)|0;if((a|0)==0){b=0;return b|0}c[a>>2]=0;c[a+4>>2]=0;b=a;return b|0}function or(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=a|0;e=c[d>>2]|0;f=a+4|0;a=b+24|0;g=0;while(1){if(g>>>0>=e>>>0){break}if((c[(c[(c[f>>2]|0)+(g<<2)>>2]|0)+24>>2]|0)==(c[a>>2]|0)){h=1;i=3507;break}else{g=g+1|0}}if((i|0)==3507){return h|0}i=e+1|0;e=u2(c[f>>2]|0,i<<2)|0;g=e;if((e|0)==0){h=1;return h|0}c[g+(c[d>>2]<<2)>>2]=b;c[d>>2]=i;c[f>>2]=g;h=0;return h|0}function os(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=a|0;d=c[b>>2]|0;if((d|0)==0){e=0;return e|0}f=a+4|0;a=0;g=0;h=d;while(1){d=c[(c[f>>2]|0)+(a<<2)>>2]|0;i=c[d+20>>2]|0;if((i|0)==0){j=g;k=h}else{l=(b2[i&127](d,53072,58256)|0)==0?g:1;j=l;k=c[b>>2]|0}l=a+1|0;if(l>>>0<k>>>0){a=l;g=j;h=k}else{e=j;break}}return e|0}function ot(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=a+4|0;g=c[a>>2]|0;a=0;while(1){if(a>>>0>=g>>>0){h=1;i=3525;break}j=c[(c[f>>2]|0)+(a<<2)>>2]|0;if((c[j+24>>2]|0)==(b|0)){break}else{a=a+1|0}}if((i|0)==3525){return h|0}if((j|0)==0){h=1;return h|0}i=c[j+20>>2]|0;if((i|0)==0){h=1;return h|0}h=b2[i&127](j,d,(e|0)==0?58256:e)|0;return h|0}function ou(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 1}function ov(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+32|0;e=d|0;if((od(a,e,0,0,23,0)|0)!=0){f=0;i=d;return f|0}if((va(e|0,52864,7)|0)!=0){f=0;i=d;return f|0}g=nY(e,15)|0;h=nY(e,7)|0;j=nY(e,11)|0;k=nY(e,19)|0;if(k>>>0<23){f=0;i=d;return f|0}e=u0(80)|0;if((e|0)==0){f=0;i=d;return f|0}l=e;oh(l,e,0,g,h,j);n2(l,4);n4(l,b);c[e+4>>2]=76;c[e+8>>2]=32;c[e+12>>2]=34;b=e+72|0;c[b>>2]=k;c[b+4>>2]=0;c[e+68>>2]=a;f=l;i=d;return f|0}function ow(a){a=a|0;var b=0;b=c[a+64>>2]|0;av(c[b+68>>2]|0)|0;u1(b);return}function ox(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;if((e+d|0)>>>0>(c[a+28>>2]|0)>>>0){f=1;return f|0}g=c[a+64>>2]|0;a=g+72|0;h=d;d=vf(c[a>>2]|0,c[a+4>>2]|0,h<<9|0>>>23,0<<9|h>>>23)|0;h=e;f=(od(c[g+68>>2]|0,b,d,G,h<<9|0>>>23,0<<9|h>>>23)|0)!=0|0;return f|0}function oy(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((a[b+56|0]|0)!=0){g=1;return g|0}if((f+e|0)>>>0>(c[b+28>>2]|0)>>>0){g=1;return g|0}h=c[b+64>>2]|0;b=h+72|0;i=e;e=vf(c[b>>2]|0,c[b+4>>2]|0,i<<9|0>>>23,0<<9|i>>>23)|0;i=f;f=h+68|0;if((oe(c[f>>2]|0,d,e,G,i<<9|0>>>23,0<<9|i>>>23)|0)!=0){g=1;return g|0}ay(c[f>>2]|0)|0;g=0;return g|0}function oz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;do{if((b|0)==0){c=aZ(a|0,47912|0)|0;if((c|0)!=0){d=0;e=c;break}f=aZ(a|0,54312|0)|0;g=1;h=3558}else{f=aZ(a|0,54312|0)|0;g=b;h=3558}}while(0);do{if((h|0)==3558){if((f|0)==0){i=0}else{d=g;e=f;break}return i|0}}while(0);f=ov(e,d)|0;if((f|0)==0){av(e|0)|0;i=0;return i|0}else{oj(f,a);i=f;return i|0}return 0}function oA(a){a=a|0;var b=0,c=0,d=0,e=0;b=i;i=i+8|0;c=aZ(a|0,54312)|0;if((c|0)==0){d=0;i=b;return d|0}a=b|0;if((od(c,a,0,0,8,0)|0)==0){e=(va(a|0,52864,7)|0)==0|0}else{e=0}av(c|0)|0;d=e;i=b;return d|0}function oB(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+32|0;e=d|0;if((bK(e|0,1,32,a|0)|0)!=32){f=0;i=d;return f|0}if((nW(e,0)|0)!=1346981191){f=0;i=d;return f|0}if((nW(e,4)|0)!=0){f=0;i=d;return f|0}if((nW(e,28)|0)!=512){f=0;i=d;return f|0}g=nW(e,12)|0;h=nW(e,16)|0;j=nW(e,20)|0;k=nW(e,24)|0;l=u0(80)|0;if((l|0)==0){f=0;i=d;return f|0}m=l;oh(m,l,g,h,j,k);n2(m,3);n4(m,b);c[l+68>>2]=a;c[l+4>>2]=18;c[l+8>>2]=54;c[l+12>>2]=8;c[l+16>>2]=50;c[l+20>>2]=24;c[l+72>>2]=nW(e,8)|0;c[l+76>>2]=nW(e,28)|0;f=m;i=d;return f|0}function oC(a){a=a|0;var b=0;b=c[a+64>>2]|0;a=c[b+68>>2]|0;if((a|0)==0){u1(b);return}av(a|0)|0;u1(b);return}function oD(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=c[a+64>>2]|0;if((e+d|0)>>>0>(c[f+28>>2]|0)>>>0){g=1;return g|0}a=d;d=vf(c[f+72>>2]|0,0,a<<9|0>>>23,0<<9|a>>>23)|0;a=e;g=(od(c[f+68>>2]|0,b,d,G,a<<9|0>>>23,0<<9|a>>>23)|0)!=0|0;return g|0}function oE(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=c[b+64>>2]|0;if((a[b+56|0]|0)!=0){h=1;return h|0}if((f+e|0)>>>0>(c[b+28>>2]|0)>>>0){h=1;return h|0}b=e;e=vf(c[g+72>>2]|0,0,b<<9|0>>>23,0<<9|b>>>23)|0;b=f;f=g+68|0;if((oe(c[f>>2]|0,d,e,G,b<<9|0>>>23,0<<9|b>>>23)|0)!=0){h=1;return h|0}ay(c[f>>2]|0)|0;h=0;return h|0}function oF(a,b,c){a=a|0;b=b|0;c=c|0;return(aQ(b|0,44160)|0)!=0|0}function oG(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;do{if((b|0)==0){c=aZ(a|0,54304|0)|0;if((c|0)!=0){d=0;e=c;break}f=aZ(a|0,52848|0)|0;g=1;h=3610}else{f=aZ(a|0,52848|0)|0;g=b;h=3610}}while(0);do{if((h|0)==3610){if((f|0)==0){i=0}else{d=g;e=f;break}return i|0}}while(0);f=oB(e,d)|0;if((f|0)==0){av(e|0)|0;i=0;return i|0}else{oj(f,a);i=f;return i|0}return 0}function oH(a){a=a|0;var b=0,c=0,d=0,e=0;b=i;i=i+8|0;c=aZ(a|0,52848)|0;if((c|0)==0){d=0;i=b;return d|0}a=b|0;if((od(c,a,0,0,4,0)|0)==0){e=(nW(a,0)|0)==1346981191|0}else{e=0}av(c|0)|0;d=e;i=b;return d|0}function oI(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;e=i;f=u0(4280)|0;if((f|0)==0){g=0;i=e;return g|0}h=f+4276|0;c[h>>2]=b;c[f+68>>2]=0;j=f+4264|0;c[j>>2]=0;k=f+4268|0;c[k>>2]=0;l=f+4272|0;c[l>>2]=0;m=f+152|0;do{if((od(b,m,0,0,4096,0)|0)==0){if((nY(m,0)|0)!=4474193){break}n=f+4248|0;a[n]=0;o=f+72|0;c[o>>2]=nY(m,4)|0;p=f+76|0;c[p>>2]=nY(m,8)|0;r=nY(m,12)|0;c[f+80>>2]=r;s=c[o>>2]|0;t=s-1|0;if((t&s|0)!=0){break}u=c[p>>2]|0;if((u-1&u|0)!=0|(r|0)==0){break}r=f+128|0;c[r>>2]=ac(u,s)|0;s=f+136|0;c[s>>2]=t;c[s+4>>2]=0;t=nZ(m,16)|0;u=f+88|0;c[u>>2]=t;c[u+4>>2]=G;t=nZ(m,24)|0;p=f+96|0;c[p>>2]=t;c[p+4>>2]=G;p=nZ(m,32)|0;t=G;v=f+104|0;c[v>>2]=p;c[v+4>>2]=t;w=c[u>>2]&-6;y=c[u+4>>2]|0;if(!((w|0)==0&(y|0)==0)){u=c[q>>2]|0;z=40584;bN(u|0,z|0,(x=i,i=i+16|0,c[x>>2]=w,c[x+8>>2]=y,x)|0)|0;break}if(!((p|0)==0&(t|0)==0)){a[n]=1;c[v>>2]=0;c[v+4>>2]=0;n$(m,32,0,0)}v=nZ(m,40)|0;t=f+112|0;c[t>>2]=v;c[t+4>>2]=G;v=f+4256|0;c[v>>2]=0;c[v+4>>2]=0;v=nZ(m,48)|0;p=G;y=f+120|0;c[y>>2]=v;c[y+4>>2]=p;if(!((c[s>>2]&c[t>>2]|0)==0&(c[s+4>>2]&c[t+4>>2]|0)==0)){break}if(!((v&511|0)==0&(p&0|0)==0)){break}p=f+144|0;if((of(c[h>>2]|0,p)|0)!=0){break}v=c[o>>2]|0;w=vf(c[p>>2]|0,c[p+4>>2]|0,-1,-1)|0;z=vf(w,G,v,0)|0;v=G&~c[s+4>>2];c[p>>2]=z&~c[s>>2];c[p+4>>2]=v;do{if((a[n]|0)!=0&(d|0)==0){if((oe(c[h>>2]|0,m,0,0,4096,0)|0)==0){v=c[h>>2]|0;ay(v|0)|0;break}u1(f);g=0;i=e;return g|0}}while(0);n=f;oh(n,f,(c[y>>2]|0)>>>9|c[y+4>>2]<<23,0,0,0);n2(n,7);n4(n,d);c[f+4>>2]=92;c[f+8>>2]=68;c[f+12>>2]=14;v=c[r>>2]|0;p=u0(v)|0;c[j>>2]=p;do{if((p|0)!=0){s=u0(v)|0;c[k>>2]=s;if((s|0)==0){break}s=u0(c[o>>2]|0)|0;c[l>>2]=s;if((s|0)==0){break}if((od(c[h>>2]|0,p,c[t>>2]|0,c[t+4>>2]|0,v,0)|0)==0){om(n)|0;g=n;i=e;return g|0}s=c[f+64>>2]|0;z=c[s+68>>2]|0;if((z|0)!=0){oi(z)}u1(c[s+4272>>2]|0);u1(c[s+4268>>2]|0);u1(c[s+4264>>2]|0);z=c[s+4276>>2]|0;av(z|0)|0;u1(s);g=0;i=e;return g|0}}while(0);n=c[f+64>>2]|0;v=c[n+68>>2]|0;if((v|0)!=0){oi(v)}u1(c[n+4272>>2]|0);u1(c[n+4268>>2]|0);u1(c[n+4264>>2]|0);v=c[n+4276>>2]|0;av(v|0)|0;u1(n);g=0;i=e;return g|0}}while(0);u1(f);g=0;i=e;return g|0}function oJ(a){a=a|0;var b=0;b=c[a+64>>2]|0;a=c[b+68>>2]|0;if((a|0)!=0){oi(a)}u1(c[b+4272>>2]|0);u1(c[b+4268>>2]|0);u1(c[b+4264>>2]|0);av(c[b+4276>>2]|0)|0;u1(b);return}function oK(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+8|0;g=f|0;if((e+d|0)>>>0>(c[a+28>>2]|0)>>>0){h=1;i=f;return h|0}j=c[a+64>>2]|0;a=j;k=j+72|0;l=j+4276|0;if((e|0)==0){h=0;i=f;return h|0}m=j+68|0;j=d;d=e;e=b;L4535:while(1){b=(c[k>>2]|0)>>>9;n=b-((j>>>0)%(b>>>0)|0)|0;b=n>>>0>d>>>0?d:n;n=j;c[g>>2]=n<<9|0>>>23;c[g+4>>2]=0<<9|n>>>23;if((oS(a,g,0)|0)!=0){h=1;o=3678;break}n=c[g>>2]|0;p=c[g+4>>2]|0;do{if((n|0)==0&(p|0)==0){q=c[m>>2]|0;if((q|0)==0){r=b<<9;u6(e|0,0,r|0);s=r;break}if((oo(q,e,j,b)|0)!=0){h=1;o=3675;break L4535}s=b<<9}else{q=b<<9;if((od(c[l>>2]|0,e,n,p,q,0)|0)==0){s=q}else{h=1;o=3676;break L4535}}}while(0);if((d|0)==(b|0)){h=0;o=3677;break}else{j=b+j|0;d=d-b|0;e=e+s|0}}if((o|0)==3678){i=f;return h|0}else if((o|0)==3676){i=f;return h|0}else if((o|0)==3677){i=f;return h|0}else if((o|0)==3675){i=f;return h|0}return 0}function oL(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+8|0;g=f|0;if((e+d|0)>>>0>(c[a+28>>2]|0)>>>0){h=1;i=f;return h|0}j=c[a+64>>2]|0;a=j;k=j+72|0;l=j+4276|0;if((e|0)==0){h=0;i=f;return h|0}else{m=d;n=e;o=b}while(1){b=(c[k>>2]|0)>>>9;e=b-((m>>>0)%(b>>>0)|0)|0;b=e>>>0>n>>>0?n:e;e=m;c[g>>2]=e<<9|0>>>23;c[g+4>>2]=0<<9|e>>>23;if((oS(a,g,1)|0)!=0){h=1;p=3687;break}e=b<<9;if((oe(c[l>>2]|0,o,c[g>>2]|0,c[g+4>>2]|0,e,0)|0)!=0){h=1;p=3688;break}if((n|0)==(b|0)){h=0;p=3690;break}else{m=b+m|0;n=n-b|0;o=o+e|0}}if((p|0)==3690){i=f;return h|0}else if((p|0)==3688){i=f;return h|0}else if((p|0)==3687){i=f;return h|0}return 0}function oM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;do{if((b|0)==0){c=aZ(a|0,54288|0)|0;if((c|0)!=0){d=0;e=c;break}f=aZ(a|0,52808|0)|0;g=1;h=3696}else{f=aZ(a|0,52808|0)|0;g=b;h=3696}}while(0);do{if((h|0)==3696){if((f|0)==0){i=0}else{d=g;e=f;break}return i|0}}while(0);f=oI(e,d)|0;if((f|0)==0){av(e|0)|0;i=0;return i|0}else{oj(f,a);i=f;return i|0}return 0}function oN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 1}function oO(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=aZ(b|0,54288)|0;do{if((d|0)==0){if((c[a>>2]|0)==7){e=c[(c[a+64>>2]|0)+72>>2]|0}else{e=0}f=c[a+28>>2]|0;g=aZ(b|0,47880)|0;if((g|0)==0){h=0;return h|0}i=oQ(g,f,e)|0;av(g|0)|0;if((i|0)==0){break}else{h=0}return h|0}else{av(d|0)|0}}while(0);d=aZ(b|0,54288)|0;do{if((d|0)==0){e=aZ(b|0,52808)|0;if((e|0)==0){h=0}else{j=1;k=e;break}return h|0}else{j=0;k=d}}while(0);d=oI(k,j)|0;if((d|0)==0){av(k|0)|0;h=0;return h|0}oj(d,b);k=c[d+64>>2]|0;c[k+68>>2]=a;c[d+16>>2]=12;c[d+20>>2]=16;c[d+24>>2]=c[a+24>>2];j=k+152|0;e=nZ(j,16)|0;i=(c[a>>2]|0)==1;n$(j,16,(i?5:1)|e,(i?0:0)|G);i=a+60|0;e=c[i>>2]|0;if((e|0)==0){l=0}else{l=u8(e|0)|0}e=l>>>0>1024?0:l;n_(j,56,64);n_(j,60,e);if((e|0)!=0){l=k+216|0;g=c[i>>2]|0;u7(l|0,g|0,e)|0}e=k+4276|0;if((oe(c[e>>2]|0,j,0,0,4096,0)|0)==0){j=c[e>>2]|0;ay(j|0)|0}n5(d,c[a+28>>2]|0,c[a+32>>2]|0,c[a+36>>2]|0,c[a+40>>2]|0)|0;n6(d,c[a+44>>2]|0,c[a+48>>2]|0,c[a+52>>2]|0);oj(d,b);h=d;return h|0}function oP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;if((aQ(b|0,44112)|0)!=0){e=1;return e|0}b=c[a+64>>2]|0;a=b+68|0;if((c[a>>2]|0)==0){e=1;return e|0}d=b+128|0;f=c[d>>2]|0;g=f>>>3;h=b+72|0;i=(c[h>>2]|0)>>>9;do{if((g|0)==0){j=f;k=b+4276|0;l=b+4264|0}else{m=b+4264|0;n=ac(i,g)|0;o=b+136|0;p=b+4256|0;q=b+4276|0;r=b+4268|0;s=b+4272|0;t=0;u=0;L4619:while(1){v=u<<3;w=nZ(c[m>>2]|0,v)|0;x=G;if((w|0)==0&(x|0)==0){y=t+n|0}else{z=w&~c[o>>2];w=x&~c[o+4>>2];if((c[p>>2]|0)==(z|0)&(c[p+4>>2]|0)==(w|0)){A=0;B=t}else{if((od(c[q>>2]|0,c[r>>2]|0,z,w,c[d>>2]|0,0)|0)!=0){e=1;C=3755;break}c[p>>2]=z;c[p+4>>2]=w;A=0;B=t}while(1){w=nZ(c[r>>2]|0,A<<3)|0;z=G;if((w|0)==0&(z|0)==0){D=B+i|0}else{if((od(c[q>>2]|0,c[s>>2]|0,w&~c[o>>2],z&~c[o+4>>2],c[h>>2]|0,0)|0)!=0){e=1;C=3751;break L4619}z=B+i|0;w=c[a>>2]|0;x=c[w+28>>2]|0;if((op(w,c[s>>2]|0,B,z>>>0>x>>>0?x-B|0:i)|0)==0){D=z}else{e=1;C=3752;break L4619}}z=A+1|0;if(z>>>0<g>>>0){A=z;B=D}else{break}}n$(c[m>>2]|0,v,0,0);y=D}z=u+1|0;if(z>>>0<g>>>0){t=y;u=z}else{C=3745;break}}if((C|0)==3745){j=c[d>>2]|0;k=q;l=m;break}else if((C|0)==3751){return e|0}else if((C|0)==3752){return e|0}else if((C|0)==3755){return e|0}}}while(0);C=b+112|0;if((oe(c[k>>2]|0,c[l>>2]|0,c[C>>2]|0,c[C+4>>2]|0,j,0)|0)!=0){e=1;return e|0}ay(c[k>>2]|0)|0;j=vf(c[d>>2]|0,0,c[C>>2]|0,c[C+4>>2]|0)|0;C=G;d=b+144|0;c[d>>2]=j;c[d+4>>2]=C;og(c[k>>2]|0,j,C)|0;e=0;return e|0}function oQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b;b=d<<9|0>>>23;e=0<<9|d>>>23;do{if(c>>>0<4097){f=4096}else{if(c>>>0>134217727){f=134217728;break}d=(c<<1)-1|0;while(1){g=d-1&d;if((g|0)==0){f=d;break}else{d=g}}}}while(0);c=f>>>3;d=0;g=c<<1|0>>>31;h=d<<1|c>>>31;i=vp(g,h,g,h)|0;h=f;g=0;j=vp(i,G,h,g)|0;i=G;if(i>>>0<e>>>0|i>>>0==e>>>0&j>>>0<b>>>0){k=2;while(1){l=k<<1;m=vp(l,0,c,d)|0;n=G;o=vp(m,n,m,n)|0;n=vp(o,G,h,g)|0;o=G;if((o>>>0<e>>>0|o>>>0==e>>>0&n>>>0<b>>>0)&l>>>0<16){k=l}else{p=l;q=o;r=n;break}}}else{p=2;q=i;r=j}j=q>>>0<e>>>0|q>>>0==e>>>0&r>>>0<b>>>0;if(j&f>>>0<134217728){r=p;q=0;i=f;while(1){k=i<<1;g=vp(i>>>2&536870911,0,r,q)|0;h=G;d=vp(g,h,k,0)|0;c=vp(d,G,g,h)|0;h=G;g=h>>>0<e>>>0|h>>>0==e>>>0&c>>>0<b>>>0;if(g&k>>>0<134217728){i=k}else{s=k;t=g;break}}}else{s=f;t=j}if(t){u=1;return u|0}t=u0(s)|0;if((t|0)==0){u=1;return u|0}u6(t|0,0,s|0);n_(t,0,4474193);n_(t,4,s);n_(t,8,p);n_(t,12,1);n$(t,16,0,0);n$(t,24,0,0);n$(t,32,0,0);j=s;f=0;n$(t,40,j,f);n$(t,48,b,e);if((oe(a,t,0,0,j,f)|0)!=0){u1(t);u=1;return u|0}u6(t|0,0,s|0);s=p|1;p=1;while(1){if(p>>>0>=s>>>0){v=3773;break}e=vp(p,0,j,f)|0;if((oe(a,t,e,G,j,f)|0)==0){p=p+1|0}else{v=3772;break}}if((v|0)==3773){u1(t);u=0;return u|0}else if((v|0)==3772){u1(t);u=1;return u|0}return 0}function oR(a){a=a|0;var b=0,c=0,d=0,e=0;b=i;i=i+8|0;c=aZ(a|0,52808)|0;if((c|0)==0){d=0;i=b;return d|0}a=b|0;if((od(c,a,0,0,4,0)|0)==0){e=(nY(a,0)|0)==4474193|0}else{e=0}av(c|0)|0;d=e;i=b;return d|0}function oS(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0;e=a+72|0;f=c[e>>2]|0;g=ac(f>>>3,c[a+76>>2]|0)|0;h=vq(c[b>>2]|0,c[b+4>>2]|0,f,0)|0;f=G;i=g;j=0;k=vq(h,f,i,j)|0;l=k;k=vr(h,f,i,j)|0;j=k;k=a+4264|0;i=l<<3;f=nZ((c[k>>2]|0)+i|0,0)|0;h=G;m=c[b>>2]|0;n=c[b+4>>2]|0;o=a+136|0;p=c[o>>2]|0;q=c[o+4>>2]|0;r=p&m;s=q&n;if(l>>>0>=g>>>0){t=1;return t|0}if((f|0)==0&(h|0)==0){if((d|0)==0){c[b>>2]=0;c[b+4>>2]=0;t=0;return t|0}g=a+144|0;l=a+128|0;u=vf(c[l>>2]|0,0,c[g>>2]|0,c[g+4>>2]|0)|0;v=G;w=a+68|0;x=c[w>>2]|0;do{if((x|0)==0){u6(c[a+4272>>2]|0,0,c[e>>2]|0)}else{y=((p^-512)&m)>>>9|((q^511)&n)<<23;z=c[e>>2]|0;A=z>>>9;B=a+4272|0;if((A+y|0)>>>0>(c[x+28>>2]|0)>>>0){u6(c[B>>2]|0,0,z|0);z=c[w>>2]|0;C=(c[z+28>>2]|0)-y|0;D=z}else{C=A;D=x}if((oo(D,c[B>>2]|0,y,C)|0)==0){break}else{t=1}return t|0}}while(0);C=a+4276|0;if((oe(c[C>>2]|0,c[a+4272>>2]|0,u,v,c[e>>2]|0,0)|0)!=0){t=1;return t|0}D=a+4268|0;u6(c[D>>2]|0,0,c[l>>2]|0);n$((c[D>>2]|0)+(j<<3)|0,0,u,v);x=c[g>>2]|0;w=c[g+4>>2]|0;if((oe(c[C>>2]|0,c[D>>2]|0,x,w,c[l>>2]|0,0)|0)!=0){t=1;return t|0}D=c[C>>2]|0;ay(D|0)|0;D=a+4256|0;c[D>>2]=x;c[D+4>>2]=w;n$((c[k>>2]|0)+i|0,0,c[g>>2]|0,c[g+4>>2]|0);i=a+112|0;if((oe(c[C>>2]|0,c[k>>2]|0,c[i>>2]|0,c[i+4>>2]|0,c[l>>2]|0,0)|0)!=0){t=1;return t|0}l=c[C>>2]|0;ay(l|0)|0;l=vf(u,v,r|0,s&0)|0;c[b>>2]=l;c[b+4>>2]=G;l=vf(c[e>>2]|0,0,u,v)|0;c[g>>2]=l;c[g+4>>2]=G;t=0;return t|0}g=f&~p;p=h&~q;q=a+4256|0;do{if((c[q>>2]|0)==(g|0)&(c[q+4>>2]|0)==(p|0)){E=a+4268|0}else{h=a+4268|0;if((od(c[a+4276>>2]|0,c[h>>2]|0,g,p,c[a+128>>2]|0,0)|0)==0){c[q>>2]=g;c[q+4>>2]=p;E=h;break}else{t=1;return t|0}}}while(0);h=j<<3;j=nZ((c[E>>2]|0)+h|0,0)|0;f=G;if(!((j|0)==0&(f|0)==0)){l=vf(j&~c[o>>2],f&~c[o+4>>2],r|0,s&0)|0;c[b>>2]=l;c[b+4>>2]=G;t=0;return t|0}if((d|0)==0){c[b>>2]=0;c[b+4>>2]=0;t=0;return t|0}d=a+68|0;l=c[d>>2]|0;do{if((l|0)==0){u6(c[a+4272>>2]|0,0,c[e>>2]|0)}else{f=((c[o>>2]^-512)&c[b>>2])>>>9|((c[o+4>>2]^511)&c[b+4>>2])<<23;j=c[e>>2]|0;v=j>>>9;u=a+4272|0;if((f+v|0)>>>0>(c[l+28>>2]|0)>>>0){u6(c[u>>2]|0,0,j|0);j=c[d>>2]|0;F=(c[j+28>>2]|0)-f|0;H=j}else{F=v;H=l}if((oo(H,c[u>>2]|0,f,F)|0)==0){break}else{t=1}return t|0}}while(0);F=a+4276|0;H=a+144|0;if((oe(c[F>>2]|0,c[a+4272>>2]|0,c[H>>2]|0,c[H+4>>2]|0,c[e>>2]|0,0)|0)!=0){t=1;return t|0}n$((c[E>>2]|0)+h|0,0,c[H>>2]|0,c[H+4>>2]|0);if((oe(c[F>>2]|0,c[E>>2]|0,g,p,c[a+128>>2]|0,0)|0)!=0){t=1;return t|0}ay(c[F>>2]|0)|0;c[q>>2]=g;c[q+4>>2]=p;p=vf(c[H>>2]|0,c[H+4>>2]|0,r|0,s&0)|0;c[b>>2]=p;c[b+4>>2]=G;b=vf(c[H>>2]|0,c[H+4>>2]|0,c[e>>2]|0,0)|0;c[H>>2]=b;c[H+4>>2]=G;t=0;return t|0}function oT(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+8|0;g=f|0;if((of(a,g)|0)!=0){h=0;i=f;return h|0}j=c[g>>2]|0;k=c[g+4>>2]|0;if(!(k>>>0>d>>>0|k>>>0==d>>>0&j>>>0>b>>>0)){h=0;i=f;return h|0}l=vg(j,k,b,d)|0;k=G;j=l>>>9|k<<23;l=k>>>9|0<<23;c[g>>2]=j;c[g+4>>2]=l;if((j|0)==0&(l|0)==0){h=0;i=f;return h|0}l=u0(80)|0;if((l|0)==0){h=0;i=f;return h|0}g=l;oh(g,l,j,0,0,0);n2(g,1);n4(g,e);c[l+4>>2]=32;c[l+8>>2]=72;c[l+12>>2]=36;e=l+72|0;c[e>>2]=b;c[e+4>>2]=d;c[l+68>>2]=a;om(g)|0;h=g;i=f;return h|0}function oU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;do{if((d|0)==0){e=aZ(a|0,54280|0)|0;if((e|0)!=0){f=0;g=e;break}h=aZ(a|0,52760|0)|0;i=1;j=3846}else{h=aZ(a|0,52760|0)|0;i=d;j=3846}}while(0);do{if((j|0)==3846){if((h|0)==0){k=0}else{f=i;g=h;break}return k|0}}while(0);h=oT(g,b,c,f)|0;if((h|0)==0){av(g|0)|0;k=0;return k|0}else{oj(h,a);k=h;return k|0}return 0}function oV(a){a=a|0;var b=0;b=c[a+64>>2]|0;av(c[b+68>>2]|0)|0;u1(b);return}function oW(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;if((e+d|0)>>>0>(c[a+28>>2]|0)>>>0){f=1;return f|0}g=c[a+64>>2]|0;a=g+72|0;h=d;d=vf(c[a>>2]|0,c[a+4>>2]|0,h<<9|0>>>23,0<<9|h>>>23)|0;h=e;f=(od(c[g+68>>2]|0,b,d,G,h<<9|0>>>23,0<<9|h>>>23)|0)!=0|0;return f|0}function oX(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((a[b+56|0]|0)!=0){g=1;return g|0}if((f+e|0)>>>0>(c[b+28>>2]|0)>>>0){g=1;return g|0}h=c[b+64>>2]|0;b=h+72|0;i=e;e=vf(c[b>>2]|0,c[b+4>>2]|0,i<<9|0>>>23,0<<9|i>>>23)|0;i=f;f=h+68|0;if((oe(c[f>>2]|0,d,e,G,i<<9|0>>>23,0<<9|i>>>23)|0)!=0){g=1;return g|0}ay(c[f>>2]|0)|0;g=0;return g|0}function oY(a,b,c){a=a|0;b=b|0;c=c|0;return c|0}function oZ(a,b){a=a|0;b=b|0;c[b>>2]=1792;return 0}function o_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return 0}function o$(b,d){b=b|0;d=d|0;var e=0,f=0;e=c[b>>2]|0;b=d&1;f=d&2;d=e+348|0;do{if(!((c[e+80>>2]|0)!=0|(f|0)==0|(b|0)==0)){if((a[d]|0)!=0){if((a[e+349|0]|0)!=0){break}}c[e+352>>2]=0;c[e+356>>2]=0;c[e+372>>2]=0;c[e+384>>2]=0;c[e+84>>2]=1;c[e+88>>2]=0;a[e+92|0]=77}}while(0);a[d]=b&255;a[e+349|0]=f>>>1&255;return 0}function o0(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=i;f=b+28|0;g=c[f>>2]|0;h=b+48|0;if((g|0)==0){c[f>>2]=0;c[h>>2]=0;i=e;return}j=b+52|0;k=(c[h>>2]|0)!=0?48032:47208;l=g;g=b+32|0;while(1){b=l>>>0<16;m=b?l:16;n=d[g]|0;bN(c[j>>2]|0,48456,(x=i,i=i+16|0,c[x>>2]=k,c[x+8>>2]=n,x)|0)|0;if(m>>>0>1){n=1;do{bN(c[j>>2]|0,46776,(x=i,i=i+8|0,c[x>>2]=d[g+n|0]|0,x)|0)|0;n=n+1|0;}while(n>>>0<m>>>0)}n=c[j>>2]|0;if(b){o=m;p=n;while(1){aC(46344,3,1,p|0)|0;q=o+1|0;r=c[j>>2]|0;if(q>>>0<16){o=q;p=r}else{s=r;break}}}else{s=n}aC(46032,2,1,s|0)|0;if((m|0)!=0){p=0;do{o=a[g+p|0]|0;aB(((o-32&255)>94?46:o&255)|0,c[j>>2]|0)|0;p=p+1|0;}while(p>>>0<m>>>0)}aB(10,c[j>>2]|0)|0;if((l|0)==(m|0)){break}else{l=l-m|0;g=g+m|0}}ay(c[j>>2]|0)|0;c[f>>2]=0;c[h>>2]=0;i=e;return}function o1(a,b){a=a|0;b=b|0;c[a>>2]=b;u6(a+4|0,0,28);u6(a+48|0,0,32);return}function o2(a){a=a|0;var b=0,d=0;if((a|0)==0){return}b=a+52|0;if((c[b>>2]|0)!=0){o0(a);d=c[b>>2]|0;av(d|0)|0}d=c[a+56>>2]|0;if((d|0)==0){return}b0[d&127](a);return}function o3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a|0)==0){e=0;return e|0}f=c[a+60>>2]|0;if((f|0)==0){e=0;return e|0}g=b2[f&127](a,b,d)|0;if((c[a+52>>2]|0)==0|(g|0)==0){e=g;return e|0}d=a+28|0;f=a+48|0;do{if((c[d>>2]|0)!=0){if((c[f>>2]|0)==0){break}o0(a)}}while(0);h=b;b=g;while(1){i=c[d>>2]|0;j=16-i|0;k=b>>>0<j>>>0?b:j;j=a+32+i|0;u7(j|0,h|0,k)|0;j=k+(c[d>>2]|0)|0;c[d>>2]=j;c[f>>2]=0;if(j>>>0>15){o0(a)}if((b|0)==(k|0)){e=g;break}h=h+k|0;b=b-k|0}return e|0}function o4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;if((a|0)==0){e=d;return e|0}f=c[a+64>>2]|0;if((f|0)==0){e=d;return e|0}g=b2[f&127](a,b,d)|0;if((c[a+52>>2]|0)==0|(g|0)==0){e=g;return e|0}d=a+28|0;f=a+48|0;do{if((c[d>>2]|0)!=0){if((c[f>>2]|0)==1){break}o0(a)}}while(0);h=b;b=g;while(1){i=c[d>>2]|0;j=16-i|0;k=b>>>0<j>>>0?b:j;j=a+32+i|0;u7(j|0,h|0,k)|0;j=k+(c[d>>2]|0)|0;c[d>>2]=j;c[f>>2]=1;if(j>>>0>15){o0(a)}if((b|0)==(k|0)){e=g;break}h=h+k|0;b=b-k|0}return e|0}function o5(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=a+52|0;if((c[f>>2]|0)==0|(b|0)==(d|0)){i=e;return}o0(a);a=d^b;if((a&512|0)!=0){b=c[f>>2]|0;g=d>>>9&1;bN(b|0,48936,(x=i,i=i+16|0,c[x>>2]=52664,c[x+8>>2]=g,x)|0)|0}if((a&1|0)!=0){g=c[f>>2]|0;b=d&1;bN(g|0,48936,(x=i,i=i+16|0,c[x>>2]=51976,c[x+8>>2]=b,x)|0)|0}if((a&2|0)!=0){b=c[f>>2]|0;g=d>>>1&1;bN(b|0,48936,(x=i,i=i+16|0,c[x>>2]=51368,c[x+8>>2]=g,x)|0)|0}if((a&256|0)!=0){g=c[f>>2]|0;b=d>>>8&1;bN(g|0,48936,(x=i,i=i+16|0,c[x>>2]=50528,c[x+8>>2]=b,x)|0)|0}if((a&1024|0)!=0){b=c[f>>2]|0;g=d>>>10&1;bN(b|0,48936,(x=i,i=i+16|0,c[x>>2]=49928,c[x+8>>2]=g,x)|0)|0}if((a&2048|0)==0){i=e;return}bN(c[f>>2]|0,48936,(x=i,i=i+16|0,c[x>>2]=49416,c[x+8>>2]=d>>>11&1,x)|0)|0;i=e;return}function o6(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;do{if((a|0)==0){d=1}else{e=a+24|0;f=c[e>>2]|0;if((f|0)==(b|0)){d=0;break}o5(a,f,b);c[e>>2]=b;e=c[a+72>>2]|0;if((e|0)==0){d=0;break}d=b6[e&63](a,b)|0}}while(0);return d|0}function o7(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;if((a|0)==0){h=1;i=g;return h|0}j=a+4|0;k=a+8|0;do{if((c[j>>2]|0)==(b|0)){if((c[k>>2]|0)!=(d|0)){break}if((c[a+12>>2]|0)!=(e|0)){break}if((c[a+16>>2]|0)==(f|0)){h=0}else{break}i=g;return h|0}}while(0);c[j>>2]=b;c[k>>2]=d;l=a+12|0;c[l>>2]=e;m=a+16|0;c[m>>2]=f;n=a+52|0;if((c[n>>2]|0)!=0){o0(a);o=c[l>>2]|0;if((o|0)==0){p=30616}else if((o|0)==1){p=29664}else if((o|0)==2){p=55448}else{p=54632}o=c[n>>2]|0;l=c[j>>2]|0;j=c[k>>2]|0;k=c[m>>2]|0;bN(o|0,53392,(x=i,i=i+32|0,c[x>>2]=l,c[x+8>>2]=j,c[x+16>>2]=p,c[x+24>>2]=k,x)|0)|0;k=c[n>>2]|0;ay(k|0)|0}k=c[a+76>>2]|0;if((k|0)==0){h=1;i=g;return h|0}h=b7[k&7](a,b,d,e,f)|0;i=g;return h|0}function o8(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=c[7122]|0;if((d|0)==0){e=0;return e|0}else{f=0;g=d}while(1){d=a[g]|0;L4933:do{if(d<<24>>24==0){h=b;i=3977}else{j=b;k=g;l=d;while(1){if(l<<24>>24!=(a[j]|0)){break}m=k+1|0;n=j+1|0;o=a[m]|0;if(o<<24>>24==0){h=n;i=3977;break L4933}else{j=n;k=m;l=o}}if(l<<24>>24==0){h=j;i=3977}}}while(0);if((i|0)==3977){i=0;d=a[h]|0;if((d<<24>>24|0)==58|(d<<24>>24|0)==0){break}}d=f+1|0;k=c[28488+(d<<3)>>2]|0;if((k|0)==0){e=0;i=3989;break}else{f=d;g=k}}if((i|0)==3989){return e|0}i=b_[c[28492+(f<<3)>>2]&511](b)|0;if((i|0)==0){e=0;return e|0}f=rQ(b,32048)|0;if((f|0)==0){e=i;return e|0}b=i+52|0;if((c[b>>2]|0)!=0){o0(i);g=c[b>>2]|0;av(g|0)|0}c[b>>2]=aZ(f|0,34608)|0;u1(f);e=i;return e|0}function o9(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=u0(388)|0;if((d|0)==0){e=0;return e|0}f=d;g=d;o1(g,d);c[d+56>>2]=46;c[d+60>>2]=22;c[d+64>>2]=38;c[d+68>>2]=40;c[d+72>>2]=22;c[d+76>>2]=2;h=d+80|0;c[h>>2]=0;c[d+84>>2]=0;c[d+88>>2]=0;a[d+348|0]=0;a[d+349|0]=0;c[d+352>>2]=0;c[d+356>>2]=0;c[d+360>>2]=0;i=rQ(b,52432)|0;if((i|0)!=0){do{if((aQ(i|0,54216)|0)==0){j=0}else{if((aQ(i|0,47848)|0)==0){j=1;break}u1(i);u1(d);e=0;return e|0}}while(0);c[h>>2]=j;u1(i)}c[d+364>>2]=rY(b,44080,1)|0;i=rY(b,40528,1)|0;j=d+368|0;c[j>>2]=i;c[d+372>>2]=0;if((i|0)==0){c[j>>2]=1}c[d+376>>2]=rY(b,37424,1)|0;j=rY(b,34600,1)|0;b=d+380|0;c[b>>2]=j;c[d+384>>2]=0;if((j|0)==0){c[b>>2]=1}b=c[14520]|0;j=b+1|0;if(j>>>0>=8){e=g;return e|0}c[14520]=j;c[58088+(b<<2)>>2]=f;e=g;return e|0}function pa(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[a>>2]|0;a=b;d=c[14520]|0;if((d|0)==0){e=0;c[14520]=e;u1(b);return}else{f=0;g=0}while(1){h=c[58088+(g<<2)>>2]|0;if((h|0)==(a|0)){i=f}else{c[58088+(f<<2)>>2]=h;i=f+1|0}h=g+1|0;if(h>>>0<d>>>0){f=i;g=h}else{e=i;break}}c[14520]=e;u1(b);return}function pb(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=c[b>>2]|0;b=f;g=f+84|0;h=c[g>>2]|0;i=f+88|0;j=c[i>>2]|0;if((h|0)==(j|0)){do{if((c[f+352>>2]|0)==0){if((c[f+356>>2]|0)==0){k=0}else{break}return k|0}}while(0);pi(b);l=c[g>>2]|0;m=c[i>>2]|0}else{l=h;m=j}if((l|0)==(m|0)){k=0;return k|0}j=l-m&255;l=j>>>0>e>>>0?e:j;if((l|0)==0){k=0;return k|0}else{n=0;o=m}while(1){a[d+n|0]=a[f+(o+92)|0]|0;m=(c[i>>2]|0)+1&255;c[i>>2]=m;j=n+1|0;if(j>>>0<l>>>0){n=j;o=m}else{k=l;break}}return k|0}function pc(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function pd(a,b,c){a=a|0;b=b|0;c=c|0;return c|0}function pe(a,b){a=a|0;b=b|0;c[b>>2]=1792;return 0}function pf(a,b){a=a|0;b=b|0;return 0}function pg(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return 0}function ph(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function pi(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[b+80>>2]|0;if((d|0)==0){e=b+84|0;f=c[e>>2]|0;if((256-(f-(c[b+88>>2]|0)&255)|0)>>>0<3){return}g=b+352|0;h=c[g>>2]|0;if((h|0)<-127){i=-127}else{i=(h|0)>127?127:h}c[g>>2]=h-i;h=b+356|0;g=c[h>>2]|0;if((g|0)<-127){j=-127}else{j=(g|0)>127?127:g}c[h>>2]=g-j;g=c[b+360>>2]|0;a[b+92+f|0]=(i>>>6&3|j>>>4&12|g<<3&16|g<<5&32|64)&255;g=(c[e>>2]|0)+1&255;c[e>>2]=g;a[b+92+g|0]=i&63;i=(c[e>>2]|0)+1&255;c[e>>2]=i;a[b+92+i|0]=j&63;c[e>>2]=(c[e>>2]|0)+1&255;return}else if((d|0)==1){d=b+84|0;e=c[d>>2]|0;if((256-(e-(c[b+88>>2]|0)&255)|0)>>>0<5){return}j=c[b+360>>2]|0;i=j>>>1;a[b+92+e|0]=((i&1|j<<2&4|i&2)^135)&255;i=(c[d>>2]|0)+1&255;c[d>>2]=i;j=b+352|0;e=b+356|0;g=c[j>>2]|0;if((g|0)<-127){k=-127}else{k=(g|0)>127?127:g}c[j>>2]=g-k;a[b+92+i|0]=k&255;k=(c[d>>2]|0)+1&255;c[d>>2]=k;i=c[e>>2]|0;if((i|0)<-127){l=-127}else{l=(i|0)>127?127:i}c[e>>2]=i-l;a[b+92+k|0]=-l&255;l=(c[d>>2]|0)+1&255;c[d>>2]=l;k=c[j>>2]|0;if((k|0)<-127){m=-127}else{m=(k|0)>127?127:k}c[j>>2]=k-m;a[b+92+l|0]=m&255;m=(c[d>>2]|0)+1&255;c[d>>2]=m;l=c[e>>2]|0;if((l|0)<-127){n=-127}else{n=(l|0)>127?127:l}c[e>>2]=l-n;a[b+92+m|0]=-n&255;c[d>>2]=(c[d>>2]|0)+1&255;return}else{return}}function pj(a){a=a|0;var b=0,d=0;a=u0(80)|0;if((a|0)==0){b=0;return b|0}d=a;o1(d,a);c[a+56>>2]=22;c[a+60>>2]=34;c[a+64>>2]=50;c[a+68>>2]=16;c[a+72>>2]=36;c[a+76>>2]=4;b=d;return b|0}function pk(a){a=a|0;u1(c[a>>2]|0);return}function pl(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=i;d=u0(100)|0;if((d|0)==0){e=0;i=b;return e|0}f=d;o1(f,d);c[d+56>>2]=10;c[d+60>>2]=58;c[d+64>>2]=68;g=d+80|0;c[g>>2]=0;h=d+84|0;c[h>>2]=0;j=d+88|0;c[j>>2]=0;k=d+92|0;c[k>>2]=-1;l=d+96|0;c[l>>2]=-1;d=rQ(a,52344)|0;c[g>>2]=d;L5048:do{if((d|0)==0){c[h>>2]=rQ(a,54208)|0;m=rQ(a,47840)|0;c[j>>2]=m;n=c[g>>2]|0;if((n|0)!=0){o=n;p=4064;break}n=c[h>>2]|0;do{if((n|0)==0){if((m|0)!=0){q=m;break}if((aR(a|0,37416,6)|0)!=0){e=f;i=b;return e|0}c[k>>2]=0;c[l>>2]=1;e=f;i=b;return e|0}else{if((aQ(n|0,44072)|0)==0){c[k>>2]=0;r=m}else{s=bm(n|0,32768,(x=i,i=i+8|0,c[x>>2]=0,x)|0)|0;c[k>>2]=s;if((s|0)<0){break L5048}r=c[j>>2]|0}if((r|0)==0){e=f}else{q=r;break}i=b;return e|0}}while(0);if((aQ(q|0,44072)|0)==0){c[l>>2]=1;e=f;i=b;return e|0}if((aQ(q|0,40520)|0)==0){c[l>>2]=2;e=f;i=b;return e|0}else{n=bm(q|0,34305,(x=i,i=i+8|0,c[x>>2]=420,x)|0)|0;c[l>>2]=n;if((n|0)<0){break}else{e=f}i=b;return e|0}}else{o=d;p=4064}}while(0);do{if((p|0)==4064){if((aQ(o|0,44072)|0)==0){c[k>>2]=0;c[l>>2]=1;e=f;i=b;return e|0}if((aQ(o|0,40520)|0)==0){c[k>>2]=0;c[l>>2]=2;e=f;i=b;return e|0}d=bm(o|0,34306,(x=i,i=i+8|0,c[x>>2]=420,x)|0)|0;c[k>>2]=d;if((d|0)<0){break}c[l>>2]=d;e=f;i=b;return e|0}}while(0);pm(f);e=0;i=b;return e|0}function pm(a){a=a|0;var b=0,d=0;b=c[a>>2]|0;a=b+96|0;d=c[a>>2]|0;if((d|0)>2){aV(d|0)|0}d=c[b+92>>2]|0;do{if((d|0)>2){if((d|0)==(c[a>>2]|0)){break}aV(d|0)|0}}while(0);d=c[b+88>>2]|0;if((d|0)!=0){u1(d)}d=c[b+84>>2]|0;if((d|0)!=0){u1(d)}d=c[b+80>>2]|0;if((d|0)==0){u1(b);return}u1(d);u1(b);return}function pn(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+8|0;g=f|0;h=(c[a>>2]|0)+92|0;a=c[h>>2]|0;if((a|0)<0){i=f;return 0}c[g>>2]=a;b[g+4>>1]=1;if((bl(g|0,1,0)|0)<0){i=f;return 0}if((b[g+6>>1]&3)==0){i=f;return 0}else{g=aK(c[h>>2]|0,d|0,((e|0)<0?2147483647:e)|0)|0;i=f;return((g|0)>0?g:0)|0}return 0}function po(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;h=(c[a>>2]|0)+96|0;a=c[h>>2]|0;if((a|0)<0){j=e;i=f;return j|0}c[g>>2]=a;b[g+4>>1]=2;if((bl(g|0,1,0)|0)<0){j=0;i=f;return j|0}if((b[g+6>>1]&3)==0){j=0;i=f;return j|0}else{j=bS(c[h>>2]|0,d|0,((e|0)<0?2147483647:e)|0)|0;i=f;return((j|0)>0?j:0)|0}return 0}function pp(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+48|0;d=b|0;e=u0(92)|0;if((e|0)==0){f=0;i=b;return f|0}g=e;o1(g,e);c[e+56>>2]=28;c[e+60>>2]=92;c[e+64>>2]=76;h=e+84|0;c[h>>2]=0;j=e+88|0;c[j>>2]=rQ(a,52312)|0;a=bQ(32770)|0;k=e+80|0;c[k>>2]=a;do{if((a|0)>=0){if((a$(a|0)|0)!=0){break}if((bi(a|0)|0)!=0){break}l=aD(a|0)|0;m=l;if((l|0)==0){break}if((u8(m|0)|0)>>>0>255){break}l=bu(m|0)|0;c[h>>2]=l;m=c[q>>2]|0;bN(m|0,47824,(x=i,i=i+8|0,c[x>>2]=l,x)|0)|0;l=c[k>>2]|0;m=a3(l|0,1,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0)|0;if((m|0)!=-1){n=m|16384;a3(l|0,4,(x=i,i=i+8|0,c[x>>2]=n,x)|0)|0}n=c[k>>2]|0;do{if((aY(n|0,d|0)|0)==0){l=d|0;c[l>>2]=c[l>>2]&-449;l=d+12|0;c[l>>2]=c[l>>2]&-11;if((aW(n|0,0,d|0)|0)!=0){break}aF(n|0,3)|0}}while(0);n=c[j>>2]|0;if((n|0)==0){f=g;i=b;return f|0}if((a6(c[h>>2]|0,n|0)|0)==0){f=g;i=b;return f|0}n=c[q>>2]|0;l=c[h>>2]|0;m=c[j>>2]|0;bN(n|0,54168,(x=i,i=i+16|0,c[x>>2]=l,c[x+8>>2]=m,x)|0)|0;f=g;i=b;return f|0}}while(0);g=c[e>>2]|0;e=g+88|0;j=c[e>>2]|0;if((j|0)!=0){bW(j|0)|0;u1(c[e>>2]|0)}e=c[g+84>>2]|0;if((e|0)!=0){u1(e)}e=c[g+80>>2]|0;if((e|0)>-1){aV(e|0)|0}u1(g);f=0;i=b;return f|0}function pq(a){a=a|0;var b=0,d=0;b=c[a>>2]|0;a=b+88|0;d=c[a>>2]|0;if((d|0)!=0){bW(d|0)|0;u1(c[a>>2]|0)}a=c[b+84>>2]|0;if((a|0)!=0){u1(a)}a=c[b+80>>2]|0;if((a|0)<=-1){u1(b);return}aV(a|0)|0;u1(b);return}function pr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=c[(c[a>>2]|0)+80>>2]|0;if((e|0)<0){return 0}else{a=aK(e|0,b|0,((d|0)<0?2147483647:d)|0)|0;return((a|0)>0?a:0)|0}return 0}function ps(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=c[(c[a>>2]|0)+80>>2]|0;if((e|0)<0){return d|0}else{a=bS(e|0,b|0,((d|0)<0?2147483647:d)|0)|0;return((a|0)>0?a:0)|0}return 0}function pt(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=u0(92)|0;if((b|0)==0){d=0;return d|0}e=b;o1(e,b);c[b+56>>2]=82;c[b+60>>2]=8;c[b+64>>2]=48;f=b+88|0;c[f>>2]=0;g=b+80|0;c[g>>2]=rQ(a,52280)|0;c[b+84>>2]=rR(a,54160,1)|0;a=c[g>>2]|0;if((a|0)==0){d=e;return d|0}if((aQ(a|0,47816)|0)==0){c[f>>2]=c[o>>2];d=e;return d|0}g=aZ(a|0,44064)|0;c[f>>2]=g;if((g|0)!=0){d=e;return d|0}e=c[b>>2]|0;b=c[e+80>>2]|0;if((b|0)!=0){u1(b)}b=c[e+88>>2]|0;if(!((b|0)==0|(b|0)==(c[p>>2]|0)|(b|0)==(c[o>>2]|0)|(b|0)==(c[q>>2]|0))){av(b|0)|0}u1(e);d=0;return d|0}function pu(a){a=a|0;var b=0;b=c[a>>2]|0;a=c[b+80>>2]|0;if((a|0)!=0){u1(a)}a=c[b+88>>2]|0;if((a|0)==0|(a|0)==(c[p>>2]|0)|(a|0)==(c[o>>2]|0)|(a|0)==(c[q>>2]|0)){u1(b);return}av(a|0)|0;u1(b);return}function pv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=c[a>>2]|0;a=e+88|0;f=c[a>>2]|0;if((f|0)==0){g=d;return g|0}h=aC(b|0,1,d|0,f|0)|0;if((c[e+84>>2]|0)==0){g=h;return g|0}ay(c[a>>2]|0)|0;g=h;return g|0}function pw(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0;f=i;i=i+1168|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=f+32|0;m=f+40|0;n=f+48|0;o=f+576|0;p=f+584|0;r=f+592|0;s=f+600|0;t=f+608|0;u=f+616|0;v=f+624|0;w=f+632|0;y=f+1160|0;z=qk(e)|0;if((z|0)==0){A=0;i=f;return A|0}pD(b,0);e=b+16|0;if((a[e]|0)!=0){A=z;i=f;return A|0}B=b+12|0;C=w|0;D=w+1|0;E=w+2|0;F=n+524|0;G=n+525|0;H=n+526|0;I=w+12|0;J=0;K=0;while(1){pE(b,y,8)|0;L=c[y>>2]|0;if((L&128|0)==0){M=L;N=8;do{pE(b,y,1)|0;O=M<<1;M=c[y>>2]&1|O;N=N+1|0;}while((O&128|0)==0&N>>>0<64);P=N>>>0>63?0:M}else{P=L}O=P&255;Q=c[B>>2]|0;R=a[e]|0;do{if(J<<24>>24==-43&K<<24>>24==-86){if((P&255|0)!=150){break}pE(b,v,8)|0;S=c[v>>2]|0;if((S&128|0)==0){T=S;U=8;do{pE(b,v,1)|0;V=T<<1;T=c[v>>2]&1|V;U=U+1|0;}while((V&128|0)==0&U>>>0<64);W=U>>>0>63?0:T}else{W=S}V=a[15656+(W&255)|0]|0;X=V&255;pE(b,u,8)|0;Y=c[u>>2]|0;if((Y&128|0)==0){Z=Y;_=8;do{pE(b,u,1)|0;$=Z<<1;Z=c[u>>2]&1|$;_=_+1|0;}while(($&128|0)==0&_>>>0<64);aa=_>>>0>63?0:Z}else{aa=Y}S=a[15656+(aa&255)|0]|0;T=S&255;pE(b,t,8)|0;U=c[t>>2]|0;if((U&128|0)==0){$=U;ab=8;do{pE(b,t,1)|0;ac=$<<1;$=c[t>>2]&1|ac;ab=ab+1|0;}while((ac&128|0)==0&ab>>>0<64);ad=ab>>>0>63?0:$}else{ad=U}Y=a[15656+(ad&255)|0]|0;Z=Y&255;pE(b,s,8)|0;_=c[s>>2]|0;if((_&128|0)==0){ac=_;ae=8;do{pE(b,s,1)|0;af=ac<<1;ac=c[s>>2]&1|af;ae=ae+1|0;}while((af&128|0)==0&ae>>>0<64);ag=ae>>>0>63?0:ac}else{ag=_}U=a[15656+(ag&255)|0]|0;pE(b,r,8)|0;$=c[r>>2]|0;if(($&128|0)==0){ab=$;af=8;do{pE(b,r,1)|0;ah=ab<<1;ab=c[r>>2]&1|ah;af=af+1|0;}while((ah&128|0)==0&af>>>0<64);ai=af>>>0>63?0:ab}else{ai=$}_=a[15656+(ai&255)|0]|0;ac=Z<<6&1984|X&63;ae=Z>>>5&3;ah=qh(ac,ae,T,512)|0;if((ah|0)!=0){p5(ah,3);p4(ah,8,1);p8(ah,U);if(_<<24>>24!=(S^V^Y^U)<<24>>24){p4(ah,1,1)}a[C]=0;a[D]=0;a[E]=0;_=0;aj=0;ak=0;while(1){a[C]=ak;a[D]=aj;pE(b,p,8)|0;al=c[p>>2]|0;if((al&128|0)==0){am=al;an=8;do{pE(b,p,1)|0;ao=am<<1;am=c[p>>2]&1|ao;an=an+1|0;}while((ao&128|0)==0&an>>>0<64);ap=an>>>0>63?0:am;aq=a[C]|0}else{ap=al;aq=ak}ao=ap&255;a[E]=ao;if(aq<<24>>24==-43){if((a[D]|0)==-86){ar=4231;break}}as=_+1|0;if(as>>>0>=64){break}_=as;aj=ao;ak=a[D]|0}do{if((ar|0)==4231){ar=0;if((ap&255|0)!=173){break}pE(b,o,8)|0;ak=c[o>>2]|0;if((ak&128|0)==0){aj=ak;U=8;do{pE(b,o,1)|0;Y=aj<<1;aj=c[o>>2]&1|Y;U=U+1|0;}while((Y&128|0)==0&U>>>0<64);at=U>>>0>63?0:aj}else{at=ak}al=a[15656+(at&255)|0]|0;a[E]=al;if(al<<24>>24!=S<<24>>24|_>>>0>63){break}p4(ah,8,0);al=0;am=0;while(1){if(((al>>>0)%3|0|0)==0){pE(b,m,8)|0;an=c[m>>2]|0;if((an&128|0)==0){Y=an;V=8;do{pE(b,m,1)|0;Z=Y<<1;Y=c[m>>2]&1|Z;V=V+1|0;}while((Z&128|0)==0&V>>>0<64);au=V>>>0>63?0:Y}else{au=an}av=a[15656+(au&255)|0]<<2}else{av=am}pE(b,l,8)|0;Z=c[l>>2]|0;if((Z&128|0)==0){X=Z;$=8;do{pE(b,l,1)|0;ab=X<<1;X=c[l>>2]&1|ab;$=$+1|0;}while((ab&128|0)==0&$>>>0<64);aw=$>>>0>63?0:X}else{aw=Z}a[n+al|0]=a[15656+(aw&255)|0]&63|av&-64;an=al+1|0;if(an>>>0<524){al=an;am=av<<2}else{break}}pE(b,k,8)|0;am=c[k>>2]|0;if((am&128|0)==0){al=am;ak=8;do{pE(b,k,1)|0;aj=al<<1;al=c[k>>2]&1|aj;ak=ak+1|0;}while((aj&128|0)==0&ak>>>0<64);ax=ak>>>0>63?0:al}else{ax=am}aj=a[15656+(ax&255)|0]|0;U=aj<<2;pE(b,j,8)|0;an=c[j>>2]|0;if((an&128|0)==0){Y=an;V=8;do{pE(b,j,1)|0;ab=Y<<1;Y=c[j>>2]&1|ab;V=V+1|0;}while((ab&128|0)==0&V>>>0<64);ay=V>>>0>63?0:Y}else{ay=an}am=a[15656+(ay&255)|0]&63|U&-64;a[F]=am;pE(b,h,8)|0;al=c[h>>2]|0;if((al&128|0)==0){ak=al;ab=8;do{pE(b,h,1)|0;af=ak<<1;ak=c[h>>2]&1|af;ab=ab+1|0;}while((af&128|0)==0&ab>>>0<64);az=ab>>>0>63?0:ak}else{az=al}U=a[15656+(az&255)|0]&63|aj<<4&-64;a[G]=U;pE(b,g,8)|0;an=c[g>>2]|0;if((an&128|0)==0){Y=an;V=8;do{pE(b,g,1)|0;af=Y<<1;Y=c[g>>2]&1|af;V=V+1|0;}while((af&128|0)==0&V>>>0<64);aA=V>>>0>63?0:Y}else{aA=an}al=a[15656+(aA&255)|0]&63|aj<<6;a[H]=al;ak=0;ab=0;af=0;ao=0;while(1){if(((ak>>>0)%3|0|0)==0){aB=ao<<1&510|ao>>>7&1}else{aB=ao}as=d[n+ak|0]^aB;aC=(aB>>>8&1)+ab+(as&255)|0;a[w+ak|0]=as&255;as=ak+1|0;if(as>>>0<524){ak=as;ab=af;af=aB&255;ao=aC}else{break}}if(am<<24>>24==(aB&255)<<24>>24&U<<24>>24==(aC&255)<<24>>24){if((al&255|0)!=(af|0)){ar=4266}}else{ar=4266}if((ar|0)==4266){ar=0;ao=c[q>>2]|0;bN(ao|0,52240,(x=i,i=i+24|0,c[x>>2]=ac,c[x+8>>2]=ae,c[x+16>>2]=T,x)|0)|0;p4(ah,2,1)}ao=c[ah+24>>2]|0;u7(ao|0,I|0,512)|0;qa(ah,C,12)|0}}while(0);qm(z,ah)|0}c[B>>2]=Q;a[e]=R}}while(0);if(R<<24>>24==0){J=K;K=O}else{A=z;break}}i=f;return A|0}function px(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=qs()|0;if((d|0)==0){e=0;return e|0}f=a|0;g=c[f>>2]|0;if((g|0)==0){e=d;return e|0}h=a+4|0;a=0;i=g;L5343:while(1){g=c[(c[h>>2]|0)+(a<<2)>>2]|0;do{if((g|0)==0){j=i}else{k=g|0;if((c[k>>2]|0)==0){j=i;break}l=g+4|0;m=0;while(1){n=c[(c[l>>2]|0)+(m<<2)>>2]|0;if((n|0)==0){o=qk(m)|0}else{o=pw(n,m)|0}do{if((b[o+2>>1]|0)==0){n=m+1|0;if((n|0)!=(c[k>>2]|0)){p=4287;break}ql(o);q=n}else{p=4287}}while(0);if((p|0)==4287){p=0;if((o|0)==0){break L5343}qv(d,o,a)|0;q=m+1|0}if(q>>>0<(c[k>>2]|0)>>>0){m=q}else{break}}j=c[f>>2]|0}}while(0);g=a+1|0;if(g>>>0<j>>>0){a=g;i=j}else{e=d;p=4297;break}}if((p|0)==4297){return e|0}qt(d);e=0;return e|0}function py(a,b){a=a|0;b=b|0;return(d[a+b|0]|0)<<8|(d[a+(b+1)|0]|0)|0}function pz(a,b){a=a|0;b=b|0;return(d[a+(b+1)|0]|0)<<8|(d[a+b|0]|0)|0}function pA(a,b){a=a|0;b=b|0;return(((d[a+b|0]|0)<<8|(d[a+(b+1)|0]|0))<<8|(d[a+(b+2)|0]|0))<<8|(d[a+(b+3)|0]|0)|0}function pB(b,c,d){b=b|0;c=c|0;d=d|0;a[b+c|0]=d>>>24&255;a[b+(c+1)|0]=d>>>16&255;a[b+(c+2)|0]=d>>>8&255;a[b+(c+3)|0]=d&255;return}function pC(a,b){a=a|0;b=b|0;c[a>>2]=b;return}function pD(b,d){b=b|0;d=d|0;var e=0;e=c[b+4>>2]|0;if((e|0)==0){return}c[b+12>>2]=(d>>>0)%(e>>>0)|0;a[b+16|0]=0;return}function pE(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b+12|0;g=c[f>>2]|0;if((e|0)==0){h=0;i=b+16|0;c[d>>2]=h;j=a[i]|0;k=j<<24>>24;return k|0}l=c[b+8>>2]|0;m=b+16|0;n=c[b+4>>2]|0;b=e;e=0;o=128>>>((g&7)>>>0)&255;p=l+(g>>>3)|0;q=g;while(1){g=(a[p]&o)<<24>>24!=0|e<<1;r=(o&255)>>>1;s=q+1|0;c[f>>2]=s;if(s>>>0<n>>>0){t=r<<24>>24==0;u=t?p+1|0:p;v=t?-128:r;w=s}else{c[f>>2]=0;a[m]=1;u=l;v=-128;w=0}s=b-1|0;if((s|0)==0){h=g;i=m;break}else{b=s;e=g;o=v;p=u;q=w}}c[d>>2]=h;j=a[i]|0;k=j<<24>>24;return k|0}function pF(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b+8|0;g=b+12|0;h=c[g>>2]|0;if((e|0)==0){i=b+16|0;j=a[i]|0;k=j<<24>>24;return k|0}l=b+4|0;m=b+16|0;b=e;e=128>>>((h&7)>>>0)&255;n=(c[f>>2]|0)+(h>>>3)|0;while(1){h=b-1|0;if((1<<h&d|0)==0){o=a[n]&~e}else{o=a[n]|e}a[n]=o;p=(e&255)>>>1;q=(c[g>>2]|0)+1|0;c[g>>2]=q;if(q>>>0<(c[l>>2]|0)>>>0){q=p<<24>>24==0;r=q?n+1|0:n;s=q?-128:p}else{p=c[f>>2]|0;c[g>>2]=0;a[m]=1;r=p;s=-128}if((h|0)==0){i=m;break}else{b=h;e=s;n=r}}j=a[i]|0;k=j<<24>>24;return k|0}function pG(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;j=i;i=i+1056|0;k=j|0;l=j+528|0;pD(f,0);m=0;do{pF(f,255,10)|0;m=m+1|0;}while(m>>>0<32);m=g+2|0;if((b[m>>1]|0)!=0){n=g+4|0;g=l|0;o=l+12|0;p=k|0;q=k+524|0;r=k+525|0;s=k+526|0;t=k+1|0;u=k+522|0;v=k+523|0;w=0;do{x=c[(c[n>>2]|0)+(w<<2)>>2]|0;y=b[x+10>>1]|0;z=c[x+24>>2]|0;if((y&65535)<512){A=y&65535;u7(o|0,z|0,A)|0}else{u7(o|0,z|0,512)|0}z=p9(x)|0;A=(z|0)==0;qj(x,g,12)|0;y=b[x+4>>1]|0;B=y&65535;C=b[x+6>>1]|0;D=b[x+8>>1]|0;x=B>>>6;E=0;do{pF(f,255,10)|0;E=E+1|0;}while(E>>>0<38);E=A?h:z;F=(C&65535)<<5|x&31;pF(f,14002838,24)|0;pF(f,d[15592+(B&63)|0]|0,8)|0;G=d[15592+(D&63)|0]|0;pF(f,G,8)|0;pF(f,d[15592+(F&63)|0]|0,8)|0;pF(f,d[15592+(E&63)|0]|0,8)|0;pF(f,d[15592+((F^E^(D^y)&65535)&63)|0]|0,8)|0;pF(f,57002,16)|0;pF(f,255,10)|0;pF(f,255,10)|0;pF(f,255,10)|0;pF(f,255,10)|0;pF(f,255,10)|0;pF(f,255,10)|0;pF(f,255,10)|0;pF(f,255,10)|0;pF(f,14002861,24)|0;pF(f,G,8)|0;G=0;E=0;F=0;H=0;while(1){if(((G>>>0)%3|0|0)==0){I=H<<1&510|H>>>7&1}else{I=H}J=d[l+G|0]|0;K=(I>>>8&1)+E+J|0;a[k+G|0]=(J^I)&255;J=G+1|0;if(J>>>0<524){G=J;E=F;F=I&255;H=K}else{break}}a[q]=I&255;a[r]=K&255;a[s]=F&255;H=0;E=p;G=t;y=(d[t]|0)>>>4&12|(d[p]|0)>>>2&48;while(1){D=E+2|0;pF(f,d[15592+((d[D]|0)>>>6|y)|0]|0,8)|0;pF(f,d[15592+(a[E]&63)|0]|0,8)|0;pF(f,d[15592+(a[G]&63)|0]|0,8)|0;pF(f,d[15592+(a[D]&63)|0]|0,8)|0;D=E+3|0;B=H+3|0;x=E+4|0;L=(d[x]|0)>>>4&12|(d[D]|0)>>>2&48;if(B>>>0<522){H=B;E=D;G=x;y=L}else{break}}pF(f,d[15592+L|0]|0,8)|0;pF(f,d[15592+(a[u]&63)|0]|0,8)|0;pF(f,d[15592+(a[v]&63)|0]|0,8)|0;pF(f,d[15592+(I>>>2&48|F>>>6|K>>>4&12)|0]|0,8)|0;pF(f,d[15592+(I&63)|0]|0,8)|0;pF(f,d[15592+(K&63)|0]|0,8)|0;pF(f,d[15592+(F&63)|0]|0,8)|0;pF(f,57002,16)|0;w=w+1|0;}while(w>>>0<(e[m>>1]|0)>>>0)}if((a[f+16|0]|0)!=0){M=1;i=j;return M|0}m=c[f+4>>2]|0;w=c[f+12>>2]|0;if((m|0)==(w|0)){M=0;i=j;return M|0}K=m-w|0;while(1){w=K>>>0<10?K:10;pF(f,255>>>((10-w|0)>>>0),w)|0;if((K|0)==(w|0)){M=0;break}else{K=K-w|0}}i=j;return M|0}function pH(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=d+4|0;g=d|0;d=b[g>>1]|0;h=d&65535;i=0;while(1){if(i>>>0>=h>>>0){j=2;break}if((e[(c[(c[f>>2]|0)+(i<<2)>>2]|0)+2>>1]|0)>1){j=34;break}else{i=i+1|0}}if(d<<16>>16==0){k=0;return k|0}else{l=0}L5446:while(1){d=c[(c[f>>2]|0)+(l<<2)>>2]|0;if(l>>>0<80){m=c[15568+(l>>>4<<2)>>2]|0}else{m=0}i=d+2|0;h=d+4|0;d=0;while(1){if(d>>>0>=(e[i>>1]|0)>>>0){break}n=c[(c[h>>2]|0)+(d<<2)>>2]|0;o=pV(a,l,d,1)|0;if((o|0)==0){k=1;p=4368;break L5446}if((pO(o,m)|0)!=0){k=1;p=4371;break L5446}pC(o,5e5);if((pG(o,n,j)|0)==0){d=d+1|0}else{k=1;p=4370;break L5446}}d=l+1|0;if(d>>>0<(e[g>>1]|0)>>>0){l=d}else{k=0;p=4372;break}}if((p|0)==4371){return k|0}else if((p|0)==4372){return k|0}else if((p|0)==4370){return k|0}else if((p|0)==4368){return k|0}return 0}function pI(a){a=a|0;var b=0,c=0;b=pR()|0;do{if((b|0)==0){c=0}else{if((pH(b,a)|0)==0){c=b;break}pS(b);c=0}}while(0);return c|0}function pJ(a,b,c){a=a|0;b=b|0;c=c|0;return(bK(b|0,1,c|0,a|0)|0)!=(c|0)|0}function pK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if((bR(a|0,b|0,0)|0)!=0){e=1;return e|0}e=(bK(c|0,1,d|0,a|0)|0)!=(d|0)|0;return e|0}function pL(a,b,c){a=a|0;b=b|0;c=c|0;return(aC(b|0,1,c|0,a|0)|0)!=(c|0)|0}function pM(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;do{if((c|0)==0){d=58216;e=0;while(1){f=b+e|0;g=a[f]|0;if((g<<24>>24|0)==0){break}else if((g<<24>>24|0)==46){h=f}else{h=d}d=h;e=e+1|0}if((ve(d|0,44056)|0)==0){i=1;break}i=(ve(d|0,40512)|0)==0?2:1}else{i=c}}while(0);c=aZ(b|0,52192)|0;if((c|0)==0){j=0;return j|0}if((i|0)==1){k=pY(c)|0}else if((i|0)==2){k=qb(c)|0}else{k=0}av(c|0)|0;j=k;return j|0}function pN(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;do{if((d|0)==0){e=58216;f=0;while(1){g=b+f|0;h=a[g]|0;if((h<<24>>24|0)==0){break}else if((h<<24>>24|0)==46){i=g}else{i=e}e=i;f=f+1|0}if((ve(e|0,44056)|0)==0){j=1;break}j=(ve(e|0,40512)|0)==0?2:1}else{j=d}}while(0);d=aZ(b|0,54152)|0;if((d|0)==0){k=1;return k|0}if((j|0)==1){l=pZ(d,c)|0}else if((j|0)==2){l=p$(d,c)|0}else{l=1}av(d|0)|0;k=l;return k|0}function pO(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=b+4|0;if((c[f>>2]|0)==(e|0)){g=0;return g|0}c[b+12>>2]=0;a[b+16|0]=0;h=b+8|0;b=c[h>>2]|0;if((e|0)==0){u1(b);c[f>>2]=0;c[h>>2]=0;g=0;return g|0}i=u2(b,(e+7|0)>>>3)|0;if((i|0)==0){g=1;return g|0}b=c[f>>2]|0;j=b>>>0>e>>>0?e:b;b=e-1|0;do{if((b|7)>>>0>=j>>>0){k=j>>>3;l=b>>>3;m=i+k|0;a[m]=(d[m]|0)&(255>>>((j&7)>>>0)^255)&255;if((k|0)==(l|0)){break}m=k+1|0;if(m>>>0<l>>>0){u6(i+m|0,0,l-1-k|0)}a[i+l|0]=0}}while(0);c[f>>2]=e;c[h>>2]=i;g=0;return g|0}function pP(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=b+4|0;f=c[e>>2]|0;if(f>>>0<=d>>>0){g=1;return g|0}if((d|0)==0){g=0;return g|0}h=(f+7|0)>>>3;i=u0(h)|0;if((i|0)==0){g=1;return g|0}u6(i|0,0,h|0);h=b+8|0;if((f|0)!=0){b=d;j=0;k=-128;l=128>>>((d&7)>>>0)&255;m=(c[h>>2]|0)+(d>>>3)|0;d=i;n=f;while(1){if((a[m]&l)<<24>>24==0){o=n}else{a[d]=a[d]|k;o=c[e>>2]|0}f=(k&255)>>>1;p=f<<24>>24==0;q=b+1|0;if(q>>>0<o>>>0){r=(l&255)>>>1;s=r<<24>>24==0;t=s?m+1|0:m;u=s?-128:r;v=q}else{t=c[h>>2]|0;u=-128;v=0}q=j+1|0;if(q>>>0<o>>>0){b=v;j=q;k=p?-128:f;l=u;m=t;d=p?d+1|0:d;n=o}else{break}}}u1(c[h>>2]|0);c[h>>2]=i;g=0;return g|0}function pQ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=a|0;f=(c[e>>2]|0)>>>0>b>>>0;do{if(f){g=c[(c[a+4>>2]|0)+(b<<2)>>2]|0;if((g|0)==0){break}else{h=g}return h|0}}while(0);if((d|0)==0){h=0;return h|0}d=u0(20)|0;g=d;if((d|0)==0){h=0;return h|0}i=d+8|0;u6(d|0,0,17);j=a+4|0;a=c[j>>2]|0;if(f){f=c[a+(b<<2)>>2]|0;if((f|0)==0){k=a}else{u1(c[f+8>>2]|0);u1(f);k=c[j>>2]|0}c[k+(b<<2)>>2]=g;h=g;return h|0}k=b+1|0;f=u2(a,k<<2)|0;a=f;if((f|0)==0){u1(c[i>>2]|0);u1(d);h=0;return h|0}d=c[e>>2]|0;if(d>>>0<b>>>0){u6(f+(d<<2)|0,0,b-d<<2|0)}c[a+(b<<2)>>2]=g;c[j>>2]=a;c[e>>2]=k;h=g;return h|0}function pR(){var a=0,b=0;a=u0(16)|0;if((a|0)==0){b=0;return b|0}u6(a|0,0,16);b=a;return b|0}function pS(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;if((a|0)==0){return}b=a|0;d=c[b>>2]|0;e=a+4|0;if((d|0)!=0){f=0;g=d;while(1){d=c[(c[e>>2]|0)+(f<<2)>>2]|0;if((d|0)==0){h=g}else{i=d|0;j=c[i>>2]|0;k=d+4|0;l=c[k>>2]|0;if((j|0)==0){m=l}else{n=0;o=l;l=j;while(1){j=c[o+(n<<2)>>2]|0;if((j|0)==0){p=l;q=o}else{u1(c[j+8>>2]|0);u1(j);p=c[i>>2]|0;q=c[k>>2]|0}j=n+1|0;if(j>>>0<p>>>0){n=j;o=q;l=p}else{m=q;break}}}u1(m);u1(d);h=c[b>>2]|0}l=f+1|0;if(l>>>0<h>>>0){f=l;g=h}else{break}}}u1(c[a+12>>2]|0);u1(c[e>>2]|0);u1(a);return}function pT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[a>>2]|0;do{if(e>>>0>b>>>0){f=c[(c[a+4>>2]|0)+(b<<2)>>2]|0;if((f|0)==0){break}else{g=f}return g|0}}while(0);if((d|0)==0){g=0;return g|0}d=u0(8)|0;if((d|0)==0){g=0;return g|0}b=d;f=d;c[f>>2]=0;h=d+4|0;c[h>>2]=0;if((pU(a,b,e)|0)==0){g=b;return g|0}b=c[f>>2]|0;e=c[h>>2]|0;if((b|0)==0){i=e}else{a=0;j=e;e=b;while(1){b=c[j+(a<<2)>>2]|0;if((b|0)==0){k=e;l=j}else{u1(c[b+8>>2]|0);u1(b);k=c[f>>2]|0;l=c[h>>2]|0}b=a+1|0;if(b>>>0<k>>>0){a=b;j=l;e=k}else{i=l;break}}}u1(i);u1(d);g=0;return g|0}function pU(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=a|0;f=a+4|0;a=c[f>>2]|0;if((c[e>>2]|0)>>>0<=d>>>0){g=d+1|0;h=u2(a,g<<2)|0;i=h;if((h|0)==0){j=1;return j|0}k=c[e>>2]|0;if(k>>>0<d>>>0){u6(h+(k<<2)|0,0,d-k<<2|0)}c[i+(d<<2)>>2]=b;c[f>>2]=i;c[e>>2]=g;if((g|0)==0){j=0;return j|0}else{l=g}while(1){g=l-1|0;if((c[i+(g<<2)>>2]|0)!=0){j=0;m=4522;break}c[e>>2]=g;if((g|0)==0){j=0;m=4520;break}else{l=g}}if((m|0)==4520){return j|0}else if((m|0)==4522){return j|0}}l=c[a+(d<<2)>>2]|0;if((l|0)==0){n=a}else{a=l|0;i=c[a>>2]|0;g=l+4|0;k=c[g>>2]|0;if((i|0)==0){o=k}else{h=0;p=k;k=i;while(1){i=c[p+(h<<2)>>2]|0;if((i|0)==0){q=k;r=p}else{u1(c[i+8>>2]|0);u1(i);q=c[a>>2]|0;r=c[g>>2]|0}i=h+1|0;if(i>>>0<q>>>0){h=i;p=r;k=q}else{o=r;break}}}u1(o);u1(l);n=c[f>>2]|0}c[n+(d<<2)>>2]=b;b=c[e>>2]|0;if((b|0)==0){j=0;return j|0}d=c[f>>2]|0;f=b;while(1){b=f-1|0;if((c[d+(b<<2)>>2]|0)!=0){j=0;m=4519;break}c[e>>2]=b;if((b|0)==0){j=0;m=4517;break}else{f=b}}if((m|0)==4517){return j|0}else if((m|0)==4519){return j|0}return 0}function pV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=pT(a,b,d)|0;if((e|0)==0){f=0;return f|0}f=pQ(e,c,d)|0;return f|0}function pW(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=a+12|0;f=a+8|0;a=u2(c[e>>2]|0,(c[f>>2]|0)+d|0)|0;if((a|0)==0){g=1;return g|0}h=c[f>>2]|0;i=a+h|0;u7(i|0,b|0,d)|0;c[f>>2]=h+d;c[e>>2]=a;g=0;return g|0}function pX(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=a+12|0;u1(c[e>>2]|0);f=a+8|0;c[f>>2]=0;c[e>>2]=0;if((b|0)==0|(d|0)==0){g=0;return g|0}a=u2(0,d)|0;if((a|0)==0){g=1;return g|0}h=c[f>>2]|0;i=a+h|0;u7(i|0,b|0,d)|0;c[f>>2]=h+d;c[e>>2]=a;g=0;return g|0}function pY(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0;e=i;i=i+560|0;f=e|0;g=e+256|0;h=e+280|0;j=e+536|0;k=e+544|0;l=e+552|0;m=pR()|0;if((m|0)==0){n=0;i=e;return n|0}o=l|0;if((pJ(b,o,4)|0)!=0){n=m;i=e;return n|0}L5686:do{if((pA(o,0)|0)==1346521428){p=l+4|0;if((pJ(b,p,4)|0)!=0){break}r=pA(o,4)|0;if(!(a[6232]|0)){s=0;do{t=s<<25;u=(s&128|0)!=0?t^517762881:t;t=u<<1;v=(u|0)<0?t^517762881:t;t=v<<1;u=(v|0)<0?t^517762881:t;t=u<<1;v=(u|0)<0?t^517762881:t;t=v<<1;u=(v|0)<0?t^517762881:t;t=u<<1;v=(u|0)<0?t^517762881:t;t=v<<1;u=(v|0)<0?t^517762881:t;t=u<<1;c[56672+(s<<2)>>2]=(u|0)<0?t^517762881:t;s=s+1|0;}while(s>>>0<256);a[6232]=1}s=l+1|0;t=c[56672+(d[o]<<2)>>2]|0;u=l+2|0;v=c[56672+((d[s]^t>>>24)<<2)>>2]^t<<8;t=l+3|0;w=c[56672+((d[u]^v>>>24)<<2)>>2]^v<<8;v=c[56672+((d[t]^w>>>24)<<2)>>2]^w<<8;w=l+5|0;y=c[56672+((d[p]^v>>>24)<<2)>>2]^v<<8;v=l+6|0;z=c[56672+((d[w]^y>>>24)<<2)>>2]^y<<8;y=l+7|0;A=c[56672+((d[v]^z>>>24)<<2)>>2]^z<<8;z=c[56672+((d[y]^A>>>24)<<2)>>2]^A<<8;A=k|0;if(r>>>0<8){break}if((pJ(b,A,8)|0)!=0){break}if(!(a[6232]|0)){B=0;do{C=B<<25;D=(B&128|0)!=0?C^517762881:C;C=D<<1;E=(D|0)<0?C^517762881:C;C=E<<1;D=(E|0)<0?C^517762881:C;C=D<<1;E=(D|0)<0?C^517762881:C;C=E<<1;D=(E|0)<0?C^517762881:C;C=D<<1;E=(D|0)<0?C^517762881:C;C=E<<1;D=(E|0)<0?C^517762881:C;C=D<<1;c[56672+(B<<2)>>2]=(D|0)<0?C^517762881:C;B=B+1|0;}while(B>>>0<256);a[6232]=1}B=c[56672+((d[A]^z>>>24)<<2)>>2]^z<<8;C=c[56672+((d[k+1|0]^B>>>24)<<2)>>2]^B<<8;B=c[56672+((d[k+2|0]^C>>>24)<<2)>>2]^C<<8;C=c[56672+((d[k+3|0]^B>>>24)<<2)>>2]^B<<8;B=c[56672+((d[k+4|0]^C>>>24)<<2)>>2]^C<<8;C=c[56672+((d[k+5|0]^B>>>24)<<2)>>2]^B<<8;B=c[56672+((d[k+6|0]^C>>>24)<<2)>>2]^C<<8;C=c[56672+((d[k+7|0]^B>>>24)<<2)>>2]|0;D=pA(A,0)|0;if((D|0)!=0){E=c[q>>2]|0;bN(E|0,47760,(x=i,i=i+8|0,c[x>>2]=D,x)|0)|0;break}if((p_(b,r-8|0,C^B<<8)|0)!=0){break}B=f|0;C=h|0;D=m+8|0;E=g|0;F=0;L5705:while(1){if((pJ(b,o,8)|0)!=0){break L5686}G=(F|0)==0;H=F+4|0;I=F+8|0;L5708:while(1){J=pA(o,0)|0;K=pA(o,4)|0;if(!(a[6232]|0)){L=0;do{M=L<<25;N=(L&128|0)!=0?M^517762881:M;M=N<<1;O=(N|0)<0?M^517762881:M;M=O<<1;N=(O|0)<0?M^517762881:M;M=N<<1;O=(N|0)<0?M^517762881:M;M=O<<1;N=(O|0)<0?M^517762881:M;M=N<<1;O=(N|0)<0?M^517762881:M;M=O<<1;N=(O|0)<0?M^517762881:M;M=N<<1;c[56672+(L<<2)>>2]=(N|0)<0?M^517762881:M;L=L+1|0;}while(L>>>0<256);a[6232]=1}L=c[56672+(d[o]<<2)>>2]|0;M=c[56672+((d[s]^L>>>24)<<2)>>2]^L<<8;L=c[56672+((d[u]^M>>>24)<<2)>>2]^M<<8;M=c[56672+((d[t]^L>>>24)<<2)>>2]^L<<8;L=c[56672+((d[p]^M>>>24)<<2)>>2]^M<<8;M=c[56672+((d[w]^L>>>24)<<2)>>2]^L<<8;L=c[56672+((d[v]^M>>>24)<<2)>>2]^M<<8;P=c[56672+((d[y]^L>>>24)<<2)>>2]^L<<8;do{if((J|0)==1413830740){if((K|0)==0){if((pJ(b,B,4)|0)!=0){break L5686}if((pA(B,0)|0)==(P|0)){break}else{Q=4565;break L5705}}R=u0(K)|0;if((R|0)==0){break L5686}if((pJ(b,R,K)|0)!=0){Q=4568;break L5705}if(a[6232]|0){S=K;T=P;U=R}else{L=0;do{M=L<<25;N=(L&128|0)!=0?M^517762881:M;M=N<<1;O=(N|0)<0?M^517762881:M;M=O<<1;N=(O|0)<0?M^517762881:M;M=N<<1;O=(N|0)<0?M^517762881:M;M=O<<1;N=(O|0)<0?M^517762881:M;M=N<<1;O=(N|0)<0?M^517762881:M;M=O<<1;N=(O|0)<0?M^517762881:M;M=N<<1;c[56672+(L<<2)>>2]=(N|0)<0?M^517762881:M;L=L+1|0;}while(L>>>0<256);a[6232]=1;S=K;T=P;U=R}while(1){V=c[56672+((d[U]^T>>>24)<<2)>>2]^T<<8;L=S-1|0;if((L|0)==0){W=0;break}else{S=L;T=V;U=U+1|0}}while(1){L=a[R+W|0]|0;if(!((L<<24>>24|0)==13|(L<<24>>24|0)==10|(L<<24>>24|0)==0)){X=W;break}L=W+1|0;if(L>>>0<K>>>0){W=L}else{X=L;break}}L5733:do{if(X>>>0<K>>>0){L=K;while(1){M=L-1|0;N=a[R+M|0]|0;if((N<<24>>24|0)==0){Y=L+1|0}else if((N<<24>>24|0)==13|(N<<24>>24|0)==10){Y=M}else{Z=L;break L5733}if(Y>>>0>X>>>0){L=Y}else{Z=Y;break}}}else{Z=K}}while(0);if((X|0)==(Z|0)){if((pJ(b,C,4)|0)!=0){break L5686}if((pA(C,0)|0)==(V|0)){break}else{Q=4583;break L5705}}if(X>>>0<Z>>>0){L=X;M=X;while(1){N=a[R+L|0]|0;do{if(N<<24>>24==13){O=L+1|0;if(O>>>0<Z>>>0){if((a[R+O|0]|0)==10){_=M;$=O;break}}a[R+M|0]=10;_=M+1|0;$=L}else{a[R+M|0]=N;_=M+1|0;$=L}}while(0);N=$+1|0;if(N>>>0<Z>>>0){L=N;M=_}else{aa=_;break}}}else{aa=X}if((c[D>>2]|0)!=0){a[j]=10;if((pW(m,j,1)|0)!=0){break L5686}}M=(pW(m,R+X|0,aa-X|0)|0)==0;u1(R);if(!M){break L5686}if((pJ(b,C,4)|0)!=0){break L5686}if((pA(C,0)|0)!=(V|0)){Q=4595;break L5705}}else if((J|0)==1414676811){break L5708}else if((J|0)==1145132097){if(G){break L5686}M=((c[H>>2]|0)+7|0)>>>3;L=M>>>0<K>>>0?K:M;if((pJ(b,c[I>>2]|0,L)|0)!=0){break L5686}M=c[I>>2]|0;if(!(a[6232]|0)){N=0;do{O=N<<25;ab=(N&128|0)!=0?O^517762881:O;O=ab<<1;ac=(ab|0)<0?O^517762881:O;O=ac<<1;ab=(ac|0)<0?O^517762881:O;O=ab<<1;ac=(ab|0)<0?O^517762881:O;O=ac<<1;ab=(ac|0)<0?O^517762881:O;O=ab<<1;ac=(ab|0)<0?O^517762881:O;O=ac<<1;ab=(ac|0)<0?O^517762881:O;O=ab<<1;c[56672+(N<<2)>>2]=(ab|0)<0?O^517762881:O;N=N+1|0;}while(N>>>0<256);a[6232]=1}if((L|0)==0){ad=P}else{N=L;O=P;ab=M;while(1){ac=c[56672+((d[ab]^O>>>24)<<2)>>2]^O<<8;ae=N-1|0;if((ae|0)==0){ad=ac;break}else{N=ae;O=ac;ab=ab+1|0}}}if((p_(b,K-L|0,ad)|0)!=0){break L5686}}else if((J|0)==1162757152){Q=4615;break L5705}else{if((p_(b,K,P)|0)!=0){break L5686}}}while(0);if((pJ(b,o,8)|0)!=0){break L5686}}if(K>>>0<20){break L5686}if((pJ(b,E,20)|0)!=0){break L5686}if(a[6232]|0){af=20;ag=P;ah=E}else{I=0;do{H=I<<25;G=(I&128|0)!=0?H^517762881:H;H=G<<1;J=(G|0)<0?H^517762881:H;H=J<<1;G=(J|0)<0?H^517762881:H;H=G<<1;J=(G|0)<0?H^517762881:H;H=J<<1;G=(J|0)<0?H^517762881:H;H=G<<1;J=(G|0)<0?H^517762881:H;H=J<<1;G=(J|0)<0?H^517762881:H;H=G<<1;c[56672+(I<<2)>>2]=(G|0)<0?H^517762881:H;I=I+1|0;}while(I>>>0<256);a[6232]=1;af=20;ag=P;ah=E}while(1){ai=c[56672+((d[ah]^ag>>>24)<<2)>>2]^ag<<8;I=af-1|0;if((I|0)==0){break}else{af=I;ag=ai;ah=ah+1|0}}I=pA(E,0)|0;H=pA(E,4)|0;G=pA(E,8)|0;J=pA(E,12)|0;ab=pV(m,I,H,1)|0;if((ab|0)==0){break L5686}if((pO(ab,G)|0)!=0){break L5686}pC(ab,J);F=(p_(b,K-20|0,ai)|0)==0?ab:0;if((F|0)==0){break L5686}}if((Q|0)==4565){F=c[q>>2]|0;aC(54064,16,1,F|0)|0;break}else if((Q|0)==4568){u1(R);break}else if((Q|0)==4583){aC(54064,16,1,c[q>>2]|0)|0;break}else if((Q|0)==4595){aC(54064,16,1,c[q>>2]|0)|0;break}else if((Q|0)==4615){if((p_(b,K,P)|0)==0){n=m}else{break}i=e;return n|0}}}while(0);pS(m);n=0;i=e;return n|0}function pZ(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;f=i;i=i+56|0;g=f|0;h=f+16|0;j=f+24|0;k=j|0;pB(k,0,1346521428);pB(k,4,8);pB(k,8,0);pB(k,12,0);if(a[6232]|0){l=16;m=0;n=k}else{o=0;do{p=o<<25;q=(o&128|0)!=0?p^517762881:p;p=q<<1;r=(q|0)<0?p^517762881:p;p=r<<1;q=(r|0)<0?p^517762881:p;p=q<<1;r=(q|0)<0?p^517762881:p;p=r<<1;q=(r|0)<0?p^517762881:p;p=q<<1;r=(q|0)<0?p^517762881:p;p=r<<1;q=(r|0)<0?p^517762881:p;p=q<<1;c[56672+(o<<2)>>2]=(q|0)<0?p^517762881:p;o=o+1|0;}while(o>>>0<256);a[6232]=1;l=16;m=0;n=k}while(1){s=c[56672+((d[n]^m>>>24)<<2)>>2]^m<<8;o=l-1|0;if((o|0)==0){break}else{l=o;m=s;n=n+1|0}}pB(k,16,s);if((pL(b,k,20)|0)!=0){t=1;i=f;return t|0}s=h|0;n=c[e+8>>2]|0;L5806:do{if((n|0)!=0){m=u0(n+2|0)|0;if((m|0)==0){t=1;i=f;return t|0}l=c[e+12>>2]|0;a[m]=10;o=0;while(1){p=a[l+o|0]|0;if(!((p<<24>>24|0)==13|(p<<24>>24|0)==10|(p<<24>>24|0)==0)){u=o;break}p=o+1|0;if(p>>>0<n>>>0){o=p}else{u=p;break}}do{if(u>>>0<n>>>0){o=1;p=u;while(1){q=a[l+p|0]|0;do{if(q<<24>>24==13){r=p+1|0;if(r>>>0<n>>>0){if((a[l+r|0]|0)==10){v=r;w=o;break}}a[m+o|0]=10;v=p;w=o+1|0}else{a[m+o|0]=q;v=p;w=o+1|0}}while(0);q=v+1|0;if(q>>>0<n>>>0){o=w;p=q}else{break}}L5826:do{if(w>>>0>1){p=w;while(1){o=p-1|0;q=a[m+o|0]|0;if(!((q<<24>>24|0)==10|(q<<24>>24|0)==0)){x=p;break L5826}if(o>>>0>1){p=o}else{x=o;break}}}else{x=w}}while(0);if((x|0)==1){break}p=x+1|0;a[m+x|0]=10;pB(s,0,1413830740);pB(s,4,p);if(!(a[6232]|0)){o=0;do{q=o<<25;r=(o&128|0)!=0?q^517762881:q;q=r<<1;y=(r|0)<0?q^517762881:q;q=y<<1;r=(y|0)<0?q^517762881:q;q=r<<1;y=(r|0)<0?q^517762881:q;q=y<<1;r=(y|0)<0?q^517762881:q;q=r<<1;y=(r|0)<0?q^517762881:q;q=y<<1;r=(y|0)<0?q^517762881:q;q=r<<1;c[56672+(o<<2)>>2]=(r|0)<0?q^517762881:q;o=o+1|0;}while(o>>>0<256);a[6232]=1}o=c[56672+(d[s]<<2)>>2]|0;q=c[56672+((d[h+1|0]^o>>>24)<<2)>>2]^o<<8;o=c[56672+((d[h+2|0]^q>>>24)<<2)>>2]^q<<8;q=c[56672+((d[h+3|0]^o>>>24)<<2)>>2]^o<<8;o=c[56672+((d[h+4|0]^q>>>24)<<2)>>2]^q<<8;q=c[56672+((d[h+5|0]^o>>>24)<<2)>>2]^o<<8;o=c[56672+((d[h+6|0]^q>>>24)<<2)>>2]^q<<8;q=c[56672+((d[h+7|0]^o>>>24)<<2)>>2]^o<<8;if((pL(b,s,8)|0)!=0){t=1;i=f;return t|0}if(!(a[6232]|0)){o=0;do{r=o<<25;y=(o&128|0)!=0?r^517762881:r;r=y<<1;z=(y|0)<0?r^517762881:r;r=z<<1;y=(z|0)<0?r^517762881:r;r=y<<1;z=(y|0)<0?r^517762881:r;r=z<<1;y=(z|0)<0?r^517762881:r;r=y<<1;z=(y|0)<0?r^517762881:r;r=z<<1;y=(z|0)<0?r^517762881:r;r=y<<1;c[56672+(o<<2)>>2]=(y|0)<0?r^517762881:r;o=o+1|0;}while(o>>>0<256);a[6232]=1}if((p|0)==0){A=q}else{o=p;r=q;y=m;while(1){z=c[56672+((d[y]^r>>>24)<<2)>>2]^r<<8;B=o-1|0;if((B|0)==0){A=z;break}else{o=B;r=z;y=y+1|0}}}if((pL(b,m,p)|0)!=0){t=1;i=f;return t|0}pB(s,0,A);if((pL(b,s,4)|0)==0){break L5806}else{t=1}i=f;return t|0}}while(0);u1(m)}}while(0);s=e|0;A=c[s>>2]|0;L5855:do{if((A|0)!=0){h=e+4|0;x=j+1|0;w=j+2|0;n=j+3|0;v=j+4|0;u=j+5|0;l=j+6|0;y=j+7|0;r=0;o=A;L5857:while(1){q=c[(c[h>>2]|0)+(r<<2)>>2]|0;do{if((q|0)==0){C=o}else{z=q|0;if((c[z>>2]|0)==0){C=o;break}B=q+4|0;D=0;do{E=c[(c[B>>2]|0)+(D<<2)>>2]|0;do{if((E|0)!=0){pB(k,0,1414676811);pB(k,4,20);pB(k,8,r);pB(k,12,D);F=E+4|0;pB(k,16,c[F>>2]|0);pB(k,20,c[E>>2]|0);pB(k,24,0);if(a[6232]|0){G=28;H=0;I=k}else{J=0;do{K=J<<25;L=(J&128|0)!=0?K^517762881:K;K=L<<1;M=(L|0)<0?K^517762881:K;K=M<<1;L=(M|0)<0?K^517762881:K;K=L<<1;M=(L|0)<0?K^517762881:K;K=M<<1;L=(M|0)<0?K^517762881:K;K=L<<1;M=(L|0)<0?K^517762881:K;K=M<<1;L=(M|0)<0?K^517762881:K;K=L<<1;c[56672+(J<<2)>>2]=(L|0)<0?K^517762881:K;J=J+1|0;}while(J>>>0<256);a[6232]=1;G=28;H=0;I=k}while(1){N=c[56672+((d[I]^H>>>24)<<2)>>2]^H<<8;J=G-1|0;if((J|0)==0){break}else{G=J;H=N;I=I+1|0}}pB(k,28,N);if((pL(b,k,32)|0)!=0){t=1;O=4691;break L5857}J=c[F>>2]|0;if((J|0)==0){break}K=(J+7|0)>>>3;pB(k,0,1145132097);pB(k,4,K);if(!(a[6232]|0)){J=0;do{L=J<<25;M=(J&128|0)!=0?L^517762881:L;L=M<<1;P=(M|0)<0?L^517762881:L;L=P<<1;M=(P|0)<0?L^517762881:L;L=M<<1;P=(M|0)<0?L^517762881:L;L=P<<1;M=(P|0)<0?L^517762881:L;L=M<<1;P=(M|0)<0?L^517762881:L;L=P<<1;M=(P|0)<0?L^517762881:L;L=M<<1;c[56672+(J<<2)>>2]=(M|0)<0?L^517762881:L;J=J+1|0;}while(J>>>0<256);a[6232]=1}J=c[56672+(d[k]<<2)>>2]|0;F=c[56672+((d[x]^J>>>24)<<2)>>2]^J<<8;J=c[56672+((d[w]^F>>>24)<<2)>>2]^F<<8;F=c[56672+((d[n]^J>>>24)<<2)>>2]^J<<8;J=c[56672+((d[v]^F>>>24)<<2)>>2]^F<<8;F=c[56672+((d[u]^J>>>24)<<2)>>2]^J<<8;J=c[56672+((d[l]^F>>>24)<<2)>>2]^F<<8;F=c[56672+((d[y]^J>>>24)<<2)>>2]^J<<8;if((pL(b,k,8)|0)!=0){t=1;O=4689;break L5857}J=E+8|0;L=c[J>>2]|0;if(!(a[6232]|0)){M=0;do{P=M<<25;Q=(M&128|0)!=0?P^517762881:P;P=Q<<1;R=(Q|0)<0?P^517762881:P;P=R<<1;Q=(R|0)<0?P^517762881:P;P=Q<<1;R=(Q|0)<0?P^517762881:P;P=R<<1;Q=(R|0)<0?P^517762881:P;P=Q<<1;R=(Q|0)<0?P^517762881:P;P=R<<1;Q=(R|0)<0?P^517762881:P;P=Q<<1;c[56672+(M<<2)>>2]=(Q|0)<0?P^517762881:P;M=M+1|0;}while(M>>>0<256);a[6232]=1}if((K|0)==0){S=F}else{M=K;P=F;Q=L;while(1){R=c[56672+((d[Q]^P>>>24)<<2)>>2]^P<<8;T=M-1|0;if((T|0)==0){S=R;break}else{M=T;P=R;Q=Q+1|0}}}if((pL(b,c[J>>2]|0,K)|0)!=0){t=1;O=4693;break L5857}pB(k,0,S);if((pL(b,k,4)|0)!=0){t=1;O=4694;break L5857}}}while(0);D=D+1|0;}while(D>>>0<(c[z>>2]|0)>>>0);C=c[s>>2]|0}}while(0);q=r+1|0;if(q>>>0<C>>>0){r=q;o=C}else{break L5855}}if((O|0)==4689){i=f;return t|0}else if((O|0)==4691){i=f;return t|0}else if((O|0)==4693){i=f;return t|0}else if((O|0)==4694){i=f;return t|0}}}while(0);O=g|0;pB(O,0,1162757152);pB(O,4,0);if(!(a[6232]|0)){C=0;do{s=C<<25;k=(C&128|0)!=0?s^517762881:s;s=k<<1;S=(k|0)<0?s^517762881:s;s=S<<1;k=(S|0)<0?s^517762881:s;s=k<<1;S=(k|0)<0?s^517762881:s;s=S<<1;k=(S|0)<0?s^517762881:s;s=k<<1;S=(k|0)<0?s^517762881:s;s=S<<1;k=(S|0)<0?s^517762881:s;s=k<<1;c[56672+(C<<2)>>2]=(k|0)<0?s^517762881:s;C=C+1|0;}while(C>>>0<256);a[6232]=1}C=c[56672+(d[O]<<2)>>2]|0;s=c[56672+((d[g+1|0]^C>>>24)<<2)>>2]^C<<8;C=c[56672+((d[g+2|0]^s>>>24)<<2)>>2]^s<<8;s=c[56672+((d[g+3|0]^C>>>24)<<2)>>2]^C<<8;C=c[56672+((d[g+4|0]^s>>>24)<<2)>>2]^s<<8;s=c[56672+((d[g+5|0]^C>>>24)<<2)>>2]^C<<8;C=c[56672+((d[g+6|0]^s>>>24)<<2)>>2]^s<<8;pB(O,8,c[56672+((d[g+7|0]^C>>>24)<<2)>>2]^C<<8);t=(pL(b,O,12)|0)!=0|0;i=f;return t|0}function p_(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0;g=i;i=i+256|0;h=g|0;L5907:do{if((e|0)==0){j=f}else{k=e;l=f;while(1){m=k>>>0<256?k:256;if((pJ(b,h,m)|0)!=0){n=1;break}if(!(a[6232]|0)){o=0;do{p=o<<25;r=(o&128|0)!=0?p^517762881:p;p=r<<1;s=(r|0)<0?p^517762881:p;p=s<<1;r=(s|0)<0?p^517762881:p;p=r<<1;s=(r|0)<0?p^517762881:p;p=s<<1;r=(s|0)<0?p^517762881:p;p=r<<1;s=(r|0)<0?p^517762881:p;p=s<<1;r=(s|0)<0?p^517762881:p;p=r<<1;c[56672+(o<<2)>>2]=(r|0)<0?p^517762881:p;o=o+1|0;}while(o>>>0<256);a[6232]=1}if((m|0)==0){t=l}else{o=m;p=l;r=h;while(1){s=c[56672+(((d[r]|0)^p>>>24)<<2)>>2]^p<<8;u=o-1|0;if((u|0)==0){t=s;break}else{o=u;p=s;r=r+1|0}}}if((k|0)==(m|0)){j=t;break L5907}else{k=k-m|0;l=t}}i=g;return n|0}}while(0);if((pJ(b,h,4)|0)!=0){n=1;i=g;return n|0}if((pA(h,0)|0)==(j|0)){n=0;i=g;return n|0}aC(54064,16,1,c[q>>2]|0)|0;n=1;i=g;return n|0}function p$(a,b){a=a|0;b=b|0;return 1}function p0(a,b){a=a|0;b=b|0;var d=0,e=0;d=a;do{e=d|0;d=c[e>>2]|0;}while((d|0)!=0);c[e>>2]=b;return}function p1(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;L5935:do{if((b|0)==0){d=a}else{e=a;f=b;while(1){if((e|0)==0){d=0;break L5935}g=c[e>>2]|0;h=f-1|0;if((h|0)==0){d=g;break}else{e=g;f=h}}}}while(0);return d|0}function p2(d,f){d=d|0;f=f|0;var g=0,h=0;g=d+10|0;if((b[g>>1]|0)==0){return}h=f&255;f=d+24|0;d=0;do{a[(c[f>>2]|0)+d|0]=h;d=d+1|0;}while(d>>>0<(e[g>>1]|0)>>>0);return}function p3(b){b=b|0;var d=0,f=0,g=0,h=0,i=0;d=b+24|0;f=e[b+10>>1]|0;b=1;while(1){if(b>>>0>=f>>>0){g=1;h=4730;break}i=c[d>>2]|0;if((a[i]|0)==(a[i+b|0]|0)){b=b+1|0}else{g=0;h=4731;break}}if((h|0)==4730){return g|0}else if((h|0)==4731){return g|0}return 0}function p4(a,b,d){a=a|0;b=b|0;d=d|0;if((d|0)==0){d=a+12|0;c[d>>2]=c[d>>2]&~b;return}else{d=a+12|0;c[d>>2]=c[d>>2]|b;return}}function p5(a,d){a=a|0;d=d|0;var e=0;if((a|0)==0){return}e=d&65535;d=a;do{b[d+16>>1]=e;d=c[d>>2]|0;}while((d|0)!=0);return}function p6(b,c){b=b|0;c=c|0;a[b+46|0]=1;a[b+47|0]=c;return}function p7(b){b=b|0;var c=0,f=0;if((a[b+46|0]|0)!=0){c=d[b+47|0]|0;return c|0}f=e[b+10>>1]|0;b=0;while(1){if((128<<b|0)<(f|0)){b=b+1|0}else{c=b;break}}return c|0}function p8(b,c){b=b|0;c=c|0;a[b+48|0]=1;a[b+49|0]=c;return}function p9(b){b=b|0;var c=0;if((a[b+48|0]|0)==0){c=0;return c|0}c=d[b+49|0]|0;return c|0}function qa(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0;f=e>>>0>16?16:e;b[c+28>>1]=f&65535;if((f|0)==0){return f|0}else{g=0}do{a[c+30+g|0]=a[d+g|0]|0;g=g+1|0;}while(g>>>0<f>>>0);return f|0}function qb(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=i;i=i+2048|0;g=f|0;h=f+512|0;j=f+1536|0;k=pR()|0;if((k|0)==0){l=0;i=f;return l|0}m=g|0;do{if((pK(e,0,m,512)|0)==0){if((py(m,0)|0)!=23205){break}n=(d[g+258|0]|0)+1|0;o=a[g+259|0]|0;p=o&255;q=2;while(1){if(q>>>0>=66){r=4770;break}if((a[g+q|0]|0)==0){r=4769;break}else{q=q+1|0}}if((r|0)==4769){if(q>>>0>2){r=4770}}if((r|0)==4770){s=g+2|0;t=q-2|0;pX(k,s,t)|0}if((pK(e,773,m,512)|0)==0){u=0}else{break}do{c[h+(u<<2)>>2]=(py(m,u<<1)|0)<<8;u=u+1|0;}while(u>>>0<256);if((pK(e,1285,m,512)|0)==0){v=0}else{break}do{b[j+(v<<1)>>1]=(pz(m,v<<1)|0)&65535;v=v+1|0;}while(v>>>0<256);if(n>>>0>99|(o&255)>2){pS(k);l=0;i=f;return l|0}if(o<<24>>24==0){q=0;while(1){t=q+1|0;if(t>>>0<n>>>0){q=t}else{l=k;break}}i=f;return l|0}else{w=0}L6017:while(1){q=0;o=w<<1;while(1){if(o>>>0>255){r=4788;break L6017}t=c[h+(o<<2)>>2]|0;do{if((t|0)!=0){s=b[j+(o<<1)>>1]|0;if(s<<16>>16==0){break}x=pV(k,w,q,1)|0;if((x|0)==0){r=4789;break L6017}if((pO(x,(s&65535)<<3)|0)!=0){r=4789;break L6017}pC(x,(s&65535)<8e3?25e4:5e5);if((pK(e,t,c[x+8>>2]|0,((c[x+4>>2]|0)+7|0)>>>3)|0)!=0){r=4789;break L6017}}}while(0);t=q+1|0;if(t>>>0<p>>>0){q=t;o=o+1|0}else{break}}o=w+1|0;if(o>>>0<n>>>0){w=o}else{l=k;r=4792;break}}if((r|0)==4788){pS(k);l=0;i=f;return l|0}else if((r|0)==4789){pS(k);l=0;i=f;return l|0}else if((r|0)==4792){i=f;return l|0}}}while(0);pS(k);l=0;i=f;return l|0}function qc(b){b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=58232;d=0;while(1){e=b+d|0;f=a[e]|0;if((f<<24>>24|0)==0){break}else if((f<<24>>24|0)==46){g=e}else{g=c}c=g;d=d+1|0}do{if((ve(c|0,54056)|0)==0){h=1}else{if((ve(c|0,47752)|0)==0){h=2;break}if((ve(c|0,44040)|0)==0){h=3;break}if((ve(c|0,40488)|0)==0){h=10;break}if((ve(c|0,37392)|0)==0){h=4;break}if((ve(c|0,34576)|0)==0){h=10;break}if((ve(c|0,32040)|0)==0){h=10;break}if((ve(c|0,30608)|0)==0){h=11;break}if((ve(c|0,29656)|0)==0){h=12;break}h=(ve(c|0,55440)|0)==0?13:5}}while(0);return h|0}function qd(a,b){a=a|0;b=b|0;var c=0;if((b|0)==12){c=rb(a)|0}else if((b|0)==13){c=rm(a)|0}else if((b|0)==5|(b|0)==6|(b|0)==7|(b|0)==8|(b|0)==9){c=qP(a)|0}else if((b|0)==2){c=qG(a)|0}else if((b|0)==3){c=qH(a)|0}else if((b|0)==1){c=qE(a)|0}else if((b|0)==4){c=qM(a)|0}else if((b|0)==11){c=q8(a)|0}else if((b|0)==10){c=q4(a)|0}else{c=0}return c|0}function qe(a){a=a|0;var b=0,c=0,d=0;b=aZ(a|0,54624)|0;if((b|0)==0){c=0;return c|0}do{if((qR(b)|0)==0){if((rd(b)|0)!=0){d=12;break}if((qO(b)|0)!=0){d=4;break}if((qJ(b)|0)!=0){d=3;break}d=(q6(b)|0)==0?0:10}else{d=5}}while(0);av(b|0)|0;c=d;return c|0}function qf(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((c|0)==10){d=q5(a,b)|0}else if((c|0)==6){d=qQ(a,b,0)|0}else if((c|0)==4){d=qN(a,b)|0}else if((c|0)==2){d=qA(a,b)|0}else if((c|0)==1){d=qF(a,b)|0}else if((c|0)==3){d=qI(a,b)|0}else if((c|0)==5){d=qQ(a,b,-1)|0}else if((c|0)==7){d=qQ(a,b,1)|0}else if((c|0)==8){d=qQ(a,b,2)|0}else if((c|0)==9){d=qQ(a,b,4)|0}else if((c|0)==12){d=rc(a,b)|0}else if((c|0)==13){d=rn(a,b)|0}else{d=1}return d|0}function qg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if((c|0)==0){d=qc(a)|0}else{d=c}c=aZ(a|0,53376|0)|0;if((c|0)==0){e=1;return e|0}a=qf(c,b,d)|0;av(c|0)|0;e=a;return e|0}function qh(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;h=u0(52)|0;i=h;if((h|0)==0){j=0;return j|0}c[h>>2]=0;b[h+4>>1]=d&65535;b[h+6>>1]=e&65535;b[h+8>>1]=f&65535;b[h+10>>1]=g&65535;c[h+12>>2]=0;b[h+16>>1]=2;c[h+20>>2]=0;do{if((g|0)==0){c[h+24>>2]=0}else{f=u0(g)|0;c[h+24>>2]=f;if((f|0)!=0){break}u1(h);j=0;return j|0}}while(0);b[h+28>>1]=0;a[h+46|0]=0;a[h+48|0]=0;j=i;return j|0}function qi(a){a=a|0;var b=0;if((a|0)==0){return}else{b=a}while(1){a=c[b>>2]|0;u1(c[b+24>>2]|0);u1(b);if((a|0)==0){break}else{b=a}}return}function qj(b,c,d){b=b|0;c=c|0;d=d|0;var f=0,g=0,h=0;f=e[b+28>>1]|0;g=f>>>0>d>>>0?d:f;if((g|0)!=0){h=0;do{a[c+h|0]=a[b+30+h|0]|0;h=h+1|0;}while(h>>>0<g>>>0)}if(g>>>0>=d>>>0){return g|0}h=~d;b=~f;f=h>>>0>b>>>0?h:b;u6(c+~f|0,0,f+d+1|0);return g|0}function qk(a){a=a|0;var d=0,e=0;d=u0(8)|0;if((d|0)==0){e=0;return e|0}b[d>>1]=a&65535;b[d+2>>1]=0;c[d+4>>2]=0;e=d;return e|0}function ql(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a|0)==0){return}d=a+2|0;e=b[d>>1]|0;f=a+4|0;g=c[f>>2]|0;if(e<<16>>16==0){h=g}else{i=0;j=g;g=e;while(1){e=c[j+(i<<2)>>2]|0;if((e|0)==0){k=g;l=j}else{m=e;while(1){e=c[m>>2]|0;u1(c[m+24>>2]|0);u1(m);if((e|0)==0){break}else{m=e}}k=b[d>>1]|0;l=c[f>>2]|0}m=i+1|0;if(m>>>0<(k&65535)>>>0){i=m;j=l;g=k}else{h=l;break}}}u1(h);u1(a);return}function qm(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,i=0;f=a+4|0;g=a+2|0;a=u2(c[f>>2]|0,((e[g>>1]|0)<<2)+4|0)|0;h=a;if((a|0)==0){i=1;return i|0}c[f>>2]=h;f=b[g>>1]|0;c[h+((f&65535)<<2)>>2]=d;b[g>>1]=f+1&65535;i=0;return i|0}function qn(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=b[a+2>>1]|0;h=g&65535;if(g<<16>>16==0){i=0;return i|0}if((f|0)!=0){if(h>>>0<=d>>>0){i=0;return i|0}i=c[(c[a+4>>2]|0)+(d<<2)>>2]|0;return i|0}f=a+4|0;a=0;j=d;d=g;L6162:while(1){k=c[f>>2]|0;l=d&65535;m=0;n=0;o=0;while(1){p=b[(c[k+(m<<2)>>2]|0)+8>>1]|0;do{if((p&65535)>>>0<a>>>0){q=o;r=n}else{if((o|0)==0){q=1;r=m;break}s=b[(c[k+(n<<2)>>2]|0)+8>>1]|0;if((p&65535)<(s&65535)){q=1;r=m;break}q=(p<<16>>16==s<<16>>16)+o|0;r=n}}while(0);p=m+1|0;if(p>>>0<l>>>0){m=p;n=r;o=q}else{break}}if((q|0)==0){i=0;t=4923;break}do{if(j>>>0<q>>>0){if(d<<16>>16==0){u=j;v=0;break}o=c[f>>2]|0;n=b[(c[o+(r<<2)>>2]|0)+8>>1]|0;m=j;l=0;while(1){k=c[o+(l<<2)>>2]|0;if((b[k+8>>1]|0)==n<<16>>16){if((m|0)==0){i=k;t=4920;break L6162}w=m-1|0}else{w=m}k=l+1|0;if(k>>>0<h>>>0){m=w;l=k}else{u=w;v=g;break}}}else{u=j-q|0;v=d}}while(0);a=(e[(c[(c[f>>2]|0)+(r<<2)>>2]|0)+8>>1]|0)+1|0;j=u;d=v}if((t|0)==4923){return i|0}else if((t|0)==4920){return i|0}return 0}function qo(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=a|0;g=b[f>>1]|0;if(g<<16>>16==0){return}h=a+4|0;a=0;i=g;while(1){g=c[(c[h>>2]|0)+(a<<2)>>2]|0;j=g+2|0;if((b[j>>1]|0)==0){k=i}else{l=g+4|0;g=0;do{m=c[(c[l>>2]|0)+(g<<2)>>2]|0;n=m+2|0;o=b[n>>1]|0;if(o<<16>>16==0){p=0}else{q=m+4|0;m=0;r=0;s=o;while(1){o=c[q>>2]|0;t=c[o+(m<<2)>>2]|0;if((t|0)==(d|0)){u=r;v=s}else{c[o+(r<<2)>>2]=t;u=r+1|0;v=b[n>>1]|0}t=m+1|0;if(t>>>0<(v&65535)>>>0){m=t;r=u;s=v}else{break}}p=u&65535}b[n>>1]=p;g=g+1|0;}while(g>>>0<(e[j>>1]|0)>>>0);k=b[f>>1]|0}j=a+1|0;if(j>>>0<(k&65535)>>>0){a=j;i=k}else{break}}return}function qp(a,b,d,f,g){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((e[a>>1]|0)>>>0<=b>>>0){h=0;return h|0}i=c[(c[a+4>>2]|0)+(b<<2)>>2]|0;if((i|0)==0){h=0;return h|0}if((e[i+2>>1]|0)>>>0<=d>>>0){h=0;return h|0}b=c[(c[i+4>>2]|0)+(d<<2)>>2]|0;if((b|0)==0){h=0;return h|0}if((g|0)!=0){if((e[b+2>>1]|0)>>>0<=f>>>0){h=0;return h|0}h=c[(c[b+4>>2]|0)+(f<<2)>>2]|0;return h|0}g=b+4|0;d=e[b+2>>1]|0;b=0;while(1){if(b>>>0>=d>>>0){h=0;j=4953;break}i=c[(c[g>>2]|0)+(b<<2)>>2]|0;if((e[i+8>>1]|0|0)==(f|0)){h=i;j=4959;break}else{b=b+1|0}}if((j|0)==4953){return h|0}else if((j|0)==4959){return h|0}return 0}function qq(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=b[a+2>>1]|0;g=f&65535;if((f&65535)<2){h=0;return h|0}f=u0(g<<2)|0;i=f;if((f|0)==0){h=1;return h|0}j=a+4|0;k=0;do{l=(c[j>>2]|0)+(k<<2)|0;m=c[l>>2]|0;c[l>>2]=0;L6244:do{if((k|0)==0){n=0}else{l=b[m+8>>1]|0;o=k;while(1){p=o-1|0;q=c[i+(p<<2)>>2]|0;if((l&65535)>=(e[q+8>>1]|0)){n=o;break L6244}c[i+(o<<2)>>2]=q;if((p|0)==0){n=0;break}else{o=p}}}}while(0);c[i+(n<<2)>>2]=m;k=k+1|0;}while(k>>>0<g>>>0);k=a+4|0;a=0;n=0;while(1){j=c[k>>2]|0;o=j+(a<<2)|0;if((c[o>>2]|0)==0){r=a;s=o}else{o=a;while(1){l=((o+1|0)>>>0)%(g>>>0)|0;p=j+(l<<2)|0;if((c[p>>2]|0)==0){r=l;s=p;break}else{o=l}}}c[s>>2]=c[i+(n<<2)>>2];o=n+1|0;if(o>>>0<g>>>0){a=((r+d|0)>>>0)%(g>>>0)|0;n=o}else{break}}u1(f);h=0;return h|0}function qr(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=a+2|0;e=b[d>>1]|0;f=a+4|0;a=c[f>>2]|0;if(e<<16>>16==0){g=a;h=g;u1(h);b[d>>1]=0;c[f>>2]=0;return}else{i=0;j=a;k=e}while(1){e=c[j+(i<<2)>>2]|0;if((e|0)==0){l=k;m=j}else{a=e+2|0;n=b[a>>1]|0;o=e+4|0;p=c[o>>2]|0;if(n<<16>>16==0){q=p}else{r=0;s=p;p=n;while(1){n=c[s+(r<<2)>>2]|0;if((n|0)==0){t=p;u=s}else{v=n;while(1){n=c[v>>2]|0;u1(c[v+24>>2]|0);u1(v);if((n|0)==0){break}else{v=n}}t=b[a>>1]|0;u=c[o>>2]|0}v=r+1|0;if(v>>>0<(t&65535)>>>0){r=v;s=u;p=t}else{q=u;break}}}u1(q);u1(e);l=b[d>>1]|0;m=c[f>>2]|0}p=i+1|0;if(p>>>0<(l&65535)>>>0){i=p;j=m;k=l}else{g=m;break}}h=g;u1(h);b[d>>1]=0;c[f>>2]=0;return}function qs(){var a=0,d=0;a=u0(16)|0;if((a|0)==0){d=0;return d|0}b[a>>1]=0;c[a+4>>2]=0;c[a+8>>2]=0;c[a+12>>2]=0;d=a;return d|0}function qt(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a|0)==0){return}d=a|0;e=b[d>>1]|0;f=a+4|0;g=c[f>>2]|0;if(e<<16>>16==0){h=g}else{i=0;j=g;g=e;while(1){e=c[j+(i<<2)>>2]|0;if((e|0)==0){k=g;l=j}else{qr(e);u1(e);k=b[d>>1]|0;l=c[f>>2]|0}e=i+1|0;if(e>>>0<(k&65535)>>>0){i=e;j=l;g=k}else{h=l;break}}}u1(h);b[d>>1]=0;c[f>>2]=0;u1(c[a+12>>2]|0);u1(a);return}function qu(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=a|0;e=b[d>>1]|0;f=a+4|0;g=c[f>>2]|0;if(e<<16>>16==0){h=g}else{i=0;j=g;g=e;while(1){e=c[j+(i<<2)>>2]|0;if((e|0)==0){k=g;l=j}else{qr(e);u1(e);k=b[d>>1]|0;l=c[f>>2]|0}e=i+1|0;if(e>>>0<(k&65535)>>>0){i=e;j=l;g=k}else{h=l;break}}}u1(h);b[d>>1]=0;c[f>>2]=0;f=a+12|0;u1(c[f>>2]|0);c[a+8>>2]=0;c[f>>2]=0;return}function qv(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=a|0;h=e[g>>1]|0;i=a+4|0;a=c[i>>2]|0;L6303:do{if(h>>>0>f>>>0){j=a}else{k=h;l=a;while(1){m=u2(l,(k<<2)+4|0)|0;if((m|0)==0){n=1;o=5021;break}p=m;c[i>>2]=p;m=b[g>>1]|0;q=u0(8)|0;if((q|0)==0){n=1;o=5024;break}b[q>>1]=m;b[q+2>>1]=0;c[q+4>>2]=0;c[p+((m&65535)<<2)>>2]=q;q=m+1&65535;b[g>>1]=q;m=q&65535;if(m>>>0>f>>>0){j=p;break L6303}else{k=m;l=p}}if((o|0)==5021){return n|0}else if((o|0)==5024){return n|0}}}while(0);o=c[j+(f<<2)>>2]|0;if((o|0)==0){n=1;return n|0}f=o+4|0;j=o+2|0;o=u2(c[f>>2]|0,((e[j>>1]|0)<<2)+4|0)|0;if((o|0)==0){n=1;return n|0}g=o;c[f>>2]=g;f=b[j>>1]|0;do{if((d|0)==0){o=u0(8)|0;if((o|0)==0){n=1;return n|0}else{b[o>>1]=f;b[o+2>>1]=0;c[o+4>>2]=0;r=o;break}}else{r=d}}while(0);c[g+((f&65535)<<2)>>2]=r;b[j>>1]=f+1&65535;n=0;return n|0}function qw(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0;h=qx(a,f,g,1)|0;if((h|0)==0){i=1;return i|0}g=h+4|0;f=h+2|0;h=u2(c[g>>2]|0,((e[f>>1]|0)<<2)+4|0)|0;a=h;if((h|0)==0){i=1;return i|0}c[g>>2]=a;g=b[f>>1]|0;c[a+((g&65535)<<2)>>2]=d;b[f>>1]=g+1&65535;i=0;return i|0}function qx(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=a|0;i=e[h>>1]|0;L6334:do{if(i>>>0>d>>>0){j=c[a+4>>2]|0}else{if((g|0)==0){k=0;return k|0}l=a+4|0;m=i;n=c[l>>2]|0;while(1){o=u2(n,(m<<2)+4|0)|0;if((o|0)==0){k=0;p=5057;break}q=o;c[l>>2]=q;o=b[h>>1]|0;r=u0(8)|0;if((r|0)==0){k=0;p=5054;break}b[r>>1]=o;b[r+2>>1]=0;c[r+4>>2]=0;c[q+((o&65535)<<2)>>2]=r;r=o+1&65535;b[h>>1]=r;o=r&65535;if(o>>>0>d>>>0){j=q;break L6334}else{m=o;n=q}}if((p|0)==5054){return k|0}else if((p|0)==5057){return k|0}}}while(0);h=c[j+(d<<2)>>2]|0;if((h|0)==0){k=0;return k|0}d=h+2|0;j=e[d>>1]|0;if(j>>>0>f>>>0){k=c[(c[h+4>>2]|0)+(f<<2)>>2]|0;return k|0}if((g|0)==0){k=0;return k|0}g=h+4|0;h=j;j=c[g>>2]|0;while(1){i=u2(j,(h<<2)+4|0)|0;if((i|0)==0){k=0;p=5050;break}s=i;c[g>>2]=s;i=b[d>>1]|0;a=u0(8)|0;if((a|0)==0){k=0;p=5055;break}b[a>>1]=i;b[a+2>>1]=0;c[a+4>>2]=0;c[s+((i&65535)<<2)>>2]=a;a=i+1&65535;b[d>>1]=a;i=a&65535;if(i>>>0>f>>>0){p=5047;break}else{h=i;j=s}}if((p|0)==5047){k=c[s+(f<<2)>>2]|0;return k|0}else if((p|0)==5055){return k|0}else if((p|0)==5050){return k|0}return 0}function qy(a,d,f,g,h){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;i=b[a>>1]|0;if(i<<16>>16==0){j=1;return j|0}k=c[a+4>>2]|0;a=0;l=d;L6371:while(1){d=c[k+(a<<2)>>2]|0;m=b[d+2>>1]|0;if(m<<16>>16==0){n=l}else{o=c[d+4>>2]|0;p=0;q=l;while(1){r=c[o+(p<<2)>>2]|0;s=r+2|0;d=e[s>>1]|0;if(q>>>0<d>>>0){break L6371}t=q-d|0;d=p+1|0;if(d>>>0<(m&65535)>>>0){p=d;q=t}else{n=t;break}}}m=a+1|0;if(m>>>0<(i&65535)>>>0){a=m;l=n}else{j=1;u=5070;break}}if((u|0)==5070){return j|0}n=qn(r,q,0)|0;if((n|0)==0){j=1;return j|0}c[f>>2]=a;c[g>>2]=p;c[h>>2]=0;p=r+4|0;if((b[s>>1]|0)==0){j=1;return j|0}else{v=0;w=0}while(1){if((c[(c[p>>2]|0)+(v<<2)>>2]|0)==(n|0)){j=0;u=5072;break}r=w+1|0;c[h>>2]=r;g=v+1|0;if(g>>>0<(e[s>>1]|0)>>>0){v=g;w=r}else{j=1;u=5073;break}}if((u|0)==5072){return j|0}else if((u|0)==5073){return j|0}return 0}function qz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=a+12|0;f=a+8|0;a=u2(c[e>>2]|0,(c[f>>2]|0)+d|0)|0;if((a|0)==0){g=1;return g|0}h=c[f>>2]|0;i=a+h|0;u7(i|0,b|0,d)|0;c[f>>2]=h+d;c[e>>2]=a;g=0;return g|0}function qA(a,b){a=a|0;b=b|0;return 1}function qB(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[a>>1]|0;if(d<<16>>16==0){e=0;return e|0}f=c[a+4>>2]|0;a=d&65535;d=0;g=0;while(1){h=c[f+(d<<2)>>2]|0;i=b[h+2>>1]|0;if(i<<16>>16==0){j=g}else{k=c[h+4>>2]|0;h=i&65535;i=0;l=g;while(1){m=c[k+(i<<2)>>2]|0;n=b[m+2>>1]|0;if(n<<16>>16==0){o=l}else{p=c[m+4>>2]|0;m=n&65535;n=0;q=l;while(1){r=c[p+(n<<2)>>2]|0;if((r|0)==0){s=q}else{t=q;u=r;while(1){r=t+1|0;v=c[u>>2]|0;if((v|0)==0){s=r;break}else{t=r;u=v}}}u=n+1|0;if(u>>>0<m>>>0){n=u;q=s}else{o=s;break}}}q=i+1|0;if(q>>>0<h>>>0){i=q;l=o}else{j=o;break}}}l=d+1|0;if(l>>>0<a>>>0){d=l;g=j}else{e=j;break}}return e|0}function qC(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=a+12|0;u1(c[e>>2]|0);f=a+8|0;c[f>>2]=0;c[e>>2]=0;if((b|0)==0|(d|0)==0){g=0;return g|0}a=u2(0,d)|0;if((a|0)==0){g=1;return g|0}h=c[f>>2]|0;i=a+h|0;u7(i|0,b|0,d)|0;c[f>>2]=h+d;c[e>>2]=a;g=0;return g|0}function qD(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b+8|0;e=c[d>>2]|0;f=b+12|0;b=c[f>>2]|0;g=0;while(1){if(g>>>0>=e>>>0){h=0;break}if((a[b+g|0]|0)==10){g=g+1|0}else{i=0;j=g;k=5106;break}}if((k|0)==5106){while(1){k=0;g=a[b+j|0]|0;do{if((g<<24>>24|0)==13){l=i+1|0;a[b+i|0]=10;m=j+1|0;if(m>>>0>=e>>>0){n=j;o=l;break}n=(a[b+m|0]|0)==10?m:j;o=l}else if((g<<24>>24|0)==0){a[b+i|0]=10;n=j;o=i+1|0}else{a[b+i|0]=g;n=j;o=i+1|0}}while(0);g=n+1|0;if(g>>>0<e>>>0){i=o;j=g;k=5106}else{h=o;break}}}while(1){if((h|0)==0){k=5115;break}o=h-1|0;if((a[b+o|0]|0)==10){h=o}else{k=5114;break}}if((k|0)==5114){c[d>>2]=h;return}else if((k|0)==5115){c[d>>2]=0;u1(c[f>>2]|0);c[f>>2]=0;return}}function qE(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;i=i+8|0;f=e|0;g=qs()|0;if((g|0)==0){h=0;i=e;return h|0}j=f|0;k=f+1|0;l=f+7|0;m=f+6|0;n=f+2|0;o=f+3|0;p=f+4|0;q=f+5|0;do{f=bK(j|0,1,8,b|0)|0;if((f|0)==0){h=g;r=5128;break}else if((f|0)!=8){break}f=a[j]|0;s=a[k]|0;t=(d[l]|0)<<8|(d[m]|0);u=qh(d[n]|0,d[o]|0,d[p]|0,t)|0;if((u|0)==0){break}p6(u,a[q]|0);if((qw(g,u,f&255,s&255)|0)!=0){r=5124;break}}while((bK(c[u+24>>2]|0,1,t|0,b|0)|0)==(t|0));if((r|0)==5124){qi(u)}else if((r|0)==5128){i=e;return h|0}qt(g);h=0;i=e;return h|0}function qF(d,f){d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;g=i;i=i+8|0;h=g|0;j=f|0;k=b[j>>1]|0;L6464:do{if(k<<16>>16!=0){l=f+4|0;m=h|0;n=h+1|0;o=h+2|0;p=h+3|0;q=h+4|0;r=h+5|0;s=h+6|0;t=h+7|0;u=0;v=k;L6466:while(1){w=c[(c[l>>2]|0)+(u<<2)>>2]|0;x=w+2|0;if((b[x>>1]|0)==0){y=v}else{z=w+4|0;w=u&255;A=0;do{B=c[(c[z>>2]|0)+(A<<2)>>2]|0;C=B+2|0;D=B+4|0;B=A&255;E=0;while(1){if(E>>>0>=(e[C>>1]|0)>>>0){break}F=c[(c[D>>2]|0)+(E<<2)>>2]|0;G=p7(F)|0;a[m]=w;a[n]=B;a[o]=b[F+4>>1]&255;a[p]=b[F+6>>1]&255;a[q]=b[F+8>>1]&255;a[r]=G&255;G=F+10|0;H=b[G>>1]|0;a[s]=H&255;a[t]=(H&65535)>>>8&255;if((aC(m|0,1,8,d|0)|0)!=8){I=1;J=5145;break L6466}H=aC(c[F+24>>2]|0,1,e[G>>1]|0,d|0)|0;if((H|0)==(e[G>>1]|0)){E=E+1|0}else{I=1;J=5144;break L6466}}A=A+1|0;}while(A>>>0<(e[x>>1]|0)>>>0);y=b[j>>1]|0}x=u+1|0;if(x>>>0<(y&65535)>>>0){u=x;v=y}else{break L6464}}if((J|0)==5144){i=g;return I|0}else if((J|0)==5145){i=g;return I|0}}}while(0);ay(d|0)|0;I=0;i=g;return I|0}function qG(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;e=i;i=i+432|0;f=e|0;g=e+8|0;h=e+400|0;j=qs()|0;if((j|0)==0){k=0;i=e;return k|0}l=h|0;L6488:do{if((rp(b,0,l,30)|0)==0){if((va(l|0,6264,16)|0)!=0){m=c[q>>2]|0;aC(34552,20,1,m|0)|0;break}m=h+16|0;n=0;while(1){if((n|0)==5){o=5154;break}if((va(m|0,c[6240+(n<<2)>>2]|0,14)|0)==0){break}else{n=n+1|0}}if((o|0)==5154){n=c[q>>2]|0;aC(32e3,34,1,n|0)|0}n=g|0;m=f|0;p=f+1|0;r=g+3|0;s=g+2|0;t=g+1|0;u=30;L6499:while(1){if((rp(b,u,m,2)|0)!=0){k=j;o=5209;break}v=d[p]<<8|d[m];if((v|0)==0){k=j;o=5207;break}w=u+2|0;if((rp(b,v+w|0,m,2)|0)!=0){break L6488}y=d[p]<<8|d[m];z=v+4|0;if(v>>>0>=387){A=z+u|0;B=0;C=387;while(1){if((rp(b,B+w|0,n,387)|0)!=0){break L6488}D=a[s]|0;E=D&255;if(D<<24>>24!=0){if((D&255)>24){break L6488}D=qx(j,d[n]|0,d[t]|0,1)|0;if((D|0)==0){break L6488}else{F=r;G=0}while(1){H=c[q>>2]|0;I=G+1|0;J=F+9|0;K=F+8|0;L=d[J]<<8|d[K];M=F+2|0;do{if((a[M]&-106)<<24>>24==0){if((a[F+10|0]|0)!=0){o=5172;break}if((a[F+11|0]|0)!=0){o=5172;break}if((a[F+14|0]&127)!=0){o=5172;break}if((a[F+15|0]|0)!=0){o=5172;break}N=a[F+7|0]|0;if((N&255)<7&L>>>0>5804){O=N}else{o=5172}}else{o=5172}}while(0);if((o|0)==5172){o=0;L=d[n]|0;N=d[t]|0;bN(H|0,54016,(x=i,i=i+24|0,c[x>>2]=L,c[x+8>>2]=N,c[x+16>>2]=I,x)|0)|0;N=0;do{do{if((N|0)==8){aC(47712,2,1,H|0)|0}else{if((N&3|0)!=0){break}aB(32,H|0)|0}}while(0);bN(H|0,40472,(x=i,i=i+8|0,c[x>>2]=d[F+N|0]|0,x)|0)|0;N=N+1|0;}while(N>>>0<16);aB(10,H|0)|0;ay(H|0)|0;O=a[F+7|0]|0}if((O&255)<7){P=128<<(O&255)}else{P=0}Q=qh(d[F+4|0]|0,d[F+5|0]|0,d[F+6|0]|0,P)|0;if((Q|0)==0){break L6488}p6(Q,a[F+7|0]|0);if((qm(D,Q)|0)!=0){o=5183;break L6499}N=d[J]<<8|d[K];do{if((a[F+14|0]&50)==0){L=F+3|0;if((a[L]&1)!=0){p2(Q,0);R=L;break}if((P-256|0)>>>0>3840){p2(Q,0);R=L;break}if(N>>>0<5805){p2(Q,0);R=L;break}S=N-5805|0;if((S+P|0)>>>0>y>>>0){T=c[q>>2]|0;U=d[n]|0;V=d[t]|0;bN(T|0,51480,(x=i,i=i+32|0,c[x>>2]=U,c[x+8>>2]=V,c[x+16>>2]=I,c[x+24>>2]=P,x)|0)|0;p2(Q,0);R=L;break}else{if((rp(b,A+S|0,c[Q+24>>2]|0,P)|0)==0){R=L;break}else{break L6488}}}else{p2(Q,0);R=F+3|0}}while(0);do{if((a[M]&32)!=0){if((a[R]&32)==0){p4(Q,1,1);break}else{p4(Q,2,1);break}}}while(0);M=a[R]|0;if((M&1)==0){W=M}else{p4(Q,8,1);W=a[R]|0}if((W&64)!=0){p4(Q,4,1)}if(I>>>0<E>>>0){F=F+16|0;G=I}else{break}}}E=C+387|0;if(E>>>0>v>>>0){break}else{B=C;C=E}}}C=y+z|0;if((C|0)==0){k=j;o=5210;break}else{u=C+u|0}}if((o|0)==5183){qi(Q);break}else if((o|0)==5207){i=e;return k|0}else if((o|0)==5209){i=e;return k|0}else if((o|0)==5210){i=e;return k|0}}}while(0);qt(j);k=0;i=e;return k|0}function qH(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0;g=i;i=i+152|0;h=g|0;j=g+16|0;k=g+24|0;l=qs()|0;if((l|0)==0){m=0;i=g;return m|0}n=k|0;L6577:do{if((ro(f,n,84)|0)==0){o=(re(n,82)|0)!=256;if(o|(d[n]|0)>63){break}o=rf(n,64)|0;p=rf(n,68)|0;r=rf(n,72)|0;s=rf(n,76)|0;t=a[k+81|0]|0;if((o|0)==737280){u=qL(f,l,9,j)|0}else if((o|0)==409600){u=qK(f,l,1,j,t&255)|0}else if((o|0)==1474560){u=qL(f,l,18,j)|0}else if((o|0)==819200){u=qK(f,l,2,j,t&255)|0}else{break}if((u|0)!=0){break}if((r|0)!=(c[j>>2]|0)){r=c[q>>2]|0;aC(47672,26,1,r|0)|0;break}if((p|0)==0){m=l;i=g;return m|0}r=h|0;c[j>>2]=0;t=l|0;o=b[t>>1]|0;if(o<<16>>16==0){v=p;w=0}else{x=l+4|0;y=h+1|0;z=h+2|0;A=h+3|0;B=h+4|0;C=h+5|0;D=h+6|0;E=h+7|0;F=h+8|0;G=h+9|0;H=h+10|0;I=h+11|0;J=0;K=p;p=o;o=0;while(1){L=c[(c[x>>2]|0)+(J<<2)>>2]|0;M=L+2|0;N=b[M>>1]|0;if(N<<16>>16==0){O=K;P=p;Q=o}else{R=L+4|0;L=0;S=K;T=N;N=o;while(1){U=(c[(c[R>>2]|0)+(L<<2)>>2]|0)+2|0;if((b[U>>1]|0)==0){V=S;W=T;X=N}else{Y=L|J;Z=0;_=S;$=N;while(1){aa=qp(l,J,L,Z,0)|0;if((aa|0)==0|_>>>0<12){break L6577}if((ro(f,r,12)|0)!=0){break L6577}qa(aa,r,12)|0;if((Y|Z|0)==0){ab=$}else{aa=(d[r]<<8|d[y])+$|0;ac=(aa>>>1|aa<<31)+(d[z]<<8|d[A])|0;aa=(ac>>>1|ac<<31)+(d[B]<<8|d[C])|0;ac=(aa>>>1|aa<<31)+(d[D]<<8|d[E])|0;aa=(ac>>>1|ac<<31)+(d[F]<<8|d[G])|0;ac=(aa>>>1|aa<<31)+(d[H]<<8|d[I])|0;aa=ac>>>1|ac<<31;c[j>>2]=aa;ab=aa}ad=_-12|0;aa=Z+1|0;if(aa>>>0<(e[U>>1]|0)>>>0){Z=aa;_=ad;$=ab}else{break}}V=ad;W=b[M>>1]|0;X=ab}$=L+1|0;if($>>>0<(W&65535)>>>0){L=$;S=V;T=W;N=X}else{break}}O=V;P=b[t>>1]|0;Q=X}N=J+1|0;if(N>>>0<(P&65535)>>>0){J=N;K=O;p=P;o=Q}else{v=O;w=Q;break}}}if((v|0)!=0){break}if((s|0)==(w|0)){m=l;i=g;return m|0}else{o=c[q>>2]|0;aC(43976,25,1,o|0)|0;break}}}while(0);qt(l);m=0;i=g;return m|0}
function qI(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;h=i;i=i+144|0;j=h|0;k=h+16|0;if((b[g>>1]|0)!=80){l=1;i=h;return l|0}m=c[g+4>>2]|0;n=0;L6625:while(1){o=c[m+(n<<2)>>2]|0;if((b[o+2>>1]|0)!=1){p=0;q=5264;break}r=12-(n>>>4)|0;s=c[c[o+4>>2]>>2]|0;if((e[s+2>>1]|0)!=(r|0)){p=0;q=5264;break}o=s+4|0;s=0;while(1){if(s>>>0>=r>>>0){break}t=c[(c[o>>2]|0)+(s<<2)>>2]|0;if((b[t+10>>1]|0)!=512){p=0;q=5264;break L6625}if((e[t+8>>1]|0)>>>0<r>>>0){s=s+1|0}else{p=0;q=5264;break L6625}}s=n+1|0;if(s>>>0<80){n=s}else{u=0;q=5257;break}}L6634:do{if((q|0)==5257){while(1){q=0;n=c[m+(u<<2)>>2]|0;s=b[n+2>>1]|0;if(s<<16>>16!=0){r=c[n+4>>2]|0;n=s&65535;s=0;do{o=c[r+(s<<2)>>2]|0;t=e[o+2>>1]|0;v=o+4|0;o=0;while(1){if(o>>>0>=t>>>0){break}if((b[(c[(c[v>>2]|0)+(o<<2)>>2]|0)+28>>1]|0)==0){o=o+1|0}else{w=9600;x=409600;y=2;z=0;A=1;break L6634}}s=s+1|0;}while(s>>>0<n>>>0)}n=u+1|0;if(n>>>0<80){u=n;q=5257}else{w=0;x=409600;y=2;z=0;A=1;break}}}else if((q|0)==5264){L6646:while(1){q=0;n=c[m+(p<<2)>>2]|0;if((b[n+2>>1]|0)!=2){B=0;break}s=12-(p>>>4)|0;r=c[n+4>>2]|0;n=c[r>>2]|0;if((e[n+2>>1]|0)!=(s|0)){B=0;break}o=n+4|0;n=0;while(1){if(n>>>0>=s>>>0){break}v=c[(c[o>>2]|0)+(n<<2)>>2]|0;if((b[v+10>>1]|0)!=512){B=0;break L6646}if((e[v+8>>1]|0)>>>0<s>>>0){n=n+1|0}else{B=0;break L6646}}n=c[r+4>>2]|0;if((e[n+2>>1]|0)!=(s|0)){B=0;break}o=n+4|0;n=0;while(1){if(n>>>0>=s>>>0){break}v=c[(c[o>>2]|0)+(n<<2)>>2]|0;if((b[v+10>>1]|0)!=512){B=0;break L6646}if((e[v+8>>1]|0)>>>0<s>>>0){n=n+1|0}else{B=0;break L6646}}n=p+1|0;if(n>>>0<80){p=n;q=5264}else{C=0;q=5271;break}}if((q|0)==5271){while(1){q=0;n=c[m+(C<<2)>>2]|0;s=b[n+2>>1]|0;if(s<<16>>16!=0){o=c[n+4>>2]|0;n=s&65535;s=0;do{r=c[o+(s<<2)>>2]|0;v=e[r+2>>1]|0;t=r+4|0;r=0;while(1){if(r>>>0>=v>>>0){break}if((b[(c[(c[t>>2]|0)+(r<<2)>>2]|0)+28>>1]|0)==0){r=r+1|0}else{w=19200;x=819200;y=290;z=0;A=2;break L6634}}s=s+1|0;}while(s>>>0<n>>>0)}n=C+1|0;if(n>>>0<80){C=n;q=5271}else{w=0;x=819200;y=290;z=0;A=2;break L6634}}}L6673:while(1){n=c[m+(B<<2)>>2]|0;if((b[n+2>>1]|0)!=2){D=0;break}s=c[n+4>>2]|0;n=c[s>>2]|0;if((b[n+2>>1]|0)!=9){D=0;break}o=n+4|0;n=0;while(1){if(n>>>0>=9){break}r=c[(c[o>>2]|0)+(n<<2)>>2]|0;if((b[r+10>>1]|0)!=512){D=0;break L6673}t=b[r+8>>1]|0;if(t<<16>>16==0|(t&65535)>9){D=0;break L6673}else{n=n+1|0}}n=c[s+4>>2]|0;if((b[n+2>>1]|0)!=9){D=0;break}o=n+4|0;n=0;while(1){if(n>>>0>=9){break}t=c[(c[o>>2]|0)+(n<<2)>>2]|0;if((b[t+10>>1]|0)!=512){D=0;break L6673}r=b[t+8>>1]|0;if(r<<16>>16==0|(r&65535)>9){D=0;break L6673}else{n=n+1|0}}n=B+1|0;if(n>>>0<80){B=n}else{w=0;x=737280;y=546;z=9;A=2;break L6634}}L6688:while(1){n=c[m+(D<<2)>>2]|0;if((b[n+2>>1]|0)!=2){l=1;q=5360;break}o=c[n+4>>2]|0;n=c[o>>2]|0;if((b[n+2>>1]|0)!=18){l=1;q=5361;break}s=n+4|0;n=0;while(1){if(n>>>0>=18){break}r=c[(c[s>>2]|0)+(n<<2)>>2]|0;if((b[r+10>>1]|0)!=512){l=1;q=5362;break L6688}t=b[r+8>>1]|0;if(t<<16>>16==0|(t&65535)>18){l=1;q=5363;break L6688}else{n=n+1|0}}n=c[o+4>>2]|0;if((b[n+2>>1]|0)!=18){l=1;q=5357;break}s=n+4|0;n=0;while(1){if(n>>>0>=18){break}t=c[(c[s>>2]|0)+(n<<2)>>2]|0;if((b[t+10>>1]|0)!=512){l=1;q=5358;break L6688}r=b[t+8>>1]|0;if(r<<16>>16==0|(r&65535)>18){l=1;q=5359;break L6688}else{n=n+1|0}}n=D+1|0;if(n>>>0<80){D=n}else{w=0;x=1474560;y=802;z=18;A=2;break L6634}}if((q|0)==5357){i=h;return l|0}else if((q|0)==5358){i=h;return l|0}else if((q|0)==5359){i=h;return l|0}else if((q|0)==5360){i=h;return l|0}else if((q|0)==5361){i=h;return l|0}else if((q|0)==5362){i=h;return l|0}else if((q|0)==5363){i=h;return l|0}}}while(0);D=j|0;m=(z|0)==0;B=m&1^1;C=z+1|0;z=j+1|0;p=j+2|0;u=j+3|0;n=j+4|0;s=j+5|0;o=j+6|0;r=j+7|0;t=j+8|0;v=j+9|0;E=j+10|0;F=j+11|0;j=0;G=0;H=0;L6712:while(1){if(m){I=12-(j>>>4)|0}else{I=C}J=B>>>0<I>>>0;K=0;L=G;M=H;while(1){if(J){N=K|j;O=B;P=L;Q=M;while(1){R=qp(g,j,K,O,0)|0;if((R|0)==0){l=1;q=5369;break L6712}S=(e[R+10>>1]|0)>>>1;if((S|0)==0){T=Q}else{U=Q;V=S;S=c[R+24>>2]|0;while(1){W=(d[S]<<8|d[S+1|0])+U|0;X=W>>>1|W<<31;W=V-1|0;if((W|0)==0){T=X;break}else{U=X;V=W;S=S+2|0}}}if((N|O|0)==0){Y=P}else{qj(R,D,12)|0;S=(d[D]<<8|d[z])+P|0;V=(S>>>1|S<<31)+(d[p]<<8|d[u])|0;S=(V>>>1|V<<31)+(d[n]<<8|d[s])|0;V=(S>>>1|S<<31)+(d[o]<<8|d[r])|0;S=(V>>>1|V<<31)+(d[t]<<8|d[v])|0;V=(S>>>1|S<<31)+(d[E]<<8|d[F])|0;Y=V>>>1|V<<31}V=O+1|0;if(V>>>0<I>>>0){O=V;P=Y;Q=T}else{Z=Y;_=T;break}}}else{Z=L;_=M}Q=K+1|0;if(Q>>>0<A>>>0){K=Q;L=Z;M=_}else{break}}M=j+1|0;if(M>>>0<80){j=M;G=Z;H=_}else{break}}if((q|0)==5369){i=h;return l|0}H=k|0;u6(H|0,0,128);G=qp(g,0,0,m?2:3,0)|0;do{if((G|0)==0){$=53992}else{j=c[G+24>>2]|0;T=a[j]|0;if((T<<24>>24|0)==66){$=(a[j+1|0]|0)==68?j+36|0:53992;break}else if((T<<24>>24|0)==(-46|0)){$=(a[j+1|0]|0)==-41?j+36|0:53992;break}else{$=53992;break}}}while(0);G=a[$]|0;j=(G&255)>63?63:G&255;if((j|0)!=0){G=0;do{G=G+1|0;a[k+G|0]=a[$+G|0]|0;}while(G>>>0<j>>>0)}a[H]=j&255;rh(H,64,x);rh(H,68,w);rh(H,72,_);rh(H,76,Z);rg(H,80,y);rg(H,82,256);if((rq(f,H,84)|0)!=0){l=1;i=h;return l|0}L6750:do{if(m){H=0;L6764:while(1){y=12-(H>>>4)|0;Z=0;do{_=B;while(1){if(_>>>0>=y>>>0){break}x=qp(g,H,Z,_,0)|0;if((x|0)==0){l=1;q=5367;break L6764}if((rq(f,c[x+24>>2]|0,e[x+10>>1]|0)|0)==0){_=_+1|0}else{l=1;q=5368;break L6764}}Z=Z+1|0;}while(Z>>>0<A>>>0);H=H+1|0;if(H>>>0>=80){break L6750}}if((q|0)==5367){i=h;return l|0}else if((q|0)==5368){i=h;return l|0}}else{H=0;L6751:while(1){Z=0;do{y=B;while(1){if(y>>>0>=C>>>0){break}_=qp(g,H,Z,y,0)|0;if((_|0)==0){l=1;q=5364;break L6751}if((rq(f,c[_+24>>2]|0,e[_+10>>1]|0)|0)==0){y=y+1|0}else{l=1;q=5365;break L6751}}Z=Z+1|0;}while(Z>>>0<A>>>0);H=H+1|0;if(H>>>0>=80){break L6750}}if((q|0)==5364){i=h;return l|0}else if((q|0)==5365){i=h;return l|0}}}while(0);L6778:do{if((w|0)!=0){H=0;L6779:while(1){if(m){aa=12-(H>>>4)|0}else{aa=C}Z=0;do{y=B;while(1){if(y>>>0>=aa>>>0){break}_=qp(g,H,Z,y,0)|0;if((_|0)==0){l=1;q=5370;break L6779}qj(_,D,12)|0;if((rq(f,D,12)|0)==0){y=y+1|0}else{l=1;q=5371;break L6779}}Z=Z+1|0;}while(Z>>>0<A>>>0);H=H+1|0;if(H>>>0>=80){break L6778}}if((q|0)==5370){i=h;return l|0}else if((q|0)==5371){i=h;return l|0}}}while(0);ay(f|0)|0;l=0;i=h;return l|0}function qJ(a){a=a|0;var b=0,c=0,e=0;b=i;i=i+128|0;do{if((bR(a|0,0,0)|0)==0){c=b|0;if((ro(a,c,84)|0)!=0){e=0;break}if((re(c,82)|0)!=256){e=0;break}e=(d[c]|0)<64|0}else{e=0}}while(0);i=b;return e|0}function qK(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;c[f>>2]=0;h=(e|0)==0;i=g&255;g=0;L6804:while(1){j=g>>>4;k=12-j|0;L6806:do{if(!h){if((j|0)==12){l=0;while(1){m=qx(b,g,l,0)|0;if((m|0)!=0){qq(m,2)|0}l=l+1|0;if(l>>>0>=e>>>0){break L6806}}}else{n=0}do{l=0;do{o=qh(g,n,l,512)|0;if((o|0)==0){p=1;q=5397;break L6804}p8(o,i);p5(o,3);if((qw(b,o,g,n)|0)!=0){q=5391;break L6804}m=o+24|0;if((ro(a,c[m>>2]|0,512)|0)!=0){p=1;q=5398;break L6804}r=c[f>>2]|0;s=256;t=c[m>>2]|0;while(1){m=((d[t]|0)<<8|(d[t+1|0]|0))+r|0;u=m>>>1|m<<31;m=s-1|0;if((m|0)==0){break}else{r=u;s=m;t=t+2|0}}c[f>>2]=u;l=l+1|0;}while(l>>>0<k>>>0);l=qx(b,g,n,0)|0;if((l|0)!=0){qq(l,2)|0}n=n+1|0;}while(n>>>0<e>>>0)}}while(0);k=g+1|0;if(k>>>0<80){g=k}else{p=0;q=5400;break}}if((q|0)==5400){return p|0}else if((q|0)==5391){qi(o);p=1;return p|0}else if((q|0)==5398){return p|0}else if((q|0)==5397){return p|0}return 0}function qL(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;c[f>>2]=0;g=e>>>0<14?2:32770;h=(e|0)==0;i=0;L6836:while(1){do{if(!h){j=0;do{j=j+1|0;k=qh(i,0,j,512)|0;if((k|0)==0){l=1;m=5419;break L6836}p5(k,g);if((qw(b,k,i,0)|0)!=0){n=k;m=5405;break L6836}o=k+24|0;if((ro(a,c[o>>2]|0,512)|0)!=0){l=1;m=5421;break L6836}k=c[f>>2]|0;p=256;q=c[o>>2]|0;while(1){o=((d[q]|0)<<8|(d[q+1|0]|0))+k|0;r=o>>>1|o<<31;o=p-1|0;if((o|0)==0){break}else{k=r;p=o;q=q+2|0}}c[f>>2]=r;}while(j>>>0<e>>>0);if(h){break}else{s=0}do{s=s+1|0;j=qh(i,1,s,512)|0;if((j|0)==0){l=1;m=5420;break L6836}p5(j,g);if((qw(b,j,i,1)|0)!=0){n=j;m=5405;break L6836}q=j+24|0;if((ro(a,c[q>>2]|0,512)|0)!=0){l=1;m=5422;break L6836}j=c[f>>2]|0;p=256;k=c[q>>2]|0;while(1){q=((d[k]|0)<<8|(d[k+1|0]|0))+j|0;t=q>>>1|q<<31;q=p-1|0;if((q|0)==0){break}else{j=t;p=q;k=k+2|0}}c[f>>2]=t;}while(s>>>0<e>>>0)}}while(0);k=i+1|0;if(k>>>0<80){i=k}else{l=0;m=5424;break}}if((m|0)==5405){qi(n);l=1;return l|0}else if((m|0)==5422){return l|0}else if((m|0)==5420){return l|0}else if((m|0)==5421){return l|0}else if((m|0)==5424){return l|0}else if((m|0)==5419){return l|0}return 0}function qM(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;f=i;i=i+784|0;g=f|0;h=f+8|0;j=f+264|0;k=f+520|0;l=f+776|0;m=qs()|0;if((m|0)==0){n=0;i=f;return n|0}o=l|0;L6869:do{if((bK(o|0,1,4,b|0)|0)==4){if((rf(o,0)|0)!=1229800480){break}qz(m,o,4)|0;while(1){p=aT(b|0)|0;if((p|0)==26){break}else if((p|0)==(-1|0)){break L6869}a[o]=p&255;qz(m,o,1)|0}qD(m);p=h|0;q=j|0;r=k|0;s=l+1|0;t=l+2|0;u=l+3|0;v=l+4|0;L6876:while(1){w=bK(o|0,1,5,b|0)|0;if((w|0)==0){n=m;x=5468;break}else if((w|0)!=5){break L6869}w=d[s]|0;y=a[t]&1;z=a[u]|0;A=z&255;B=a[v]|0;if(z<<24>>24==0){continue}if((B&255)>6){break L6869}z=128<<(B&255);if((bK(p|0,1,A|0,b|0)|0)!=(A|0)){break L6869}C=a[t]|0;if(C<<24>>24<0){if((bK(q|0,1,A|0,b|0)|0)!=(A|0)){break L6869}D=a[t]|0}else{D=C}if((D&64)==0){E=0}else{if((bK(r|0,1,A|0,b|0)|0)==(A|0)){E=0}else{break L6869}}while(1){C=a[t]|0;if(C<<24>>24<0){F=d[j+E|0]|0}else{F=w}if((C&64)==0){G=y}else{G=d[k+E|0]|0}C=a[h+E|0]|0;if((bK(g|0,1,1,b|0)|0)!=1){break L6869}H=qh(F,G,C&255,z)|0;if((H|0)==0){break L6869}p6(H,B);if((qw(m,H,w,y)|0)!=0){x=5448;break L6876}C=d[o]|0;if((C|0)==5){I=2}else if((C|0)==0){I=32769}else if((C|0)==2){I=1}else if((C|0)==3){I=32770}else if((C|0)==4){I=2}else if((C|0)==1){I=1}else{break L6869}p5(H,I);C=a[g]|0;if((C-5&255)<4){p4(H,2,1)}if((C<<24>>24|0)==1|(C<<24>>24|0)==5){x=5462}else if((C<<24>>24|0)==3|(C<<24>>24|0)==4|(C<<24>>24|0)==7|(C<<24>>24|0)==8){p4(H,4,1);if((C<<24>>24|0)==3|(C<<24>>24|0)==5|(C<<24>>24|0)==7){x=5462}else if((C<<24>>24|0)==4|(C<<24>>24|0)==6|(C<<24>>24|0)==8){x=5460}else{break L6869}}else if((C<<24>>24|0)==0){p4(H,2,1);p2(H,0)}else if((C<<24>>24|0)==2|(C<<24>>24|0)==6){x=5460}else{break L6869}if((x|0)==5462){x=0;C=H+10|0;J=bK(c[H+24>>2]|0,1,e[C>>1]|0|0,b|0)|0;if((J|0)!=(e[C>>1]|0|0)){break L6869}}else if((x|0)==5460){x=0;if((bK(g|0,1,1,b|0)|0)!=1){break L6869}p2(H,d[g]|0)}C=E+1|0;if(C>>>0<A>>>0){E=C}else{continue L6876}}}if((x|0)==5468){i=f;return n|0}else if((x|0)==5448){qi(H);break}}}while(0);qt(m);n=0;i=f;return n|0}function qN(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;h=i;i=i+784|0;j=h|0;k=h+776|0;l=g+12|0;m=c[l>>2]|0;n=g+8|0;do{if((c[n>>2]|0)>>>0<29){o=5478}else{if((a[m]|0)!=73){o=5478;break}if((a[m+1|0]|0)!=77){o=5478;break}if((a[m+2|0]|0)!=68){o=5478;break}if((a[m+12|0]|0)!=47){o=5478;break}if((a[m+15|0]|0)!=47){o=5478;break}if((a[m+20|0]|0)!=32){o=5478;break}rq(f,m,29)|0;if((c[n>>2]|0)>>>0<=29){p=29;break}p=(a[(c[l>>2]|0)+29|0]|0)==10?30:29}}while(0);if((o|0)==5478){c[k>>2]=bZ(0)|0;m=bH(k|0)|0;k=c[m+12>>2]|0;q=(c[m+16>>2]|0)+1|0;r=(c[m+20>>2]|0)+1900|0;s=c[m+8>>2]|0;t=c[m+4>>2]|0;u=c[m>>2]|0;bN(f|0,53952,(x=i,i=i+48|0,c[x>>2]=k,c[x+8>>2]=q,c[x+16>>2]=r,c[x+24>>2]=s,c[x+32>>2]=t,c[x+40>>2]=u,x)|0)|0;p=0}aB(13,f|0)|0;aB(10,f|0)|0;if(p>>>0<(c[n>>2]|0)>>>0){u=p;do{p=a[(c[l>>2]|0)+u|0]|0;if(p<<24>>24==10){aB(13,f|0)|0;aB(10,f|0)|0}else{t=p&255;aB(t|0,f|0)|0}u=u+1|0;}while(u>>>0<(c[n>>2]|0)>>>0)}aB(26,f|0)|0;n=g|0;u=b[n>>1]|0;L6943:do{if(u<<16>>16!=0){l=g+4|0;t=j|0;p=j+1|0;s=j+2|0;r=j+3|0;q=j+4|0;k=0;m=u;L6945:while(1){v=c[(c[l>>2]|0)+(k<<2)>>2]|0;w=v+2|0;if((b[w>>1]|0)==0){y=m}else{z=v+4|0;v=k&255;A=0;do{B=c[(c[z>>2]|0)+(A<<2)>>2]|0;C=b[B+2>>1]|0;D=C&65535;if(C<<16>>16!=0){E=B+4|0;B=c[E>>2]|0;F=0;G=0;H=1;while(1){if(H>>>0>=D>>>0){break}I=c[B+(H<<2)>>2]|0;J=c[B>>2]|0;if((b[I+10>>1]|0)!=(b[J+10>>1]|0)){K=1;o=5530;break L6945}if((b[I+16>>1]|0)==(b[J+16>>1]|0)){F=(e[I+6>>1]|0)==(A|0)?F:1;G=(e[I+4>>1]|0)==(k|0)?G:1;H=H+1|0}else{K=1;o=5531;break L6945}}H=c[B>>2]|0;I=e[H+16>>1]|0;if((I|0)==1){a[t]=2}else if((I|0)==32769){a[t]=0}else if((I|0)==2){a[t]=5}else if((I|0)==32770){a[t]=3}else{a[t]=5}a[p]=v;I=A&255;a[s]=I;a[r]=C&255;J=b[H+10>>1]|0;H=J&65535;if((H+65535&H|0)!=0|(J&65535)>8192){K=1;o=5532;break L6945}a[q]=0;if((J&65535)>255){J=H;H=0;while(1){L=H+1&255;if(J>>>0>511){J=J>>>1;H=L}else{break}}a[q]=L}H=D+5|0;if((G|0)==0){M=0;N=H;O=I}else{J=I|-128;a[s]=J;M=j+H|0;N=H+D|0;O=J}if((F|0)==0){P=0;Q=N}else{a[s]=O|64;P=j+N|0;Q=N+D|0}J=(P|0)==0;if((M|0)==0){if(J){H=0;do{a[j+(H+5)|0]=b[(c[B+(H<<2)>>2]|0)+8>>1]&255;H=H+1|0;}while(H>>>0<D>>>0)}else{H=0;do{F=c[B+(H<<2)>>2]|0;a[j+(H+5)|0]=b[F+8>>1]&255;a[P+H|0]=b[F+6>>1]&255;H=H+1|0;}while(H>>>0<D>>>0)}}else{if(J){H=0;do{F=c[B+(H<<2)>>2]|0;a[j+(H+5)|0]=b[F+8>>1]&255;a[M+H|0]=b[F+4>>1]&255;H=H+1|0;}while(H>>>0<D>>>0)}else{H=0;do{J=c[B+(H<<2)>>2]|0;a[j+(H+5)|0]=b[J+8>>1]&255;a[M+H|0]=b[J+4>>1]&255;a[P+H|0]=b[J+6>>1]&255;H=H+1|0;}while(H>>>0<D>>>0)}}if((aC(t|0,1,Q|0,f|0)|0)==(Q|0)){R=0}else{K=1;o=5528;break L6945}do{H=c[(c[E>>2]|0)+(R<<2)>>2]|0;if((p3(H)|0)==0){S=0}else{S=(b[H+10>>1]|0)!=0}B=c[H+12>>2]|0;J=(B&6|0)==6;if(J|(B&2|0)!=0){T=J?7:5}else{T=B>>>1&2|1}aB(T+(S&1)|0,f|0)|0;B=c[H+24>>2]|0;if(S){J=d[B]|0;aB(J|0,f|0)|0}else{J=H+10|0;H=aC(B|0,1,e[J>>1]|0,f|0)|0;if((H|0)!=(e[J>>1]|0)){K=1;o=5529;break L6945}}R=R+1|0;}while(R>>>0<D>>>0)}A=A+1|0;}while(A>>>0<(e[w>>1]|0)>>>0);y=b[n>>1]|0}w=k+1|0;if(w>>>0<(y&65535)>>>0){k=w;m=y}else{break L6943}}if((o|0)==5532){i=h;return K|0}else if((o|0)==5528){i=h;return K|0}else if((o|0)==5529){i=h;return K|0}else if((o|0)==5530){i=h;return K|0}else if((o|0)==5531){i=h;return K|0}}}while(0);ay(f|0)|0;K=0;i=h;return K|0}function qO(a){a=a|0;var b=0,c=0,d=0;b=i;i=i+16|0;do{if((bR(a|0,0,0)|0)==0){c=b|0;if((bK(c|0,1,4,a|0)|0)!=4){d=0;break}d=(rf(c,0)|0)==1229800480|0}else{d=0}}while(0);i=b;return d|0}function qP(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+8|0;c=qs()|0;if((c|0)==0){d=0;i=b;return d|0}e=b|0;do{if((ro(a,e,8)|0)==0){f=rf(e,0)|0;g=rf(e,4)|0;if((f|0)!=1346782275){break}if((g|0)==131072){h=qX(a,c,1346782275,131072)|0}else if((g|0)==65536){h=qU(a,c,1346782275,65536)|0}else if((g|0)==0){h=qS(a,c,1346782275,0)|0}else{h=q$(a,c,1346782275,g)|0}if((h|0)==0){d=c}else{break}i=b;return d|0}}while(0);qt(c);d=0;i=b;return d|0}function qQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((c|0)==1){d=qV(a,b)|0}else if((c|0)==0){d=qT(a,b)|0}else if((c|0)==2){d=qY(a,b)|0}else{d=q0(a,b)|0}return d|0}function qR(a){a=a|0;var b=0,c=0,d=0;b=i;i=i+8|0;c=b|0;if((rp(a,0,c,4)|0)!=0){d=0;i=b;return d|0}d=(rf(c,0)|0)==1346782275|0;i=b;return d|0}function qS(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=i;i=i+24|0;f=g|0;aC(51128,49,1,c[q>>2]|0)|0;h=g+16|0;if((ro(b,h,8)|0)!=0){j=1;i=g;return j|0}k=rf(h,0)|0;l=rf(h,4)|0;if(l>>>0<16){j=1;i=g;return j|0}if((rs(b,l-16|0)|0)!=0){j=1;i=g;return j|0}if((k|0)==0){j=0;i=g;return j|0}l=f|0;h=f+1|0;m=f+5|0;n=f+2|0;o=f+3|0;p=f+4|0;r=f+12|0;f=0;while(1){if((ro(b,l,12)|0)!=0){j=1;s=5586;break}t=a[l]|0;u=a[h]|0;v=d[m]|0;w=re(l,6)|0;x=qh(d[n]|0,d[o]|0,d[p]|0,w)|0;if((x|0)==0){j=1;s=5589;break}if((qw(e,x,t&255,u&255)|0)!=0){s=5571;break}rf(l,8)|0;p5(x,(v&1|0)==0?v&2:1);if((v&4|0)!=0){u=x+12|0;c[u>>2]=c[u>>2]|1}if((v&8|0)!=0){u=x+12|0;c[u>>2]=c[u>>2]|2}if((v&16|0)!=0){u=x+12|0;c[u>>2]=c[u>>2]|4}if((v&128|0)==0){if((ro(b,c[x+24>>2]|0,w)|0)!=0){j=1;s=5584;break}}else{if((ro(b,r,1)|0)!=0){j=1;s=5593;break}p2(x,d[r]|0)}w=f+1|0;if(w>>>0<k>>>0){f=w}else{j=0;s=5591;break}}if((s|0)==5589){i=g;return j|0}else if((s|0)==5586){i=g;return j|0}else if((s|0)==5571){qi(x);j=1;i=g;return j|0}else if((s|0)==5591){i=g;return j|0}else if((s|0)==5593){i=g;return j|0}else if((s|0)==5584){i=g;return j|0}return 0}function qT(d,f){d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;g=i;i=i+32|0;h=g|0;j=qB(f)|0;k=g+16|0;rh(k,0,1346782275);rh(k,4,0);rh(k,8,j);rh(k,12,16);if((rq(d,k,16)|0)!=0){l=1;i=g;return l|0}k=f|0;j=b[k>>1]|0;L7091:do{if(j<<16>>16!=0){m=f+4|0;n=h|0;o=h+1|0;p=h+2|0;q=h+3|0;r=h+4|0;s=h+5|0;t=h+6|0;u=h+7|0;v=h+12|0;w=0;x=j;L7093:while(1){y=c[(c[m>>2]|0)+(w<<2)>>2]|0;z=y+2|0;A=b[z>>1]|0;if(A<<16>>16==0){B=x}else{C=y+4|0;y=w&255;D=0;E=A;while(1){A=c[(c[C>>2]|0)+(D<<2)>>2]|0;F=A+2|0;if((b[F>>1]|0)==0){G=E}else{H=A+4|0;A=D&255;I=0;do{J=c[(c[H>>2]|0)+(I<<2)>>2]|0;K=e[J+16>>1]|0;if((K|0)==16386){L=1e6;M=2}else if((K|0)==1){L=125e3;M=1}else if((K|0)==2){L=25e4;M=2}else if((K|0)==32770){L=5e5;M=2}else if((K|0)==32769){L=25e4;M=1}else{L=0;M=0}K=c[J+12>>2]|0;N=(K&1|0)==0?M:M|4;O=(K&2|0)==0?N:N|8;a[n]=y;a[o]=A;a[p]=b[J+4>>1]&255;a[q]=b[J+6>>1]&255;a[r]=b[J+8>>1]&255;a[s]=((K&4|0)==0?O:O|16)&255;O=J+10|0;K=b[O>>1]|0;a[t]=(K&65535)>>>8&255;a[u]=K&255;rh(n,8,L);do{if((p3(J)|0)==0){P=5610}else{if((b[O>>1]|0)==0){P=5610;break}a[s]=a[s]|-128;a[v]=a[c[J+24>>2]|0]|0;if((rq(d,n,13)|0)!=0){l=1;P=5619;break L7093}}}while(0);if((P|0)==5610){P=0;if((rq(d,n,12)|0)!=0){l=1;P=5621;break L7093}if((rq(d,c[J+24>>2]|0,e[O>>1]|0)|0)!=0){l=1;P=5622;break L7093}}I=I+1|0;}while(I>>>0<(e[F>>1]|0)>>>0);G=b[z>>1]|0}F=D+1|0;if(F>>>0<(G&65535)>>>0){D=F;E=G}else{break}}B=b[k>>1]|0}E=w+1|0;if(E>>>0<(B&65535)>>>0){w=E;x=B}else{break L7091}}if((P|0)==5622){i=g;return l|0}else if((P|0)==5619){i=g;return l|0}else if((P|0)==5621){i=g;return l|0}}}while(0);ay(d|0)|0;l=0;i=g;return l|0}function qU(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=i;i=i+40|0;f=g|0;aC(51032,49,1,c[q>>2]|0)|0;h=g+32|0;if((ro(b,h,8)|0)!=0){j=1;i=g;return j|0}k=rf(h,0)|0;l=rf(h,4)|0;if(l>>>0<16){j=1;i=g;return j|0}if((rs(b,l-16|0)|0)!=0){j=1;i=g;return j|0}if((k|0)==0){j=0;i=g;return j|0}l=f|0;h=f+1|0;m=f+2|0;n=f+3|0;o=f+4|0;p=f+5|0;r=f+8|0;s=f+16|0;f=0;t=0;while(1){u=(ro(b,l,16)|0)==0;if(!(u&(a[l]|0)==83)){j=1;v=5653;break}u=d[h]|0;w=d[m]|0;x=re(l,6)|0;y=qh(d[n]|0,d[o]|0,d[p]|0,x)|0;if((y|0)==0){j=1;v=5659;break}z=rf(l,12)|0;A=(rf(l,8)|0)&16777215;if((z&4|0)!=0){B=y+12|0;c[B>>2]=c[B>>2]|1}if((z&8|0)!=0){B=y+12|0;c[B>>2]=c[B>>2]|2}if((z&16|0)!=0){B=y+12|0;c[B>>2]=c[B>>2]|4}B=d[r]|0;if((B|0)==2){C=A>>>0<375e3?2:32770}else if((B|0)==1){C=A>>>0<375e3?1:32769}else{C=0}p5(y,C);if((z&1|0)==0){if((qw(e,y,u,w)|0)!=0){v=5645;break}}else{if((f|0)==0){v=5642;break}p0(f,y)}if((z&128|0)==0){if((ro(b,c[y+24>>2]|0,x)|0)!=0){j=1;v=5655;break}}else{if((ro(b,s,1)|0)!=0){j=1;v=5660;break}p2(y,d[s]|0)}x=t+1|0;if(x>>>0<k>>>0){f=y;t=x}else{j=0;v=5657;break}}if((v|0)==5645){qi(y);j=1;i=g;return j|0}else if((v|0)==5653){i=g;return j|0}else if((v|0)==5655){i=g;return j|0}else if((v|0)==5657){i=g;return j|0}else if((v|0)==5642){qi(y);j=1;i=g;return j|0}else if((v|0)==5659){i=g;return j|0}else if((v|0)==5660){i=g;return j|0}return 0}function qV(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+16|0;g=qB(d)|0;h=f|0;rh(h,0,1346782275);rg(h,4,1);rg(h,6,0);rh(h,8,g);rh(h,12,16);if((rq(a,h,16)|0)!=0){j=1;i=f;return j|0}h=d|0;g=b[h>>1]|0;L7181:do{if(g<<16>>16!=0){k=d+4|0;l=0;m=g;L7183:while(1){n=c[(c[k>>2]|0)+(l<<2)>>2]|0;o=n+2|0;p=b[o>>1]|0;if(p<<16>>16==0){q=m}else{r=n+4|0;n=0;s=p;while(1){p=c[(c[r>>2]|0)+(n<<2)>>2]|0;t=p+2|0;if((b[t>>1]|0)==0){u=s}else{v=p+4|0;p=0;do{w=c[(c[v>>2]|0)+(p<<2)>>2]|0;if((qW(a,w,l,n,0)|0)==0){x=w}else{j=1;y=5681;break L7183}while(1){w=c[x>>2]|0;if((w|0)==0){break}if((qW(a,w,l,n,1)|0)==0){x=w}else{j=1;y=5682;break L7183}}p=p+1|0;}while(p>>>0<(e[t>>1]|0)>>>0);u=b[o>>1]|0}t=n+1|0;if(t>>>0<(u&65535)>>>0){n=t;s=u}else{break}}q=b[h>>1]|0}s=l+1|0;if(s>>>0<(q&65535)>>>0){l=s;m=q}else{break L7181}}if((y|0)==5681){i=f;return j|0}else if((y|0)==5682){i=f;return j|0}}}while(0);ay(a|0)|0;j=0;i=f;return j|0}function qW(d,f,g,h,j){d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=i;i=i+32|0;l=k|0;m=c[f+12>>2]|0;n=m<<2&4;o=(m&2|0)==0?n:n|8;n=(m&4|0)==0?o:o|16;if((p3(f)|0)==0){p=n}else{p=(b[f+10>>1]|0)==0?n:n|128}n=p|(j|0)!=0;j=e[f+16>>1]|0;if((j|0)==32769){q=25e4;r=1}else if((j|0)==2){q=25e4;r=2}else if((j|0)==32770){q=5e5;r=2}else if((j|0)==16386){q=1e6;r=2}else if((j|0)==1){q=125e3;r=1}else{q=0;r=0}j=l|0;rh(j,8,q);a[j]=83;a[l+1|0]=g&255;a[l+2|0]=h&255;a[l+3|0]=b[f+4>>1]&255;a[l+4|0]=b[f+6>>1]&255;a[l+5|0]=b[f+8>>1]&255;h=f+10|0;g=b[h>>1]|0;a[l+6|0]=(g&65535)>>>8&255;a[l+7|0]=g&255;a[l+8|0]=r;rh(j,12,n);do{if((p&128|0)==0){if((rq(d,j,16)|0)!=0){s=1;i=k;return s|0}if((rq(d,c[f+24>>2]|0,e[h>>1]|0)|0)==0){break}else{s=1}i=k;return s|0}else{a[l+16|0]=a[c[f+24>>2]|0]|0;if((rq(d,j,17)|0)==0){break}else{s=1}i=k;return s|0}}while(0);s=0;i=k;return s|0}function qX(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0;j=i;i=i+568|0;k=j|0;l=j+32|0;m=j+288|0;n=j+296|0;o=j+552|0;aC(50952,49,1,c[q>>2]|0)|0;p=o|0;rh(p,0,g);rh(p,4,h);h=-1;g=8;r=p;while(1){s=d[r]<<24^h;t=s<<1;u=(s|0)<0?t^79764919:t;t=u<<1;s=(u|0)<0?t^79764919:t;t=s<<1;u=(s|0)<0?t^79764919:t;t=u<<1;s=(u|0)<0?t^79764919:t;t=s<<1;u=(s|0)<0?t^79764919:t;t=u<<1;s=(u|0)<0?t^79764919:t;t=s<<1;u=(s|0)<0?t^79764919:t;t=u<<1;v=(u|0)<0?t^79764919:t;t=g-1|0;if((t|0)==0){break}else{h=v;g=t;r=r+1|0}}c[14504]=v;v=o+8|0;if((ro(b,v,8)|0)!=0){w=1;i=j;return w|0}o=c[14504]|0;r=8;g=v;while(1){v=d[g]<<24^o;h=v<<1;t=(v|0)<0?h^79764919:h;h=t<<1;v=(t|0)<0?h^79764919:h;h=v<<1;t=(v|0)<0?h^79764919:h;h=t<<1;v=(t|0)<0?h^79764919:h;h=v<<1;t=(v|0)<0?h^79764919:h;h=t<<1;v=(t|0)<0?h^79764919:h;h=v<<1;t=(v|0)<0?h^79764919:h;h=t<<1;x=(t|0)<0?h^79764919:h;h=r-1|0;if((h|0)==0){break}else{o=x;r=h;g=g+1|0}}c[14504]=x;x=rf(p,12)|0;if(x>>>0<16){w=1;i=j;return w|0}g=x-16|0;x=n|0;L34:do{if((g|0)!=0){n=g;while(1){r=n>>>0<256?n:256;if((ro(b,x,r)|0)!=0){w=1;break}o=c[14504]|0;if((r|0)==0){y=o}else{h=o;o=r;t=x;while(1){v=d[t]<<24^h;u=v<<1;s=(v|0)<0?u^79764919:u;u=s<<1;v=(s|0)<0?u^79764919:u;u=v<<1;s=(v|0)<0?u^79764919:u;u=s<<1;v=(s|0)<0?u^79764919:u;u=v<<1;s=(v|0)<0?u^79764919:u;u=s<<1;v=(s|0)<0?u^79764919:u;u=v<<1;s=(v|0)<0?u^79764919:u;u=s<<1;v=(s|0)<0?u^79764919:u;u=o-1|0;if((u|0)==0){y=v;break}else{h=v;o=u;t=t+1|0}}}c[14504]=y;if((n|0)==(r|0)){break L34}else{n=n-r|0}}i=j;return w|0}}while(0);y=m|0;m=l|0;l=k|0;g=k+1|0;n=k+2|0;t=k+3|0;o=k+4|0;h=k+5|0;u=k+8|0;k=0;L44:while(1){if((ro(b,y,4)|0)!=0){w=1;z=159;break}v=(k|0)==0;while(1){s=c[14504]|0;A=4;B=y;while(1){C=d[B]<<24^s;D=C<<1;E=(C|0)<0?D^79764919:D;D=E<<1;C=(E|0)<0?D^79764919:D;D=C<<1;E=(C|0)<0?D^79764919:D;D=E<<1;C=(E|0)<0?D^79764919:D;D=C<<1;E=(C|0)<0?D^79764919:D;D=E<<1;C=(E|0)<0?D^79764919:D;D=C<<1;E=(C|0)<0?D^79764919:D;D=E<<1;F=(E|0)<0?D^79764919:D;D=A-1|0;if((D|0)==0){break}else{s=F;A=D;B=B+1|0}}c[14504]=F;B=re(y,0)|0;G=re(y,2)|0;A=0;s=4;r=y;while(1){D=d[r]<<24^A;E=D<<1;C=(D|0)<0?E^79764919:E;E=C<<1;D=(C|0)<0?E^79764919:E;E=D<<1;C=(D|0)<0?E^79764919:E;E=C<<1;D=(C|0)<0?E^79764919:E;E=D<<1;C=(D|0)<0?E^79764919:E;E=C<<1;D=(C|0)<0?E^79764919:E;E=D<<1;C=(D|0)<0?E^79764919:E;E=C<<1;H=(C|0)<0?E^79764919:E;E=s-1|0;if((E|0)==0){break}else{A=H;s=E;r=r+1|0}}if((B|0)==17742){z=38;break L44}else if((B|0)==21315){break}else if((B|0)==21575){if(v){w=1;z=175;break L44}r=G>>>0<256?G:256;if((ro(b,x,r)|0)!=0){w=1;z=176;break L44}s=c[14504]|0;if((r|0)==0){c[14504]=s;I=H}else{A=s;s=r;E=x;while(1){C=d[E]<<24^A;D=C<<1;J=(C|0)<0?D^79764919:D;D=J<<1;C=(J|0)<0?D^79764919:D;D=C<<1;J=(C|0)<0?D^79764919:D;D=J<<1;C=(J|0)<0?D^79764919:D;D=C<<1;J=(C|0)<0?D^79764919:D;D=J<<1;C=(J|0)<0?D^79764919:D;D=C<<1;J=(C|0)<0?D^79764919:D;D=J<<1;K=(J|0)<0?D^79764919:D;D=s-1|0;if((D|0)==0){break}else{A=K;s=D;E=E+1|0}}c[14504]=K;E=H;s=r;A=x;while(1){D=d[A]<<24^E;J=D<<1;C=(D|0)<0?J^79764919:J;J=C<<1;D=(C|0)<0?J^79764919:J;J=D<<1;C=(D|0)<0?J^79764919:J;J=C<<1;D=(C|0)<0?J^79764919:J;J=D<<1;C=(D|0)<0?J^79764919:J;J=C<<1;D=(C|0)<0?J^79764919:J;J=D<<1;C=(D|0)<0?J^79764919:J;J=C<<1;D=(C|0)<0?J^79764919:J;J=s-1|0;if((J|0)==0){I=D;break}else{E=D;s=J;A=A+1|0}}}qa(k,x,r)|0;if((r|0)==(G|0)){L=I}else{A=G-r|0;s=I;while(1){E=A>>>0<256?A:256;if((ro(b,m,E)|0)!=0){w=1;z=177;break L44}J=c[14504]|0;if((E|0)==0){c[14504]=J;M=s}else{D=J;J=E;C=m;while(1){N=d[C]<<24^D;O=N<<1;P=(N|0)<0?O^79764919:O;O=P<<1;N=(P|0)<0?O^79764919:O;O=N<<1;P=(N|0)<0?O^79764919:O;O=P<<1;N=(P|0)<0?O^79764919:O;O=N<<1;P=(N|0)<0?O^79764919:O;O=P<<1;N=(P|0)<0?O^79764919:O;O=N<<1;P=(N|0)<0?O^79764919:O;O=P<<1;Q=(P|0)<0?O^79764919:O;O=J-1|0;if((O|0)==0){break}else{D=Q;J=O;C=C+1|0}}c[14504]=Q;C=s;J=E;D=m;while(1){O=d[D]<<24^C;P=O<<1;N=(O|0)<0?P^79764919:P;P=N<<1;O=(N|0)<0?P^79764919:P;P=O<<1;N=(O|0)<0?P^79764919:P;P=N<<1;O=(N|0)<0?P^79764919:P;P=O<<1;N=(O|0)<0?P^79764919:P;P=N<<1;O=(N|0)<0?P^79764919:P;P=O<<1;N=(O|0)<0?P^79764919:P;P=N<<1;O=(N|0)<0?P^79764919:P;P=J-1|0;if((P|0)==0){M=O;break}else{C=O;J=P;D=D+1|0}}}if((A|0)==(E|0)){L=M;break}else{A=A-E|0;s=M}}}if((ro(b,m,4)|0)!=0){w=1;z=178;break L44}s=c[14504]|0;A=4;r=m;while(1){D=d[r]<<24^s;J=D<<1;C=(D|0)<0?J^79764919:J;J=C<<1;D=(C|0)<0?J^79764919:J;J=D<<1;C=(D|0)<0?J^79764919:J;J=C<<1;D=(C|0)<0?J^79764919:J;J=D<<1;C=(D|0)<0?J^79764919:J;J=C<<1;D=(C|0)<0?J^79764919:J;J=D<<1;C=(D|0)<0?J^79764919:J;J=C<<1;R=(C|0)<0?J^79764919:J;J=A-1|0;if((J|0)==0){break}else{s=R;A=J;r=r+1|0}}c[14504]=R;if((rf(m,0)|0)!=(L|0)){w=1;z=179;break L44}}else if((B|0)==17229){if((G|0)==0){if((ro(b,m,4)|0)!=0){w=1;z=180;break L44}r=c[14504]|0;A=4;s=m;while(1){J=d[s]<<24^r;C=J<<1;D=(J|0)<0?C^79764919:C;C=D<<1;J=(D|0)<0?C^79764919:C;C=J<<1;D=(J|0)<0?C^79764919:C;C=D<<1;J=(D|0)<0?C^79764919:C;C=J<<1;D=(J|0)<0?C^79764919:C;C=D<<1;J=(D|0)<0?C^79764919:C;C=J<<1;D=(J|0)<0?C^79764919:C;C=D<<1;S=(D|0)<0?C^79764919:C;C=A-1|0;if((C|0)==0){break}else{r=S;A=C;s=s+1|0}}c[14504]=S;T=(rf(m,0)|0)!=(H|0)|0}else{U=u0(G)|0;if((U|0)==0){w=1;z=181;break L44}if((ro(b,U,G)|0)!=0){z=127;break L44}s=c[14504]|0;A=G;r=U;while(1){B=d[r]<<24^s;C=B<<1;D=(B|0)<0?C^79764919:C;C=D<<1;B=(D|0)<0?C^79764919:C;C=B<<1;D=(B|0)<0?C^79764919:C;C=D<<1;B=(D|0)<0?C^79764919:C;C=B<<1;D=(B|0)<0?C^79764919:C;C=D<<1;B=(D|0)<0?C^79764919:C;C=B<<1;D=(B|0)<0?C^79764919:C;C=D<<1;V=(D|0)<0?C^79764919:C;C=A-1|0;if((C|0)==0){break}else{s=V;A=C;r=r+1|0}}c[14504]=V;r=H;A=G;s=U;while(1){C=d[s]<<24^r;D=C<<1;B=(C|0)<0?D^79764919:D;D=B<<1;C=(B|0)<0?D^79764919:D;D=C<<1;B=(C|0)<0?D^79764919:D;D=B<<1;C=(B|0)<0?D^79764919:D;D=C<<1;B=(C|0)<0?D^79764919:D;D=B<<1;C=(B|0)<0?D^79764919:D;D=C<<1;B=(C|0)<0?D^79764919:D;D=B<<1;W=(B|0)<0?D^79764919:D;D=A-1|0;if((D|0)==0){break}else{r=W;A=D;s=s+1|0}}s=(a[U]|0)==10;A=(s<<31>>31)+G|0;if((A|0)==0){X=0}else{r=A-1|0;X=(a[U+r|0]|0)==10?r:A}A=qz(f,U+(s&1)|0,X)|0;u1(U);if((ro(b,m,4)|0)==0){s=c[14504]|0;r=4;D=m;while(1){B=d[D]<<24^s;C=B<<1;J=(B|0)<0?C^79764919:C;C=J<<1;B=(J|0)<0?C^79764919:C;C=B<<1;J=(B|0)<0?C^79764919:C;C=J<<1;B=(J|0)<0?C^79764919:C;C=B<<1;J=(B|0)<0?C^79764919:C;C=J<<1;B=(J|0)<0?C^79764919:C;C=B<<1;J=(B|0)<0?C^79764919:C;C=J<<1;Y=(J|0)<0?C^79764919:C;C=r-1|0;if((C|0)==0){break}else{s=Y;r=C;D=D+1|0}}c[14504]=Y;Z=(rf(m,0)|0)!=(W|0)|0}else{Z=1}T=Z|A}if((T|0)!=0){w=1;z=183;break L44}}else{if((G|0)==0){_=H}else{D=G;r=H;while(1){s=D>>>0<256?D:256;if((ro(b,m,s)|0)!=0){w=1;z=185;break L44}C=c[14504]|0;if((s|0)==0){c[14504]=C;$=r}else{J=C;C=s;B=m;while(1){P=d[B]<<24^J;O=P<<1;N=(P|0)<0?O^79764919:O;O=N<<1;P=(N|0)<0?O^79764919:O;O=P<<1;N=(P|0)<0?O^79764919:O;O=N<<1;P=(N|0)<0?O^79764919:O;O=P<<1;N=(P|0)<0?O^79764919:O;O=N<<1;P=(N|0)<0?O^79764919:O;O=P<<1;N=(P|0)<0?O^79764919:O;O=N<<1;aa=(N|0)<0?O^79764919:O;O=C-1|0;if((O|0)==0){break}else{J=aa;C=O;B=B+1|0}}c[14504]=aa;B=r;C=s;J=m;while(1){E=d[J]<<24^B;O=E<<1;N=(E|0)<0?O^79764919:O;O=N<<1;E=(N|0)<0?O^79764919:O;O=E<<1;N=(E|0)<0?O^79764919:O;O=N<<1;E=(N|0)<0?O^79764919:O;O=E<<1;N=(E|0)<0?O^79764919:O;O=N<<1;E=(N|0)<0?O^79764919:O;O=E<<1;N=(E|0)<0?O^79764919:O;O=N<<1;E=(N|0)<0?O^79764919:O;O=C-1|0;if((O|0)==0){$=E;break}else{B=E;C=O;J=J+1|0}}}if((D|0)==(s|0)){_=$;break}else{D=D-s|0;r=$}}}if((ro(b,m,4)|0)!=0){w=1;z=186;break L44}r=c[14504]|0;D=4;A=m;while(1){J=d[A]<<24^r;C=J<<1;B=(J|0)<0?C^79764919:C;C=B<<1;J=(B|0)<0?C^79764919:C;C=J<<1;B=(J|0)<0?C^79764919:C;C=B<<1;J=(B|0)<0?C^79764919:C;C=J<<1;B=(J|0)<0?C^79764919:C;C=B<<1;J=(B|0)<0?C^79764919:C;C=J<<1;B=(J|0)<0?C^79764919:C;C=B<<1;ab=(B|0)<0?C^79764919:C;C=D-1|0;if((C|0)==0){break}else{r=ab;D=C;A=A+1|0}}c[14504]=ab;if((rf(m,0)|0)!=(_|0)){w=1;z=187;break L44}}if((ro(b,y,4)|0)!=0){w=1;z=184;break L44}}if(G>>>0<12){w=1;z=163;break}if((ro(b,l,12)|0)!=0){w=1;z=164;break}A=c[14504]|0;D=12;r=l;while(1){C=d[r]<<24^A;B=C<<1;J=(C|0)<0?B^79764919:B;B=J<<1;C=(J|0)<0?B^79764919:B;B=C<<1;J=(C|0)<0?B^79764919:B;B=J<<1;C=(J|0)<0?B^79764919:B;B=C<<1;J=(C|0)<0?B^79764919:B;B=J<<1;C=(J|0)<0?B^79764919:B;B=C<<1;J=(C|0)<0?B^79764919:B;B=J<<1;ac=(J|0)<0?B^79764919:B;B=D-1|0;if((B|0)==0){break}else{A=ac;D=B;r=r+1|0}}c[14504]=ac;r=d[l]|0;D=d[g]|0;A=d[n]|0;B=re(l,6)|0;ad=qh(d[t]|0,d[o]|0,d[h]|0,B)|0;if((ad|0)==0){w=1;z=165;break}J=(rf(l,8)|0)&16777215;if((r&1|0)!=0){C=ad+12|0;c[C>>2]=c[C>>2]|1}if((r&2|0)!=0){C=ad+12|0;c[C>>2]=c[C>>2]|2}if((r&4|0)!=0){C=ad+12|0;c[C>>2]=c[C>>2]|4}if((r&8|0)!=0){C=ad+12|0;c[C>>2]=c[C>>2]|8}C=d[u]|0;if((C|0)==1){ae=J>>>0<375e3?1:32769}else if((C|0)==2){ae=J>>>0<375e3?2:32770}else if((C|0)==3){ae=3}else{ae=0}p5(ad,ae);if((r&64|0)==0){if((qw(f,ad,D,A)|0)==0){af=H;ag=12;ah=l}else{z=72;break}}else{if(v){z=69;break}p0(k,ad);af=H;ag=12;ah=l}while(1){A=d[ah]<<24^af;D=A<<1;C=(A|0)<0?D^79764919:D;D=C<<1;A=(C|0)<0?D^79764919:D;D=A<<1;C=(A|0)<0?D^79764919:D;D=C<<1;A=(C|0)<0?D^79764919:D;D=A<<1;C=(A|0)<0?D^79764919:D;D=C<<1;A=(C|0)<0?D^79764919:D;D=A<<1;C=(A|0)<0?D^79764919:D;D=C<<1;ai=(C|0)<0?D^79764919:D;D=ag-1|0;if((D|0)==0){break}else{af=ai;ag=D;ah=ah+1|0}}v=G-12|0;if((r&128|0)==0){D=ad+10|0;if(v>>>0<(e[D>>1]|0)>>>0){w=1;z=170;break}C=ad+24|0;A=c[C>>2]|0;if((ro(b,A,B)|0)!=0){w=1;z=171;break}J=c[14504]|0;if((B|0)==0){c[14504]=J;aj=ai}else{O=J;J=B;E=A;while(1){A=d[E]<<24^O;N=A<<1;P=(A|0)<0?N^79764919:N;N=P<<1;A=(P|0)<0?N^79764919:N;N=A<<1;P=(A|0)<0?N^79764919:N;N=P<<1;A=(P|0)<0?N^79764919:N;N=A<<1;P=(A|0)<0?N^79764919:N;N=P<<1;A=(P|0)<0?N^79764919:N;N=A<<1;P=(A|0)<0?N^79764919:N;N=P<<1;ak=(P|0)<0?N^79764919:N;N=J-1|0;if((N|0)==0){break}else{O=ak;J=N;E=E+1|0}}c[14504]=ak;E=ai;J=B;O=c[C>>2]|0;while(1){r=d[O]<<24^E;N=r<<1;P=(r|0)<0?N^79764919:N;N=P<<1;r=(P|0)<0?N^79764919:N;N=r<<1;P=(r|0)<0?N^79764919:N;N=P<<1;r=(P|0)<0?N^79764919:N;N=r<<1;P=(r|0)<0?N^79764919:N;N=P<<1;r=(P|0)<0?N^79764919:N;N=r<<1;P=(r|0)<0?N^79764919:N;N=P<<1;r=(P|0)<0?N^79764919:N;N=J-1|0;if((N|0)==0){aj=r;break}else{E=r;J=N;O=O+1|0}}}al=v-(e[D>>1]|0)|0;am=aj}else{if((v|0)==0){w=1;z=168;break}if((ro(b,l,1)|0)!=0){w=1;z=169;break}O=d[l]|0;J=O<<24;E=J^c[14504];C=E<<1;B=(E|0)<0?C^79764919:C;C=B<<1;E=(B|0)<0?C^79764919:C;C=E<<1;B=(E|0)<0?C^79764919:C;C=B<<1;E=(B|0)<0?C^79764919:C;C=E<<1;B=(E|0)<0?C^79764919:C;C=B<<1;E=(B|0)<0?C^79764919:C;C=E<<1;B=(E|0)<0?C^79764919:C;C=B<<1;c[14504]=(B|0)<0?C^79764919:C;C=J^ai;J=C<<1;B=(C|0)<0?J^79764919:J;J=B<<1;C=(B|0)<0?J^79764919:J;J=C<<1;B=(C|0)<0?J^79764919:J;J=B<<1;C=(B|0)<0?J^79764919:J;J=C<<1;B=(C|0)<0?J^79764919:J;J=B<<1;C=(B|0)<0?J^79764919:J;J=C<<1;B=(C|0)<0?J^79764919:J;J=B<<1;p2(ad,O);al=G-13|0;am=(B|0)<0?J^79764919:J}if((al|0)==0){an=am}else{J=al;B=am;while(1){O=J>>>0<256?J:256;if((ro(b,m,O)|0)!=0){w=1;z=172;break L44}C=c[14504]|0;if((O|0)==0){c[14504]=C;ao=B}else{E=C;C=O;N=m;while(1){r=d[N]<<24^E;P=r<<1;A=(r|0)<0?P^79764919:P;P=A<<1;r=(A|0)<0?P^79764919:P;P=r<<1;A=(r|0)<0?P^79764919:P;P=A<<1;r=(A|0)<0?P^79764919:P;P=r<<1;A=(r|0)<0?P^79764919:P;P=A<<1;r=(A|0)<0?P^79764919:P;P=r<<1;A=(r|0)<0?P^79764919:P;P=A<<1;ap=(A|0)<0?P^79764919:P;P=C-1|0;if((P|0)==0){break}else{E=ap;C=P;N=N+1|0}}c[14504]=ap;N=B;C=O;E=m;while(1){P=d[E]<<24^N;A=P<<1;r=(P|0)<0?A^79764919:A;A=r<<1;P=(r|0)<0?A^79764919:A;A=P<<1;r=(P|0)<0?A^79764919:A;A=r<<1;P=(r|0)<0?A^79764919:A;A=P<<1;r=(P|0)<0?A^79764919:A;A=r<<1;P=(r|0)<0?A^79764919:A;A=P<<1;r=(P|0)<0?A^79764919:A;A=r<<1;P=(r|0)<0?A^79764919:A;A=C-1|0;if((A|0)==0){ao=P;break}else{N=P;C=A;E=E+1|0}}}if((J|0)==(O|0)){an=ao;break}else{J=J-O|0;B=ao}}}if((ro(b,m,4)|0)!=0){w=1;z=173;break}B=c[14504]|0;J=4;v=m;while(1){D=d[v]<<24^B;E=D<<1;C=(D|0)<0?E^79764919:E;E=C<<1;D=(C|0)<0?E^79764919:E;E=D<<1;C=(D|0)<0?E^79764919:E;E=C<<1;D=(C|0)<0?E^79764919:E;E=D<<1;C=(D|0)<0?E^79764919:E;E=C<<1;D=(C|0)<0?E^79764919:E;E=D<<1;C=(D|0)<0?E^79764919:E;E=C<<1;aq=(C|0)<0?E^79764919:E;E=J-1|0;if((E|0)==0){break}else{B=aq;J=E;v=v+1|0}}c[14504]=aq;if((rf(m,0)|0)==(an|0)){k=ad}else{w=1;z=174;break}}if((z|0)==38){L196:do{if((G|0)==0){ar=H}else{k=G;an=H;while(1){aq=k>>>0<256?k:256;if((ro(b,m,aq)|0)!=0){w=1;break}ao=c[14504]|0;if((aq|0)==0){c[14504]=ao;as=an}else{ap=ao;ao=aq;am=m;while(1){al=d[am]<<24^ap;ai=al<<1;l=(al|0)<0?ai^79764919:ai;ai=l<<1;al=(l|0)<0?ai^79764919:ai;ai=al<<1;l=(al|0)<0?ai^79764919:ai;ai=l<<1;al=(l|0)<0?ai^79764919:ai;ai=al<<1;l=(al|0)<0?ai^79764919:ai;ai=l<<1;al=(l|0)<0?ai^79764919:ai;ai=al<<1;l=(al|0)<0?ai^79764919:ai;ai=l<<1;at=(l|0)<0?ai^79764919:ai;ai=ao-1|0;if((ai|0)==0){break}else{ap=at;ao=ai;am=am+1|0}}c[14504]=at;am=an;ao=aq;ap=m;while(1){O=d[ap]<<24^am;ai=O<<1;l=(O|0)<0?ai^79764919:ai;ai=l<<1;O=(l|0)<0?ai^79764919:ai;ai=O<<1;l=(O|0)<0?ai^79764919:ai;ai=l<<1;O=(l|0)<0?ai^79764919:ai;ai=O<<1;l=(O|0)<0?ai^79764919:ai;ai=l<<1;O=(l|0)<0?ai^79764919:ai;ai=O<<1;l=(O|0)<0?ai^79764919:ai;ai=l<<1;O=(l|0)<0?ai^79764919:ai;ai=ao-1|0;if((ai|0)==0){as=O;break}else{am=O;ao=ai;ap=ap+1|0}}}if((k|0)==(aq|0)){ar=as;break L196}else{k=k-aq|0;an=as}}i=j;return w|0}}while(0);if((ro(b,m,4)|0)!=0){w=1;i=j;return w|0}as=c[14504]|0;at=4;H=m;while(1){G=d[H]<<24^as;an=G<<1;k=(G|0)<0?an^79764919:an;an=k<<1;G=(k|0)<0?an^79764919:an;an=G<<1;k=(G|0)<0?an^79764919:an;an=k<<1;G=(k|0)<0?an^79764919:an;an=G<<1;k=(G|0)<0?an^79764919:an;an=k<<1;G=(k|0)<0?an^79764919:an;an=G<<1;k=(G|0)<0?an^79764919:an;an=k<<1;au=(k|0)<0?an^79764919:an;an=at-1|0;if((an|0)==0){break}else{as=au;at=an;H=H+1|0}}c[14504]=au;if((rf(m,0)|0)!=(ar|0)){w=1;i=j;return w|0}qD(f);f=c[14504]|0;if((ro(b,p,4)|0)!=0){w=1;i=j;return w|0}b=c[14504]|0;ar=4;m=p;while(1){au=d[m]<<24^b;H=au<<1;at=(au|0)<0?H^79764919:H;H=at<<1;au=(at|0)<0?H^79764919:H;H=au<<1;at=(au|0)<0?H^79764919:H;H=at<<1;au=(at|0)<0?H^79764919:H;H=au<<1;at=(au|0)<0?H^79764919:H;H=at<<1;au=(at|0)<0?H^79764919:H;H=au<<1;at=(au|0)<0?H^79764919:H;H=at<<1;av=(at|0)<0?H^79764919:H;H=ar-1|0;if((H|0)==0){break}else{b=av;ar=H;m=m+1|0}}c[14504]=av;w=(rf(p,0)|0)!=(f|0)|0;i=j;return w|0}else if((z|0)==69){qi(ad);w=1;i=j;return w|0}else if((z|0)==72){qi(ad);w=1;i=j;return w|0}else if((z|0)==127){u1(U);w=1;i=j;return w|0}else if((z|0)==159){i=j;return w|0}else if((z|0)==163){i=j;return w|0}else if((z|0)==164){i=j;return w|0}else if((z|0)==165){i=j;return w|0}else if((z|0)==168){i=j;return w|0}else if((z|0)==169){i=j;return w|0}else if((z|0)==170){i=j;return w|0}else if((z|0)==171){i=j;return w|0}else if((z|0)==172){i=j;return w|0}else if((z|0)==173){i=j;return w|0}else if((z|0)==174){i=j;return w|0}else if((z|0)==175){i=j;return w|0}else if((z|0)==176){i=j;return w|0}else if((z|0)==177){i=j;return w|0}else if((z|0)==178){i=j;return w|0}else if((z|0)==179){i=j;return w|0}else if((z|0)==180){i=j;return w|0}else if((z|0)==181){i=j;return w|0}else if((z|0)==183){i=j;return w|0}else if((z|0)==184){i=j;return w|0}else if((z|0)==185){i=j;return w|0}else if((z|0)==186){i=j;return w|0}else if((z|0)==187){i=j;return w|0}return 0}function qY(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=i;i=i+32|0;j=h|0;c[14504]=-1;k=h+16|0;rh(k,0,1346782275);rg(k,4,2);rg(k,6,0);rh(k,8,0);rh(k,12,16);if((rq(f,k,16)|0)!=0){l=1;i=h;return l|0}m=c[14504]|0;n=16;o=k;while(1){p=d[o]<<24^m;q=p<<1;r=(p|0)<0?q^79764919:q;q=r<<1;p=(r|0)<0?q^79764919:q;q=p<<1;r=(p|0)<0?q^79764919:q;q=r<<1;p=(r|0)<0?q^79764919:q;q=p<<1;r=(p|0)<0?q^79764919:q;q=r<<1;p=(r|0)<0?q^79764919:q;q=p<<1;r=(p|0)<0?q^79764919:q;q=r<<1;s=(r|0)<0?q^79764919:q;q=n-1|0;if((q|0)==0){break}else{m=s;n=q;o=o+1|0}}c[14504]=s;s=j|0;o=g+8|0;do{if((c[o>>2]|0)!=0){rg(s,0,17229);rg(s,2,(c[o>>2]|0)+2|0);n=j+4|0;a[n]=10;m=0;q=5;r=s;while(1){p=d[r]<<24^m;t=p<<1;u=(p|0)<0?t^79764919:t;t=u<<1;p=(u|0)<0?t^79764919:t;t=p<<1;u=(p|0)<0?t^79764919:t;t=u<<1;p=(u|0)<0?t^79764919:t;t=p<<1;u=(p|0)<0?t^79764919:t;t=u<<1;p=(u|0)<0?t^79764919:t;t=p<<1;u=(p|0)<0?t^79764919:t;t=u<<1;v=(u|0)<0?t^79764919:t;t=q-1|0;if((t|0)==0){break}else{m=v;q=t;r=r+1|0}}r=g+12|0;q=c[o>>2]|0;if((q|0)==0){w=v}else{m=v;t=q;q=c[r>>2]|0;while(1){u=d[q]<<24^m;p=u<<1;x=(u|0)<0?p^79764919:p;p=x<<1;u=(x|0)<0?p^79764919:p;p=u<<1;x=(u|0)<0?p^79764919:p;p=x<<1;u=(x|0)<0?p^79764919:p;p=u<<1;x=(u|0)<0?p^79764919:p;p=x<<1;u=(x|0)<0?p^79764919:p;p=u<<1;x=(u|0)<0?p^79764919:p;p=x<<1;u=(x|0)<0?p^79764919:p;p=t-1|0;if((p|0)==0){w=u;break}else{m=u;t=p;q=q+1|0}}}q=(w>>31)+335544320&-54452809^w<<1;t=q<<1;m=(q|0)<0?t^79764919:t;t=m<<1;q=(m|0)<0?t^79764919:t;t=q<<1;m=(q|0)<0?t^79764919:t;t=m<<1;q=(m|0)<0?t^79764919:t;t=q<<1;m=(q|0)<0?t^79764919:t;t=m<<1;q=(m|0)<0?t^79764919:t;t=q<<1;m=(q|0)<0?t^79764919:t;if((rq(f,s,5)|0)==0){t=c[14504]|0;q=5;p=s;while(1){u=d[p]<<24^t;x=u<<1;y=(u|0)<0?x^79764919:x;x=y<<1;u=(y|0)<0?x^79764919:x;x=u<<1;y=(u|0)<0?x^79764919:x;x=y<<1;u=(y|0)<0?x^79764919:x;x=u<<1;y=(u|0)<0?x^79764919:x;x=y<<1;u=(y|0)<0?x^79764919:x;x=u<<1;y=(u|0)<0?x^79764919:x;x=y<<1;z=(y|0)<0?x^79764919:x;x=q-1|0;if((x|0)==0){break}else{t=z;q=x;p=p+1|0}}c[14504]=z;A=0}else{A=1}p=c[r>>2]|0;q=c[o>>2]|0;if((rq(f,p,q)|0)==0){t=c[14504]|0;if((q|0)==0){B=t}else{x=t;t=q;q=p;while(1){p=d[q]<<24^x;y=p<<1;u=(p|0)<0?y^79764919:y;y=u<<1;p=(u|0)<0?y^79764919:y;y=p<<1;u=(p|0)<0?y^79764919:y;y=u<<1;p=(u|0)<0?y^79764919:y;y=p<<1;u=(p|0)<0?y^79764919:y;y=u<<1;p=(u|0)<0?y^79764919:y;y=p<<1;u=(p|0)<0?y^79764919:y;y=u<<1;p=(u|0)<0?y^79764919:y;y=t-1|0;if((y|0)==0){B=p;break}else{x=p;t=y;q=q+1|0}}}c[14504]=B;C=0}else{C=1}if((rq(f,n,1)|0)==0){q=d[n]<<24^c[14504];t=q<<1;x=(q|0)<0?t^79764919:t;t=x<<1;q=(x|0)<0?t^79764919:t;t=q<<1;x=(q|0)<0?t^79764919:t;t=x<<1;q=(x|0)<0?t^79764919:t;t=q<<1;x=(q|0)<0?t^79764919:t;t=x<<1;q=(x|0)<0?t^79764919:t;t=q<<1;x=(q|0)<0?t^79764919:t;t=x<<1;c[14504]=(x|0)<0?t^79764919:t;D=0}else{D=1}t=C|A|D;rh(s,0,m);if((rq(f,s,4)|0)==0){x=c[14504]|0;q=4;r=s;while(1){y=d[r]<<24^x;p=y<<1;u=(y|0)<0?p^79764919:p;p=u<<1;y=(u|0)<0?p^79764919:p;p=y<<1;u=(y|0)<0?p^79764919:p;p=u<<1;y=(u|0)<0?p^79764919:p;p=y<<1;u=(y|0)<0?p^79764919:p;p=u<<1;y=(u|0)<0?p^79764919:p;p=y<<1;u=(y|0)<0?p^79764919:p;p=u<<1;E=(u|0)<0?p^79764919:p;p=q-1|0;if((p|0)==0){break}else{x=E;q=p;r=r+1|0}}c[14504]=E;F=0}else{F=1}if((t|F|0)==0){break}else{l=1}i=h;return l|0}}while(0);F=g|0;E=b[F>>1]|0;L296:do{if(E<<16>>16!=0){s=g+4|0;D=0;A=E;L298:while(1){C=c[(c[s>>2]|0)+(D<<2)>>2]|0;B=C+2|0;o=b[B>>1]|0;if(o<<16>>16==0){G=A}else{z=C+4|0;C=0;w=o;while(1){o=c[(c[z>>2]|0)+(C<<2)>>2]|0;v=o+2|0;if((b[v>>1]|0)==0){H=w}else{j=o+4|0;o=0;do{r=c[(c[j>>2]|0)+(o<<2)>>2]|0;if((q_(f,r,D,C,0)|0)==0){I=r}else{l=1;J=237;break L298}while(1){r=c[I>>2]|0;if((r|0)==0){break}if((q_(f,r,D,C,1)|0)==0){I=r}else{l=1;J=238;break L298}}o=o+1|0;}while(o>>>0<(e[v>>1]|0)>>>0);H=b[B>>1]|0}v=C+1|0;if(v>>>0<(H&65535)>>>0){C=v;w=H}else{break}}G=b[F>>1]|0}w=D+1|0;if(w>>>0<(G&65535)>>>0){D=w;A=G}else{break L296}}if((J|0)==237){i=h;return l|0}else if((J|0)==238){i=h;return l|0}}}while(0);if((qZ(f,17742,0,0)|0)!=0){l=1;i=h;return l|0}rh(k,0,c[14504]|0);if((rq(f,k,4)|0)!=0){l=1;i=h;return l|0}J=c[14504]|0;G=4;F=k;while(1){k=d[F]<<24^J;H=k<<1;I=(k|0)<0?H^79764919:H;H=I<<1;k=(I|0)<0?H^79764919:H;H=k<<1;I=(k|0)<0?H^79764919:H;H=I<<1;k=(I|0)<0?H^79764919:H;H=k<<1;I=(k|0)<0?H^79764919:H;H=I<<1;k=(I|0)<0?H^79764919:H;H=k<<1;I=(k|0)<0?H^79764919:H;H=I<<1;K=(I|0)<0?H^79764919:H;H=G-1|0;if((H|0)==0){break}else{J=K;G=H;F=F+1|0}}c[14504]=K;ay(f|0)|0;l=0;i=h;return l|0}function qZ(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+8|0;h=g|0;rg(h,0,b);rg(h,2,e);b=0;j=4;k=h;while(1){l=(d[k]|0)<<24^b;m=l<<1;n=(l|0)<0?m^79764919:m;m=n<<1;l=(n|0)<0?m^79764919:m;m=l<<1;n=(l|0)<0?m^79764919:m;m=n<<1;l=(n|0)<0?m^79764919:m;m=l<<1;n=(l|0)<0?m^79764919:m;m=n<<1;l=(n|0)<0?m^79764919:m;m=l<<1;n=(l|0)<0?m^79764919:m;m=n<<1;o=(n|0)<0?m^79764919:m;m=j-1|0;if((m|0)==0){break}else{b=o;j=m;k=k+1|0}}if((rq(a,h,4)|0)!=0){p=1;i=g;return p|0}k=c[14504]|0;j=4;b=h;while(1){m=(d[b]|0)<<24^k;n=m<<1;l=(m|0)<0?n^79764919:n;n=l<<1;m=(l|0)<0?n^79764919:n;n=m<<1;l=(m|0)<0?n^79764919:n;n=l<<1;m=(l|0)<0?n^79764919:n;n=m<<1;l=(m|0)<0?n^79764919:n;n=l<<1;m=(l|0)<0?n^79764919:n;n=m<<1;l=(m|0)<0?n^79764919:n;n=l<<1;q=(l|0)<0?n^79764919:n;n=j-1|0;if((n|0)==0){break}else{k=q;j=n;b=b+1|0}}c[14504]=q;if((e|0)==0){r=o}else{q=o;o=e;b=f;while(1){j=(d[b]|0)<<24^q;k=j<<1;n=(j|0)<0?k^79764919:k;k=n<<1;j=(n|0)<0?k^79764919:k;k=j<<1;n=(j|0)<0?k^79764919:k;k=n<<1;j=(n|0)<0?k^79764919:k;k=j<<1;n=(j|0)<0?k^79764919:k;k=n<<1;j=(n|0)<0?k^79764919:k;k=j<<1;n=(j|0)<0?k^79764919:k;k=n<<1;s=(n|0)<0?k^79764919:k;k=o-1|0;if((k|0)==0){break}else{q=s;o=k;b=b+1|0}}if((rq(a,f,e)|0)!=0){p=1;i=g;return p|0}b=c[14504]|0;o=e;e=f;while(1){f=(d[e]|0)<<24^b;q=f<<1;k=(f|0)<0?q^79764919:q;q=k<<1;f=(k|0)<0?q^79764919:q;q=f<<1;k=(f|0)<0?q^79764919:q;q=k<<1;f=(k|0)<0?q^79764919:q;q=f<<1;k=(f|0)<0?q^79764919:q;q=k<<1;f=(k|0)<0?q^79764919:q;q=f<<1;k=(f|0)<0?q^79764919:q;q=k<<1;t=(k|0)<0?q^79764919:q;q=o-1|0;if((q|0)==0){break}else{b=t;o=q;e=e+1|0}}c[14504]=t;r=s}rh(h,0,r);if((rq(a,h,4)|0)!=0){p=1;i=g;return p|0}a=c[14504]|0;r=4;s=h;while(1){h=(d[s]|0)<<24^a;t=h<<1;e=(h|0)<0?t^79764919:t;t=e<<1;h=(e|0)<0?t^79764919:t;t=h<<1;e=(h|0)<0?t^79764919:t;t=e<<1;h=(e|0)<0?t^79764919:t;t=h<<1;e=(h|0)<0?t^79764919:t;t=e<<1;h=(e|0)<0?t^79764919:t;t=h<<1;e=(h|0)<0?t^79764919:t;t=e<<1;u=(e|0)<0?t^79764919:t;t=r-1|0;if((t|0)==0){break}else{a=u;r=t;s=s+1|0}}c[14504]=u;p=0;i=g;return p|0}function q_(e,f,g,h,j){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;k=i;i=i+256|0;l=k|0;m=c[f+12>>2]|0;n=m&1;o=(m&2|0)==0?n:n|2;n=(m&4|0)==0?o:o|4;o=(m&8|0)==0?n:n|8;n=o&255;m=(p3(f)|0)==0;p=b[f+10>>1]|0;do{if(m){q=n;r=(p&65535)+12|0}else{if(p<<16>>16==0){q=n;r=12;break}q=(o|128)&255;r=13}}while(0);o=(j|0)==0?q:q|64;q=l|0;rg(q,0,21315);rg(q,2,r);r=b[f+16>>1]|0;j=r&65535;if((j|0)==32769){s=25e4;t=1}else if((j|0)==2){s=25e4;t=r&255}else if((j|0)==32770){s=5e5;t=2}else if((j|0)==16386){s=1e6;t=2}else if((j|0)==3){s=5e5;t=r&255}else if((j|0)==1){s=125e3;t=1}else{s=0;t=0}rh(q,12,s);a[l+4|0]=o;a[l+5|0]=g&255;a[l+6|0]=h&255;a[l+7|0]=b[f+4>>1]&255;a[l+8|0]=b[f+6>>1]&255;a[l+9|0]=b[f+8>>1]&255;h=f+10|0;g=b[h>>1]|0;a[l+10|0]=(g&65535)>>>8&255;a[l+11|0]=g&255;a[l+12|0]=t;t=0;l=16;g=q;while(1){s=(d[g]|0)<<24^t;j=s<<1;r=(s|0)<0?j^79764919:j;j=r<<1;s=(r|0)<0?j^79764919:j;j=s<<1;r=(s|0)<0?j^79764919:j;j=r<<1;s=(r|0)<0?j^79764919:j;j=s<<1;r=(s|0)<0?j^79764919:j;j=r<<1;s=(r|0)<0?j^79764919:j;j=s<<1;r=(s|0)<0?j^79764919:j;j=r<<1;u=(r|0)<0?j^79764919:j;j=l-1|0;if((j|0)==0){break}else{t=u;l=j;g=g+1|0}}if((rq(e,q,16)|0)!=0){v=1;i=k;return v|0}g=c[14504]|0;l=16;t=q;while(1){j=(d[t]|0)<<24^g;r=j<<1;s=(j|0)<0?r^79764919:r;r=s<<1;j=(s|0)<0?r^79764919:r;r=j<<1;s=(j|0)<0?r^79764919:r;r=s<<1;j=(s|0)<0?r^79764919:r;r=j<<1;s=(j|0)<0?r^79764919:r;r=s<<1;j=(s|0)<0?r^79764919:r;r=j<<1;s=(j|0)<0?r^79764919:r;r=s<<1;w=(s|0)<0?r^79764919:r;r=l-1|0;if((r|0)==0){break}else{g=w;l=r;t=t+1|0}}c[14504]=w;w=c[f+24>>2]|0;do{if(o<<24>>24<0){t=a[w]|0;a[q]=t;l=(t&255)<<24^u;t=l<<1;g=(l|0)<0?t^79764919:t;t=g<<1;l=(g|0)<0?t^79764919:t;t=l<<1;g=(l|0)<0?t^79764919:t;t=g<<1;l=(g|0)<0?t^79764919:t;t=l<<1;g=(l|0)<0?t^79764919:t;t=g<<1;l=(g|0)<0?t^79764919:t;t=l<<1;g=(l|0)<0?t^79764919:t;t=g<<1;if((rq(e,q,1)|0)==0){l=(d[q]|0)<<24^c[14504];r=l<<1;s=(l|0)<0?r^79764919:r;r=s<<1;l=(s|0)<0?r^79764919:r;r=l<<1;s=(l|0)<0?r^79764919:r;r=s<<1;l=(s|0)<0?r^79764919:r;r=l<<1;s=(l|0)<0?r^79764919:r;r=s<<1;l=(s|0)<0?r^79764919:r;r=l<<1;s=(l|0)<0?r^79764919:r;r=s<<1;x=(g|0)<0?t^79764919:t;y=(s|0)<0?r^79764919:r;break}else{v=1;i=k;return v|0}}else{r=b[h>>1]|0;s=r<<16>>16==0;if(s){z=u;A=0}else{t=r&65535;r=u;g=t;l=w;while(1){j=(d[l]|0)<<24^r;n=j<<1;p=(j|0)<0?n^79764919:n;n=p<<1;j=(p|0)<0?n^79764919:n;n=j<<1;p=(j|0)<0?n^79764919:n;n=p<<1;j=(p|0)<0?n^79764919:n;n=j<<1;p=(j|0)<0?n^79764919:n;n=p<<1;j=(p|0)<0?n^79764919:n;n=j<<1;p=(j|0)<0?n^79764919:n;n=p<<1;j=(p|0)<0?n^79764919:n;n=g-1|0;if((n|0)==0){z=j;A=t;break}else{r=j;g=n;l=l+1|0}}}if((rq(e,w,A)|0)!=0){v=1;i=k;return v|0}l=c[14504]|0;if(s){x=z;y=l;break}else{B=l;C=A;D=w}while(1){l=(d[D]|0)<<24^B;g=l<<1;r=(l|0)<0?g^79764919:g;g=r<<1;l=(r|0)<0?g^79764919:g;g=l<<1;r=(l|0)<0?g^79764919:g;g=r<<1;l=(r|0)<0?g^79764919:g;g=l<<1;r=(l|0)<0?g^79764919:g;g=r<<1;l=(r|0)<0?g^79764919:g;g=l<<1;r=(l|0)<0?g^79764919:g;g=r<<1;l=(r|0)<0?g^79764919:g;g=C-1|0;if((g|0)==0){x=z;y=l;break}else{B=l;C=g;D=D+1|0}}}}while(0);c[14504]=y;rh(q,0,x);if((rq(e,q,4)|0)!=0){v=1;i=k;return v|0}x=c[14504]|0;y=4;D=q;while(1){C=(d[D]|0)<<24^x;B=C<<1;z=(C|0)<0?B^79764919:B;B=z<<1;C=(z|0)<0?B^79764919:B;B=C<<1;z=(C|0)<0?B^79764919:B;B=z<<1;C=(z|0)<0?B^79764919:B;B=C<<1;z=(C|0)<0?B^79764919:B;B=z<<1;C=(z|0)<0?B^79764919:B;B=C<<1;z=(C|0)<0?B^79764919:B;B=z<<1;E=(z|0)<0?B^79764919:B;B=y-1|0;if((B|0)==0){break}else{x=E;y=B;D=D+1|0}}c[14504]=E;E=qj(f,q,256)|0;do{if((E|0)!=0){if((qZ(e,21575,E,q)|0)==0){break}else{v=1}i=k;return v|0}}while(0);v=0;i=k;return v|0}function q$(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0;j=i;i=i+560|0;k=j|0;l=j+256|0;m=j+288|0;n=j+296|0;o=j+552|0;p=o|0;rh(p,0,g);rh(p,4,h);if(!(a[6192]|0)){g=0;do{r=g<<25;s=(g&128|0)!=0?r^517762881:r;r=s<<1;t=(s|0)<0?r^517762881:r;r=t<<1;s=(t|0)<0?r^517762881:r;r=s<<1;t=(s|0)<0?r^517762881:r;r=t<<1;s=(t|0)<0?r^517762881:r;r=s<<1;t=(s|0)<0?r^517762881:r;r=t<<1;s=(t|0)<0?r^517762881:r;r=s<<1;c[55616+(g<<2)>>2]=(s|0)<0?r^517762881:r;g=g+1|0;}while(g>>>0<256);a[6192]=1}g=o+1|0;r=c[55616+(d[p]<<2)>>2]|0;s=o+2|0;t=c[55616+((d[g]^r>>>24)<<2)>>2]^r<<8;r=o+3|0;u=c[55616+((d[s]^t>>>24)<<2)>>2]^t<<8;t=o+4|0;v=c[55616+((d[r]^u>>>24)<<2)>>2]^u<<8;u=o+5|0;w=c[55616+((d[t]^v>>>24)<<2)>>2]^v<<8;v=o+6|0;y=c[55616+((d[u]^w>>>24)<<2)>>2]^w<<8;w=o+7|0;o=c[55616+((d[v]^y>>>24)<<2)>>2]^y<<8;y=c[55616+((d[w]^o>>>24)<<2)>>2]^o<<8;o=m|0;if(h>>>0<4){z=1;i=j;return z|0}if((bK(o|0,1,4,b|0)|0)!=4){z=1;i=j;return z|0}if(!(a[6192]|0)){A=0;do{B=A<<25;C=(A&128|0)!=0?B^517762881:B;B=C<<1;D=(C|0)<0?B^517762881:B;B=D<<1;C=(D|0)<0?B^517762881:B;B=C<<1;D=(C|0)<0?B^517762881:B;B=D<<1;C=(D|0)<0?B^517762881:B;B=C<<1;D=(C|0)<0?B^517762881:B;B=D<<1;C=(D|0)<0?B^517762881:B;B=C<<1;c[55616+(A<<2)>>2]=(C|0)<0?B^517762881:B;A=A+1|0;}while(A>>>0<256);a[6192]=1}A=c[55616+((d[o]^y>>>24)<<2)>>2]^y<<8;y=c[55616+((d[m+1|0]^A>>>24)<<2)>>2]^A<<8;A=c[55616+((d[m+2|0]^y>>>24)<<2)>>2]^y<<8;y=c[55616+((d[m+3|0]^A>>>24)<<2)>>2]^A<<8;A=rf(o,0)|0;if((A|0)!=262144){o=c[q>>2]|0;bN(o|0,47632,(x=i,i=i+8|0,c[x>>2]=A,x)|0)|0;z=1;i=j;return z|0}A=h-4|0;h=n|0;L430:do{if((A|0)==0){E=y}else{n=y;o=A;while(1){m=o>>>0<256?o:256;if((bK(h|0,1,m|0,b|0)|0)!=(m|0)){z=1;break}if(!(a[6192]|0)){B=0;do{C=B<<25;D=(B&128|0)!=0?C^517762881:C;C=D<<1;F=(D|0)<0?C^517762881:C;C=F<<1;D=(F|0)<0?C^517762881:C;C=D<<1;F=(D|0)<0?C^517762881:C;C=F<<1;D=(F|0)<0?C^517762881:C;C=D<<1;F=(D|0)<0?C^517762881:C;C=F<<1;D=(F|0)<0?C^517762881:C;C=D<<1;c[55616+(B<<2)>>2]=(D|0)<0?C^517762881:C;B=B+1|0;}while(B>>>0<256);a[6192]=1}if((m|0)==0){G=n}else{B=m;C=n;D=h;while(1){F=c[55616+((d[D]^C>>>24)<<2)>>2]^C<<8;H=B-1|0;if((H|0)==0){G=F;break}else{B=H;C=F;D=D+1|0}}}if((o|0)==(m|0)){E=G;break L430}else{n=G;o=o-m|0}}i=j;return z|0}}while(0);if((bK(h|0,1,4,b|0)|0)!=4){z=1;i=j;return z|0}if((rf(h,0)|0)!=(E|0)){E=c[q>>2]|0;aC(50888,16,1,E|0)|0;z=1;i=j;return z|0}E=k|0;k=l|0;G=l+12|0;A=l+13|0;l=0;L452:while(1){if((bK(p|0,1,8,b|0)|0)!=8){z=1;I=461;break}y=(l|0)==0;o=l+10|0;n=l+24|0;L455:while(1){if(!(a[6192]|0)){D=0;do{C=D<<25;B=(D&128|0)!=0?C^517762881:C;C=B<<1;F=(B|0)<0?C^517762881:C;C=F<<1;B=(F|0)<0?C^517762881:C;C=B<<1;F=(B|0)<0?C^517762881:C;C=F<<1;B=(F|0)<0?C^517762881:C;C=B<<1;F=(B|0)<0?C^517762881:C;C=F<<1;B=(F|0)<0?C^517762881:C;C=B<<1;c[55616+(D<<2)>>2]=(B|0)<0?C^517762881:C;D=D+1|0;}while(D>>>0<256);a[6192]=1}D=c[55616+(d[p]<<2)>>2]|0;m=c[55616+((d[g]^D>>>24)<<2)>>2]^D<<8;D=c[55616+((d[s]^m>>>24)<<2)>>2]^m<<8;m=c[55616+((d[r]^D>>>24)<<2)>>2]^D<<8;D=c[55616+((d[t]^m>>>24)<<2)>>2]^m<<8;m=c[55616+((d[u]^D>>>24)<<2)>>2]^D<<8;D=c[55616+((d[v]^m>>>24)<<2)>>2]^m<<8;J=c[55616+((d[w]^D>>>24)<<2)>>2]^D<<8;D=rf(p,0)|0;K=rf(p,4)|0;do{if((D|0)==1162757152){I=325;break L452}else if((D|0)==1397048148){break L455}else if((D|0)==1145132097){if(y){z=1;I=463;break L452}m=e[o>>1]|0;C=m>>>0<K>>>0?m:K;if((C|0)==0){L=J}else{m=c[n>>2]|0;if((bK(m|0,1,C|0,b|0)|0)!=(C|0)){z=1;I=464;break L452}if(a[6192]|0){M=C;N=J;O=m}else{B=0;do{F=B<<25;H=(B&128|0)!=0?F^517762881:F;F=H<<1;P=(H|0)<0?F^517762881:F;F=P<<1;H=(P|0)<0?F^517762881:F;F=H<<1;P=(H|0)<0?F^517762881:F;F=P<<1;H=(P|0)<0?F^517762881:F;F=H<<1;P=(H|0)<0?F^517762881:F;F=P<<1;H=(P|0)<0?F^517762881:F;F=H<<1;c[55616+(B<<2)>>2]=(H|0)<0?F^517762881:F;B=B+1|0;}while(B>>>0<256);a[6192]=1;M=C;N=J;O=m}while(1){B=c[55616+((d[O]^N>>>24)<<2)>>2]^N<<8;F=M-1|0;if((F|0)==0){L=B;break}else{M=F;N=B;O=O+1|0}}}if((C|0)==(K|0)){Q=L}else{m=L;B=K-C|0;while(1){F=B>>>0<256?B:256;if((bK(h|0,1,F|0,b|0)|0)!=(F|0)){z=1;I=465;break L452}if(!(a[6192]|0)){H=0;do{P=H<<25;R=(H&128|0)!=0?P^517762881:P;P=R<<1;S=(R|0)<0?P^517762881:P;P=S<<1;R=(S|0)<0?P^517762881:P;P=R<<1;S=(R|0)<0?P^517762881:P;P=S<<1;R=(S|0)<0?P^517762881:P;P=R<<1;S=(R|0)<0?P^517762881:P;P=S<<1;R=(S|0)<0?P^517762881:P;P=R<<1;c[55616+(H<<2)>>2]=(R|0)<0?P^517762881:P;H=H+1|0;}while(H>>>0<256);a[6192]=1}if((F|0)==0){T=m}else{H=F;P=m;R=h;while(1){S=c[55616+((d[R]^P>>>24)<<2)>>2]^P<<8;U=H-1|0;if((U|0)==0){T=S;break}else{H=U;P=S;R=R+1|0}}}if((B|0)==(F|0)){Q=T;break}else{m=T;B=B-F|0}}}if((bK(h|0,1,4,b|0)|0)!=4){z=1;I=466;break L452}if((rf(h,0)|0)!=(Q|0)){I=394;break L452}}else if((D|0)==1413564243){if(y){z=1;I=468;break L452}B=K>>>0<256?K:256;if((bK(E|0,1,B|0,b|0)|0)!=(B|0)){z=1;I=469;break L452}if(!(a[6192]|0)){m=0;do{C=m<<25;R=(m&128|0)!=0?C^517762881:C;C=R<<1;P=(R|0)<0?C^517762881:C;C=P<<1;R=(P|0)<0?C^517762881:C;C=R<<1;P=(R|0)<0?C^517762881:C;C=P<<1;R=(P|0)<0?C^517762881:C;C=R<<1;P=(R|0)<0?C^517762881:C;C=P<<1;R=(P|0)<0?C^517762881:C;C=R<<1;c[55616+(m<<2)>>2]=(R|0)<0?C^517762881:C;m=m+1|0;}while(m>>>0<256);a[6192]=1}if((B|0)==0){V=J}else{m=B;C=J;R=E;while(1){P=c[55616+((d[R]^C>>>24)<<2)>>2]^C<<8;H=m-1|0;if((H|0)==0){V=P;break}else{m=H;C=P;R=R+1|0}}}qa(l,E,B)|0;if((B|0)==(K|0)){W=V}else{R=V;C=K-B|0;while(1){m=C>>>0<256?C:256;if((bK(h|0,1,m|0,b|0)|0)!=(m|0)){z=1;I=470;break L452}if(!(a[6192]|0)){P=0;do{H=P<<25;S=(P&128|0)!=0?H^517762881:H;H=S<<1;U=(S|0)<0?H^517762881:H;H=U<<1;S=(U|0)<0?H^517762881:H;H=S<<1;U=(S|0)<0?H^517762881:H;H=U<<1;S=(U|0)<0?H^517762881:H;H=S<<1;U=(S|0)<0?H^517762881:H;H=U<<1;S=(U|0)<0?H^517762881:H;H=S<<1;c[55616+(P<<2)>>2]=(S|0)<0?H^517762881:H;P=P+1|0;}while(P>>>0<256);a[6192]=1}if((m|0)==0){X=R}else{P=m;F=R;H=h;while(1){S=c[55616+((d[H]^F>>>24)<<2)>>2]^F<<8;U=P-1|0;if((U|0)==0){X=S;break}else{P=U;F=S;H=H+1|0}}}if((C|0)==(m|0)){W=X;break}else{R=X;C=C-m|0}}}if((bK(h|0,1,4,b|0)|0)!=4){z=1;I=471;break L452}if((rf(h,0)|0)!=(W|0)){I=413;break L452}}else if((D|0)==1413830740){if((K|0)==0){if((bK(h|0,1,4,b|0)|0)!=4){z=1;I=473;break L452}if((rf(h,0)|0)==(J|0)){break}else{I=417;break L452}}Y=u0(K)|0;if((Y|0)==0){z=1;I=475;break L452}if((bK(Y|0,1,K|0,b|0)|0)!=(K|0)){I=424;break L452}if(a[6192]|0){Z=K;_=J;$=Y}else{C=0;do{R=C<<25;B=(C&128|0)!=0?R^517762881:R;R=B<<1;H=(B|0)<0?R^517762881:R;R=H<<1;B=(H|0)<0?R^517762881:R;R=B<<1;H=(B|0)<0?R^517762881:R;R=H<<1;B=(H|0)<0?R^517762881:R;R=B<<1;H=(B|0)<0?R^517762881:R;R=H<<1;B=(H|0)<0?R^517762881:R;R=B<<1;c[55616+(C<<2)>>2]=(B|0)<0?R^517762881:R;C=C+1|0;}while(C>>>0<256);a[6192]=1;Z=K;_=J;$=Y}while(1){aa=c[55616+((d[$]^_>>>24)<<2)>>2]^_<<8;C=Z-1|0;if((C|0)==0){break}else{Z=C;_=aa;$=$+1|0}}C=(a[Y]|0)==10;R=(C<<31>>31)+K|0;if((R|0)==0){ab=0}else{B=R-1|0;ab=(a[Y+B|0]|0)==10?B:R}R=qz(f,Y+(C&1)|0,ab)|0;u1(Y);do{if((bK(h|0,1,4,b|0)|0)==4){if((rf(h,0)|0)==(aa|0)){ac=0;break}C=c[q>>2]|0;aC(50888,16,1,C|0)|0;ac=1}else{ac=1}}while(0);if((ac|R|0)!=0){z=1;I=477;break L452}}else{if((K|0)==0){ad=J}else{C=J;B=K;while(1){H=B>>>0<256?B:256;if((bK(h|0,1,H|0,b|0)|0)!=(H|0)){z=1;I=479;break L452}if(!(a[6192]|0)){F=0;do{P=F<<25;S=(F&128|0)!=0?P^517762881:P;P=S<<1;U=(S|0)<0?P^517762881:P;P=U<<1;S=(U|0)<0?P^517762881:P;P=S<<1;U=(S|0)<0?P^517762881:P;P=U<<1;S=(U|0)<0?P^517762881:P;P=S<<1;U=(S|0)<0?P^517762881:P;P=U<<1;S=(U|0)<0?P^517762881:P;P=S<<1;c[55616+(F<<2)>>2]=(S|0)<0?P^517762881:P;F=F+1|0;}while(F>>>0<256);a[6192]=1}if((H|0)==0){ae=C}else{F=H;m=C;P=h;while(1){S=c[55616+((d[P]^m>>>24)<<2)>>2]^m<<8;U=F-1|0;if((U|0)==0){ae=S;break}else{F=U;m=S;P=P+1|0}}}if((B|0)==(H|0)){ad=ae;break}else{C=ae;B=B-H|0}}}if((bK(h|0,1,4,b|0)|0)!=4){z=1;I=480;break L452}if((rf(h,0)|0)!=(ad|0)){I=442;break L452}}}while(0);if((bK(p|0,1,8,b|0)|0)!=8){z=1;I=478;break L452}}if(K>>>0<18){z=1;I=454;break}if((bK(k|0,1,18,b|0)|0)!=18){z=1;I=455;break}if(a[6192]|0){af=18;ag=J;ah=k}else{n=0;do{o=n<<25;D=(n&128|0)!=0?o^517762881:o;o=D<<1;B=(D|0)<0?o^517762881:o;o=B<<1;D=(B|0)<0?o^517762881:o;o=D<<1;B=(D|0)<0?o^517762881:o;o=B<<1;D=(B|0)<0?o^517762881:o;o=D<<1;B=(D|0)<0?o^517762881:o;o=B<<1;D=(B|0)<0?o^517762881:o;o=D<<1;c[55616+(n<<2)>>2]=(D|0)<0?o^517762881:o;n=n+1|0;}while(n>>>0<256);a[6192]=1;af=18;ag=J;ah=k}while(1){ai=c[55616+((d[ah]^ag>>>24)<<2)>>2]^ag<<8;n=af-1|0;if((n|0)==0){break}else{af=n;ag=ai;ah=ah+1|0}}n=re(k,0)|0;o=re(k,2)|0;D=re(k,4)|0;B=re(k,6)|0;C=re(k,8)|0;R=re(k,10)|0;P=a[G]|0;m=re(k,14)|0;F=re(k,16)|0;aj=qh(D,B,C,R)|0;if((aj|0)==0){z=1;I=456;break}if((m&1|0)!=0){R=aj+12|0;c[R>>2]=c[R>>2]|1}if((m&2|0)!=0){R=aj+12|0;c[R>>2]=c[R>>2]|2}if((m&4|0)!=0){R=aj+12|0;c[R>>2]=c[R>>2]|4}if((m&8|0)!=0){R=aj+12|0;c[R>>2]=c[R>>2]|8}p5(aj,F);R=F&4095;if((R|0)==1|(R|0)==2){p6(aj,P)}else if((R|0)==3){p8(aj,P)}if((m&16384|0)==0){if((qw(f,aj,n,o)|0)!=0){I=360;break}}else{if(y){I=357;break}p0(l,aj)}o=K-18|0;if((m&32768|0)!=0){p2(aj,d[A]|0)}if((o|0)==0){ak=ai}else{m=ai;n=o;while(1){o=n>>>0<256?n:256;if((bK(h|0,1,o|0,b|0)|0)!=(o|0)){z=1;I=459;break L452}if(!(a[6192]|0)){P=0;do{R=P<<25;F=(P&128|0)!=0?R^517762881:R;R=F<<1;C=(F|0)<0?R^517762881:R;R=C<<1;F=(C|0)<0?R^517762881:R;R=F<<1;C=(F|0)<0?R^517762881:R;R=C<<1;F=(C|0)<0?R^517762881:R;R=F<<1;C=(F|0)<0?R^517762881:R;R=C<<1;F=(C|0)<0?R^517762881:R;R=F<<1;c[55616+(P<<2)>>2]=(F|0)<0?R^517762881:R;P=P+1|0;}while(P>>>0<256);a[6192]=1}if((o|0)==0){al=m}else{P=o;R=m;F=h;while(1){C=c[55616+((d[F]^R>>>24)<<2)>>2]^R<<8;B=P-1|0;if((B|0)==0){al=C;break}else{P=B;R=C;F=F+1|0}}}if((n|0)==(o|0)){ak=al;break}else{m=al;n=n-o|0}}}if((bK(h|0,1,4,b|0)|0)!=4){z=1;I=460;break}if((rf(h,0)|0)==(ak|0)){l=aj}else{I=375;break}}if((I|0)==325){L609:do{if((K|0)==0){am=J}else{l=J;ak=K;while(1){al=ak>>>0<256?ak:256;if((bK(h|0,1,al|0,b|0)|0)!=(al|0)){z=1;break}if(!(a[6192]|0)){ai=0;do{A=ai<<25;k=(ai&128|0)!=0?A^517762881:A;A=k<<1;G=(k|0)<0?A^517762881:A;A=G<<1;k=(G|0)<0?A^517762881:A;A=k<<1;G=(k|0)<0?A^517762881:A;A=G<<1;k=(G|0)<0?A^517762881:A;A=k<<1;G=(k|0)<0?A^517762881:A;A=G<<1;k=(G|0)<0?A^517762881:A;A=k<<1;c[55616+(ai<<2)>>2]=(k|0)<0?A^517762881:A;ai=ai+1|0;}while(ai>>>0<256);a[6192]=1}if((al|0)==0){an=l}else{ai=al;o=l;A=h;while(1){k=c[55616+((d[A]^o>>>24)<<2)>>2]^o<<8;G=ai-1|0;if((G|0)==0){an=k;break}else{ai=G;o=k;A=A+1|0}}}if((ak|0)==(al|0)){am=an;break L609}else{l=an;ak=ak-al|0}}i=j;return z|0}}while(0);if((bK(h|0,1,4,b|0)|0)!=4){z=1;i=j;return z|0}if((rf(h,0)|0)==(am|0)){qD(f);z=0;i=j;return z|0}else{f=c[q>>2]|0;aC(50888,16,1,f|0)|0;z=1;i=j;return z|0}}else if((I|0)==357){aC(53904,32,1,c[q>>2]|0)|0;qi(aj);z=1;i=j;return z|0}else if((I|0)==360){qi(aj);z=1;i=j;return z|0}else if((I|0)==375){aC(50888,16,1,c[q>>2]|0)|0;z=1;i=j;return z|0}else if((I|0)==394){aC(50888,16,1,c[q>>2]|0)|0;z=1;i=j;return z|0}else if((I|0)==413){aC(50888,16,1,c[q>>2]|0)|0;z=1;i=j;return z|0}else if((I|0)==417){aC(50888,16,1,c[q>>2]|0)|0;z=1;i=j;return z|0}else if((I|0)==424){u1(Y);z=1;i=j;return z|0}else if((I|0)==442){aC(50888,16,1,c[q>>2]|0)|0;z=1;i=j;return z|0}else if((I|0)==454){i=j;return z|0}else if((I|0)==455){i=j;return z|0}else if((I|0)==456){i=j;return z|0}else if((I|0)==459){i=j;return z|0}else if((I|0)==460){i=j;return z|0}else if((I|0)==461){i=j;return z|0}else if((I|0)==463){i=j;return z|0}else if((I|0)==464){i=j;return z|0}else if((I|0)==465){i=j;return z|0}else if((I|0)==466){i=j;return z|0}else if((I|0)==468){i=j;return z|0}else if((I|0)==469){i=j;return z|0}else if((I|0)==470){i=j;return z|0}else if((I|0)==471){i=j;return z|0}else if((I|0)==473){i=j;return z|0}else if((I|0)==475){i=j;return z|0}else if((I|0)==477){i=j;return z|0}else if((I|0)==478){i=j;return z|0}else if((I|0)==479){i=j;return z|0}else if((I|0)==480){i=j;return z|0}return 0}function q0(d,f){d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;i=i+48|0;h=g|0;j=g+8|0;k=g+16|0;l=g+24|0;m=g+40|0;rg(m,0,4);rg(m,2,0);if((q1(d,1346782275,4,m)|0)!=0){n=1;i=g;return n|0}m=l|0;o=f+8|0;do{if((c[o>>2]|0)!=0){rh(m,0,1413830740);rh(m,4,(c[o>>2]|0)+2|0);p=l+8|0;a[p]=10;c[k>>2]=0;q=q2(d,m,9,k)|0;r=q2(d,c[f+12>>2]|0,c[o>>2]|0,k)|0|q;q=r|(q2(d,p,1,k)|0);rh(m,0,c[k>>2]|0);if((q|(aC(m|0,1,4,d|0)|0)!=4|0)==0){break}else{n=1}i=g;return n|0}}while(0);m=f|0;k=b[m>>1]|0;L676:do{if(k<<16>>16!=0){o=f+4|0;l=0;q=k;L678:while(1){p=c[(c[o>>2]|0)+(l<<2)>>2]|0;r=p+2|0;s=b[r>>1]|0;if(s<<16>>16==0){t=q}else{u=p+4|0;p=0;v=s;while(1){s=c[(c[u>>2]|0)+(p<<2)>>2]|0;w=s+2|0;if((b[w>>1]|0)==0){x=v}else{y=s+4|0;s=0;do{z=c[(c[y>>2]|0)+(s<<2)>>2]|0;if((q3(d,z,l,p,0)|0)==0){A=z}else{n=1;B=506;break L678}while(1){z=c[A>>2]|0;if((z|0)==0){break}if((q3(d,z,l,p,1)|0)==0){A=z}else{n=1;B=503;break L678}}s=s+1|0;}while(s>>>0<(e[w>>1]|0)>>>0);x=b[r>>1]|0}w=p+1|0;if(w>>>0<(x&65535)>>>0){p=w;v=x}else{break}}t=b[m>>1]|0}v=l+1|0;if(v>>>0<(t&65535)>>>0){l=v;q=t}else{break L676}}if((B|0)==503){i=g;return n|0}else if((B|0)==506){i=g;return n|0}}}while(0);B=j|0;rh(B,0,1162757152);rh(B,4,0);c[h>>2]=0;if((q2(d,B,8,h)|0)!=0){n=1;i=g;return n|0}rh(B,0,c[h>>2]|0);if((aC(B|0,1,4,d|0)|0)!=4){n=1;i=g;return n|0}ay(d|0)|0;n=0;i=g;return n|0}function q1(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+16|0;g=f|0;h=f+8|0;rh(h,0,b);rh(h,4,d);c[g>>2]=0;if((q2(a,h,8,g)|0)!=0){j=1;i=f;return j|0}do{if((d|0)!=0){if((q2(a,e,d,g)|0)==0){break}else{j=1}i=f;return j|0}}while(0);rh(h,0,c[g>>2]|0);j=(aC(h|0,1,4,a|0)|0)!=4|0;i=f;return j|0}function q2(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((g|0)==0){h=aC(e|0,1,f|0,b|0)|0;i=(h|0)!=(f|0);j=i&1;return j|0}k=c[g>>2]|0;if(!(a[6192]|0)){l=0;do{m=l<<25;n=(l&128|0)!=0?m^517762881:m;m=n<<1;o=(n|0)<0?m^517762881:m;m=o<<1;n=(o|0)<0?m^517762881:m;m=n<<1;o=(n|0)<0?m^517762881:m;m=o<<1;n=(o|0)<0?m^517762881:m;m=n<<1;o=(n|0)<0?m^517762881:m;m=o<<1;n=(o|0)<0?m^517762881:m;m=n<<1;c[55616+(l<<2)>>2]=(n|0)<0?m^517762881:m;l=l+1|0;}while(l>>>0<256);a[6192]=1}if((f|0)==0){p=k}else{l=f;m=k;k=e;while(1){n=c[55616+(((d[k]|0)^m>>>24)<<2)>>2]^m<<8;o=l-1|0;if((o|0)==0){p=n;break}else{l=o;m=n;k=k+1|0}}}c[g>>2]=p;h=aC(e|0,1,f|0,b|0)|0;i=(h|0)!=(f|0);j=i&1;return j|0}function q3(d,f,g,h,j){d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=i;i=i+256|0;l=k|0;m=c[f+12>>2]|0;n=m&1;o=(m&2|0)==0?n:n|2;n=(m&4|0)==0?o:o|4;o=(m&8|0)==0?n:n|8;n=f+10|0;if((p3(f)|0)==0){p=o}else{p=(b[n>>1]|0)==0?o:o|32768}o=(j|0)==0?p:p|16384;p=l|0;rg(p,0,g);rg(p,2,h);rg(p,4,e[f+4>>1]|0);rg(p,6,e[f+6>>1]|0);rg(p,8,e[f+8>>1]|0);rg(p,10,e[n>>1]|0);rg(p,12,0);rg(p,14,o);h=f+16|0;rg(p,16,e[h>>1]|0);if((o&32768|0)!=0){a[l+13|0]=a[c[f+24>>2]|0]|0}g=b[h>>1]&4095;if((g|0)==3){a[l+12|0]=(p9(f)|0)&255}else if((g|0)==1|(g|0)==2){a[l+12|0]=(p7(f)|0)&255}if((q1(d,1397048148,18,p)|0)!=0){q=1;i=k;return q|0}g=qj(f,p,256)|0;L744:do{if((g|0)!=0){h=0;while(1){if(h>>>0>=g>>>0){break L744}if((a[l+h|0]|0)==0){h=h+1|0}else{break}}if((q1(d,1413564243,g,p)|0)==0){break}else{q=1}i=k;return q|0}}while(0);do{if((o&32776|0)==0){p=b[n>>1]|0;if(p<<16>>16==0){break}if((q1(d,1145132097,p&65535,c[f+24>>2]|0)|0)==0){break}else{q=1}i=k;return q|0}}while(0);q=0;i=k;return q|0}function q4(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;b=qs()|0;if((b|0)==0){d=0;return d|0}e=a0(a|0)|0;L761:do{if((bR(a|0,0,2)|0)==0){f=a0(a|0)|0;if((bR(a|0,e|0,0)|0)==0){g=0}else{break}while(1){h=c[28544+(g*24|0)>>2]|0;if((h|0)==0){break L761}if((h|0)==(f|0)){break}else{g=g+1|0}}f=28548+(g*24|0)|0;h=c[f>>2]|0;if((h|0)==0){d=b;return d|0}i=28552+(g*24|0)|0;j=28556+(g*24|0)|0;k=28560+(g*24|0)|0;l=28564+(g*24|0)|0;m=0;n=c[i>>2]|0;o=h;L770:while(1){if((n|0)==0){p=0;q=o}else{h=0;do{r=qx(b,m,h,1)|0;if((r|0)==0){break L761}else{s=0}while(1){if(s>>>0>=(c[j>>2]|0)>>>0){break}s=s+1|0;t=qh(m,h,s,c[k>>2]|0)|0;if((t|0)==0){break L761}p5(t,c[l>>2]|0);if((qm(r,t)|0)!=0){u=561;break L770}v=bK(c[t+24>>2]|0,1,c[k>>2]|0,a|0)|0;if((v|0)!=(c[k>>2]|0)){break L761}}h=h+1|0;w=c[i>>2]|0;}while(h>>>0<w>>>0);p=w;q=c[f>>2]|0}h=m+1|0;if(h>>>0<q>>>0){m=h;n=p;o=q}else{d=b;u=568;break}}if((u|0)==568){return d|0}else if((u|0)==561){qi(t);break}}}while(0);qt(b);d=0;return d|0}function q5(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=d|0;g=b[f>>1]|0;L789:do{if(g<<16>>16!=0){h=d+4|0;i=0;j=g;L791:while(1){k=c[(c[h>>2]|0)+(i<<2)>>2]|0;l=k+2|0;if((b[l>>1]|0)==0){m=j}else{n=k+4|0;k=0;do{o=c[(c[n>>2]|0)+(k<<2)>>2]|0;p=o+2|0;q=b[p>>1]|0;L797:do{if(q<<16>>16!=0){r=c[o+4>>2]|0;s=q&65535;t=0;u=65535;v=0;while(1){w=c[r+(t<<2)>>2]|0;x=e[w+8>>1]|0;y=x>>>0<u>>>0;z=y?w:v;w=t+1|0;if(w>>>0<s>>>0){t=w;u=y?x:u;v=z}else{break}}if((z|0)==0){break}v=o+4|0;u=z;t=z;while(1){s=(e[u+8>>1]|0)+1|0;r=t+10|0;x=aC(c[t+24>>2]|0,1,e[r>>1]|0,a|0)|0;if((x|0)!=(e[r>>1]|0)){A=1;break L791}r=b[p>>1]|0;if(r<<16>>16==0){break L797}x=c[v>>2]|0;y=r&65535;r=0;w=65535;B=0;while(1){C=c[x+(r<<2)>>2]|0;D=e[C+8>>1]|0;E=D>>>0>=s>>>0&D>>>0<w>>>0;F=E?C:B;C=r+1|0;if(C>>>0<y>>>0){r=C;w=E?D:w;B=F}else{break}}if((F|0)==0){break L797}u=F;t=F}}}while(0);k=k+1|0;}while(k>>>0<(e[l>>1]|0)>>>0);m=b[f>>1]|0}l=i+1|0;if(l>>>0<(m&65535)>>>0){i=l;j=m}else{break L789}}return A|0}}while(0);ay(a|0)|0;A=0;return A|0}function q6(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;if((bR(a|0,0,2)|0)!=0){b=0;return b|0}d=a0(a|0)|0;a=0;while(1){e=28544+(a*24|0)|0;f=c[e>>2]|0;if((f|0)==0){g=0;break}if((f|0)==(d|0)){g=e;break}else{a=a+1|0}}b=(g|0)!=0|0;return b|0}function q7(b){b=b|0;var e=0,f=0,g=0,h=0;e=b+65544|0;f=c[e>>2]|0;g=(d[(f>>>3)+(b+4)|0]&128>>>((f&7)>>>0)|0)!=0|0;h=f+1|0;c[e>>2]=h;if(h>>>0>=(c[b+65540>>2]|0)>>>0){c[e>>2]=0;e=b+65548|0;c[e>>2]=(c[e>>2]|0)+1}e=b+65555|0;a[e]=(a[e]|0)==0|0;return g|0}function q8(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0;g=i;i=i+65616|0;h=g+8|0;j=g+16|0;k=g+24|0;l=g+32|0;m=g+40|0;n=g+48|0;o=g+56|0;p=qs()|0;if((p|0)==0){r=0;i=g;return r|0}s=o|0;c[s>>2]=f;f=o+65540|0;u6(f|0,0,16);t=g|0;u=o+65544|0;v=o+65554|0;w=o+65548|0;y=j|0;z=j+1|0;A=j+2|0;B=j+3|0;C=j+4|0;D=j+5|0;j=o+65552|0;E=h|0;F=h+1|0;h=o+4|0;G=0;L834:while(1){H=G<<1;I=0;do{c[u>>2]=0;c[f>>2]=0;a[v]=0;J=c[s>>2]|0;K=I+H<<1;if((bR(J|0,K+773|0,0)|0)!=0){break L834}if((bK(t|0,1,2,J|0)|0)!=2){break L834}L=(re(t,0)|0)<<8;L840:do{if((L|0)!=0){if((bR(J|0,K+1285|0,0)|0)!=0){break L834}if((bK(t|0,1,2,J|0)|0)!=2){break L834}M=ri(t,0)|0;if((bR(J|0,L|0,0)|0)!=0){break L834}if((bK(h|0,1,M|0,J|0)|0)!=(M|0)){break L834}c[u>>2]=0;N=M<<3;c[f>>2]=N;if((N|0)==0){break}else{O=0}while(1){if(O>>>0>=2){break L840}c[w>>2]=0;c[u>>2]=0;L849:do{do{if((q9(o,n,m)|0)==0){if((O|0)==0){if((c[m>>2]|0)!=0){break}}else if((O|0)==1){if((c[m>>2]|0)==0){break}}if((c[w>>2]|0)!=0){break L849}N=d[n]|0;M=c[m>>2]|0;P=c[u>>2]|0;do{if((N|0)==254){ra(o,y);ra(o,z);ra(o,A);ra(o,B);ra(o,C);ra(o,D);Q=re(y,4)|0;R=e[j>>1]|0;S=4;T=y;while(1){U=d[T]<<8^R;V=U<<1;W=(U&32768|0)==0?V:V^4129;V=W<<1;U=(W&32768|0)==0?V:V^4129;V=U<<1;W=(U&32768|0)==0?V:V^4129;V=W<<1;U=(W&32768|0)==0?V:V^4129;V=U<<1;W=(U&32768|0)==0?V:V^4129;V=W<<1;U=(W&32768|0)==0?V:V^4129;V=U<<1;W=(U&32768|0)==0?V:V^4129;V=W<<1;X=(W&32768|0)==0?V:V^4129;V=S-1|0;if((V|0)==0){break}else{R=X;S=V;T=T+1|0}}b[j>>1]=X&65535;T=a[B]|0;S=qh(d[y]|0,d[z]|0,d[A]|0,(T&255)<6?128<<(T&255):8192)|0;if((S|0)==0){break L834}p6(S,a[B]|0);p4(S,8,1);if((X&65535|0)!=(Q|0)){p4(S,1,1)}p2(S,0);if((M|0)==0){p5(S,2)}else{p5(S,1)}qw(p,S,G,I)|0;if((q9(o,l,k)|0)!=0){break}T=a[l]|0;if(!((T<<24>>24|0)==(-8|0)|(T<<24>>24|0)==(-5|0))){break}R=S+24|0;V=c[R>>2]|0;W=S+10|0;U=b[W>>1]|0;Y=U&65535;if(U<<16>>16!=0){Z=0;do{ra(o,V+Z|0);Z=Z+1|0;}while(Z>>>0<Y>>>0);if(U<<16>>16!=(b[W>>1]|0)){break L834}}ra(o,E);ra(o,F);p4(S,8,0);p4(S,4,T<<24>>24==-8|0);Y=re(E,0)|0;Z=e[j>>1]|0;V=b[W>>1]|0;if(V<<16>>16==0){_=Z}else{Q=Z;Z=V&65535;V=c[R>>2]|0;while(1){$=d[V]<<8^Q;aa=$<<1;ab=($&32768|0)==0?aa:aa^4129;aa=ab<<1;$=(ab&32768|0)==0?aa:aa^4129;aa=$<<1;ab=($&32768|0)==0?aa:aa^4129;aa=ab<<1;$=(ab&32768|0)==0?aa:aa^4129;aa=$<<1;ab=($&32768|0)==0?aa:aa^4129;aa=ab<<1;$=(ab&32768|0)==0?aa:aa^4129;aa=$<<1;ab=($&32768|0)==0?aa:aa^4129;aa=ab<<1;$=(ab&32768|0)==0?aa:aa^4129;aa=Z-1|0;if((aa|0)==0){_=$;break}else{Q=$;Z=aa;V=V+1|0}}}b[j>>1]=_&65535;if((_&65535|0)==(Y|0)){break}p4(S,2,1)}else if(!((N|0)==248|(N|0)==251)){V=c[f>>2]|0;bN(c[q>>2]|0,50776,(x=i,i=i+48|0,c[x>>2]=N,c[x+8>>2]=(M|0)!=0?53896:47624,c[x+16>>2]=G,c[x+24>>2]=I,c[x+32>>2]=P,c[x+40>>2]=V,x)|0)|0}}while(0);c[w>>2]=0;c[u>>2]=P}}while(0);}while((c[w>>2]|0)==0);if((qp(p,G,I,0,1)|0)==0){O=O+1|0}else{break}}}}while(0);I=I+1|0;}while(I>>>0<2);I=G+1|0;if(I>>>0<80){G=I}else{r=p;ac=652;break}}if((ac|0)==652){i=g;return r|0}qt(p);r=0;i=g;return r|0}function q9(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;c[h>>2]=0;a[g]=0;i=f+65554|0;a[i]=0;j=f+65548|0;k=c[j>>2]|0;l=k+2|0;m=f+65544|0;n=f+65555|0;o=c[f+65540>>2]|0;p=0;q=c[m>>2]|0;r=k;while(1){k=(d[(q>>>3)+(f+4)|0]&128>>>((q&7)>>>0)|0)!=0|0;s=q+1|0;c[m>>2]=s;if(s>>>0<o>>>0){t=s;u=r}else{c[m>>2]=0;s=r+1|0;c[j>>2]=s;t=0;u=s}a[n]=(a[n]|0)==0|0;s=k|p<<1;k=s&65535;if((k|0)==17545){v=657;break}else if((k|0)==63338){v=658;break}else if((k|0)==62846){v=659;break}else if((k|0)==62831){v=660;break}else if((k|0)==62826){v=661;break}if((a[g]|0)!=0){break}if(u>>>0<l>>>0){p=s;q=t;r=u}else{w=1;v=669;break}}if((v|0)==657){a[g]=-95}else if((v|0)==669){return w|0}else if((v|0)==658){a[g]=-4}else if((v|0)==659){a[g]=-2}else if((v|0)==660){a[g]=-5}else if((v|0)==661){a[g]=-8}a[i]=1;a[n]=1;n=d[g]<<8^65535;i=n<<1;u=(n&32768|0)==0?i:i^4129;i=u<<1;n=(u&32768|0)==0?i:i^4129;i=n<<1;u=(n&32768|0)==0?i:i^4129;i=u<<1;n=(u&32768|0)==0?i:i^4129;i=n<<1;u=(n&32768|0)==0?i:i^4129;i=u<<1;n=(u&32768|0)==0?i:i^4129;i=n<<1;u=(n&32768|0)==0?i:i^4129;i=u<<1;n=f+65552|0;b[n>>1]=((u&32768|0)==0?i:i^4129)&65535;if((a[g]|0)==-95){x=0}else{c[h>>2]=1;w=0;return w|0}while(1){ra(f,g);h=d[g]<<8^e[n>>1];i=h<<1;u=(h&32768|0)==0?i:i^4129;i=u<<1;h=(u&32768|0)==0?i:i^4129;i=h<<1;u=(h&32768|0)==0?i:i^4129;i=u<<1;h=(u&32768|0)==0?i:i^4129;i=h<<1;u=(h&32768|0)==0?i:i^4129;i=u<<1;h=(u&32768|0)==0?i:i^4129;i=h<<1;u=(h&32768|0)==0?i:i^4129;i=u<<1;b[n>>1]=((u&32768|0)==0?i:i^4129)&65535;if(x>>>0>=2){w=0;v=670;break}if((a[g]|0)==-95){x=x+1|0}else{w=0;v=671;break}}if((v|0)==670){return w|0}else if((v|0)==671){return w|0}return 0}function ra(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;a[d]=0;e=b+65555|0;if((a[e]|0)==0){f=0}else{g=b+65544|0;h=(c[g>>2]|0)+1|0;c[g>>2]=h;if(h>>>0>=(c[b+65540>>2]|0)>>>0){c[g>>2]=0;g=b+65548|0;c[g>>2]=(c[g>>2]|0)+1}a[e]=0;f=a[d]<<1}a[d]=f;if((q7(b)|0)!=0){a[d]=a[d]|1}q7(b)|0;a[d]=a[d]<<1;if((q7(b)|0)!=0){a[d]=a[d]|1}q7(b)|0;a[d]=a[d]<<1;if((q7(b)|0)!=0){a[d]=a[d]|1}q7(b)|0;a[d]=a[d]<<1;if((q7(b)|0)!=0){a[d]=a[d]|1}q7(b)|0;a[d]=a[d]<<1;if((q7(b)|0)!=0){a[d]=a[d]|1}q7(b)|0;a[d]=a[d]<<1;if((q7(b)|0)!=0){a[d]=a[d]|1}q7(b)|0;a[d]=a[d]<<1;if((q7(b)|0)!=0){a[d]=a[d]|1}q7(b)|0;a[d]=a[d]<<1;if((q7(b)|0)==0){i=q7(b)|0;return}a[d]=a[d]|1;i=q7(b)|0;return}function rb(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0;g=i;i=i+48|0;h=g|0;j=g+8|0;k=g+16|0;l=g+32|0;m=qs()|0;if((m|0)==0){n=0;i=g;return n|0}o=l|0;L955:do{if((ro(f,o,12)|0)==0){p=a[o]|0;if((p<<24>>24|0)==116){if((a[l+1|0]|0)!=100){break}r=c[q>>2]|0;aC(53848,40,1,r|0)|0;break}else if((p<<24>>24|0)!=84){break}if((a[l+1|0]|0)!=68){break}if((a[l+2|0]|0)!=0){break}if((d[l+4|0]|0)>21){break}p=a[l+5|0]|0;r=a[l+7|0]|0;s=ri(o,10)|0;t=0;u=10;v=o;while(1){w=d[v]<<8^t;y=w<<1;z=(w&32768|0)==0?y:y^41111;y=z<<1;w=(z&32768|0)==0?y:y^41111;y=w<<1;z=(w&32768|0)==0?y:y^41111;y=z<<1;w=(z&32768|0)==0?y:y^41111;y=w<<1;z=(w&32768|0)==0?y:y^41111;y=z<<1;w=(z&32768|0)==0?y:y^41111;y=w<<1;z=(w&32768|0)==0?y:y^41111;y=z<<1;A=(z&32768|0)==0?y:y^41111;y=u-1|0;if((y|0)==0){break}else{t=A;u=y;v=v+1|0}}v=p&255;u=A&65535;if((s|0)!=(u|0)){t=c[q>>2]|0;bN(t|0,47592,(x=i,i=i+16|0,c[x>>2]=s,c[x+8>>2]=u,x)|0)|0;break}u=k|0;do{if(r<<24>>24<0){if((ro(f,u,10)|0)!=0){break L955}t=ri(u,0)|0;y=0;z=8;w=k+2|0;while(1){B=d[w]<<8^y;C=B<<1;D=(B&32768|0)==0?C:C^41111;C=D<<1;B=(D&32768|0)==0?C:C^41111;C=B<<1;D=(B&32768|0)==0?C:C^41111;C=D<<1;B=(D&32768|0)==0?C:C^41111;C=B<<1;D=(B&32768|0)==0?C:C^41111;C=D<<1;B=(D&32768|0)==0?C:C^41111;C=B<<1;D=(B&32768|0)==0?C:C^41111;C=D<<1;E=(D&32768|0)==0?C:C^41111;C=z-1|0;if((C|0)==0){break}else{y=E;z=C;w=w+1|0}}w=E&65535;z=ri(u,2)|0;if((z|0)==0){F=w}else{y=u0(z)|0;if((y|0)==0){break L955}if((ro(f,y,z)|0)==0){G=w;H=z;I=y}else{u1(y);break L955}while(1){w=d[I]<<8^G;C=w<<1;D=(w&32768|0)==0?C:C^41111;C=D<<1;w=(D&32768|0)==0?C:C^41111;C=w<<1;D=(w&32768|0)==0?C:C^41111;C=D<<1;w=(D&32768|0)==0?C:C^41111;C=w<<1;D=(w&32768|0)==0?C:C^41111;C=D<<1;w=(D&32768|0)==0?C:C^41111;C=w<<1;D=(w&32768|0)==0?C:C^41111;C=D<<1;J=(D&32768|0)==0?C:C^41111;C=H-1|0;if((C|0)==0){break}else{G=J;H=C;I=I+1|0}}C=J&65535;D=0;while(1){if(D>>>0>=z>>>0){K=z;break}if((a[y+D|0]|0)==0){D=D+1|0}else{K=z;break}}while(1){if(D>>>0>=K>>>0){break}z=K-1|0;if((a[y+z|0]|0)==0){K=z}else{L=D;M=722;break}}if((M|0)==722){while(1){M=0;z=y+L|0;if((a[z]|0)==0){a[z]=10}z=L+1|0;if(z>>>0<K>>>0){L=z;M=722}else{break}}}qC(m,y+D|0,K-D|0)|0;u1(y);qD(m);F=C}if((t|0)==(F|0)){break}bN(c[q>>2]|0,54576,(x=i,i=i+16|0,c[x>>2]=t,c[x+8>>2]=F,x)|0)|0;break L955}}while(0);if((ro(f,u,1)|0)!=0){break}r=k+1|0;s=k+3|0;p=v|128;z=j|0;w=j+2|0;B=j+3|0;N=j+4|0;O=j+1|0;P=j+5|0;Q=h|0;R=h+2|0;S=h+3|0;T=h+1|0;U=k+2|0;L1001:while(1){if((a[u]|0)==-1){n=m;M=800;break}if((ro(f,r,3)|0)!=0){break L955}V=a[u]|0;W=V&255;X=W<<9;Y=(W&128|0)==0?X:X^41111;X=Y<<1;Z=(Y&32768|0)==0?X:X^41111;X=Z<<1;Y=(Z&32768|0)==0?X:X^41111;X=Y<<1;Z=(Y&32768|0)==0?X:X^41111;X=Z<<1;Y=(Z&32768|0)==0?X:X^41111;X=Y<<1;Z=(Y&32768|0)==0?X:X^41111;X=Z<<1;Y=(Z&32768|0)==0?X:X^41111;X=Y<<1;_=d[r]|0;Z=((Y&32768|0)==0?X:X^41111)^_<<8;X=Z<<1;Y=(Z&32768|0)==0?X:X^41111;X=Y<<1;Z=(Y&32768|0)==0?X:X^41111;X=Z<<1;Y=(Z&32768|0)==0?X:X^41111;X=Y<<1;Z=(Y&32768|0)==0?X:X^41111;X=Z<<1;Y=(Z&32768|0)==0?X:X^41111;X=Y<<1;Z=(Y&32768|0)==0?X:X^41111;X=Z<<1;Y=(Z&32768|0)==0?X:X^41111;X=Y<<1;Z=d[U]|0;$=((Y&32768|0)==0?X:X^41111)^Z<<8;X=$<<1;Y=($&32768|0)==0?X:X^41111;X=Y<<1;$=(Y&32768|0)==0?X:X^41111;X=$<<1;Y=($&32768|0)==0?X:X^41111;X=Y<<1;$=(Y&32768|0)==0?X:X^41111;X=$<<1;Y=($&32768|0)==0?X:X^41111;X=Y<<1;$=(Y&32768|0)==0?X:X^41111;X=$<<1;Y=($&32768|0)==0?X:X^41111;X=Y<<1;aa=(Y&32768|0)==0?X:X^41111;ab=d[s]|0;if((ab|0)!=(aa&255|0)){M=734;break}ac=Z&127;X=(Z&128|0)==0?v:p;if(V<<24>>24!=0){V=2-(X>>>7)|0;Z=(X&127|0)==2?V|32768:V;V=0;do{if((ro(f,z,6)|0)!=0){break L955}ad=d[w]|0;X=a[B]|0;Y=d[N]|0;$=(X&255)<7;if($){ae=128<<(X&255)}else{ae=0}af=qh(d[z]|0,d[O]|0,ad,ae)|0;if((af|0)==0){break L955}p6(af,a[B]|0);if((qw(m,af,_,ac)|0)!=0){M=742;break L1001}p5(af,Z);if((Y&2|0)!=0){p4(af,2,1)}if((Y&4|0)!=0){p4(af,4,1)}X=a[P]|0;ag=0;ah=5;ai=z;while(1){aj=d[ai]<<8^ag;ak=aj<<1;al=(aj&32768|0)==0?ak:ak^41111;ak=al<<1;aj=(al&32768|0)==0?ak:ak^41111;ak=aj<<1;al=(aj&32768|0)==0?ak:ak^41111;ak=al<<1;aj=(al&32768|0)==0?ak:ak^41111;ak=aj<<1;al=(aj&32768|0)==0?ak:ak^41111;ak=al<<1;aj=(al&32768|0)==0?ak:ak^41111;ak=aj<<1;al=(aj&32768|0)==0?ak:ak^41111;ak=al<<1;am=(al&32768|0)==0?ak:ak^41111;ak=ah-1|0;if((ak|0)==0){break}else{ag=am;ah=ak;ai=ai+1|0}}an=X&255;ai=am&65535;do{if((Y&48|0)==0){do{if($){if((ro(f,z,3)|0)!=0){break L955}ah=ri(z,0)|0;if((ah|0)==0){M=757;break L1001}ag=ah-1|0;ao=a[w]|0;if((ao<<24>>24|0)==2){ah=af+10|0;if((ag|0)==0){ap=0}else{ak=af+24|0;al=ag;aj=0;while(1){if(al>>>0<2){break L955}if((ro(f,Q,2)|0)!=0){break L955}aq=al-2|0;ar=a[Q]|0;do{if((ar<<24>>24|0)==0){as=d[T]|0;if(as>>>0>aq>>>0){break L955}at=as+aj|0;if(at>>>0>(e[ah>>1]|0)>>>0){break L955}if((ro(f,(c[ak>>2]|0)+aj|0,as)|0)!=0){break L955}au=at;av=aq-as|0}else if((ar<<24>>24|0)==1){as=a[T]|0;at=as&255;if(aq>>>0<2){break L955}aw=(at<<1)+aj|0;if(aw>>>0>(e[ah>>1]|0)>>>0){break L955}if((ro(f,R,2)|0)!=0){break L955}ax=al-4|0;if(as<<24>>24==0){au=aj;av=ax;break}else{ay=aj;az=at}while(1){a[(c[ak>>2]|0)+ay|0]=a[R]|0;a[(c[ak>>2]|0)+(ay+1)|0]=a[S]|0;at=az-1|0;if((at|0)==0){au=aw;av=ax;break}else{ay=ay+2|0;az=at}}}else{break L955}}while(0);if((av|0)==0){ap=au;break}else{al=av;aj=au}}}if(ap>>>0<(e[ah>>1]|0)>>>0){break L955}else{aA=ah;break}}else if((ao<<24>>24|0)==0){aj=af+10|0;if((e[aj>>1]|0)!=(ag|0)){break L955}if((ro(f,c[af+24>>2]|0,ag)|0)==0){aA=aj;break}else{M=761;break L1001}}else if((ao<<24>>24|0)==1){if((ag|0)!=4){break L955}if((ro(f,Q,4)|0)!=0){break L955}aj=ri(Q,0)|0;al=af+10|0;if((aj<<1|0)!=(e[al>>1]|0)){break L955}if((aj|0)==0){aA=al;break}ak=af+24|0;aq=0;while(1){ar=aq<<1;a[(c[ak>>2]|0)+ar|0]=a[R]|0;a[(c[ak>>2]|0)+(ar|1)|0]=a[S]|0;ar=aq+1|0;if(ar>>>0<aj>>>0){aq=ar}else{aA=al;break}}}else{M=784;break L1001}}else{aA=af+10|0}}while(0);al=b[aA>>1]|0;if(al<<16>>16==0){aB=0;aD=ai;aE=ai}else{aq=al&65535;al=c[af+24>>2]|0;aj=ai;ak=aq;ag=al;while(1){ah=d[ag]<<8^aj;ar=ah<<1;ax=(ah&32768|0)==0?ar:ar^41111;ar=ax<<1;ah=(ax&32768|0)==0?ar:ar^41111;ar=ah<<1;ax=(ah&32768|0)==0?ar:ar^41111;ar=ax<<1;ah=(ax&32768|0)==0?ar:ar^41111;ar=ah<<1;ax=(ah&32768|0)==0?ar:ar^41111;ar=ax<<1;ah=(ax&32768|0)==0?ar:ar^41111;ar=ah<<1;ax=(ah&32768|0)==0?ar:ar^41111;ar=ax<<1;aF=(ax&32768|0)==0?ar:ar^41111;ar=ak-1|0;if((ar|0)==0){aG=0;aH=aq;aI=al;break}else{aj=aF;ak=ar;ag=ag+1|0}}while(1){ag=d[aI]<<8^aG;ak=ag<<1;aj=(ag&32768|0)==0?ak:ak^41111;ak=aj<<1;ag=(aj&32768|0)==0?ak:ak^41111;ak=ag<<1;aj=(ag&32768|0)==0?ak:ak^41111;ak=aj<<1;ag=(aj&32768|0)==0?ak:ak^41111;ak=ag<<1;aj=(ag&32768|0)==0?ak:ak^41111;ak=aj<<1;ag=(aj&32768|0)==0?ak:ak^41111;ak=ag<<1;aj=(ag&32768|0)==0?ak:ak^41111;ak=aj<<1;aJ=(aj&32768|0)==0?ak:ak^41111;ak=aH-1|0;if((ak|0)==0){break}else{aG=aJ;aH=ak;aI=aI+1|0}}aB=aJ;aD=aF;aE=aF&65535}if((an|0)!=(aB&255|0)){ak=c[q>>2]|0;aC(31952,33,1,ak|0)|0;if((an|0)!=(aD&255|0)){M=792;break L1001}}if((Y&64|0)==0){break}ak=c[q>>2]|0;aj=e[af+8>>1]|0;bN(ak|0,29592,(x=i,i=i+24|0,c[x>>2]=_,c[x+8>>2]=ac,c[x+16>>2]=aj,x)|0)|0;qo(m,af);qi(af)}else{if((an|0)!=(am&255|0)){M=751;break L1001}p2(af,(Y&16|0)!=0?246:0)}}while(0);V=V+1|0;}while(V>>>0<W>>>0)}if((ro(f,u,1)|0)!=0){break L955}}if((M|0)==742){qi(af);break}else if((M|0)==734){bN(c[q>>2]|0,43944,(x=i,i=i+16|0,c[x>>2]=ab,c[x+8>>2]=aa&65535,x)|0)|0;break}else if((M|0)==800){i=g;return n|0}else if((M|0)==792){u=e[af+8>>1]|0;bN(c[q>>2]|0,30520,(x=i,i=i+48|0,c[x>>2]=_,c[x+8>>2]=ac,c[x+16>>2]=u,c[x+24>>2]=an,c[x+32>>2]=aB&65535,c[x+40>>2]=aE,x)|0)|0;break}else if((M|0)==784){bN(c[q>>2]|0,34480,(x=i,i=i+32|0,c[x>>2]=_,c[x+8>>2]=ac,c[x+16>>2]=ad,c[x+24>>2]=ao&255,x)|0)|0;break}else if((M|0)==761){aC(55384,16,1,c[q>>2]|0)|0;break}else if((M|0)==751){u=e[af+8>>1]|0;bN(c[q>>2]|0,40416,(x=i,i=i+24|0,c[x>>2]=_,c[x+8>>2]=ac,c[x+16>>2]=u,x)|0)|0;break}else if((M|0)==757){bN(c[q>>2]|0,37320,(x=i,i=i+24|0,c[x>>2]=_,c[x+8>>2]=ac,c[x+16>>2]=ad,x)|0)|0;break}}}while(0);qt(m);n=0;i=g;return n|0}function rc(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0;h=i;i=i+40|0;j=h|0;k=h+8|0;l=h+16|0;m=h+32|0;n=l|0;o=g|0;p=b[o>>1]|0;do{if(p<<16>>16==0){q=0;r=0;s=816}else{t=c[g+4>>2]|0;u=p&65535;v=0;w=0;x=0;y=0;while(1){z=c[t+(y<<2)>>2]|0;A=b[z+2>>1]|0;B=A&65535;C=B>>>0>v>>>0?B:v;if(A<<16>>16==0){D=w;E=x}else{A=c[z+4>>2]|0;z=w;F=x;G=0;while(1){H=c[A+(G<<2)>>2]|0;I=b[H+2>>1]|0;J=I&65535;K=J>>>0>z>>>0?J:z;if(I<<16>>16==0){L=F}else{I=H+4|0;H=F;M=0;while(1){if((H|0)==0){N=e[(c[(c[I>>2]|0)+(M<<2)>>2]|0)+16>>1]|0}else{N=H}O=M+1|0;if(O>>>0<J>>>0){H=N;M=O}else{L=N;break}}}M=G+1|0;if(M>>>0<B>>>0){z=K;F=L;G=M}else{D=K;E=L;break}}}G=y+1|0;if(G>>>0<u>>>0){v=C;w=D;x=E;y=G}else{break}}y=C&255;if((E|0)==1){P=-128;Q=D;R=y;break}else if((E|0)==32770){P=2;Q=D;R=y;break}else if((E|0)==32769){P=-126;Q=D;R=y;break}else if((E|0)==2){P=0;Q=D;R=y;break}else{q=D;r=y;s=816;break}}}while(0);if((s|0)==816){P=0;Q=q;R=r}do{if((p&65535)<45){S=1}else{if(Q>>>0<12){S=3;break}S=Q>>>0<17?2:4}}while(0);a[n]=84;Q=l+1|0;a[Q]=68;p=l+2|0;a[p]=0;r=l+3|0;a[r]=0;q=l+4|0;a[q]=21;D=l+5|0;a[D]=P;P=l+6|0;a[P]=S;S=l+7|0;a[S]=0;E=l+8|0;a[E]=0;C=l+9|0;a[C]=R;R=g+8|0;if((c[R>>2]|0)==0){T=0;U=9;V=n;W=21504}else{a[S]=-128;T=0;U=9;V=n;W=21504}while(1){l=T^W;L=l<<1;N=(l&32768|0)==0?L:L^41111;L=N<<1;l=(N&32768|0)==0?L:L^41111;L=l<<1;N=(l&32768|0)==0?L:L^41111;L=N<<1;l=(N&32768|0)==0?L:L^41111;L=l<<1;N=(l&32768|0)==0?L:L^41111;L=N<<1;l=(N&32768|0)==0?L:L^41111;L=l<<1;N=(l&32768|0)==0?L:L^41111;L=N<<1;X=(N&32768|0)==0?L:L^41111;L=V+1|0;if((U|0)==0){break}T=X;U=U-1|0;V=L;W=d[L]<<8}rj(n,10,X&65535);if((rq(f,n,12)|0)!=0){Y=1;i=h;return Y|0}X=c[R>>2]|0;do{if((X|0)!=0){R=X>>>0>65535?65535:X;rj(n,2,R);c[k>>2]=bZ(0)|0;W=a5(k|0)|0;a[q]=c[W+20>>2]&255;a[D]=c[W+16>>2]&255;a[P]=c[W+12>>2]&255;a[S]=c[W+8>>2]&255;a[E]=c[W+4>>2]&255;a[C]=c[W>>2]&255;W=u0(R)|0;if((W|0)==0){Y=1;i=h;return Y|0}V=(R|0)==0;if(V){Z=0;_=8;$=p}else{U=c[g+12>>2]|0;T=0;while(1){L=a[U+T|0]|0;a[W+T|0]=L<<24>>24==10?0:L;L=T+1|0;if(L>>>0<R>>>0){T=L}else{Z=0;_=8;$=p;break}}}while(1){T=d[$]<<8^Z;U=T<<1;L=(T&32768|0)==0?U:U^41111;U=L<<1;T=(L&32768|0)==0?U:U^41111;U=T<<1;L=(T&32768|0)==0?U:U^41111;U=L<<1;T=(L&32768|0)==0?U:U^41111;U=T<<1;L=(T&32768|0)==0?U:U^41111;U=L<<1;T=(L&32768|0)==0?U:U^41111;U=T<<1;L=(T&32768|0)==0?U:U^41111;U=L<<1;aa=(L&32768|0)==0?U:U^41111;U=_-1|0;if((U|0)==0){break}else{Z=aa;_=U;$=$+1|0}}U=aa&65535;L1141:do{if(V){ab=U}else{L=U;T=R;N=W;while(1){l=d[N]<<8^L;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=T-1|0;if((y|0)==0){ab=l;break L1141}L=l;T=y;N=N+1|0}}}while(0);rj(n,0,ab&65535);if((rq(f,n,10)|0)==0){U=rq(f,W,R)|0;u1(W);if((U|0)==0){break}else{Y=1}i=h;return Y|0}else{u1(W);Y=1;i=h;return Y|0}}}while(0);ab=b[o>>1]|0;L1152:do{if(ab<<16>>16!=0){aa=g+4|0;$=j|0;_=j+1|0;Z=j+2|0;C=j+3|0;E=0;S=ab;L1154:while(1){k=c[(c[aa>>2]|0)+(E<<2)>>2]|0;X=k+2|0;if((b[X>>1]|0)==0){ac=S}else{U=k+4|0;k=E&255;V=E<<8&65280;N=0;do{T=c[(c[U>>2]|0)+(N<<2)>>2]|0;L=T+2|0;y=b[L>>1]|0;a[$]=y&255;a[_]=k;a[Z]=N&255;l=y&255;y=l<<9;x=(l&128|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=((x&32768|0)==0?y:y^41111)^V;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=((x&32768|0)==0?y:y^41111)^N<<8&65280;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;l=(x&32768|0)==0?y:y^41111;y=l<<1;x=(l&32768|0)==0?y:y^41111;y=x<<1;a[C]=((x&32768|0)==0?y:y^151)&255;if((rq(f,$,4)|0)!=0){Y=1;s=878;break L1154}y=T+4|0;if((b[L>>1]|0)!=0){T=0;do{x=c[(c[y>>2]|0)+(T<<2)>>2]|0;l=x+10|0;w=e[l>>1]|0;if((w+65535&w|0)!=0){Y=1;s=875;break L1154}a[n]=b[x+4>>1]&255;a[Q]=b[x+6>>1]&255;a[p]=b[x+8>>1]&255;a[r]=(p7(x)|0)&255;a[q]=0;w=c[x+12>>2]|0;if((w&2|0)==0){ad=4}else{a[q]=2;ad=6}if((w&4|0)!=0){a[q]=ad}w=x+24|0;x=b[l>>1]|0;if(x<<16>>16==0){ae=0}else{v=0;u=x&65535;x=c[w>>2]|0;while(1){t=d[x]<<8^v;G=t<<1;F=(t&32768|0)==0?G:G^41111;G=F<<1;t=(F&32768|0)==0?G:G^41111;G=t<<1;F=(t&32768|0)==0?G:G^41111;G=F<<1;t=(F&32768|0)==0?G:G^41111;G=t<<1;F=(t&32768|0)==0?G:G^41111;G=F<<1;t=(F&32768|0)==0?G:G^41111;G=t<<1;F=(t&32768|0)==0?G:G^41111;G=F<<1;af=(F&32768|0)==0?G:G^41111;G=u-1|0;if((G|0)==0){break}else{v=af;u=G;x=x+1|0}}ae=af&255}a[D]=ae;if((rq(f,n,6)|0)!=0){Y=1;s=867;break L1154}L1178:do{if((d[r]|0)<=6){x=b[l>>1]|0;u=x&65535;L1180:do{if(!((x&1)!=0|(x&65535)<2)){v=2;while(1){if(v>>>0>=u>>>0){break}G=c[w>>2]|0;if((a[G+v|0]|0)==(a[G+(v&1)|0]|0)){v=v+1|0}else{break L1180}}rj(n,0,5);a[p]=1;rj(n,3,(e[l>>1]|0)>>>1);v=c[w>>2]|0;a[D]=a[v]|0;a[P]=a[v+1|0]|0;if((rq(f,n,7)|0)==0){break L1178}else{Y=1;s=876;break L1154}}}while(0);rj(n,0,u+1|0);a[p]=0;if((rq(f,n,3)|0)!=0){Y=1;s=874;break L1154}if((rq(f,c[w>>2]|0,e[l>>1]|0)|0)!=0){Y=1;s=877;break L1154}}}while(0);T=T+1|0;}while(T>>>0<(e[L>>1]|0)>>>0)}N=N+1|0;}while(N>>>0<(e[X>>1]|0)>>>0);ac=b[o>>1]|0}X=E+1|0;if(X>>>0<(ac&65535)>>>0){E=X;S=ac}else{break L1152}}if((s|0)==874){i=h;return Y|0}else if((s|0)==875){i=h;return Y|0}else if((s|0)==867){i=h;return Y|0}else if((s|0)==876){i=h;return Y|0}else if((s|0)==877){i=h;return Y|0}else if((s|0)==878){i=h;return Y|0}}}while(0);s=m|0;a[s]=-1;a[m+1|0]=0;a[m+2|0]=0;a[m+3|0]=53;if((rq(f,s,4)|0)!=0){Y=1;i=h;return Y|0}ay(f|0)|0;Y=0;i=h;return Y|0}function rd(b){b=b|0;var c=0,d=0,e=0,f=0,g=0;c=i;i=i+16|0;d=c|0;do{if((bR(b|0,0,0)|0)==0){e=d|0;if((ro(b,e,16)|0)!=0){f=0;break}g=a[e]|0;if((g<<24>>24|0)==84){if((a[d+1|0]|0)!=68){f=0;break}}else if((g<<24>>24|0)==116){if((a[d+1|0]|0)!=100){f=0;break}}else{f=0;break}f=(a[d+2|0]|0)==0|0}else{f=0}}while(0);i=c;return f|0}function re(a,b){a=a|0;b=b|0;return(d[a+b|0]|0)<<8|(d[a+(b+1)|0]|0)|0}function rf(a,b){a=a|0;b=b|0;return(((d[a+b|0]|0)<<8|(d[a+(b+1)|0]|0))<<8|(d[a+(b+2)|0]|0))<<8|(d[a+(b+3)|0]|0)|0}function rg(b,c,d){b=b|0;c=c|0;d=d|0;a[b+c|0]=d>>>8&255;a[b+(c+1)|0]=d&255;return}function rh(b,c,d){b=b|0;c=c|0;d=d|0;a[b+c|0]=d>>>24&255;a[b+(c+1)|0]=d>>>16&255;a[b+(c+2)|0]=d>>>8&255;a[b+(c+3)|0]=d&255;return}function ri(a,b){a=a|0;b=b|0;return(d[a+(b+1)|0]|0)<<8|(d[a+b|0]|0)|0}function rj(b,c,d){b=b|0;c=c|0;d=d|0;a[b+c|0]=d&255;a[b+(c+1)|0]=d>>>8&255;return}function rk(a,d,f,g,h,i){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;if((g|0)==0){return}j=(i|0)!=0?32768:0;i=a+28|0;k=a+32|0;l=a+24|0;m=a+40|0;n=a+44|0;o=a+36|0;p=a|0;q=a+4|0;r=a+8|0;s=a+16|0;t=a+20|0;a=g;g=f;f=d;while(1){d=((e[g>>1]|0)^j)-32768|0;u=c[i>>2]|0;c[k>>2]=u;v=c[l>>2]|0;c[i>>2]=v;c[l>>2]=d;w=c[m>>2]|0;c[n>>2]=w;x=c[o>>2]|0;c[m>>2]=x;y=ac(d,c[p>>2]|0)|0;d=ac(v,c[q>>2]|0)|0;v=d+y+(ac(u,c[r>>2]|0)|0)|0;u=ac(x,c[s>>2]|0)|0;x=(v-u-(ac(w,c[t>>2]|0)|0)|0)/8192|0;c[o>>2]=x;w=x+32768|0;if((w|0)<0){z=0}else{z=(w|0)>65535?65535:w&65535}b[f>>1]=(z^j)&65535;w=a-1|0;if((w|0)==0){break}else{a=w;g=g+(h<<1)|0;f=f+(h<<1)|0}}return}function rl(c,d,e,f,g){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=(f|0)!=0?-32768:0;f=(e|0)==0;if((g|0)==0){if(f){return}else{i=d;j=0;k=c}while(1){g=b[i>>1]^h;a[k]=g&255;a[k+1|0]=(g&65535)>>>8&255;g=j+1|0;if(g>>>0<e>>>0){i=i+2|0;j=g;k=k+2|0}else{break}}return}else{if(f){return}else{l=d;m=0;n=c}while(1){c=b[l>>1]^h;a[n]=(c&65535)>>>8&255;a[n+1|0]=c&255;c=m+1|0;if(c>>>0<e>>>0){l=l+2|0;m=c;n=n+2|0}else{break}}return}}function rm(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=qs()|0;if((b|0)==0){e=0;return e|0}else{f=0}while(1){if(f>>>0>=(c[96]|0)>>>0){g=915;break}h=c[97]|0;i=128<<(d[h+(f<<3)+2|0]|0);j=h+(f<<3)|0;k=qh(0,d[j]|0,d[h+(f<<3)+1|0]|0,i)|0;if((k|0)==0){break}p5(k,32770);if((qw(b,k,0,d[j]|0)|0)!=0){break}if((rp(a,c[h+(f<<3)+4>>2]|0,c[k+24>>2]|0,i)|0)==0){f=f+1|0}else{break}}L1250:do{if((g|0)==915){if((c[94]|0)>>>0<=1){e=b;return e|0}f=1;i=c[95]|0;while(1){k=0;while(1){if(k>>>0>=(c[98]|0)>>>0){break}h=c[99]|0;j=128<<(d[h+(k<<3)+2|0]|0);l=h+(k<<3)|0;m=qh(f,d[l]|0,d[h+(k<<3)+1|0]|0,j)|0;if((m|0)==0){break L1250}p5(m,32770);if((qw(b,m,f,d[l]|0)|0)!=0){break L1250}if((rp(a,(c[h+(k<<3)+4>>2]|0)+i|0,c[m+24>>2]|0,j)|0)!=0){break L1250}k=k+1|0}k=f+1|0;if(k>>>0<(c[94]|0)>>>0){f=k;i=(c[95]|0)+i|0}else{e=b;break}}return e|0}}while(0);qt(b);e=0;return e|0}function rn(a,b){a=a|0;b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=0;while(1){if(f>>>0>=(c[96]|0)>>>0){g=935;break}h=c[97]|0;i=128<<(d[h+(f<<3)+2|0]|0);j=qp(b,0,d[h+(f<<3)|0]|0,d[h+(f<<3)+1|0]|0,0)|0;if((j|0)==0){k=1;g=951;break}if((e[j+10>>1]|0|0)!=(i|0)){k=1;g=952;break}if((rr(a,c[h+(f<<3)+4>>2]|0,c[j+24>>2]|0,i)|0)==0){f=f+1|0}else{k=1;g=945;break}}if((g|0)==951){return k|0}else if((g|0)==945){return k|0}else if((g|0)==935){if((c[94]|0)>>>0<=1){k=0;return k|0}f=1;i=c[95]|0;L1280:while(1){j=0;while(1){if(j>>>0>=(c[98]|0)>>>0){break}h=c[99]|0;l=128<<(d[h+(j<<3)+2|0]|0);m=qp(b,f,d[h+(j<<3)|0]|0,d[h+(j<<3)+1|0]|0,0)|0;if((m|0)==0){k=1;g=950;break L1280}if((e[m+10>>1]|0|0)!=(l|0)){k=1;g=947;break L1280}if((rr(a,(c[h+(j<<3)+4>>2]|0)+i|0,c[m+24>>2]|0,l)|0)!=0){k=1;g=948;break L1280}j=j+1|0}j=f+1|0;if(j>>>0<(c[94]|0)>>>0){f=j;i=(c[95]|0)+i|0}else{k=0;g=949;break}}if((g|0)==947){return k|0}else if((g|0)==948){return k|0}else if((g|0)==950){return k|0}else if((g|0)==949){return k|0}}else if((g|0)==952){return k|0}return 0}function ro(a,b,c){a=a|0;b=b|0;c=c|0;return(bK(b|0,1,c|0,a|0)|0)!=(c|0)|0}function rp(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if((bR(a|0,b|0,0)|0)!=0){e=1;return e|0}e=(bK(c|0,1,d|0,a|0)|0)!=(d|0)|0;return e|0}function rq(a,b,c){a=a|0;b=b|0;c=c|0;return(aC(b|0,1,c|0,a|0)|0)!=(c|0)|0}function rr(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if((bR(a|0,b|0,0)|0)!=0){e=1;return e|0}e=(aC(c|0,1,d|0,a|0)|0)!=(d|0)|0;return e|0}function rs(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=i;i=i+256|0;d=c|0;e=b;while(1){if((e|0)==0){f=0;g=969;break}b=e>>>0<256?e:256;if((bK(d|0,1,b|0,a|0)|0)==(b|0)){e=e-b|0}else{f=1;g=970;break}}if((g|0)==969){i=c;return f|0}else if((g|0)==970){i=c;return f|0}return 0}function rt(a){a=a|0;u6(a|0,0,48);c[a>>2]=8192;return}function ru(a){a=a|0;u6(a+24|0,0,24);return}function rv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0.0,h=0.0;e=a|0;u6(a|0,0,48);c[e>>2]=8192;if((b|0)==0|(d|0)==0){return}if(b<<1>>>0<d>>>0){f=b}else{f=(d>>>1)-1|0}g=1.0/+W(+(+(f>>>0>>>0)*3.141592653589793/+(d>>>0>>>0)));h=g*(g+1.4142135623730951)+1.0;d=~~(8192.0/h);c[e>>2]=d;c[a+4>>2]=~~(16384.0/h);c[a+8>>2]=d;c[a+12>>2]=8192;c[a+16>>2]=~~((1.0-g*g)*16384.0/h);c[a+20>>2]=~~((g*(g-1.4142135623730951)+1.0)*8192.0/h);return}function rw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a+788|0;e=a+792|0;a=c[e>>2]|0;if((c[d>>2]|0)>>>0>=b>>>0){f=a;return f|0}g=u2(a,b)|0;if((g|0)==0){f=0;return f|0}c[e>>2]=g;c[d>>2]=b;f=g;return f|0}function rx(b,d){b=b|0;d=d|0;c[b>>2]=d;u6(b+4|0,0,16);u6(b+788|0,0,24);a[b+812|0]=1;c[b+816>>2]=0;c[b+820>>2]=0;c[b+824>>2]=0;return}function ry(a){a=a|0;var b=0;if((a|0)==0){return}rL(a);b=c[a+816>>2]|0;if((b|0)!=0){b0[b&127](a)}b=c[a+800>>2]|0;if((b|0)!=0){u1(b)}b=c[a+792>>2]|0;if((b|0)==0){return}u1(b);return}function rz(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;if((b|0)==0){f=1;return f|0}g=b+820|0;if((c[g>>2]|0)==0){f=1;return f|0}do{if((c[b+16>>2]|0)==0){h=d}else{i=b+4|0;j=ac(c[i>>2]|0,e)|0;k=b+796|0;l=b+800|0;m=c[l>>2]|0;if((c[k>>2]|0)>>>0<j>>>0){n=u2(m,j<<1)|0;if((n|0)==0){h=0;break}o=n;c[l>>2]=o;c[k>>2]=j;p=o}else{p=m}if((p|0)==0){h=0;break}m=c[i>>2]|0;if((m|0)==0){h=p;break}o=b+12|0;j=0;k=m;while(1){rk(b+20+(j*48|0)|0,p+(j<<1)|0,d+(j<<1)|0,e,k,c[o>>2]|0);m=j+1|0;l=c[i>>2]|0;if(m>>>0<l>>>0){j=m;k=l}else{h=p;break}}}}while(0);p=b2[c[g>>2]&127](b,h,e)|0;rN(b,(a[b+812|0]|0)!=0?h:d,e)|0;f=p;return f|0}function rA(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;if((a|0)==0){f=1;return f|0}g=c[a+824>>2]|0;if((g|0)==0){f=1;return f|0}h=(e|0)!=0|0;if(b>>>0>16){f=1;return f|0}e=a+4|0;do{if((c[e>>2]|0)==(b|0)){if((c[a+8>>2]|0)!=(d|0)){break}if((c[a+12>>2]|0)==(h|0)){f=0}else{break}return f|0}}while(0);if((b5[g&127](a,b,d,h)|0)!=0){f=1;return f|0}c[e>>2]=b;g=a+8|0;c[g>>2]=d;c[a+12>>2]=h;if((rO(a,b,d,h)|0)!=0){f=1;return f|0}if((c[e>>2]|0)==0){f=0;return f|0}h=a+16|0;d=0;while(1){b=a+20+(d*48|0)|0;rv(b,c[h>>2]|0,c[g>>2]|0);ru(b);b=d+1|0;if(b>>>0<(c[e>>2]|0)>>>0){d=b}else{f=0;break}}return f|0}function rB(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b;e=47560;f=110;while(1){if(f<<24>>24!=(a[d]|0)){g=1037;break}h=e+1|0;i=d+1|0;j=a[h]|0;if(j<<24>>24==0){k=i;g=1038;break}else{d=i;e=h;f=j}}if((g|0)==1037){if((a[e]|0)==0){k=d;g=1038}else{l=b;m=43920;n=119;g=1051}}if((g|0)==1038){d=a[k]|0;if((d<<24>>24|0)==58|(d<<24>>24|0)==0){o=0}else{l=b;m=43920;n=119;g=1051}}do{if((g|0)==1051){while(1){g=0;if(n<<24>>24!=(a[l]|0)){g=1052;break}d=m+1|0;k=l+1|0;e=a[d]|0;if(e<<24>>24==0){p=k;g=1054;break}else{l=k;m=d;n=e;g=1051}}if((g|0)==1052){if((a[m]|0)==0){p=l;g=1054}else{q=b;r=40400;s=115}}if((g|0)==1054){e=a[p]|0;if((e<<24>>24|0)==58|(e<<24>>24|0)==0){o=1;break}else{q=b;r=40400;s=115}}while(1){if(s<<24>>24!=(a[q]|0)){g=1056;break}e=r+1|0;d=q+1|0;k=a[e]|0;if(k<<24>>24==0){t=d;break}else{q=d;r=e;s=k}}do{if((g|0)==1056){if((a[r]|0)==0){t=q;break}else{u=0}return u|0}}while(0);k=a[t]|0;if((k<<24>>24|0)==58|(k<<24>>24|0)==0){o=2;break}else{u=0}return u|0}}while(0);t=b_[c[28460+(o<<3)>>2]&511](b)|0;if((t|0)==0){u=0;return u|0}if((rP(t,b)|0)==0){a[t+812|0]=(rR(b,50536,1)|0)&255;o=rX(b,53768,0)|0;b=t+16|0;c[b>>2]=o;q=t+4|0;if((c[q>>2]|0)==0){u=t;return u|0}r=t+8|0;g=t+20|0;rv(g,o,c[r>>2]|0);ru(g);if((c[q>>2]|0)>>>0>1){v=1}else{u=t;return u|0}while(1){g=t+20+(v*48|0)|0;rv(g,c[b>>2]|0,c[r>>2]|0);ru(g);g=v+1|0;if(g>>>0<(c[q>>2]|0)>>>0){v=g}else{u=t;break}}return u|0}rL(t);v=c[t+816>>2]|0;if((v|0)!=0){b0[v&127](t)}v=c[t+800>>2]|0;if((v|0)!=0){u1(v)}v=c[t+792>>2]|0;if((v|0)==0){u=0;return u|0}u1(v);u=0;return u|0}function rC(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function rD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 0}function rE(a){a=a|0;var b=0,d=0;a=u0(828)|0;if((a|0)==0){b=0;return b|0}d=a;rx(d,a);c[a+816>>2]=94;c[a+820>>2]=26;c[a+824>>2]=48;b=d;return b|0}function rF(a){a=a|0;u1(c[a>>2]|0);return}function rG(b){b=b|0;var d=0,e=0;b=u0(856)|0;if((b|0)==0){d=0;return d|0}e=b;rx(e,b);c[b+816>>2]=8;c[b+820>>2]=84;c[b+824>>2]=6;a[b+828|0]=0;a[b+829|0]=1;u6(b+840|0,0,16);d=e;return d|0}function rH(b){b=b|0;var d=0,e=0,f=0;d=c[b>>2]|0;if((a[d+828|0]|0)!=0){bC()}b=c[d+844>>2]|0;if((b|0)!=0){e=b;while(1){b=c[e>>2]|0;u1(c[e+16>>2]|0);u1(e);if((b|0)==0){break}else{e=b}}}e=c[d+852>>2]|0;if((e|0)==0){u1(d);return}else{f=e}while(1){e=c[f>>2]|0;u1(c[f+16>>2]|0);u1(f);if((e|0)==0){break}else{f=e}}u1(d);return}function rI(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[b>>2]|0;g=ac(c[b+4>>2]|0,e)|0;e=g<<1;h=f+852|0;i=c[h>>2]|0;do{if((i|0)==0){j=f+840|0;k=c[j>>2]|0;if(k>>>0>32){break}l=u0(20)|0;if((l|0)==0){break}c[l+12>>2]=0;c[l+16>>2]=0;c[j>>2]=k+1;m=l;n=1094}else{c[h>>2]=c[i>>2];m=i;n=1094}}while(0);L1474:do{if((n|0)==1094){c[m>>2]=0;i=m+4|0;c[i>>2]=0;h=m+8|0;c[h>>2]=0;l=m+12|0;do{if((c[l>>2]|0)>>>0<e>>>0){k=m+16|0;j=u2(c[k>>2]|0,e)|0;if((j|0)==0){u1(c[k>>2]|0);u1(m);o=f+840|0;c[o>>2]=(c[o>>2]|0)-1;break L1474}else{c[l>>2]=e;c[k>>2]=j;break}}}while(0);if((m|0)==0){p=1;return p|0}rl(c[m+16>>2]|0,d,g,(c[b+12>>2]|0)!=(c[f+832>>2]|0)|0,c[f+836>>2]|0);c[i>>2]=0;c[h>>2]=e;l=f+848|0;j=c[l>>2]|0;if((j|0)==0){c[f+844>>2]=m}else{c[j>>2]=m}c[l>>2]=m;l=f+829|0;if((a[l]|0)==0){p=0;return p|0}aO(0);a[l]=0;p=0;return p|0}}while(0);p=1;return p|0}function rJ(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;g=i;i=i+24|0;h=g|0;j=c[d>>2]|0;do{if((aJ(16)|0)==0){if((bt(16)|0)>=0){break}d=c[q>>2]|0;k=bv()|0;bN(d|0,50288,(x=i,i=i+8|0,c[x>>2]=k,x)|0)|0;l=1;i=g;return l|0}}while(0);k=j+828|0;if((a[k]|0)!=0){bC();a[k]=0}c[h>>2]=f;b[h+4>>1]=-32752;a[h+6|0]=e&255;b[h+8>>1]=1024;c[h+16>>2]=10;c[h+20>>2]=j;if((bG(h|0,0)|0)<0){h=c[q>>2]|0;e=bv()|0;bN(h|0,53720,(x=i,i=i+8|0,c[x>>2]=e,x)|0)|0;l=1;i=g;return l|0}else{aO(1);a[k]=1;a[j+829|0]=1;c[j+832>>2]=1;c[j+836>>2]=0;l=0;i=g;return l|0}return 0}function rK(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=b+844|0;g=c[f>>2]|0;if((g|0)==0){aO(1);a[b+829|0]=1;return}if((e|0)<=0){return}h=b+848|0;i=b+852|0;b=e;e=d;d=g;while(1){if((d|0)==0){j=1126;break}k=d+4|0;g=c[k>>2]|0;l=(c[d+8>>2]|0)-g|0;m=(c[d+16>>2]|0)+g|0;if((l|0)>(b|0)){j=1133;break}u7(e|0,m|0,l)|0;g=b-l|0;n=d|0;o=c[n>>2]|0;c[f>>2]=o;if((o|0)==0){c[h>>2]=0}c[n>>2]=c[i>>2];c[i>>2]=d;if((g|0)<=0){j=1138;break}b=g;e=e+l|0;d=c[f>>2]|0}if((j|0)==1133){u7(e|0,m|0,b)|0;c[k>>2]=(c[k>>2]|0)+b;return}else if((j|0)==1126){u6(e|0,0,b|0);return}else if((j|0)==1138){return}}function rL(a){a=a|0;if((c[a+804>>2]|0)==0){return}rM(a)|0;return}function rM(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+64|0;e=d|0;f=b+804|0;if((bR(c[f>>2]|0,0,0)|0)!=0){g=1;i=d;return g|0}h=e|0;a[h]=82;a[e+1|0]=73;a[e+2|0]=70;a[e+3|0]=70;j=b+808|0;k=c[j>>2]|0;l=k+36|0;a[e+4|0]=l&255;a[e+5|0]=l>>>8&255;a[e+6|0]=l>>>16&255;a[e+7|0]=l>>>24&255;a[e+8|0]=87;a[e+9|0]=65;a[e+10|0]=86;a[e+11|0]=69;a[e+12|0]=102;a[e+13|0]=109;a[e+14|0]=116;a[e+15|0]=32;a[e+16|0]=16;a[e+17|0]=0;a[e+18|0]=0;a[e+19|0]=0;a[e+20|0]=1;a[e+21|0]=0;l=c[b+4>>2]|0;a[e+22|0]=l&255;a[e+23|0]=l>>>8&255;m=c[b+8>>2]|0;a[e+24|0]=m&255;a[e+25|0]=m>>>8&255;a[e+26|0]=m>>>16&255;a[e+27|0]=m>>>24&255;b=l<<1;n=ac(b,m)|0;a[e+28|0]=n&255;a[e+29|0]=n>>>8&255;a[e+30|0]=n>>>16&255;a[e+31|0]=n>>>24&255;a[e+32|0]=b&255;a[e+33|0]=l>>>7&255;a[e+34|0]=16;a[e+35|0]=0;a[e+36|0]=100;a[e+37|0]=97;a[e+38|0]=116;a[e+39|0]=97;a[e+40|0]=k&255;a[e+41|0]=k>>>8&255;a[e+42|0]=k>>>16&255;a[e+43|0]=k>>>24&255;if((aC(h|0,1,44,c[f>>2]|0)|0)!=44){g=1;i=d;return g|0}g=(bR(c[f>>2]|0,(c[j>>2]|0)+44|0,0)|0)!=0|0;i=d;return g|0}function rN(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=a+804|0;if((c[e>>2]|0)==0){f=0;return f|0}g=ac(c[a+4>>2]|0,d)|0;d=g<<1;h=rw(a,d)|0;if((b|0)==0){f=1;return f|0}rl(h,b,g,(c[a+12>>2]|0)==0|0,0);if((aC(h|0,1,d|0,c[e>>2]|0)|0)!=(d|0)){f=1;return f|0}e=a+808|0;c[e>>2]=(c[e>>2]|0)+d;f=0;return f|0}function rO(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;if((c[a+804>>2]|0)==0){f=0;return f|0}f=(rM(a)|0)!=0|0;return f|0}function rP(b,d){b=b|0;d=d|0;var e=0,f=0;e=b+804|0;c[e>>2]=0;c[b+808>>2]=0;b=rQ(d,50256)|0;if((b|0)==0){f=0;return f|0}if((a[b]|0)==0){f=0;return f|0}c[e>>2]=aZ(b|0,53712)|0;u1(b);f=(c[e>>2]|0)==0|0;return f|0}function rQ(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;if((b|0)==0){d=0;return d|0}e=a[c]|0;L1572:do{if(e<<24>>24==0){f=b;L1601:while(1){g=f;while(1){h=a[g]|0;if(!((h<<24>>24|0)==32|(h<<24>>24|0)==9)){i=g;j=h;break}g=g+1|0}while(1){if((j<<24>>24|0)==61){k=i;l=1179;break}else if(!((j<<24>>24|0)==32|(j<<24>>24|0)==9)){break}g=i+1|0;i=g;j=a[g]|0}if((l|0)==1179){while(1){l=0;m=k+1|0;n=a[m]|0;if((n<<24>>24|0)==32|(n<<24>>24|0)==9){k=m;l=1179}else{break}}if((m|0)!=0){o=k;p=n;break L1572}}g=a[f]|0;if(g<<24>>24==0){d=0;l=1222;break}else{q=f;r=g}while(1){s=q+1|0;if(r<<24>>24==58){if((a[s]|0)!=58){break}t=q+2|0}else{t=s}g=a[t]|0;if(g<<24>>24==0){d=0;l=1227;break L1601}else{q=t;r=g}}if((s|0)==0){d=0;l=1229;break}else{f=s}}if((l|0)==1222){return d|0}else if((l|0)==1227){return d|0}else if((l|0)==1229){return d|0}}else{f=b;L1573:while(1){g=f;while(1){u=a[g]|0;if(!((u<<24>>24|0)==32|(u<<24>>24|0)==9)){break}g=g+1|0}L1579:do{if(u<<24>>24==e<<24>>24){h=c;v=g;while(1){v=v+1|0;h=h+1|0;w=a[h]|0;if(w<<24>>24==0){x=v;break}if((a[v]|0)!=w<<24>>24){break L1579}}while(1){v=a[x]|0;if((v<<24>>24|0)==61){y=x;break}else if(!((v<<24>>24|0)==32|(v<<24>>24|0)==9)){break L1579}x=x+1|0}while(1){z=y+1|0;A=a[z]|0;if((A<<24>>24|0)==32|(A<<24>>24|0)==9){y=z}else{break}}if((z|0)!=0){o=y;p=A;break L1572}}}while(0);g=a[f]|0;if(g<<24>>24==0){d=0;l=1223;break}else{B=f;C=g}while(1){D=B+1|0;if(C<<24>>24==58){if((a[D]|0)!=58){break}E=B+2|0}else{E=D}g=a[E]|0;if(g<<24>>24==0){d=0;l=1224;break L1573}else{B=E;C=g}}if((D|0)==0){d=0;l=1225;break}else{f=D}}if((l|0)==1223){return d|0}else if((l|0)==1224){return d|0}else if((l|0)==1225){return d|0}}}while(0);L1626:do{if(p<<24>>24==0){F=0}else{D=0;C=p;while(1){E=D+1|0;if(C<<24>>24==58){B=D+2|0;if((a[o+B|0]|0)==58){G=B}else{H=D;break}}else{G=E}E=a[o+(G+1)|0]|0;if(E<<24>>24==0){H=G;break}else{D=G;C=E}}if((H|0)==0){F=0;break}else{I=H}while(1){C=I-1|0;D=a[o+I|0]|0;if(!((D<<24>>24|0)==32|(D<<24>>24|0)==9)){F=I;break L1626}if((C|0)==0){F=0;break}else{I=C}}}}while(0);I=u0(F+1|0)|0;if((I|0)==0){d=0;return d|0}L1640:do{if((F|0)==0){J=0}else{H=0;G=0;C=p;while(1){D=H+1|0;do{if(C<<24>>24==58){E=H+2|0;if((a[o+E|0]|0)!=58){l=1210;break}a[I+G|0]=58;K=E}else{l=1210}}while(0);if((l|0)==1210){l=0;a[I+G|0]=C;K=D}E=G+1|0;if(K>>>0>=F>>>0){J=E;break L1640}H=K;G=E;C=a[o+(K+1)|0]|0}}}while(0);a[I+J|0]=0;d=I;return d|0}function rR(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=rQ(a,b)|0;if((d|0)==0){e=c;return e|0}do{if((aQ(d|0,50152)|0)==0){f=1}else{if((aQ(d|0,53704)|0)==0){f=1;break}if((aQ(d|0,47552)|0)==0){f=1;break}if((aQ(d|0,43912)|0)==0){f=0;break}if((aQ(d|0,40392)|0)==0){f=0;break}f=(aQ(d|0,37296)|0)==0?0:c}}while(0);u1(d);e=f;return e|0}function rS(a,b,d){a=a|0;b=b|0;d=d|0;return(c[a+28>>2]|0)==((b<<4)+d|0)|0}function rT(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;do{if((c[a+24>>2]|0)==(b|0)){if((c[a+28>>2]|0)==(d|0)){e=1}else{break}return e|0}}while(0);e=0;return e|0}function rU(a){a=a|0;c[a>>2]=0;c[a+4>>2]=0;return}function rV(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;c[b>>2]=0;e=0;while(1){if(e>>>0>=256){break}f=d+e|0;a[b+4+e|0]=a[f]|0;if((a[f]|0)==0){g=1254;break}else{e=e+1|0}}if((g|0)==1254){return}a[b+259|0]=0;return}function rW(a){a=a|0;return(c[a>>2]|0)+(a+4)|0}function rX(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;h=rQ(b,d)|0;L1682:do{if((h|0)==0){j=e}else{d=ax(h|0,g|0,0)|0;b=c[g>>2]|0;do{if((b|0)!=0){if((a[b]|0)==0){break}u1(h);j=e;break L1682}}while(0);u1(h);j=d}}while(0);i=f;return j|0}function rY(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+8|0;g=f|0;h=rQ(b,d)|0;L1690:do{if((h|0)==0){j=e}else{d=aA(h|0,g|0,0)|0;b=c[g>>2]|0;do{if((b|0)!=0){if((a[b]|0)==0){break}u1(h);j=e;break L1690}}while(0);u1(h);j=d}}while(0);i=f;return j|0}function rZ(a){a=a|0;var b=0,d=0,e=0;b=u0(36)|0;if((b|0)==0){d=0;return d|0}c[b>>2]=1;e=b+4|0;u6(e|0,0,20);c[e>>2]=48;c[b+8>>2]=36;c[b+12>>2]=156;c[b+24>>2]=0;c[b+28>>2]=a;d=b;return d|0}function r_(a){a=a|0;u1(a);return}function r$(a,b){a=a|0;b=b|0;var d=0,e=0;b=i;d=c[a+16>>2]|0;e=c[a+20>>2]|0;bh(53312,(x=i,i=i+24|0,c[x>>2]=c[a+28>>2],c[x+8>>2]=d,c[x+16>>2]=e,x)|0)|0;i=b;return}function r0(a){a=a|0;u1(a);return}function r1(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;b=i;d=c[a+28>>2]|0;e=c[a+16>>2]|0;f=c[a+20>>2]|0;bh(54544,(x=i,i=i+32|0,c[x>>2]=c[a+24>>2],c[x+8>>2]=d,c[x+16>>2]=e,c[x+24>>2]=f,x)|0)|0;i=b;return}function r2(a){a=a|0;u1(c[a+32>>2]|0);u1(a);return}function r3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;d=i;i=i+272|0;b=d|0;e=d+8|0;rV(e,c[a+32>>2]|0);a=(si(e,b)|0)!=0;i=d;return a&(c[b>>2]|0)!=0&1|0}function r4(a,b){a=a|0;b=b|0;b=i;bh(55368,(x=i,i=i+8|0,c[x>>2]=c[a+32>>2],x)|0)|0;i=b;return}function r5(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=a+4|0;e=a|0;a=u2(c[d>>2]|0,(c[e>>2]<<2)+4|0)|0;f=a;if((a|0)==0){g=1;return g|0}c[d>>2]=f;d=c[e>>2]|0;c[f+(d<<2)>>2]=b;c[e>>2]=d+1;g=0;return g|0}function r6(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=a|0;if((c[f>>2]|0)==0){g=0;return g|0}h=a+4|0;a=0;L1718:while(1){i=c[(c[h>>2]|0)+(a<<2)>>2]|0;j=c[i+8>>2]|0;do{if((j|0)!=0){if((b2[j&127](i,b,d)|0)==0){break}k=i+16|0;l=c[k>>2]|0;if((l|0)==0){break L1718}m=l-1|0;c[k>>2]=m;if((m|0)==0){break L1718}}}while(0);j=a+1|0;if(j>>>0<(c[f>>2]|0)>>>0){a=j}else{g=0;n=1311;break}}if((n|0)==1311){return g|0}d=c[i+20>>2]|0;if((d|0)!=0){c[k>>2]=d}d=c[(c[h>>2]|0)+(a<<2)>>2]|0;if((d|0)==0){g=0;return g|0}a=c[d+12>>2]|0;if((a|0)!=0){b1[a&511](d,e)}if((c[d+16>>2]|0)!=0){g=1;return g|0}e=c[f>>2]|0;a=0;while(1){if(a>>>0>=e>>>0){g=1;n=1314;break}o=a+1|0;if((c[(c[h>>2]|0)+(a<<2)>>2]|0)==(d|0)){break}else{a=o}}if((n|0)==1314){return g|0}n=c[d+4>>2]|0;if((n|0)==0){u1(d)}else{b0[n&127](d)}d=c[f>>2]|0;if(o>>>0<d>>>0){n=a;a=o;while(1){o=c[h>>2]|0;c[o+(n<<2)>>2]=c[o+(a<<2)>>2];o=a+1|0;e=c[f>>2]|0;if(o>>>0<e>>>0){n=a;a=o}else{p=e;break}}}else{p=d}c[f>>2]=p-1;g=1;return g|0}function r7(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0;f=i;i=i+304|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=f+32|0;m=f+40|0;n=f+48|0;if((sb(a,53696)|0)!=0){if((se(a)|0)==0){i=f;return}p=c[o>>2]|0;q=d|0;if((c[q>>2]|0)!=0){r=d+4|0;s=0;do{bN(p|0,50112,(x=i,i=i+8|0,c[x>>2]=s,x)|0)|0;t=c[(c[r>>2]|0)+(s<<2)>>2]|0;u=c[t+12>>2]|0;if((u|0)!=0){b1[u&511](t,p)}s=s+1|0;}while(s>>>0<(c[q>>2]|0)>>>0)}ay(p|0)|0;i=f;return}if((sb(a,47544)|0)==0){if((sb(a,43904)|0)==0){r9(a,40368);i=f;return}if((sa(a)|0)!=0){p=d|0;q=d+4|0;s=c[q>>2]|0;if((c[p>>2]|0)==0){v=s}else{r=0;t=s;while(1){s=c[t+(r<<2)>>2]|0;u=c[s+4>>2]|0;if((u|0)==0){u1(s)}else{b0[u&127](s)}s=r+1|0;u=c[q>>2]|0;if(s>>>0<(c[p>>2]|0)>>>0){r=s;t=u}else{v=u;break}}}u1(v);c[p>>2]=0;c[q>>2]=0;i=f;return}if((sh(a,g)|0)!=0){q=d|0;p=d+4|0;do{v=e[g>>1]|0;if((c[q>>2]|0)>>>0>v>>>0){t=c[(c[p>>2]|0)+(v<<2)>>2]|0;r=c[t+4>>2]|0;if((r|0)==0){u1(t)}else{b0[r&127](t)}t=v+1|0;r=c[q>>2]|0;if(t>>>0<r>>>0){u=v;v=t;while(1){t=c[p>>2]|0;c[t+(u<<2)>>2]=c[t+(v<<2)>>2];t=v+1|0;s=c[q>>2]|0;if(t>>>0<s>>>0){u=v;v=t}else{w=s;break}}}else{w=r}c[q>>2]=w-1}}while((sh(a,g)|0)!=0)}se(a)|0;i=f;return}if((sb(a,37288)|0)!=0){g=n|0;b[l>>1]=1;b[m>>1]=0;if((sd(a,g,256)|0)==0){r9(a,29568);i=f;return}sh(a,l)|0;sh(a,m)|0;if((se(a)|0)==0){i=f;return}n=b[l>>1]|0;if(n<<16>>16==0){i=f;return}w=u0(36)|0;if((w|0)==0){y=0;z=n}else{c[w>>2]=3;n=w+4|0;u6(n|0,0,20);c[n>>2]=62;c[w+8>>2]=60;c[w+12>>2]=204;c[w+32>>2]=bu(g|0)|0;y=w;z=b[l>>1]|0}l=e[m>>1]|0;c[y+16>>2]=z&65535;c[y+20>>2]=l;l=c[y+12>>2]|0;if((l|0)!=0){b1[l&511](y,c[o>>2]|0)}l=d+4|0;z=d|0;m=u2(c[l>>2]|0,(c[z>>2]<<2)+4|0)|0;w=m;if((m|0)==0){i=f;return}c[l>>2]=w;l=c[z>>2]|0;c[w+(l<<2)>>2]=y;c[z>>2]=l+1;i=f;return}b[j>>1]=1;b[k>>1]=0;c[h>>2]=0;if((si(a,h)|0)==0){r9(a,34440);i=f;return}do{if((sb(a,31944)|0)==0){A=0;B=0}else{l=c[h>>2]|0;if((si(a,h)|0)!=0){A=l&65535;B=1;break}r9(a,30496);i=f;return}}while(0);sh(a,j)|0;sh(a,k)|0;if((se(a)|0)==0){i=f;return}a=b[j>>1]|0;if(a<<16>>16==0){i=f;return}j=c[h>>2]|0;h=u0(36)|0;l=(h|0)==0;do{if((B|0)==0){if(l){C=0;break}c[h>>2]=1;z=h+4|0;u6(z|0,0,20);c[z>>2]=48;c[h+8>>2]=36;c[h+12>>2]=156;c[h+24>>2]=0;c[h+28>>2]=j;C=h}else{if(l){C=0;break}c[h>>2]=2;z=h+4|0;u6(z|0,0,20);c[z>>2]=20;c[h+8>>2]=40;c[h+12>>2]=294;c[h+24>>2]=A;c[h+28>>2]=j&65535;C=h}}while(0);h=e[k>>1]|0;c[C+16>>2]=a&65535;c[C+20>>2]=h;h=c[C+12>>2]|0;if((h|0)!=0){b1[h&511](C,c[o>>2]|0)}h=d+4|0;a=d|0;d=u2(c[h>>2]|0,(c[a>>2]<<2)+4|0)|0;k=d;if((d|0)==0){i=f;return}c[h>>2]=k;h=c[a>>2]|0;c[k+(h<<2)>>2]=C;c[a>>2]=h+1;i=f;return}function r8(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=a[d]|0;f=(b-36&255)<2?d+1|0:d;do{if(b<<24>>24!=36){g=c[14538]|0;do{if((g|0)==0){h=b}else{if((b2[g&127](c[14540]|0,f,e)|0)==0){i=0;return i|0}else{h=a[d]|0;break}}}while(0);if(h<<24>>24==37){i=1}else{break}return i|0}}while(0);h=c[14534]|0;d=c[14536]|0;b=0;while(1){if(b>>>0>=h>>>0){break}if((aQ(c[d+(b<<3)>>2]|0,f|0)|0)==0){j=1397;break}else{b=b+1|0}}if((j|0)==1397){c[d+(b<<3)+4>>2]=e;i=0;return i|0}b=u2(d,(h<<3)+8|0)|0;h=b;if((b|0)==0){i=1;return i|0}b=c[14534]|0;L1881:do{if((b|0)==0){k=0}else{d=b;while(1){j=d-1|0;g=h+(j<<3)|0;if((aQ(c[g>>2]|0,f|0)|0)<0){k=d;break L1881}l=g;g=h+(d<<3)|0;m=c[l+4>>2]|0;c[g>>2]=c[l>>2];c[g+4>>2]=m;if((j|0)==0){k=0;break}else{d=j}}}}while(0);c[h+(k<<3)>>2]=bu(f|0)|0;c[h+(k<<3)+4>>2]=e;c[14536]=h;c[14534]=(c[14534]|0)+1;i=0;return i|0}function r9(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=(c[a>>2]|0)+(a+4)|0;sp(40352,(x=i,i=i+16|0,c[x>>2]=b,c[x+8>>2]=e,x)|0);i=d;return}function sa(b){b=b|0;var d=0,e=0,f=0,g=0;d=b|0;e=c[d>>2]|0;while(1){f=b+4+e|0;g=a[f]|0;if(!((g<<24>>24|0)==13|(g<<24>>24|0)==32|(g<<24>>24|0)==9|(g<<24>>24|0)==10)){break}e=e+1|0}c[d>>2]=e;return(a[f]|0)==0|0}function sb(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=b|0;f=c[e>>2]|0;while(1){g=a[b+4+f|0]|0;if(!((g<<24>>24|0)==13|(g<<24>>24|0)==32|(g<<24>>24|0)==9|(g<<24>>24|0)==10)){break}f=f+1|0}c[e>>2]=f;g=a[d]|0;L1898:do{if(g<<24>>24==0){h=f}else{i=d;j=f;k=g;while(1){if((a[b+4+j|0]|0)!=k<<24>>24){l=0;break}m=j+1|0;n=i+1|0;o=a[n]|0;if(o<<24>>24==0){h=m;break L1898}else{i=n;j=m;k=o}}return l|0}}while(0);c[e>>2]=h;l=1;return l|0}function sc(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;g=b|0;h=c[g>>2]|0;while(1){j=b+4+h|0;k=a[j]|0;if(!((k<<24>>24|0)==13|(k<<24>>24|0)==32|(k<<24>>24|0)==9|(k<<24>>24|0)==10)){break}h=h+1|0}c[g>>2]=h;k=a[j]|0;if(((k<<24>>24)-36|0)>>>0<2){a[d]=k;l=1;m=h+1|0;n=d+1|0}else{l=0;m=h;n=d}while(1){d=a[b+4+m|0]|0;if(d<<24>>24==0){o=1433;break}if(!((d-48&255)<10|(d-97&255)<26|(d-65&255)<26|d<<24>>24==95)){o=1433;break}a[n]=d;d=l+1|0;if(d>>>0<e>>>0){l=d;m=m+1|0;n=n+1|0}else{o=1432;break}}if((o|0)==1432){e=(c[g>>2]|0)+(b+4)|0;sp(40352,(x=i,i=i+16|0,c[x>>2]=37264,c[x+8>>2]=e,x)|0);p=0;i=f;return p|0}else if((o|0)==1433){a[n]=0;c[g>>2]=m;p=(l|0)!=0|0;i=f;return p|0}return 0}function sd(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;g=b|0;h=c[g>>2]|0;while(1){j=b+4+h|0;k=a[j]|0;if(!((k<<24>>24|0)==13|(k<<24>>24|0)==32|(k<<24>>24|0)==9|(k<<24>>24|0)==10)){break}h=h+1|0}c[g>>2]=h;k=(a[j]|0)==34;j=(k&1)+h|0;L1926:do{if(k){h=0;l=j;m=d;while(1){n=a[b+4+l|0]|0;if((n<<24>>24|0)==34){break}else if((n<<24>>24|0)==0){o=l;p=m;q=h;r=1447;break L1926}a[m]=n;n=h+1|0;if(n>>>0<e>>>0){h=n;l=l+1|0;m=m+1|0}else{r=1446;break L1926}}o=l+1|0;p=m;q=h;r=1447}else{n=0;s=j;t=d;while(1){u=a[b+4+s|0]|0;if((u<<24>>24|0)==0|(u<<24>>24|0)==32|(u<<24>>24|0)==9|(u<<24>>24|0)==10|(u<<24>>24|0)==13){o=s;p=t;q=n;r=1447;break L1926}a[t]=u;u=n+1|0;if(u>>>0<e>>>0){n=u;s=s+1|0;t=t+1|0}else{r=1446;break}}}}while(0);if((r|0)==1446){e=(c[g>>2]|0)+(b+4)|0;sp(40352,(x=i,i=i+16|0,c[x>>2]=34424,c[x+8>>2]=e,x)|0);v=0;i=f;return v|0}else if((r|0)==1447){a[p]=0;c[g>>2]=o;v=(q|0)!=0|0;i=f;return v|0}return 0}function se(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;e=b|0;f=c[e>>2]|0;while(1){g=b+4+f|0;h=a[g]|0;if(!((h<<24>>24|0)==13|(h<<24>>24|0)==32|(h<<24>>24|0)==9|(h<<24>>24|0)==10)){break}f=f+1|0}c[e>>2]=f;if((a[g]|0)==0){j=1;i=d;return j|0}sp(40352,(x=i,i=i+16|0,c[x>>2]=31928,c[x+8>>2]=g,x)|0);j=0;i=d;return j|0}function sf(a,b,d){a=a|0;b=b|0;d=d|0;c[14544]=a;c[14542]=b;c[14540]=a;c[14538]=d;return}function sg(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ad=0,ae=0,af=0;f=i;i=i+264|0;g=f|0;h=f+256|0;j=g|0;k=b|0;l=g+1|0;m=c[k>>2]|0;while(1){n=a[b+4+m|0]|0;if((n<<24>>24|0)==13|(n<<24>>24|0)==32|(n<<24>>24|0)==9|(n<<24>>24|0)==10){m=m+1|0;continue}c[k>>2]=m;n=m;while(1){o=b+4+n|0;p=a[o]|0;if(!((p<<24>>24|0)==13|(p<<24>>24|0)==32|(p<<24>>24|0)==9|(p<<24>>24|0)==10)){break}n=n+1|0}c[k>>2]=n;p=a[o]|0;if(((p<<24>>24)-36|0)>>>0<2){a[j]=p;q=1;r=n+1|0;s=l}else{q=0;r=n;s=j}while(1){p=a[b+4+r|0]|0;if(p<<24>>24==0){t=1472;break}if(!((p-48&255)<10|(p-97&255)<26|(p-65&255)<26|p<<24>>24==95)){t=1472;break}a[s]=p;p=q+1|0;if(p>>>0<256){q=p;r=r+1|0;s=s+1|0}else{t=1471;break}}L1965:do{if((t|0)==1471){t=0;n=(c[k>>2]|0)+(b+4)|0;sp(40352,(x=i,i=i+16|0,c[x>>2]=37264,c[x+8>>2]=n,x)|0);t=1552}else if((t|0)==1472){t=0;a[s]=0;c[k>>2]=r;if((q|0)==0){t=1552;break}else{u=0}while(1){v=g+u|0;w=a[v]|0;y=u+1|0;if(w<<24>>24==37){u=y}else{z=r;break}}while(1){A=b+4+z|0;n=a[A]|0;if(!((n<<24>>24|0)==13|(n<<24>>24|0)==32|(n<<24>>24|0)==9|(n<<24>>24|0)==10)){break}z=z+1|0}c[k>>2]=z;n=a[A]|0;L1974:do{if(n<<24>>24==61){p=z+1|0;c[k>>2]=p;B=1;C=p}else{p=z;D=n;while(1){if(!((D<<24>>24|0)==13|(D<<24>>24|0)==32|(D<<24>>24|0)==9|(D<<24>>24|0)==10)){break}E=p+1|0;p=E;D=a[b+4+E|0]|0}c[k>>2]=p;D=a[b+4+p|0]|0;do{if(D<<24>>24==43){if((a[p+1+(b+4)|0]|0)!=61){F=p;G=43;break}E=p+2|0;c[k>>2]=E;B=2;C=E;break L1974}else{F=p;G=D}}while(0);while(1){if(!((G<<24>>24|0)==13|(G<<24>>24|0)==32|(G<<24>>24|0)==9|(G<<24>>24|0)==10)){break}D=F+1|0;F=D;G=a[b+4+D|0]|0}c[k>>2]=F;D=a[b+4+F|0]|0;do{if(D<<24>>24==45){if((a[F+1+(b+4)|0]|0)!=61){H=F;I=45;break}p=F+2|0;c[k>>2]=p;B=3;C=p;break L1974}else{H=F;I=D}}while(0);while(1){if(!((I<<24>>24|0)==13|(I<<24>>24|0)==32|(I<<24>>24|0)==9|(I<<24>>24|0)==10)){break}D=H+1|0;H=D;I=a[b+4+D|0]|0}c[k>>2]=H;D=a[b+4+H|0]|0;do{if(D<<24>>24==42){if((a[H+1+(b+4)|0]|0)!=61){J=H;K=42;break}p=H+2|0;c[k>>2]=p;B=4;C=p;break L1974}else{J=H;K=D}}while(0);while(1){if(!((K<<24>>24|0)==13|(K<<24>>24|0)==32|(K<<24>>24|0)==9|(K<<24>>24|0)==10)){break}D=J+1|0;J=D;K=a[b+4+D|0]|0}c[k>>2]=J;D=a[b+4+J|0]|0;do{if(D<<24>>24==47){if((a[J+1+(b+4)|0]|0)!=61){L=J;M=47;break}p=J+2|0;c[k>>2]=p;B=5;C=p;break L1974}else{L=J;M=D}}while(0);while(1){if(!((M<<24>>24|0)==13|(M<<24>>24|0)==32|(M<<24>>24|0)==9|(M<<24>>24|0)==10)){break}D=L+1|0;L=D;M=a[b+4+D|0]|0}c[k>>2]=L;D=a[b+4+L|0]|0;do{if(D<<24>>24==60){if((a[L+1+(b+4)|0]|0)!=60){N=L;O=60;break}if((a[L+2+(b+4)|0]|0)!=61){N=L;O=D;break}p=L+3|0;c[k>>2]=p;B=6;C=p;break L1974}else{N=L;O=D}}while(0);while(1){if(!((O<<24>>24|0)==13|(O<<24>>24|0)==32|(O<<24>>24|0)==9|(O<<24>>24|0)==10)){break}D=N+1|0;N=D;O=a[b+4+D|0]|0}c[k>>2]=N;D=a[b+4+N|0]|0;do{if(D<<24>>24==62){if((a[N+1+(b+4)|0]|0)!=62){P=N;Q=62;break}if((a[N+2+(b+4)|0]|0)!=61){P=N;Q=D;break}p=N+3|0;c[k>>2]=p;B=7;C=p;break L1974}else{P=N;Q=D}}while(0);while(1){if(!((Q<<24>>24|0)==13|(Q<<24>>24|0)==32|(Q<<24>>24|0)==9|(Q<<24>>24|0)==10)){break}D=P+1|0;P=D;Q=a[b+4+D|0]|0}c[k>>2]=P;D=a[b+4+P|0]|0;do{if(D<<24>>24==124){if((a[P+1+(b+4)|0]|0)!=61){R=P;S=124;break}p=P+2|0;c[k>>2]=p;B=8;C=p;break L1974}else{R=P;S=D}}while(0);while(1){if(!((S<<24>>24|0)==13|(S<<24>>24|0)==32|(S<<24>>24|0)==9|(S<<24>>24|0)==10)){break}D=R+1|0;R=D;S=a[b+4+D|0]|0}c[k>>2]=R;D=a[b+4+R|0]|0;do{if(D<<24>>24==38){if((a[R+1+(b+4)|0]|0)!=61){T=R;U=38;break}p=R+2|0;c[k>>2]=p;B=9;C=p;break L1974}else{T=R;U=D}}while(0);while(1){if(!((U<<24>>24|0)==13|(U<<24>>24|0)==32|(U<<24>>24|0)==9|(U<<24>>24|0)==10)){break}D=T+1|0;T=D;U=a[b+4+D|0]|0}c[k>>2]=T;if((a[b+4+T|0]|0)!=94){t=1552;break L1965}if((a[T+1+(b+4)|0]|0)!=61){t=1552;break L1965}D=T+2|0;c[k>>2]=D;B=10;C=D}}while(0);n=C;while(1){V=b+4+n|0;D=a[V]|0;if(!((D<<24>>24|0)==13|(D<<24>>24|0)==32|(D<<24>>24|0)==9|(D<<24>>24|0)==10)){break}n=n+1|0}c[k>>2]=n;if((a[V]|0)==59){c[k>>2]=n+1;if((w<<24>>24|0)==37){break}else if((w<<24>>24|0)==36){W=g+y|0}else{W=v}c[d>>2]=0;D=c[14534]|0;if((D|0)==0){X=0}else{p=0;E=0;Y=D;while(1){D=c[14536]|0;if((aQ(c[D+(p<<3)>>2]|0,W|0)|0)==0){c[d>>2]=c[D+(p<<3)+4>>2];u1(c[(c[14536]|0)+(p<<3)>>2]|0);Z=E;_=c[14534]|0}else{$=D+(p<<3)|0;aa=D+(E<<3)|0;D=c[$+4>>2]|0;c[aa>>2]=c[$>>2];c[aa+4>>2]=D;Z=E+1|0;_=Y}D=p+1|0;if(D>>>0<_>>>0){p=D;E=Z;Y=_}else{X=Z;break}}}c[14534]=X;break}Y=(w-36&255)<2?g+y|0:v;do{if(w<<24>>24==36){t=1531}else{E=c[14542]|0;if((E|0)==0){ab=w}else{if((b2[E&127](c[14544]|0,Y,d)|0)==0){break}ab=a[v]|0}if(ab<<24>>24==37){t=1535}else{t=1531}}}while(0);L2065:do{if((t|0)==1531){t=0;E=c[14534]|0;p=c[14536]|0;n=0;while(1){if(n>>>0>=E>>>0){t=1535;break L2065}if((aQ(c[p+(n<<3)>>2]|0,Y|0)|0)==0){break}else{n=n+1|0}}c[d>>2]=c[p+(n<<3)+4>>2]}}while(0);if((t|0)==1535){t=0;c[d>>2]=0}if((sj(b,h,e)|0)==0){t=1552;break}do{if((B|0)==5){Y=c[h>>2]|0;if((Y|0)==0){c[d>>2]=-1;ad=-1;break}else{E=((c[d>>2]|0)>>>0)/(Y>>>0)|0;c[d>>2]=E;ad=E;break}}else if((B|0)==6){E=c[d>>2]<<c[h>>2];c[d>>2]=E;ad=E}else if((B|0)==7){E=(c[d>>2]|0)>>>((c[h>>2]|0)>>>0);c[d>>2]=E;ad=E}else if((B|0)==3){E=(c[d>>2]|0)-(c[h>>2]|0)|0;c[d>>2]=E;ad=E}else if((B|0)==4){E=ac(c[d>>2]|0,c[h>>2]|0)|0;c[d>>2]=E;ad=E}else if((B|0)==1){E=c[h>>2]|0;c[d>>2]=E;ad=E}else if((B|0)==2){E=(c[d>>2]|0)+(c[h>>2]|0)|0;c[d>>2]=E;ad=E}else if((B|0)==8){E=c[d>>2]|c[h>>2];c[d>>2]=E;ad=E}else if((B|0)==9){E=c[d>>2]&c[h>>2];c[d>>2]=E;ad=E}else if((B|0)==10){E=c[d>>2]^c[h>>2];c[d>>2]=E;ad=E}else{E=c[h>>2]|0;c[d>>2]=E;ad=E}}while(0);r8(0,v,ad)|0}}while(0);if((t|0)==1552){t=0;c[k>>2]=m;if((sj(b,d,e)|0)==0){ae=0;t=1570;break}}E=c[k>>2]|0;while(1){af=b+4+E|0;Y=a[af]|0;if(!((Y<<24>>24|0)==13|(Y<<24>>24|0)==32|(Y<<24>>24|0)==9|(Y<<24>>24|0)==10)){break}E=E+1|0}c[k>>2]=E;if((a[af]|0)!=44){ae=1;t=1571;break}Y=E+1|0;c[k>>2]=Y;m=Y}if((t|0)==1570){i=f;return ae|0}else if((t|0)==1571){i=f;return ae|0}return 0}function sh(a,d){a=a|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+8|0;f=e|0;if((sg(a,f,16)|0)==0){g=0;i=e;return g|0}b[d>>1]=c[f>>2]&65535;g=1;i=e;return g|0}function si(a,b){a=a|0;b=b|0;return sg(a,b,16)|0}
function sj(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0,fn=0,fo=0,fp=0,fq=0,fr=0,fs=0,ft=0,fu=0,fv=0,fw=0,fx=0,fy=0,fz=0,fA=0,fB=0,fC=0,fD=0,fE=0,fF=0,fG=0,fH=0,fI=0,fJ=0,fK=0,fL=0,fM=0,fN=0,fO=0,fP=0,fQ=0,fR=0,fS=0,fT=0,fU=0,fV=0,fW=0,fX=0,fY=0,fZ=0,f_=0,f$=0,f0=0,f1=0,f2=0,f3=0,f4=0,f5=0,f6=0,f7=0,f8=0,f9=0,ga=0,gb=0,gc=0,gd=0,ge=0,gf=0,gg=0,gh=0,gi=0,gj=0,gk=0,gl=0,gm=0,gn=0,go=0,gp=0,gq=0,gr=0,gs=0,gt=0,gu=0,gv=0,gw=0,gx=0,gy=0,gz=0,gA=0,gB=0,gC=0,gD=0,gE=0,gF=0,gG=0,gH=0,gI=0,gJ=0,gK=0,gL=0,gM=0,gN=0,gO=0,gP=0,gQ=0,gR=0,gS=0,gT=0,gU=0,gV=0,gW=0,gX=0,gY=0,gZ=0,g_=0,g$=0,g0=0,g1=0,g2=0,g3=0,g4=0,g5=0,g6=0,g7=0,g8=0,g9=0,ha=0,hb=0,hc=0,hd=0,he=0,hf=0,hg=0,hh=0,hi=0,hj=0,hk=0,hl=0,hm=0,hn=0,ho=0,hp=0,hq=0,hr=0,hs=0,ht=0,hu=0,hv=0,hw=0,hx=0,hy=0,hz=0,hA=0,hB=0,hC=0,hD=0,hE=0,hF=0,hG=0,hH=0,hI=0,hJ=0,hK=0,hL=0,hM=0,hN=0,hO=0,hP=0,hQ=0,hR=0,hS=0,hT=0,hU=0,hV=0,hW=0,hX=0,hY=0,hZ=0,h_=0,h$=0,h0=0,h1=0,h2=0,h3=0,h4=0,h5=0,h6=0,h7=0,h8=0,h9=0,ia=0,ib=0,ic=0,id=0,ie=0,ig=0,ih=0,ii=0,ij=0,ik=0,il=0,im=0,io=0,ip=0,iq=0,ir=0,is=0,it=0,iu=0,iv=0,iw=0,ix=0,iy=0,iz=0,iA=0,iB=0,iC=0,iD=0,iE=0,iF=0,iG=0,iH=0,iI=0,iJ=0,iK=0,iL=0,iM=0,iN=0,iO=0,iP=0,iQ=0,iR=0,iS=0,iT=0,iU=0,iV=0,iW=0,iX=0,iY=0,iZ=0,i_=0,i$=0,i0=0,i1=0,i2=0,i3=0,i4=0,i5=0,i6=0,i7=0,i8=0,i9=0,ja=0,jb=0,jc=0,jd=0,je=0,jf=0,jg=0,jh=0,ji=0,jj=0,jk=0,jl=0,jm=0,jn=0,jo=0,jp=0,jq=0,jr=0,js=0,jt=0,ju=0,jv=0,jw=0,jx=0,jy=0,jz=0,jA=0,jB=0,jC=0,jD=0,jE=0,jF=0,jG=0,jH=0,jI=0,jJ=0,jK=0,jL=0,jM=0,jN=0,jO=0,jP=0,jQ=0,jR=0,jS=0,jT=0,jU=0,jV=0,jW=0,jX=0,jY=0,jZ=0,j_=0,j$=0,j0=0,j1=0,j2=0,j3=0,j4=0,j5=0,j6=0,j7=0,j8=0,j9=0,ka=0,kb=0,kc=0,kd=0,ke=0,kf=0,kg=0,kh=0,ki=0,kj=0,kk=0,kl=0,km=0,kn=0,ko=0,kp=0,kq=0,kr=0,ks=0,kt=0,ku=0,kv=0,kw=0,kx=0,ky=0,kz=0,kA=0,kB=0,kC=0,kD=0,kE=0,kF=0,kG=0,kH=0,kI=0,kJ=0,kK=0,kL=0,kM=0,kN=0,kO=0,kP=0,kQ=0,kR=0,kS=0,kT=0,kU=0,kV=0,kW=0,kX=0,kY=0,kZ=0,k_=0,k$=0,k0=0,k1=0,k2=0,k3=0,k4=0,k5=0,k6=0,k7=0,k8=0,k9=0,la=0,lb=0,lc=0,ld=0,le=0,lf=0,lg=0,lh=0,li=0,lj=0,lk=0,ll=0,lm=0,ln=0,lo=0,lp=0,lq=0,lr=0,ls=0,lt=0,lu=0,lv=0,lw=0,lx=0,ly=0,lz=0,lA=0,lB=0,lC=0,lD=0,lE=0,lF=0,lG=0,lH=0,lI=0,lJ=0,lK=0,lL=0,lM=0,lN=0,lO=0,lP=0,lQ=0,lR=0,lS=0,lT=0,lU=0,lV=0,lW=0,lX=0,lY=0,lZ=0,l_=0,l$=0,l0=0,l1=0,l2=0,l3=0,l4=0,l5=0,l6=0,l7=0,l8=0,l9=0,ma=0,mb=0,mc=0,md=0,me=0,mf=0,mg=0,mh=0,mi=0,mj=0,mk=0,ml=0,mm=0,mn=0,mo=0,mp=0,mq=0,mr=0,ms=0,mt=0,mu=0,mv=0,mw=0,mx=0,my=0,mz=0,mA=0,mB=0,mC=0,mD=0,mE=0,mF=0,mG=0,mH=0,mI=0,mJ=0,mK=0,mL=0,mM=0,mN=0,mO=0,mP=0,mQ=0,mR=0,mS=0,mT=0,mU=0,mV=0,mW=0,mX=0,mY=0,mZ=0,m_=0,m$=0,m0=0,m1=0,m2=0,m3=0,m4=0,m5=0,m6=0,m7=0,m8=0,m9=0,na=0,nb=0,nc=0,nd=0,ne=0,nf=0,ng=0,nh=0,ni=0,nj=0,nk=0,nl=0,nm=0,nn=0,no=0,np=0,nq=0,nr=0,ns=0,nt=0,nu=0,nv=0,nw=0,nx=0,ny=0,nz=0,nA=0,nB=0,nC=0,nD=0,nE=0,nF=0,nG=0,nH=0,nI=0,nJ=0,nK=0,nL=0,nM=0,nN=0,nO=0,nP=0,nQ=0,nR=0,nS=0,nT=0,nU=0,nV=0,nW=0,nX=0,nY=0,nZ=0,n_=0,n$=0,n0=0,n1=0,n2=0,n3=0,n4=0,n5=0,n6=0,n7=0,n8=0,n9=0,oa=0,ob=0,oc=0,od=0,oe=0,of=0,og=0,oh=0,oi=0,oj=0,ok=0,ol=0,om=0,on=0,oo=0,op=0,oq=0,or=0,os=0,ot=0,ou=0,ov=0,ow=0,ox=0,oy=0,oz=0,oA=0,oB=0,oC=0,oD=0,oE=0,oF=0,oG=0,oH=0,oI=0,oJ=0,oK=0,oL=0,oM=0,oN=0,oO=0,oP=0,oQ=0,oR=0,oS=0,oT=0,oU=0,oV=0,oW=0,oX=0,oY=0,oZ=0,o_=0,o$=0,o0=0,o1=0,o2=0,o3=0,o4=0,o5=0,o6=0,o7=0,o8=0,o9=0,pa=0,pb=0,pc=0,pd=0,pe=0,pf=0,pg=0,ph=0,pi=0,pj=0,pk=0,pl=0,pm=0,pn=0,po=0,pp=0,pq=0,pr=0,ps=0,pt=0,pu=0,pv=0,pw=0,px=0,py=0,pz=0,pA=0,pB=0,pC=0,pD=0,pE=0,pF=0,pG=0,pH=0,pI=0,pJ=0,pK=0,pL=0,pM=0,pN=0,pO=0,pP=0,pQ=0,pR=0,pS=0,pT=0,pU=0,pV=0,pW=0,pX=0,pY=0,pZ=0,p_=0,p$=0,p0=0,p1=0,p2=0,p3=0,p4=0,p5=0,p6=0,p7=0,p8=0,p9=0,qa=0,qb=0,qc=0,qd=0,qe=0,qf=0,qg=0;f=i;i=i+1528|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=f+32|0;m=f+40|0;n=f+48|0;o=f+56|0;p=f+64|0;q=f+72|0;r=f+80|0;s=f+88|0;t=f+96|0;u=f+104|0;v=f+112|0;w=f+120|0;x=f+128|0;y=f+136|0;z=f+144|0;A=f+152|0;B=f+160|0;C=f+168|0;D=f+176|0;E=f+184|0;F=f+192|0;G=f+200|0;H=f+208|0;I=f+216|0;J=f+224|0;K=f+232|0;L=f+240|0;M=f+248|0;N=f+256|0;O=f+264|0;P=f+272|0;Q=f+280|0;R=f+288|0;S=f+296|0;T=f+304|0;U=f+312|0;V=f+320|0;W=f+328|0;X=f+336|0;Y=f+344|0;Z=f+352|0;_=f+360|0;$=f+368|0;aa=f+376|0;ab=f+384|0;ac=f+392|0;ad=f+400|0;ae=f+408|0;af=f+416|0;ag=f+424|0;ah=f+432|0;ai=f+440|0;aj=f+448|0;ak=f+456|0;al=f+464|0;am=f+472|0;an=f+480|0;ao=f+488|0;ap=f+496|0;aq=f+504|0;ar=f+512|0;as=f+520|0;at=f+528|0;au=f+536|0;av=f+544|0;aw=f+552|0;ax=f+560|0;ay=f+568|0;az=f+576|0;aA=f+584|0;aB=f+592|0;aC=f+600|0;aD=f+608|0;aE=f+616|0;aF=f+624|0;aG=f+632|0;aH=f+640|0;aI=f+648|0;aJ=f+656|0;aK=f+664|0;aL=f+672|0;aM=f+680|0;aN=f+688|0;aO=f+696|0;aP=f+704|0;aQ=f+712|0;aR=f+720|0;aS=f+728|0;aT=f+736|0;aU=f+744|0;aV=f+752|0;aW=f+760|0;aX=f+768|0;aY=f+776|0;aZ=f+784|0;a_=f+792|0;a$=f+800|0;a0=f+808|0;a1=f+816|0;a2=f+824|0;a3=f+832|0;a4=f+840|0;a5=f+848|0;a6=f+856|0;a7=f+864|0;a8=f+872|0;a9=f+880|0;ba=f+888|0;bb=f+896|0;bc=f+904|0;bd=f+912|0;be=f+920|0;bf=f+928|0;bg=f+936|0;bh=f+944|0;bi=f+952|0;bj=f+960|0;bk=f+968|0;bl=f+976|0;bm=f+984|0;bn=f+992|0;bo=f+1e3|0;bp=f+1008|0;bq=f+1016|0;br=f+1024|0;bs=f+1032|0;bt=f+1040|0;bu=f+1048|0;bv=f+1056|0;bw=f+1064|0;bx=f+1072|0;by=f+1080|0;bz=f+1088|0;bA=f+1096|0;bB=f+1104|0;bC=f+1112|0;bD=f+1120|0;bE=f+1128|0;bF=f+1136|0;bG=f+1144|0;bH=f+1152|0;bI=f+1160|0;bJ=f+1168|0;bK=f+1176|0;bL=f+1184|0;bM=f+1192|0;bN=f+1200|0;bO=f+1208|0;bP=f+1216|0;bQ=f+1224|0;bR=f+1232|0;bS=f+1240|0;bT=f+1248|0;bU=f+1256|0;bV=f+1264|0;bW=f+1272|0;bX=f+1280|0;bY=f+1288|0;bZ=f+1296|0;b_=f+1304|0;b$=f+1312|0;b0=f+1320|0;b1=f+1328|0;b2=f+1336|0;b3=f+1344|0;b4=f+1352|0;b5=f+1360|0;b6=f+1368|0;b7=f+1376|0;b8=f+1384|0;b9=f+1392|0;ca=f+1400|0;cb=f+1408|0;cc=f+1416|0;cd=f+1424|0;ce=f+1432|0;cf=f+1440|0;cg=f+1448|0;ch=f+1456|0;ci=f+1464|0;cj=f+1472|0;ck=f+1480|0;cl=f+1488|0;cm=f+1496|0;cn=f+1504|0;co=f+1512|0;cp=f+1520|0;cq=b|0;cr=c[cq>>2]|0;if((sk(b,d,e)|0)==0){cs=0;i=f;return cs|0}while(1){ct=c[cq>>2]|0;while(1){cu=b+4+ct|0;cv=a[cu]|0;if(!((cv<<24>>24|0)==13|(cv<<24>>24|0)==32|(cv<<24>>24|0)==9|(cv<<24>>24|0)==10)){break}ct=ct+1|0}c[cq>>2]=ct;cv=a[cu]|0;if(cv<<24>>24==61){if((a[ct+1+(b+4)|0]|0)==61){cw=1;cx=ct}else{cy=ct;cz=61;cA=1584}}else{cy=ct;cz=cv;cA=1584}if((cA|0)==1584){while(1){cA=0;if(!((cz<<24>>24|0)==13|(cz<<24>>24|0)==32|(cz<<24>>24|0)==9|(cz<<24>>24|0)==10)){break}cv=cy+1|0;cy=cv;cz=a[b+4+cv|0]|0;cA=1584}c[cq>>2]=cy;if((a[b+4+cy|0]|0)!=33){break}if((a[cy+1+(b+4)|0]|0)==61){cw=2;cx=cy}else{break}}c[cq>>2]=cx+2;if((sk(b,aW,e)|0)==0){cA=1590;break}if((cw|0)==1){c[d>>2]=(c[d>>2]|0)==(c[aW>>2]|0);continue}else if((cw|0)==2){c[d>>2]=(c[d>>2]|0)!=(c[aW>>2]|0);continue}else{continue}}if((cA|0)==1590){c[cq>>2]=cr;cs=0;i=f;return cs|0}aW=cy;L2134:while(1){cy=aW;while(1){cB=b+4+cy|0;cw=a[cB]|0;if(!((cw<<24>>24|0)==13|(cw<<24>>24|0)==32|(cw<<24>>24|0)==9|(cw<<24>>24|0)==10)){break}cy=cy+1|0}c[cq>>2]=cy;cw=a[cB]|0;if(cw<<24>>24==38){if((a[cy+1+(b+4)|0]|0)==38){cA=3895;break}else{cC=cy;cD=38}}else{cC=cy;cD=cw}while(1){if(!((cD<<24>>24|0)==13|(cD<<24>>24|0)==32|(cD<<24>>24|0)==9|(cD<<24>>24|0)==10)){break}cw=cC+1|0;cC=cw;cD=a[b+4+cw|0]|0}c[cq>>2]=cC;if((a[b+4+cC|0]|0)!=38){cE=cC;break}cF=cC+1|0;c[cq>>2]=cF;if((sk(b,bG,e)|0)==0){cA=1618;break}while(1){cy=c[cq>>2]|0;while(1){cG=b+4+cy|0;cw=a[cG]|0;if(!((cw<<24>>24|0)==13|(cw<<24>>24|0)==32|(cw<<24>>24|0)==9|(cw<<24>>24|0)==10)){break}cy=cy+1|0}c[cq>>2]=cy;cw=a[cG]|0;if(cw<<24>>24==61){if((a[cy+1+(b+4)|0]|0)==61){cH=1;cI=cy}else{cJ=cy;cK=61;cA=1609}}else{cJ=cy;cK=cw;cA=1609}if((cA|0)==1609){while(1){cA=0;if(!((cK<<24>>24|0)==13|(cK<<24>>24|0)==32|(cK<<24>>24|0)==9|(cK<<24>>24|0)==10)){break}cw=cJ+1|0;cJ=cw;cK=a[b+4+cw|0]|0;cA=1609}c[cq>>2]=cJ;if((a[b+4+cJ|0]|0)!=33){break}if((a[cJ+1+(b+4)|0]|0)==61){cH=2;cI=cJ}else{break}}c[cq>>2]=cI+2;if((sk(b,aV,e)|0)==0){cA=1614;break L2134}if((cH|0)==1){c[bG>>2]=(c[bG>>2]|0)==(c[aV>>2]|0);continue}else if((cH|0)==2){c[bG>>2]=(c[bG>>2]|0)!=(c[aV>>2]|0);continue}else{continue}}c[d>>2]=c[bG>>2]&c[d>>2];aW=c[cq>>2]|0}if((cA|0)==1614){c[cq>>2]=cF;cA=1618}else if((cA|0)==3895){c[cq>>2]=aW;cE=aW}if((cA|0)==1618){c[cq>>2]=cr;cs=0;i=f;return cs|0}aW=cE;L2174:while(1){cE=b+4+aW|0;cF=a[cE]|0;if((cF<<24>>24|0)==13|(cF<<24>>24|0)==32|(cF<<24>>24|0)==9|(cF<<24>>24|0)==10){aW=aW+1|0;continue}c[cq>>2]=aW;if((a[cE]|0)!=94){cA=1623;break}cL=aW+1|0;c[cq>>2]=cL;if((sk(b,b2,e)|0)==0){break}while(1){cE=c[cq>>2]|0;while(1){cM=b+4+cE|0;cF=a[cM]|0;if(!((cF<<24>>24|0)==13|(cF<<24>>24|0)==32|(cF<<24>>24|0)==9|(cF<<24>>24|0)==10)){break}cE=cE+1|0}c[cq>>2]=cE;cF=a[cM]|0;if(cF<<24>>24==61){if((a[cE+1+(b+4)|0]|0)==61){cN=1;cO=cE}else{cP=cE;cQ=61;cA=1630}}else{cP=cE;cQ=cF;cA=1630}if((cA|0)==1630){while(1){cA=0;if(!((cQ<<24>>24|0)==13|(cQ<<24>>24|0)==32|(cQ<<24>>24|0)==9|(cQ<<24>>24|0)==10)){break}cF=cP+1|0;cP=cF;cQ=a[b+4+cF|0]|0;cA=1630}c[cq>>2]=cP;if((a[b+4+cP|0]|0)!=33){cR=cP;break}if((a[cP+1+(b+4)|0]|0)==61){cN=2;cO=cP}else{cR=cP;break}}c[cq>>2]=cO+2;if((sk(b,aU,e)|0)==0){cA=1635;break L2174}if((cN|0)==1){c[b2>>2]=(c[b2>>2]|0)==(c[aU>>2]|0);continue}else if((cN|0)==2){c[b2>>2]=(c[b2>>2]|0)!=(c[aU>>2]|0);continue}else{continue}}while(1){cE=cR;while(1){cS=b+4+cE|0;cF=a[cS]|0;if(!((cF<<24>>24|0)==13|(cF<<24>>24|0)==32|(cF<<24>>24|0)==9|(cF<<24>>24|0)==10)){break}cE=cE+1|0}c[cq>>2]=cE;cF=a[cS]|0;if(cF<<24>>24==38){if((a[cE+1+(b+4)|0]|0)==38){cA=3894;break}else{cT=cE;cU=38}}else{cT=cE;cU=cF}while(1){if(!((cU<<24>>24|0)==13|(cU<<24>>24|0)==32|(cU<<24>>24|0)==9|(cU<<24>>24|0)==10)){break}cF=cT+1|0;cT=cF;cU=a[b+4+cF|0]|0}c[cq>>2]=cT;if((a[b+4+cT|0]|0)!=38){break}cV=cT+1|0;c[cq>>2]=cV;if((sk(b,bF,e)|0)==0){cA=1662;break L2174}while(1){cE=c[cq>>2]|0;while(1){cW=b+4+cE|0;cF=a[cW]|0;if(!((cF<<24>>24|0)==13|(cF<<24>>24|0)==32|(cF<<24>>24|0)==9|(cF<<24>>24|0)==10)){break}cE=cE+1|0}c[cq>>2]=cE;cF=a[cW]|0;if(cF<<24>>24==61){if((a[cE+1+(b+4)|0]|0)==61){cX=1;cY=cE}else{cZ=cE;c_=61;cA=1653}}else{cZ=cE;c_=cF;cA=1653}if((cA|0)==1653){while(1){cA=0;if(!((c_<<24>>24|0)==13|(c_<<24>>24|0)==32|(c_<<24>>24|0)==9|(c_<<24>>24|0)==10)){break}cF=cZ+1|0;cZ=cF;c_=a[b+4+cF|0]|0;cA=1653}c[cq>>2]=cZ;if((a[b+4+cZ|0]|0)!=33){break}if((a[cZ+1+(b+4)|0]|0)==61){cX=2;cY=cZ}else{break}}c[cq>>2]=cY+2;if((sk(b,aT,e)|0)==0){cA=1658;break L2174}if((cX|0)==1){c[bF>>2]=(c[bF>>2]|0)==(c[aT>>2]|0);continue}else if((cX|0)==2){c[bF>>2]=(c[bF>>2]|0)!=(c[aT>>2]|0);continue}else{continue}}c[b2>>2]=c[bF>>2]&c[b2>>2];cR=cZ}if((cA|0)==3894){cA=0;c[cq>>2]=cR}c[d>>2]=c[b2>>2]^c[d>>2];aW=c[cq>>2]|0}if((cA|0)==1623){b2=aW;L2237:while(1){aW=b2;while(1){c$=b+4+aW|0;cR=a[c$]|0;if(!((cR<<24>>24|0)==13|(cR<<24>>24|0)==32|(cR<<24>>24|0)==9|(cR<<24>>24|0)==10)){break}aW=aW+1|0}c[cq>>2]=aW;cR=a[c$]|0;if(cR<<24>>24==124){if((a[aW+1+(b+4)|0]|0)==124){cA=3891;break}else{c0=aW;c1=124}}else{c0=aW;c1=cR}while(1){if(!((c1<<24>>24|0)==13|(c1<<24>>24|0)==32|(c1<<24>>24|0)==9|(c1<<24>>24|0)==10)){break}cR=c0+1|0;c0=cR;c1=a[b+4+cR|0]|0}c[cq>>2]=c0;if((a[b+4+c0|0]|0)!=124){c2=c0;cA=1674;break}c3=c0+1|0;c[cq>>2]=c3;if((sk(b,ce,e)|0)==0){break}while(1){aW=c[cq>>2]|0;while(1){c4=b+4+aW|0;cR=a[c4]|0;if(!((cR<<24>>24|0)==13|(cR<<24>>24|0)==32|(cR<<24>>24|0)==9|(cR<<24>>24|0)==10)){break}aW=aW+1|0}c[cq>>2]=aW;cR=a[c4]|0;if(cR<<24>>24==61){if((a[aW+1+(b+4)|0]|0)==61){c5=1;c6=aW}else{c7=aW;c8=61;cA=1681}}else{c7=aW;c8=cR;cA=1681}if((cA|0)==1681){while(1){cA=0;if(!((c8<<24>>24|0)==13|(c8<<24>>24|0)==32|(c8<<24>>24|0)==9|(c8<<24>>24|0)==10)){break}cR=c7+1|0;c7=cR;c8=a[b+4+cR|0]|0;cA=1681}c[cq>>2]=c7;if((a[b+4+c7|0]|0)!=33){c9=c7;break}if((a[c7+1+(b+4)|0]|0)==61){c5=2;c6=c7}else{c9=c7;break}}c[cq>>2]=c6+2;if((sk(b,aS,e)|0)==0){cA=1686;break L2237}if((c5|0)==2){c[ce>>2]=(c[ce>>2]|0)!=(c[aS>>2]|0);continue}else if((c5|0)==1){c[ce>>2]=(c[ce>>2]|0)==(c[aS>>2]|0);continue}else{continue}}while(1){aW=c9;while(1){da=b+4+aW|0;cR=a[da]|0;if(!((cR<<24>>24|0)==13|(cR<<24>>24|0)==32|(cR<<24>>24|0)==9|(cR<<24>>24|0)==10)){break}aW=aW+1|0}c[cq>>2]=aW;cR=a[da]|0;if(cR<<24>>24==38){if((a[aW+1+(b+4)|0]|0)==38){cA=3892;break}else{db=aW;dc=38}}else{db=aW;dc=cR}while(1){if(!((dc<<24>>24|0)==13|(dc<<24>>24|0)==32|(dc<<24>>24|0)==9|(dc<<24>>24|0)==10)){break}cR=db+1|0;db=cR;dc=a[b+4+cR|0]|0}c[cq>>2]=db;if((a[b+4+db|0]|0)!=38){dd=db;break}de=db+1|0;c[cq>>2]=de;if((sk(b,bE,e)|0)==0){cA=1713;break L2237}while(1){aW=c[cq>>2]|0;while(1){df=b+4+aW|0;cR=a[df]|0;if(!((cR<<24>>24|0)==13|(cR<<24>>24|0)==32|(cR<<24>>24|0)==9|(cR<<24>>24|0)==10)){break}aW=aW+1|0}c[cq>>2]=aW;cR=a[df]|0;if(cR<<24>>24==61){if((a[aW+1+(b+4)|0]|0)==61){dg=1;dh=aW}else{di=aW;dj=61;cA=1704}}else{di=aW;dj=cR;cA=1704}if((cA|0)==1704){while(1){cA=0;if(!((dj<<24>>24|0)==13|(dj<<24>>24|0)==32|(dj<<24>>24|0)==9|(dj<<24>>24|0)==10)){break}cR=di+1|0;di=cR;dj=a[b+4+cR|0]|0;cA=1704}c[cq>>2]=di;if((a[b+4+di|0]|0)!=33){break}if((a[di+1+(b+4)|0]|0)==61){dg=2;dh=di}else{break}}c[cq>>2]=dh+2;if((sk(b,aR,e)|0)==0){cA=1709;break L2237}if((dg|0)==2){c[bE>>2]=(c[bE>>2]|0)!=(c[aR>>2]|0);continue}else if((dg|0)==1){c[bE>>2]=(c[bE>>2]|0)==(c[aR>>2]|0);continue}else{continue}}c[ce>>2]=c[bE>>2]&c[ce>>2];c9=di}if((cA|0)==3892){cA=0;c[cq>>2]=c9;dd=c9}while(1){aW=b+4+dd|0;cR=a[aW]|0;if((cR<<24>>24|0)==13|(cR<<24>>24|0)==32|(cR<<24>>24|0)==9|(cR<<24>>24|0)==10){dd=dd+1|0;continue}c[cq>>2]=dd;if((a[aW]|0)!=94){break}dk=dd+1|0;c[cq>>2]=dk;if((sk(b,b1,e)|0)==0){cA=1758;break L2237}while(1){aW=c[cq>>2]|0;while(1){dl=b+4+aW|0;cR=a[dl]|0;if(!((cR<<24>>24|0)==13|(cR<<24>>24|0)==32|(cR<<24>>24|0)==9|(cR<<24>>24|0)==10)){break}aW=aW+1|0}c[cq>>2]=aW;cR=a[dl]|0;if(cR<<24>>24==61){if((a[aW+1+(b+4)|0]|0)==61){dm=1;dn=aW}else{dp=aW;dq=61;cA=1724}}else{dp=aW;dq=cR;cA=1724}if((cA|0)==1724){while(1){cA=0;if(!((dq<<24>>24|0)==13|(dq<<24>>24|0)==32|(dq<<24>>24|0)==9|(dq<<24>>24|0)==10)){break}cR=dp+1|0;dp=cR;dq=a[b+4+cR|0]|0;cA=1724}c[cq>>2]=dp;if((a[b+4+dp|0]|0)!=33){dr=dp;break}if((a[dp+1+(b+4)|0]|0)==61){dm=2;dn=dp}else{dr=dp;break}}c[cq>>2]=dn+2;if((sk(b,aQ,e)|0)==0){cA=1729;break L2237}if((dm|0)==1){c[b1>>2]=(c[b1>>2]|0)==(c[aQ>>2]|0);continue}else if((dm|0)==2){c[b1>>2]=(c[b1>>2]|0)!=(c[aQ>>2]|0);continue}else{continue}}while(1){aW=dr;while(1){ds=b+4+aW|0;cR=a[ds]|0;if(!((cR<<24>>24|0)==13|(cR<<24>>24|0)==32|(cR<<24>>24|0)==9|(cR<<24>>24|0)==10)){break}aW=aW+1|0}c[cq>>2]=aW;cR=a[ds]|0;if(cR<<24>>24==38){if((a[aW+1+(b+4)|0]|0)==38){cA=3893;break}else{dt=aW;du=38}}else{dt=aW;du=cR}while(1){if(!((du<<24>>24|0)==13|(du<<24>>24|0)==32|(du<<24>>24|0)==9|(du<<24>>24|0)==10)){break}cR=dt+1|0;dt=cR;du=a[b+4+cR|0]|0}c[cq>>2]=dt;if((a[b+4+dt|0]|0)!=38){dv=dt;break}dw=dt+1|0;c[cq>>2]=dw;if((sk(b,bD,e)|0)==0){cA=1756;break L2237}while(1){aW=c[cq>>2]|0;while(1){dx=b+4+aW|0;cR=a[dx]|0;if(!((cR<<24>>24|0)==13|(cR<<24>>24|0)==32|(cR<<24>>24|0)==9|(cR<<24>>24|0)==10)){break}aW=aW+1|0}c[cq>>2]=aW;cR=a[dx]|0;if(cR<<24>>24==61){if((a[aW+1+(b+4)|0]|0)==61){dy=1;dz=aW}else{dA=aW;dB=61;cA=1747}}else{dA=aW;dB=cR;cA=1747}if((cA|0)==1747){while(1){cA=0;if(!((dB<<24>>24|0)==13|(dB<<24>>24|0)==32|(dB<<24>>24|0)==9|(dB<<24>>24|0)==10)){break}cR=dA+1|0;dA=cR;dB=a[b+4+cR|0]|0;cA=1747}c[cq>>2]=dA;if((a[b+4+dA|0]|0)!=33){break}if((a[dA+1+(b+4)|0]|0)==61){dy=2;dz=dA}else{break}}c[cq>>2]=dz+2;if((sk(b,aP,e)|0)==0){cA=1752;break L2237}if((dy|0)==2){c[bD>>2]=(c[bD>>2]|0)!=(c[aP>>2]|0);continue}else if((dy|0)==1){c[bD>>2]=(c[bD>>2]|0)==(c[aP>>2]|0);continue}else{continue}}c[b1>>2]=c[bD>>2]&c[b1>>2];dr=dA}if((cA|0)==3893){cA=0;c[cq>>2]=dr;dv=dr}c[ce>>2]=c[b1>>2]^c[ce>>2];dd=dv}c[d>>2]=c[ce>>2]|c[d>>2];b2=c[cq>>2]|0}if((cA|0)==1752){c[cq>>2]=dw;cA=1756}else if((cA|0)==1709){c[cq>>2]=de;cA=1713}else if((cA|0)==1686){c[cq>>2]=c3}else if((cA|0)==1729){c[cq>>2]=dk;cA=1758}else if((cA|0)==3891){c[cq>>2]=b2;c2=b2;cA=1674}if((cA|0)==1674){b2=c2;L2374:while(1){c2=b+4+b2|0;de=a[c2]|0;if((de<<24>>24|0)==13|(de<<24>>24|0)==32|(de<<24>>24|0)==9|(de<<24>>24|0)==10){b2=b2+1|0;continue}c[cq>>2]=b2;if((a[c2]|0)!=38){cA=1765;break}if((a[b2+1+(b+4)|0]|0)!=38){cA=1765;break}dC=b2+2|0;c[cq>>2]=dC;if((sk(b,ck,e)|0)==0){break}while(1){c2=c[cq>>2]|0;while(1){dD=b+4+c2|0;de=a[dD]|0;if(!((de<<24>>24|0)==13|(de<<24>>24|0)==32|(de<<24>>24|0)==9|(de<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;de=a[dD]|0;if(de<<24>>24==61){if((a[c2+1+(b+4)|0]|0)==61){dE=1;dF=c2}else{dG=c2;dH=61;cA=1772}}else{dG=c2;dH=de;cA=1772}if((cA|0)==1772){while(1){cA=0;if(!((dH<<24>>24|0)==13|(dH<<24>>24|0)==32|(dH<<24>>24|0)==9|(dH<<24>>24|0)==10)){break}de=dG+1|0;dG=de;dH=a[b+4+de|0]|0;cA=1772}c[cq>>2]=dG;if((a[b+4+dG|0]|0)!=33){dI=dG;break}if((a[dG+1+(b+4)|0]|0)==61){dE=2;dF=dG}else{dI=dG;break}}c[cq>>2]=dF+2;if((sk(b,aO,e)|0)==0){cA=1777;break L2374}if((dE|0)==1){c[ck>>2]=(c[ck>>2]|0)==(c[aO>>2]|0);continue}else if((dE|0)==2){c[ck>>2]=(c[ck>>2]|0)!=(c[aO>>2]|0);continue}else{continue}}while(1){c2=dI;while(1){dJ=b+4+c2|0;de=a[dJ]|0;if(!((de<<24>>24|0)==13|(de<<24>>24|0)==32|(de<<24>>24|0)==9|(de<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;de=a[dJ]|0;if(de<<24>>24==38){if((a[c2+1+(b+4)|0]|0)==38){cA=3886;break}else{dK=c2;dL=38}}else{dK=c2;dL=de}while(1){if(!((dL<<24>>24|0)==13|(dL<<24>>24|0)==32|(dL<<24>>24|0)==9|(dL<<24>>24|0)==10)){break}de=dK+1|0;dK=de;dL=a[b+4+de|0]|0}c[cq>>2]=dK;if((a[b+4+dK|0]|0)!=38){dM=dK;break}dN=dK+1|0;c[cq>>2]=dN;if((sk(b,bC,e)|0)==0){cA=1804;break L2374}while(1){c2=c[cq>>2]|0;while(1){dO=b+4+c2|0;de=a[dO]|0;if(!((de<<24>>24|0)==13|(de<<24>>24|0)==32|(de<<24>>24|0)==9|(de<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;de=a[dO]|0;if(de<<24>>24==61){if((a[c2+1+(b+4)|0]|0)==61){dP=1;dQ=c2}else{dR=c2;dS=61;cA=1795}}else{dR=c2;dS=de;cA=1795}if((cA|0)==1795){while(1){cA=0;if(!((dS<<24>>24|0)==13|(dS<<24>>24|0)==32|(dS<<24>>24|0)==9|(dS<<24>>24|0)==10)){break}de=dR+1|0;dR=de;dS=a[b+4+de|0]|0;cA=1795}c[cq>>2]=dR;if((a[b+4+dR|0]|0)!=33){break}if((a[dR+1+(b+4)|0]|0)==61){dP=2;dQ=dR}else{break}}c[cq>>2]=dQ+2;if((sk(b,aN,e)|0)==0){cA=1800;break L2374}if((dP|0)==1){c[bC>>2]=(c[bC>>2]|0)==(c[aN>>2]|0);continue}else if((dP|0)==2){c[bC>>2]=(c[bC>>2]|0)!=(c[aN>>2]|0);continue}else{continue}}c[ck>>2]=c[bC>>2]&c[ck>>2];dI=dR}if((cA|0)==3886){cA=0;c[cq>>2]=dI;dM=dI}while(1){c2=b+4+dM|0;de=a[c2]|0;if((de<<24>>24|0)==13|(de<<24>>24|0)==32|(de<<24>>24|0)==9|(de<<24>>24|0)==10){dM=dM+1|0;continue}c[cq>>2]=dM;if((a[c2]|0)!=94){dT=dM;break}dU=dM+1|0;c[cq>>2]=dU;if((sk(b,b0,e)|0)==0){cA=1849;break L2374}while(1){c2=c[cq>>2]|0;while(1){dV=b+4+c2|0;de=a[dV]|0;if(!((de<<24>>24|0)==13|(de<<24>>24|0)==32|(de<<24>>24|0)==9|(de<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;de=a[dV]|0;if(de<<24>>24==61){if((a[c2+1+(b+4)|0]|0)==61){dW=1;dX=c2}else{dY=c2;dZ=61;cA=1815}}else{dY=c2;dZ=de;cA=1815}if((cA|0)==1815){while(1){cA=0;if(!((dZ<<24>>24|0)==13|(dZ<<24>>24|0)==32|(dZ<<24>>24|0)==9|(dZ<<24>>24|0)==10)){break}de=dY+1|0;dY=de;dZ=a[b+4+de|0]|0;cA=1815}c[cq>>2]=dY;if((a[b+4+dY|0]|0)!=33){d_=dY;break}if((a[dY+1+(b+4)|0]|0)==61){dW=2;dX=dY}else{d_=dY;break}}c[cq>>2]=dX+2;if((sk(b,aM,e)|0)==0){cA=1820;break L2374}if((dW|0)==1){c[b0>>2]=(c[b0>>2]|0)==(c[aM>>2]|0);continue}else if((dW|0)==2){c[b0>>2]=(c[b0>>2]|0)!=(c[aM>>2]|0);continue}else{continue}}while(1){c2=d_;while(1){d$=b+4+c2|0;de=a[d$]|0;if(!((de<<24>>24|0)==13|(de<<24>>24|0)==32|(de<<24>>24|0)==9|(de<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;de=a[d$]|0;if(de<<24>>24==38){if((a[c2+1+(b+4)|0]|0)==38){cA=3887;break}else{d0=c2;d1=38}}else{d0=c2;d1=de}while(1){if(!((d1<<24>>24|0)==13|(d1<<24>>24|0)==32|(d1<<24>>24|0)==9|(d1<<24>>24|0)==10)){break}de=d0+1|0;d0=de;d1=a[b+4+de|0]|0}c[cq>>2]=d0;if((a[b+4+d0|0]|0)!=38){d2=d0;break}d3=d0+1|0;c[cq>>2]=d3;if((sk(b,bB,e)|0)==0){cA=1847;break L2374}while(1){c2=c[cq>>2]|0;while(1){d4=b+4+c2|0;de=a[d4]|0;if(!((de<<24>>24|0)==13|(de<<24>>24|0)==32|(de<<24>>24|0)==9|(de<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;de=a[d4]|0;if(de<<24>>24==61){if((a[c2+1+(b+4)|0]|0)==61){d5=1;d6=c2}else{d7=c2;d8=61;cA=1838}}else{d7=c2;d8=de;cA=1838}if((cA|0)==1838){while(1){cA=0;if(!((d8<<24>>24|0)==13|(d8<<24>>24|0)==32|(d8<<24>>24|0)==9|(d8<<24>>24|0)==10)){break}de=d7+1|0;d7=de;d8=a[b+4+de|0]|0;cA=1838}c[cq>>2]=d7;if((a[b+4+d7|0]|0)!=33){break}if((a[d7+1+(b+4)|0]|0)==61){d5=2;d6=d7}else{break}}c[cq>>2]=d6+2;if((sk(b,aL,e)|0)==0){cA=1843;break L2374}if((d5|0)==1){c[bB>>2]=(c[bB>>2]|0)==(c[aL>>2]|0);continue}else if((d5|0)==2){c[bB>>2]=(c[bB>>2]|0)!=(c[aL>>2]|0);continue}else{continue}}c[b0>>2]=c[bB>>2]&c[b0>>2];d_=d7}if((cA|0)==3887){cA=0;c[cq>>2]=d_;d2=d_}c[ck>>2]=c[b0>>2]^c[ck>>2];dM=d2}while(1){c2=dT;while(1){d9=b+4+c2|0;de=a[d9]|0;if(!((de<<24>>24|0)==13|(de<<24>>24|0)==32|(de<<24>>24|0)==9|(de<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;de=a[d9]|0;if(de<<24>>24==124){if((a[c2+1+(b+4)|0]|0)==124){cA=3888;break}else{ea=c2;eb=124}}else{ea=c2;eb=de}while(1){if(!((eb<<24>>24|0)==13|(eb<<24>>24|0)==32|(eb<<24>>24|0)==9|(eb<<24>>24|0)==10)){break}de=ea+1|0;ea=de;eb=a[b+4+de|0]|0}c[cq>>2]=ea;if((a[b+4+ea|0]|0)!=124){break}ec=ea+1|0;c[cq>>2]=ec;if((sk(b,cd,e)|0)==0){cA=1944;break L2374}while(1){c2=c[cq>>2]|0;while(1){ed=b+4+c2|0;de=a[ed]|0;if(!((de<<24>>24|0)==13|(de<<24>>24|0)==32|(de<<24>>24|0)==9|(de<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;de=a[ed]|0;if(de<<24>>24==61){if((a[c2+1+(b+4)|0]|0)==61){ee=1;ef=c2}else{eg=c2;eh=61;cA=1865}}else{eg=c2;eh=de;cA=1865}if((cA|0)==1865){while(1){cA=0;if(!((eh<<24>>24|0)==13|(eh<<24>>24|0)==32|(eh<<24>>24|0)==9|(eh<<24>>24|0)==10)){break}de=eg+1|0;eg=de;eh=a[b+4+de|0]|0;cA=1865}c[cq>>2]=eg;if((a[b+4+eg|0]|0)!=33){ei=eg;break}if((a[eg+1+(b+4)|0]|0)==61){ee=2;ef=eg}else{ei=eg;break}}c[cq>>2]=ef+2;if((sk(b,aK,e)|0)==0){cA=1870;break L2374}if((ee|0)==1){c[cd>>2]=(c[cd>>2]|0)==(c[aK>>2]|0);continue}else if((ee|0)==2){c[cd>>2]=(c[cd>>2]|0)!=(c[aK>>2]|0);continue}else{continue}}while(1){c2=ei;while(1){ej=b+4+c2|0;de=a[ej]|0;if(!((de<<24>>24|0)==13|(de<<24>>24|0)==32|(de<<24>>24|0)==9|(de<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;de=a[ej]|0;if(de<<24>>24==38){if((a[c2+1+(b+4)|0]|0)==38){cA=3889;break}else{ek=c2;el=38}}else{ek=c2;el=de}while(1){if(!((el<<24>>24|0)==13|(el<<24>>24|0)==32|(el<<24>>24|0)==9|(el<<24>>24|0)==10)){break}de=ek+1|0;ek=de;el=a[b+4+de|0]|0}c[cq>>2]=ek;if((a[b+4+ek|0]|0)!=38){em=ek;break}en=ek+1|0;c[cq>>2]=en;if((sk(b,bA,e)|0)==0){cA=1897;break L2374}while(1){c2=c[cq>>2]|0;while(1){eo=b+4+c2|0;de=a[eo]|0;if(!((de<<24>>24|0)==13|(de<<24>>24|0)==32|(de<<24>>24|0)==9|(de<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;de=a[eo]|0;if(de<<24>>24==61){if((a[c2+1+(b+4)|0]|0)==61){ep=1;eq=c2}else{er=c2;es=61;cA=1888}}else{er=c2;es=de;cA=1888}if((cA|0)==1888){while(1){cA=0;if(!((es<<24>>24|0)==13|(es<<24>>24|0)==32|(es<<24>>24|0)==9|(es<<24>>24|0)==10)){break}de=er+1|0;er=de;es=a[b+4+de|0]|0;cA=1888}c[cq>>2]=er;if((a[b+4+er|0]|0)!=33){break}if((a[er+1+(b+4)|0]|0)==61){ep=2;eq=er}else{break}}c[cq>>2]=eq+2;if((sk(b,aJ,e)|0)==0){cA=1893;break L2374}if((ep|0)==1){c[bA>>2]=(c[bA>>2]|0)==(c[aJ>>2]|0);continue}else if((ep|0)==2){c[bA>>2]=(c[bA>>2]|0)!=(c[aJ>>2]|0);continue}else{continue}}c[cd>>2]=c[bA>>2]&c[cd>>2];ei=er}if((cA|0)==3889){cA=0;c[cq>>2]=ei;em=ei}while(1){c2=b+4+em|0;de=a[c2]|0;if((de<<24>>24|0)==13|(de<<24>>24|0)==32|(de<<24>>24|0)==9|(de<<24>>24|0)==10){em=em+1|0;continue}c[cq>>2]=em;if((a[c2]|0)!=94){break}et=em+1|0;c[cq>>2]=et;if((sk(b,b$,e)|0)==0){cA=1942;break L2374}while(1){c2=c[cq>>2]|0;while(1){eu=b+4+c2|0;de=a[eu]|0;if(!((de<<24>>24|0)==13|(de<<24>>24|0)==32|(de<<24>>24|0)==9|(de<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;de=a[eu]|0;if(de<<24>>24==61){if((a[c2+1+(b+4)|0]|0)==61){ev=1;ew=c2}else{ex=c2;ey=61;cA=1908}}else{ex=c2;ey=de;cA=1908}if((cA|0)==1908){while(1){cA=0;if(!((ey<<24>>24|0)==13|(ey<<24>>24|0)==32|(ey<<24>>24|0)==9|(ey<<24>>24|0)==10)){break}de=ex+1|0;ex=de;ey=a[b+4+de|0]|0;cA=1908}c[cq>>2]=ex;if((a[b+4+ex|0]|0)!=33){ez=ex;break}if((a[ex+1+(b+4)|0]|0)==61){ev=2;ew=ex}else{ez=ex;break}}c[cq>>2]=ew+2;if((sk(b,aI,e)|0)==0){cA=1913;break L2374}if((ev|0)==1){c[b$>>2]=(c[b$>>2]|0)==(c[aI>>2]|0);continue}else if((ev|0)==2){c[b$>>2]=(c[b$>>2]|0)!=(c[aI>>2]|0);continue}else{continue}}while(1){c2=ez;while(1){eA=b+4+c2|0;de=a[eA]|0;if(!((de<<24>>24|0)==13|(de<<24>>24|0)==32|(de<<24>>24|0)==9|(de<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;de=a[eA]|0;if(de<<24>>24==38){if((a[c2+1+(b+4)|0]|0)==38){cA=3890;break}else{eB=c2;eC=38}}else{eB=c2;eC=de}while(1){if(!((eC<<24>>24|0)==13|(eC<<24>>24|0)==32|(eC<<24>>24|0)==9|(eC<<24>>24|0)==10)){break}de=eB+1|0;eB=de;eC=a[b+4+de|0]|0}c[cq>>2]=eB;if((a[b+4+eB|0]|0)!=38){eD=eB;break}eE=eB+1|0;c[cq>>2]=eE;if((sk(b,bz,e)|0)==0){cA=1940;break L2374}while(1){c2=c[cq>>2]|0;while(1){eF=b+4+c2|0;de=a[eF]|0;if(!((de<<24>>24|0)==13|(de<<24>>24|0)==32|(de<<24>>24|0)==9|(de<<24>>24|0)==10)){break}c2=c2+1|0}c[cq>>2]=c2;de=a[eF]|0;if(de<<24>>24==61){if((a[c2+1+(b+4)|0]|0)==61){eG=1;eH=c2}else{eI=c2;eJ=61;cA=1931}}else{eI=c2;eJ=de;cA=1931}if((cA|0)==1931){while(1){cA=0;if(!((eJ<<24>>24|0)==13|(eJ<<24>>24|0)==32|(eJ<<24>>24|0)==9|(eJ<<24>>24|0)==10)){break}de=eI+1|0;eI=de;eJ=a[b+4+de|0]|0;cA=1931}c[cq>>2]=eI;if((a[b+4+eI|0]|0)!=33){break}if((a[eI+1+(b+4)|0]|0)==61){eG=2;eH=eI}else{break}}c[cq>>2]=eH+2;if((sk(b,aH,e)|0)==0){cA=1936;break L2374}if((eG|0)==1){c[bz>>2]=(c[bz>>2]|0)==(c[aH>>2]|0);continue}else if((eG|0)==2){c[bz>>2]=(c[bz>>2]|0)!=(c[aH>>2]|0);continue}else{continue}}c[b$>>2]=c[bz>>2]&c[b$>>2];ez=eI}if((cA|0)==3890){cA=0;c[cq>>2]=ez;eD=ez}c[cd>>2]=c[b$>>2]^c[cd>>2];em=eD}c[ck>>2]=c[cd>>2]|c[ck>>2];dT=em}if((cA|0)==3888){cA=0;c[cq>>2]=dT}if((c[d>>2]|0)==0){eK=0}else{eK=(c[ck>>2]|0)!=0|0}c[d>>2]=eK;b2=c[cq>>2]|0}if((cA|0)==1870){c[cq>>2]=ec;cA=1944}else if((cA|0)==1765){eK=b2;L2634:while(1){b2=b+4+eK|0;ck=a[b2]|0;if((ck<<24>>24|0)==13|(ck<<24>>24|0)==32|(ck<<24>>24|0)==9|(ck<<24>>24|0)==10){eK=eK+1|0;continue}c[cq>>2]=eK;ck=a[b2]|0;if(ck<<24>>24!=124){eL=eK;eM=ck;cA=2324;break}if((a[eK+1+(b+4)|0]|0)!=124){eL=eK;eM=ck;cA=2324;break}eN=eK+2|0;c[cq>>2]=eN;if((sk(b,cn,e)|0)==0){break}while(1){ck=c[cq>>2]|0;while(1){eO=b+4+ck|0;b2=a[eO]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[eO]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){eP=1;eQ=ck}else{eR=ck;eS=61;cA=1959}}else{eR=ck;eS=b2;cA=1959}if((cA|0)==1959){while(1){cA=0;if(!((eS<<24>>24|0)==13|(eS<<24>>24|0)==32|(eS<<24>>24|0)==9|(eS<<24>>24|0)==10)){break}b2=eR+1|0;eR=b2;eS=a[b+4+b2|0]|0;cA=1959}c[cq>>2]=eR;if((a[b+4+eR|0]|0)!=33){eT=eR;break}if((a[eR+1+(b+4)|0]|0)==61){eP=2;eQ=eR}else{eT=eR;break}}c[cq>>2]=eQ+2;if((sk(b,aG,e)|0)==0){cA=1964;break L2634}if((eP|0)==1){c[cn>>2]=(c[cn>>2]|0)==(c[aG>>2]|0);continue}else if((eP|0)==2){c[cn>>2]=(c[cn>>2]|0)!=(c[aG>>2]|0);continue}else{continue}}while(1){ck=eT;while(1){eU=b+4+ck|0;b2=a[eU]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[eU]|0;if(b2<<24>>24==38){if((a[ck+1+(b+4)|0]|0)==38){cA=3874;break}else{eV=ck;eW=38}}else{eV=ck;eW=b2}while(1){if(!((eW<<24>>24|0)==13|(eW<<24>>24|0)==32|(eW<<24>>24|0)==9|(eW<<24>>24|0)==10)){break}b2=eV+1|0;eV=b2;eW=a[b+4+b2|0]|0}c[cq>>2]=eV;if((a[b+4+eV|0]|0)!=38){eX=eV;break}eY=eV+1|0;c[cq>>2]=eY;if((sk(b,by,e)|0)==0){cA=1991;break L2634}while(1){ck=c[cq>>2]|0;while(1){eZ=b+4+ck|0;b2=a[eZ]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[eZ]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){e_=1;e$=ck}else{e0=ck;e1=61;cA=1982}}else{e0=ck;e1=b2;cA=1982}if((cA|0)==1982){while(1){cA=0;if(!((e1<<24>>24|0)==13|(e1<<24>>24|0)==32|(e1<<24>>24|0)==9|(e1<<24>>24|0)==10)){break}b2=e0+1|0;e0=b2;e1=a[b+4+b2|0]|0;cA=1982}c[cq>>2]=e0;if((a[b+4+e0|0]|0)!=33){break}if((a[e0+1+(b+4)|0]|0)==61){e_=2;e$=e0}else{break}}c[cq>>2]=e$+2;if((sk(b,aF,e)|0)==0){cA=1987;break L2634}if((e_|0)==1){c[by>>2]=(c[by>>2]|0)==(c[aF>>2]|0);continue}else if((e_|0)==2){c[by>>2]=(c[by>>2]|0)!=(c[aF>>2]|0);continue}else{continue}}c[cn>>2]=c[by>>2]&c[cn>>2];eT=e0}if((cA|0)==3874){cA=0;c[cq>>2]=eT;eX=eT}while(1){ck=b+4+eX|0;b2=a[ck]|0;if((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10){eX=eX+1|0;continue}c[cq>>2]=eX;if((a[ck]|0)!=94){e2=eX;break}e3=eX+1|0;c[cq>>2]=e3;if((sk(b,b_,e)|0)==0){cA=2036;break L2634}while(1){ck=c[cq>>2]|0;while(1){e4=b+4+ck|0;b2=a[e4]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[e4]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){e5=1;e6=ck}else{e7=ck;e8=61;cA=2002}}else{e7=ck;e8=b2;cA=2002}if((cA|0)==2002){while(1){cA=0;if(!((e8<<24>>24|0)==13|(e8<<24>>24|0)==32|(e8<<24>>24|0)==9|(e8<<24>>24|0)==10)){break}b2=e7+1|0;e7=b2;e8=a[b+4+b2|0]|0;cA=2002}c[cq>>2]=e7;if((a[b+4+e7|0]|0)!=33){e9=e7;break}if((a[e7+1+(b+4)|0]|0)==61){e5=2;e6=e7}else{e9=e7;break}}c[cq>>2]=e6+2;if((sk(b,aE,e)|0)==0){cA=2007;break L2634}if((e5|0)==1){c[b_>>2]=(c[b_>>2]|0)==(c[aE>>2]|0);continue}else if((e5|0)==2){c[b_>>2]=(c[b_>>2]|0)!=(c[aE>>2]|0);continue}else{continue}}while(1){ck=e9;while(1){fa=b+4+ck|0;b2=a[fa]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[fa]|0;if(b2<<24>>24==38){if((a[ck+1+(b+4)|0]|0)==38){cA=3875;break}else{fb=ck;fc=38}}else{fb=ck;fc=b2}while(1){if(!((fc<<24>>24|0)==13|(fc<<24>>24|0)==32|(fc<<24>>24|0)==9|(fc<<24>>24|0)==10)){break}b2=fb+1|0;fb=b2;fc=a[b+4+b2|0]|0}c[cq>>2]=fb;if((a[b+4+fb|0]|0)!=38){fd=fb;break}fe=fb+1|0;c[cq>>2]=fe;if((sk(b,bx,e)|0)==0){cA=2034;break L2634}while(1){ck=c[cq>>2]|0;while(1){ff=b+4+ck|0;b2=a[ff]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[ff]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){fg=1;fh=ck}else{fi=ck;fj=61;cA=2025}}else{fi=ck;fj=b2;cA=2025}if((cA|0)==2025){while(1){cA=0;if(!((fj<<24>>24|0)==13|(fj<<24>>24|0)==32|(fj<<24>>24|0)==9|(fj<<24>>24|0)==10)){break}b2=fi+1|0;fi=b2;fj=a[b+4+b2|0]|0;cA=2025}c[cq>>2]=fi;if((a[b+4+fi|0]|0)!=33){break}if((a[fi+1+(b+4)|0]|0)==61){fg=2;fh=fi}else{break}}c[cq>>2]=fh+2;if((sk(b,aD,e)|0)==0){cA=2030;break L2634}if((fg|0)==1){c[bx>>2]=(c[bx>>2]|0)==(c[aD>>2]|0);continue}else if((fg|0)==2){c[bx>>2]=(c[bx>>2]|0)!=(c[aD>>2]|0);continue}else{continue}}c[b_>>2]=c[bx>>2]&c[b_>>2];e9=fi}if((cA|0)==3875){cA=0;c[cq>>2]=e9;fd=e9}c[cn>>2]=c[b_>>2]^c[cn>>2];eX=fd}while(1){ck=e2;while(1){fk=b+4+ck|0;b2=a[fk]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[fk]|0;if(b2<<24>>24==124){if((a[ck+1+(b+4)|0]|0)==124){cA=3876;break}else{fl=ck;fm=124}}else{fl=ck;fm=b2}while(1){if(!((fm<<24>>24|0)==13|(fm<<24>>24|0)==32|(fm<<24>>24|0)==9|(fm<<24>>24|0)==10)){break}b2=fl+1|0;fl=b2;fm=a[b+4+b2|0]|0}c[cq>>2]=fl;if((a[b+4+fl|0]|0)!=124){fn=fl;break}fo=fl+1|0;c[cq>>2]=fo;if((sk(b,cc,e)|0)==0){cA=2131;break L2634}while(1){ck=c[cq>>2]|0;while(1){fp=b+4+ck|0;b2=a[fp]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[fp]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){fq=1;fr=ck}else{fs=ck;ft=61;cA=2052}}else{fs=ck;ft=b2;cA=2052}if((cA|0)==2052){while(1){cA=0;if(!((ft<<24>>24|0)==13|(ft<<24>>24|0)==32|(ft<<24>>24|0)==9|(ft<<24>>24|0)==10)){break}b2=fs+1|0;fs=b2;ft=a[b+4+b2|0]|0;cA=2052}c[cq>>2]=fs;if((a[b+4+fs|0]|0)!=33){fu=fs;break}if((a[fs+1+(b+4)|0]|0)==61){fq=2;fr=fs}else{fu=fs;break}}c[cq>>2]=fr+2;if((sk(b,aC,e)|0)==0){cA=2057;break L2634}if((fq|0)==1){c[cc>>2]=(c[cc>>2]|0)==(c[aC>>2]|0);continue}else if((fq|0)==2){c[cc>>2]=(c[cc>>2]|0)!=(c[aC>>2]|0);continue}else{continue}}while(1){ck=fu;while(1){fv=b+4+ck|0;b2=a[fv]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[fv]|0;if(b2<<24>>24==38){if((a[ck+1+(b+4)|0]|0)==38){cA=3877;break}else{fw=ck;fx=38}}else{fw=ck;fx=b2}while(1){if(!((fx<<24>>24|0)==13|(fx<<24>>24|0)==32|(fx<<24>>24|0)==9|(fx<<24>>24|0)==10)){break}b2=fw+1|0;fw=b2;fx=a[b+4+b2|0]|0}c[cq>>2]=fw;if((a[b+4+fw|0]|0)!=38){fy=fw;break}fz=fw+1|0;c[cq>>2]=fz;if((sk(b,bw,e)|0)==0){cA=2084;break L2634}while(1){ck=c[cq>>2]|0;while(1){fA=b+4+ck|0;b2=a[fA]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[fA]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){fB=1;fC=ck}else{fD=ck;fE=61;cA=2075}}else{fD=ck;fE=b2;cA=2075}if((cA|0)==2075){while(1){cA=0;if(!((fE<<24>>24|0)==13|(fE<<24>>24|0)==32|(fE<<24>>24|0)==9|(fE<<24>>24|0)==10)){break}b2=fD+1|0;fD=b2;fE=a[b+4+b2|0]|0;cA=2075}c[cq>>2]=fD;if((a[b+4+fD|0]|0)!=33){break}if((a[fD+1+(b+4)|0]|0)==61){fB=2;fC=fD}else{break}}c[cq>>2]=fC+2;if((sk(b,aB,e)|0)==0){cA=2080;break L2634}if((fB|0)==1){c[bw>>2]=(c[bw>>2]|0)==(c[aB>>2]|0);continue}else if((fB|0)==2){c[bw>>2]=(c[bw>>2]|0)!=(c[aB>>2]|0);continue}else{continue}}c[cc>>2]=c[bw>>2]&c[cc>>2];fu=fD}if((cA|0)==3877){cA=0;c[cq>>2]=fu;fy=fu}while(1){ck=b+4+fy|0;b2=a[ck]|0;if((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10){fy=fy+1|0;continue}c[cq>>2]=fy;if((a[ck]|0)!=94){break}fF=fy+1|0;c[cq>>2]=fF;if((sk(b,bZ,e)|0)==0){cA=2129;break L2634}while(1){ck=c[cq>>2]|0;while(1){fG=b+4+ck|0;b2=a[fG]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[fG]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){fH=1;fI=ck}else{fJ=ck;fK=61;cA=2095}}else{fJ=ck;fK=b2;cA=2095}if((cA|0)==2095){while(1){cA=0;if(!((fK<<24>>24|0)==13|(fK<<24>>24|0)==32|(fK<<24>>24|0)==9|(fK<<24>>24|0)==10)){break}b2=fJ+1|0;fJ=b2;fK=a[b+4+b2|0]|0;cA=2095}c[cq>>2]=fJ;if((a[b+4+fJ|0]|0)!=33){fL=fJ;break}if((a[fJ+1+(b+4)|0]|0)==61){fH=2;fI=fJ}else{fL=fJ;break}}c[cq>>2]=fI+2;if((sk(b,aA,e)|0)==0){cA=2100;break L2634}if((fH|0)==1){c[bZ>>2]=(c[bZ>>2]|0)==(c[aA>>2]|0);continue}else if((fH|0)==2){c[bZ>>2]=(c[bZ>>2]|0)!=(c[aA>>2]|0);continue}else{continue}}while(1){ck=fL;while(1){fM=b+4+ck|0;b2=a[fM]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[fM]|0;if(b2<<24>>24==38){if((a[ck+1+(b+4)|0]|0)==38){cA=3878;break}else{fN=ck;fO=38}}else{fN=ck;fO=b2}while(1){if(!((fO<<24>>24|0)==13|(fO<<24>>24|0)==32|(fO<<24>>24|0)==9|(fO<<24>>24|0)==10)){break}b2=fN+1|0;fN=b2;fO=a[b+4+b2|0]|0}c[cq>>2]=fN;if((a[b+4+fN|0]|0)!=38){fP=fN;break}fQ=fN+1|0;c[cq>>2]=fQ;if((sk(b,bv,e)|0)==0){cA=2127;break L2634}while(1){ck=c[cq>>2]|0;while(1){fR=b+4+ck|0;b2=a[fR]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[fR]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){fS=1;fT=ck}else{fU=ck;fV=61;cA=2118}}else{fU=ck;fV=b2;cA=2118}if((cA|0)==2118){while(1){cA=0;if(!((fV<<24>>24|0)==13|(fV<<24>>24|0)==32|(fV<<24>>24|0)==9|(fV<<24>>24|0)==10)){break}b2=fU+1|0;fU=b2;fV=a[b+4+b2|0]|0;cA=2118}c[cq>>2]=fU;if((a[b+4+fU|0]|0)!=33){break}if((a[fU+1+(b+4)|0]|0)==61){fS=2;fT=fU}else{break}}c[cq>>2]=fT+2;if((sk(b,az,e)|0)==0){cA=2123;break L2634}if((fS|0)==1){c[bv>>2]=(c[bv>>2]|0)==(c[az>>2]|0);continue}else if((fS|0)==2){c[bv>>2]=(c[bv>>2]|0)!=(c[az>>2]|0);continue}else{continue}}c[bZ>>2]=c[bv>>2]&c[bZ>>2];fL=fU}if((cA|0)==3878){cA=0;c[cq>>2]=fL;fP=fL}c[cc>>2]=c[bZ>>2]^c[cc>>2];fy=fP}c[cn>>2]=c[cc>>2]|c[cn>>2];e2=fy}if((cA|0)==3876){cA=0;c[cq>>2]=e2;fn=e2}while(1){ck=b+4+fn|0;b2=a[ck]|0;if((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10){fn=fn+1|0;continue}c[cq>>2]=fn;if((a[ck]|0)!=38){break}if((a[fn+1+(b+4)|0]|0)!=38){break}fW=fn+2|0;c[cq>>2]=fW;if((sk(b,cj,e)|0)==0){cA=2316;break L2634}while(1){ck=c[cq>>2]|0;while(1){fX=b+4+ck|0;b2=a[fX]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[fX]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){fY=1;fZ=ck}else{f_=ck;f$=61;cA=2142}}else{f_=ck;f$=b2;cA=2142}if((cA|0)==2142){while(1){cA=0;if(!((f$<<24>>24|0)==13|(f$<<24>>24|0)==32|(f$<<24>>24|0)==9|(f$<<24>>24|0)==10)){break}b2=f_+1|0;f_=b2;f$=a[b+4+b2|0]|0;cA=2142}c[cq>>2]=f_;if((a[b+4+f_|0]|0)!=33){f0=f_;break}if((a[f_+1+(b+4)|0]|0)==61){fY=2;fZ=f_}else{f0=f_;break}}c[cq>>2]=fZ+2;if((sk(b,ay,e)|0)==0){cA=2147;break L2634}if((fY|0)==1){c[cj>>2]=(c[cj>>2]|0)==(c[ay>>2]|0);continue}else if((fY|0)==2){c[cj>>2]=(c[cj>>2]|0)!=(c[ay>>2]|0);continue}else{continue}}while(1){ck=f0;while(1){f1=b+4+ck|0;b2=a[f1]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[f1]|0;if(b2<<24>>24==38){if((a[ck+1+(b+4)|0]|0)==38){cA=3880;break}else{f2=ck;f3=38}}else{f2=ck;f3=b2}while(1){if(!((f3<<24>>24|0)==13|(f3<<24>>24|0)==32|(f3<<24>>24|0)==9|(f3<<24>>24|0)==10)){break}b2=f2+1|0;f2=b2;f3=a[b+4+b2|0]|0}c[cq>>2]=f2;if((a[b+4+f2|0]|0)!=38){f4=f2;break}f5=f2+1|0;c[cq>>2]=f5;if((sk(b,bu,e)|0)==0){cA=2174;break L2634}while(1){ck=c[cq>>2]|0;while(1){f6=b+4+ck|0;b2=a[f6]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[f6]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){f7=1;f8=ck}else{f9=ck;ga=61;cA=2165}}else{f9=ck;ga=b2;cA=2165}if((cA|0)==2165){while(1){cA=0;if(!((ga<<24>>24|0)==13|(ga<<24>>24|0)==32|(ga<<24>>24|0)==9|(ga<<24>>24|0)==10)){break}b2=f9+1|0;f9=b2;ga=a[b+4+b2|0]|0;cA=2165}c[cq>>2]=f9;if((a[b+4+f9|0]|0)!=33){break}if((a[f9+1+(b+4)|0]|0)==61){f7=2;f8=f9}else{break}}c[cq>>2]=f8+2;if((sk(b,ax,e)|0)==0){cA=2170;break L2634}if((f7|0)==1){c[bu>>2]=(c[bu>>2]|0)==(c[ax>>2]|0);continue}else if((f7|0)==2){c[bu>>2]=(c[bu>>2]|0)!=(c[ax>>2]|0);continue}else{continue}}c[cj>>2]=c[bu>>2]&c[cj>>2];f0=f9}if((cA|0)==3880){cA=0;c[cq>>2]=f0;f4=f0}while(1){ck=b+4+f4|0;b2=a[ck]|0;if((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10){f4=f4+1|0;continue}c[cq>>2]=f4;if((a[ck]|0)!=94){gb=f4;break}gc=f4+1|0;c[cq>>2]=gc;if((sk(b,bY,e)|0)==0){cA=2219;break L2634}while(1){ck=c[cq>>2]|0;while(1){gd=b+4+ck|0;b2=a[gd]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[gd]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){ge=1;gf=ck}else{gg=ck;gh=61;cA=2185}}else{gg=ck;gh=b2;cA=2185}if((cA|0)==2185){while(1){cA=0;if(!((gh<<24>>24|0)==13|(gh<<24>>24|0)==32|(gh<<24>>24|0)==9|(gh<<24>>24|0)==10)){break}b2=gg+1|0;gg=b2;gh=a[b+4+b2|0]|0;cA=2185}c[cq>>2]=gg;if((a[b+4+gg|0]|0)!=33){gi=gg;break}if((a[gg+1+(b+4)|0]|0)==61){ge=2;gf=gg}else{gi=gg;break}}c[cq>>2]=gf+2;if((sk(b,aw,e)|0)==0){cA=2190;break L2634}if((ge|0)==1){c[bY>>2]=(c[bY>>2]|0)==(c[aw>>2]|0);continue}else if((ge|0)==2){c[bY>>2]=(c[bY>>2]|0)!=(c[aw>>2]|0);continue}else{continue}}while(1){ck=gi;while(1){gj=b+4+ck|0;b2=a[gj]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[gj]|0;if(b2<<24>>24==38){if((a[ck+1+(b+4)|0]|0)==38){cA=3881;break}else{gk=ck;gl=38}}else{gk=ck;gl=b2}while(1){if(!((gl<<24>>24|0)==13|(gl<<24>>24|0)==32|(gl<<24>>24|0)==9|(gl<<24>>24|0)==10)){break}b2=gk+1|0;gk=b2;gl=a[b+4+b2|0]|0}c[cq>>2]=gk;if((a[b+4+gk|0]|0)!=38){gm=gk;break}gn=gk+1|0;c[cq>>2]=gn;if((sk(b,bt,e)|0)==0){cA=2217;break L2634}while(1){ck=c[cq>>2]|0;while(1){go=b+4+ck|0;b2=a[go]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[go]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){gp=1;gq=ck}else{gr=ck;gs=61;cA=2208}}else{gr=ck;gs=b2;cA=2208}if((cA|0)==2208){while(1){cA=0;if(!((gs<<24>>24|0)==13|(gs<<24>>24|0)==32|(gs<<24>>24|0)==9|(gs<<24>>24|0)==10)){break}b2=gr+1|0;gr=b2;gs=a[b+4+b2|0]|0;cA=2208}c[cq>>2]=gr;if((a[b+4+gr|0]|0)!=33){break}if((a[gr+1+(b+4)|0]|0)==61){gp=2;gq=gr}else{break}}c[cq>>2]=gq+2;if((sk(b,av,e)|0)==0){cA=2213;break L2634}if((gp|0)==1){c[bt>>2]=(c[bt>>2]|0)==(c[av>>2]|0);continue}else if((gp|0)==2){c[bt>>2]=(c[bt>>2]|0)!=(c[av>>2]|0);continue}else{continue}}c[bY>>2]=c[bt>>2]&c[bY>>2];gi=gr}if((cA|0)==3881){cA=0;c[cq>>2]=gi;gm=gi}c[cj>>2]=c[bY>>2]^c[cj>>2];f4=gm}while(1){ck=gb;while(1){gt=b+4+ck|0;b2=a[gt]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[gt]|0;if(b2<<24>>24==124){if((a[ck+1+(b+4)|0]|0)==124){cA=3882;break}else{gu=ck;gv=124}}else{gu=ck;gv=b2}while(1){if(!((gv<<24>>24|0)==13|(gv<<24>>24|0)==32|(gv<<24>>24|0)==9|(gv<<24>>24|0)==10)){break}b2=gu+1|0;gu=b2;gv=a[b+4+b2|0]|0}c[cq>>2]=gu;if((a[b+4+gu|0]|0)!=124){gw=gu;break}gx=gu+1|0;c[cq>>2]=gx;if((sk(b,cb,e)|0)==0){cA=2314;break L2634}while(1){ck=c[cq>>2]|0;while(1){gy=b+4+ck|0;b2=a[gy]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[gy]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){gz=1;gA=ck}else{gB=ck;gC=61;cA=2235}}else{gB=ck;gC=b2;cA=2235}if((cA|0)==2235){while(1){cA=0;if(!((gC<<24>>24|0)==13|(gC<<24>>24|0)==32|(gC<<24>>24|0)==9|(gC<<24>>24|0)==10)){break}b2=gB+1|0;gB=b2;gC=a[b+4+b2|0]|0;cA=2235}c[cq>>2]=gB;if((a[b+4+gB|0]|0)!=33){gD=gB;break}if((a[gB+1+(b+4)|0]|0)==61){gz=2;gA=gB}else{gD=gB;break}}c[cq>>2]=gA+2;if((sk(b,au,e)|0)==0){cA=2240;break L2634}if((gz|0)==1){c[cb>>2]=(c[cb>>2]|0)==(c[au>>2]|0);continue}else if((gz|0)==2){c[cb>>2]=(c[cb>>2]|0)!=(c[au>>2]|0);continue}else{continue}}while(1){ck=gD;while(1){gE=b+4+ck|0;b2=a[gE]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[gE]|0;if(b2<<24>>24==38){if((a[ck+1+(b+4)|0]|0)==38){cA=3883;break}else{gF=ck;gG=38}}else{gF=ck;gG=b2}while(1){if(!((gG<<24>>24|0)==13|(gG<<24>>24|0)==32|(gG<<24>>24|0)==9|(gG<<24>>24|0)==10)){break}b2=gF+1|0;gF=b2;gG=a[b+4+b2|0]|0}c[cq>>2]=gF;if((a[b+4+gF|0]|0)!=38){gH=gF;break}gI=gF+1|0;c[cq>>2]=gI;if((sk(b,bs,e)|0)==0){cA=2267;break L2634}while(1){ck=c[cq>>2]|0;while(1){gJ=b+4+ck|0;b2=a[gJ]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[gJ]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){gK=1;gL=ck}else{gM=ck;gN=61;cA=2258}}else{gM=ck;gN=b2;cA=2258}if((cA|0)==2258){while(1){cA=0;if(!((gN<<24>>24|0)==13|(gN<<24>>24|0)==32|(gN<<24>>24|0)==9|(gN<<24>>24|0)==10)){break}b2=gM+1|0;gM=b2;gN=a[b+4+b2|0]|0;cA=2258}c[cq>>2]=gM;if((a[b+4+gM|0]|0)!=33){break}if((a[gM+1+(b+4)|0]|0)==61){gK=2;gL=gM}else{break}}c[cq>>2]=gL+2;if((sk(b,at,e)|0)==0){cA=2263;break L2634}if((gK|0)==1){c[bs>>2]=(c[bs>>2]|0)==(c[at>>2]|0);continue}else if((gK|0)==2){c[bs>>2]=(c[bs>>2]|0)!=(c[at>>2]|0);continue}else{continue}}c[cb>>2]=c[bs>>2]&c[cb>>2];gD=gM}if((cA|0)==3883){cA=0;c[cq>>2]=gD;gH=gD}while(1){ck=b+4+gH|0;b2=a[ck]|0;if((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10){gH=gH+1|0;continue}c[cq>>2]=gH;if((a[ck]|0)!=94){break}gO=gH+1|0;c[cq>>2]=gO;if((sk(b,bX,e)|0)==0){cA=2312;break L2634}while(1){ck=c[cq>>2]|0;while(1){gP=b+4+ck|0;b2=a[gP]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[gP]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){gQ=1;gR=ck}else{gS=ck;gT=61;cA=2278}}else{gS=ck;gT=b2;cA=2278}if((cA|0)==2278){while(1){cA=0;if(!((gT<<24>>24|0)==13|(gT<<24>>24|0)==32|(gT<<24>>24|0)==9|(gT<<24>>24|0)==10)){break}b2=gS+1|0;gS=b2;gT=a[b+4+b2|0]|0;cA=2278}c[cq>>2]=gS;if((a[b+4+gS|0]|0)!=33){gU=gS;break}if((a[gS+1+(b+4)|0]|0)==61){gQ=2;gR=gS}else{gU=gS;break}}c[cq>>2]=gR+2;if((sk(b,as,e)|0)==0){cA=2283;break L2634}if((gQ|0)==1){c[bX>>2]=(c[bX>>2]|0)==(c[as>>2]|0);continue}else if((gQ|0)==2){c[bX>>2]=(c[bX>>2]|0)!=(c[as>>2]|0);continue}else{continue}}while(1){ck=gU;while(1){gV=b+4+ck|0;b2=a[gV]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[gV]|0;if(b2<<24>>24==38){if((a[ck+1+(b+4)|0]|0)==38){cA=3884;break}else{gW=ck;gX=38}}else{gW=ck;gX=b2}while(1){if(!((gX<<24>>24|0)==13|(gX<<24>>24|0)==32|(gX<<24>>24|0)==9|(gX<<24>>24|0)==10)){break}b2=gW+1|0;gW=b2;gX=a[b+4+b2|0]|0}c[cq>>2]=gW;if((a[b+4+gW|0]|0)!=38){gY=gW;break}gZ=gW+1|0;c[cq>>2]=gZ;if((sk(b,br,e)|0)==0){cA=2310;break L2634}while(1){ck=c[cq>>2]|0;while(1){g_=b+4+ck|0;b2=a[g_]|0;if(!((b2<<24>>24|0)==13|(b2<<24>>24|0)==32|(b2<<24>>24|0)==9|(b2<<24>>24|0)==10)){break}ck=ck+1|0}c[cq>>2]=ck;b2=a[g_]|0;if(b2<<24>>24==61){if((a[ck+1+(b+4)|0]|0)==61){g$=1;g0=ck}else{g1=ck;g2=61;cA=2301}}else{g1=ck;g2=b2;cA=2301}if((cA|0)==2301){while(1){cA=0;if(!((g2<<24>>24|0)==13|(g2<<24>>24|0)==32|(g2<<24>>24|0)==9|(g2<<24>>24|0)==10)){break}b2=g1+1|0;g1=b2;g2=a[b+4+b2|0]|0;cA=2301}c[cq>>2]=g1;if((a[b+4+g1|0]|0)!=33){break}if((a[g1+1+(b+4)|0]|0)==61){g$=2;g0=g1}else{break}}c[cq>>2]=g0+2;if((sk(b,ar,e)|0)==0){cA=2306;break L2634}if((g$|0)==1){c[br>>2]=(c[br>>2]|0)==(c[ar>>2]|0);continue}else if((g$|0)==2){c[br>>2]=(c[br>>2]|0)!=(c[ar>>2]|0);continue}else{continue}}c[bX>>2]=c[br>>2]&c[bX>>2];gU=g1}if((cA|0)==3884){cA=0;c[cq>>2]=gU;gY=gU}c[cb>>2]=c[bX>>2]^c[cb>>2];gH=gY}c[cj>>2]=c[cb>>2]|c[cj>>2];gb=gH}if((cA|0)==3882){cA=0;c[cq>>2]=gb;gw=gb}if((c[cn>>2]|0)==0){g3=0}else{g3=(c[cj>>2]|0)!=0|0}c[cn>>2]=g3;fn=gw}if((c[d>>2]|0)==0){g4=(c[cn>>2]|0)!=0|0}else{g4=1}c[d>>2]=g4;eK=c[cq>>2]|0}if((cA|0)==1964){c[cq>>2]=eN}else if((cA|0)==1987){c[cq>>2]=eY;cA=1991}else if((cA|0)==2007){c[cq>>2]=e3;cA=2036}else if((cA|0)==2030){c[cq>>2]=fe;cA=2034}else if((cA|0)==2057){c[cq>>2]=fo;cA=2131}else if((cA|0)==2080){c[cq>>2]=fz;cA=2084}else if((cA|0)==2100){c[cq>>2]=fF;cA=2129}else if((cA|0)==2123){c[cq>>2]=fQ;cA=2127}else if((cA|0)==2147){c[cq>>2]=fW;cA=2316}else if((cA|0)==2170){c[cq>>2]=f5;cA=2174}else if((cA|0)==2190){c[cq>>2]=gc;cA=2219}else if((cA|0)==2213){c[cq>>2]=gn;cA=2217}else if((cA|0)==2240){c[cq>>2]=gx;cA=2314}else if((cA|0)==2263){c[cq>>2]=gI;cA=2267}else if((cA|0)==2283){c[cq>>2]=gO;cA=2312}else if((cA|0)==2306){c[cq>>2]=gZ;cA=2310}else if((cA|0)==2324){while(1){cA=0;if(!((eM<<24>>24|0)==13|(eM<<24>>24|0)==32|(eM<<24>>24|0)==9|(eM<<24>>24|0)==10)){break}gZ=eL+1|0;eL=gZ;eM=a[b+4+gZ|0]|0;cA=2324}c[cq>>2]=eL;if((a[b+4+eL|0]|0)!=63){cs=1;i=f;return cs|0}eM=eL+1|0;c[cq>>2]=eM;do{if((sk(b,co,e)|0)!=0){while(1){eL=c[cq>>2]|0;while(1){g5=b+4+eL|0;gZ=a[g5]|0;if(!((gZ<<24>>24|0)==13|(gZ<<24>>24|0)==32|(gZ<<24>>24|0)==9|(gZ<<24>>24|0)==10)){break}eL=eL+1|0}c[cq>>2]=eL;gZ=a[g5]|0;if(gZ<<24>>24==61){if((a[eL+1+(b+4)|0]|0)==61){g6=1;g7=eL}else{g8=eL;g9=61;cA=2333}}else{g8=eL;g9=gZ;cA=2333}if((cA|0)==2333){while(1){cA=0;if(!((g9<<24>>24|0)==13|(g9<<24>>24|0)==32|(g9<<24>>24|0)==9|(g9<<24>>24|0)==10)){break}gZ=g8+1|0;g8=gZ;g9=a[b+4+gZ|0]|0;cA=2333}c[cq>>2]=g8;if((a[b+4+g8|0]|0)!=33){break}if((a[g8+1+(b+4)|0]|0)==61){g6=2;g7=g8}else{break}}c[cq>>2]=g7+2;if((sk(b,aq,e)|0)==0){cA=2339;break}if((g6|0)==1){c[co>>2]=(c[co>>2]|0)==(c[aq>>2]|0);continue}else if((g6|0)==2){c[co>>2]=(c[co>>2]|0)!=(c[aq>>2]|0);continue}else{continue}}if((cA|0)==2339){c[cq>>2]=eM;break}eL=g8;L3195:while(1){gZ=eL;while(1){ha=b+4+gZ|0;gI=a[ha]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gZ=gZ+1|0}c[cq>>2]=gZ;gI=a[ha]|0;if(gI<<24>>24==38){if((a[gZ+1+(b+4)|0]|0)==38){cA=3872;break}else{hb=gZ;hc=38}}else{hb=gZ;hc=gI}while(1){if(!((hc<<24>>24|0)==13|(hc<<24>>24|0)==32|(hc<<24>>24|0)==9|(hc<<24>>24|0)==10)){break}gI=hb+1|0;hb=gI;hc=a[b+4+gI|0]|0}c[cq>>2]=hb;if((a[b+4+hb|0]|0)!=38){hd=hb;break}he=hb+1|0;c[cq>>2]=he;if((sk(b,bq,e)|0)==0){cA=2367;break}while(1){gZ=c[cq>>2]|0;while(1){hf=b+4+gZ|0;gI=a[hf]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gZ=gZ+1|0}c[cq>>2]=gZ;gI=a[hf]|0;if(gI<<24>>24==61){if((a[gZ+1+(b+4)|0]|0)==61){hg=1;hh=gZ}else{hi=gZ;hj=61;cA=2358}}else{hi=gZ;hj=gI;cA=2358}if((cA|0)==2358){while(1){cA=0;if(!((hj<<24>>24|0)==13|(hj<<24>>24|0)==32|(hj<<24>>24|0)==9|(hj<<24>>24|0)==10)){break}gI=hi+1|0;hi=gI;hj=a[b+4+gI|0]|0;cA=2358}c[cq>>2]=hi;if((a[b+4+hi|0]|0)!=33){break}if((a[hi+1+(b+4)|0]|0)==61){hg=2;hh=hi}else{break}}c[cq>>2]=hh+2;if((sk(b,ap,e)|0)==0){cA=2363;break L3195}if((hg|0)==1){c[bq>>2]=(c[bq>>2]|0)==(c[ap>>2]|0);continue}else if((hg|0)==2){c[bq>>2]=(c[bq>>2]|0)!=(c[ap>>2]|0);continue}else{continue}}c[co>>2]=c[bq>>2]&c[co>>2];eL=hi}if((cA|0)==2363){c[cq>>2]=he;cA=2367}else if((cA|0)==3872){c[cq>>2]=eL;hd=eL}if((cA|0)==2367){c[cq>>2]=eM;break}gZ=hd;L3234:while(1){gI=b+4+gZ|0;gn=a[gI]|0;if((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10){gZ=gZ+1|0;continue}c[cq>>2]=gZ;if((a[gI]|0)!=94){cA=2372;break}hk=gZ+1|0;c[cq>>2]=hk;if((sk(b,bW,e)|0)==0){break}while(1){gI=c[cq>>2]|0;while(1){hl=b+4+gI|0;gn=a[hl]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[hl]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){hm=1;hn=gI}else{ho=gI;hp=61;cA=2379}}else{ho=gI;hp=gn;cA=2379}if((cA|0)==2379){while(1){cA=0;if(!((hp<<24>>24|0)==13|(hp<<24>>24|0)==32|(hp<<24>>24|0)==9|(hp<<24>>24|0)==10)){break}gn=ho+1|0;ho=gn;hp=a[b+4+gn|0]|0;cA=2379}c[cq>>2]=ho;if((a[b+4+ho|0]|0)!=33){hq=ho;break}if((a[ho+1+(b+4)|0]|0)==61){hm=2;hn=ho}else{hq=ho;break}}c[cq>>2]=hn+2;if((sk(b,ao,e)|0)==0){cA=2384;break L3234}if((hm|0)==1){c[bW>>2]=(c[bW>>2]|0)==(c[ao>>2]|0);continue}else if((hm|0)==2){c[bW>>2]=(c[bW>>2]|0)!=(c[ao>>2]|0);continue}else{continue}}while(1){gI=hq;while(1){hr=b+4+gI|0;gn=a[hr]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[hr]|0;if(gn<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=3871;break}else{hs=gI;ht=38}}else{hs=gI;ht=gn}while(1){if(!((ht<<24>>24|0)==13|(ht<<24>>24|0)==32|(ht<<24>>24|0)==9|(ht<<24>>24|0)==10)){break}gn=hs+1|0;hs=gn;ht=a[b+4+gn|0]|0}c[cq>>2]=hs;if((a[b+4+hs|0]|0)!=38){hu=hs;break}hv=hs+1|0;c[cq>>2]=hv;if((sk(b,bp,e)|0)==0){cA=2411;break L3234}while(1){gI=c[cq>>2]|0;while(1){hw=b+4+gI|0;gn=a[hw]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[hw]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){hx=1;hy=gI}else{hz=gI;hA=61;cA=2402}}else{hz=gI;hA=gn;cA=2402}if((cA|0)==2402){while(1){cA=0;if(!((hA<<24>>24|0)==13|(hA<<24>>24|0)==32|(hA<<24>>24|0)==9|(hA<<24>>24|0)==10)){break}gn=hz+1|0;hz=gn;hA=a[b+4+gn|0]|0;cA=2402}c[cq>>2]=hz;if((a[b+4+hz|0]|0)!=33){break}if((a[hz+1+(b+4)|0]|0)==61){hx=2;hy=hz}else{break}}c[cq>>2]=hy+2;if((sk(b,an,e)|0)==0){cA=2407;break L3234}if((hx|0)==1){c[bp>>2]=(c[bp>>2]|0)==(c[an>>2]|0);continue}else if((hx|0)==2){c[bp>>2]=(c[bp>>2]|0)!=(c[an>>2]|0);continue}else{continue}}c[bW>>2]=c[bp>>2]&c[bW>>2];hq=hz}if((cA|0)==3871){cA=0;c[cq>>2]=hq;hu=hq}c[co>>2]=c[bW>>2]^c[co>>2];gZ=hu}if((cA|0)==2372){eL=gZ;L3297:while(1){gI=eL;while(1){hB=b+4+gI|0;gn=a[hB]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[hB]|0;if(gn<<24>>24==124){if((a[gI+1+(b+4)|0]|0)==124){cA=3868;break}else{hC=gI;hD=124}}else{hC=gI;hD=gn}while(1){if(!((hD<<24>>24|0)==13|(hD<<24>>24|0)==32|(hD<<24>>24|0)==9|(hD<<24>>24|0)==10)){break}gn=hC+1|0;hC=gn;hD=a[b+4+gn|0]|0}c[cq>>2]=hC;if((a[b+4+hC|0]|0)!=124){hE=hC;cA=2423;break}hF=hC+1|0;c[cq>>2]=hF;if((sk(b,ca,e)|0)==0){break}while(1){gI=c[cq>>2]|0;while(1){hG=b+4+gI|0;gn=a[hG]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[hG]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){hH=1;hI=gI}else{hJ=gI;hK=61;cA=2430}}else{hJ=gI;hK=gn;cA=2430}if((cA|0)==2430){while(1){cA=0;if(!((hK<<24>>24|0)==13|(hK<<24>>24|0)==32|(hK<<24>>24|0)==9|(hK<<24>>24|0)==10)){break}gn=hJ+1|0;hJ=gn;hK=a[b+4+gn|0]|0;cA=2430}c[cq>>2]=hJ;if((a[b+4+hJ|0]|0)!=33){hL=hJ;break}if((a[hJ+1+(b+4)|0]|0)==61){hH=2;hI=hJ}else{hL=hJ;break}}c[cq>>2]=hI+2;if((sk(b,am,e)|0)==0){cA=2435;break L3297}if((hH|0)==1){c[ca>>2]=(c[ca>>2]|0)==(c[am>>2]|0);continue}else if((hH|0)==2){c[ca>>2]=(c[ca>>2]|0)!=(c[am>>2]|0);continue}else{continue}}while(1){gI=hL;while(1){hM=b+4+gI|0;gn=a[hM]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[hM]|0;if(gn<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=3869;break}else{hN=gI;hO=38}}else{hN=gI;hO=gn}while(1){if(!((hO<<24>>24|0)==13|(hO<<24>>24|0)==32|(hO<<24>>24|0)==9|(hO<<24>>24|0)==10)){break}gn=hN+1|0;hN=gn;hO=a[b+4+gn|0]|0}c[cq>>2]=hN;if((a[b+4+hN|0]|0)!=38){hP=hN;break}hQ=hN+1|0;c[cq>>2]=hQ;if((sk(b,bo,e)|0)==0){cA=2462;break L3297}while(1){gI=c[cq>>2]|0;while(1){hR=b+4+gI|0;gn=a[hR]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[hR]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){hS=1;hT=gI}else{hU=gI;hV=61;cA=2453}}else{hU=gI;hV=gn;cA=2453}if((cA|0)==2453){while(1){cA=0;if(!((hV<<24>>24|0)==13|(hV<<24>>24|0)==32|(hV<<24>>24|0)==9|(hV<<24>>24|0)==10)){break}gn=hU+1|0;hU=gn;hV=a[b+4+gn|0]|0;cA=2453}c[cq>>2]=hU;if((a[b+4+hU|0]|0)!=33){break}if((a[hU+1+(b+4)|0]|0)==61){hS=2;hT=hU}else{break}}c[cq>>2]=hT+2;if((sk(b,al,e)|0)==0){cA=2458;break L3297}if((hS|0)==1){c[bo>>2]=(c[bo>>2]|0)==(c[al>>2]|0);continue}else if((hS|0)==2){c[bo>>2]=(c[bo>>2]|0)!=(c[al>>2]|0);continue}else{continue}}c[ca>>2]=c[bo>>2]&c[ca>>2];hL=hU}if((cA|0)==3869){cA=0;c[cq>>2]=hL;hP=hL}while(1){gI=b+4+hP|0;gn=a[gI]|0;if((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10){hP=hP+1|0;continue}c[cq>>2]=hP;if((a[gI]|0)!=94){break}hW=hP+1|0;c[cq>>2]=hW;if((sk(b,bV,e)|0)==0){cA=2507;break L3297}while(1){gI=c[cq>>2]|0;while(1){hX=b+4+gI|0;gn=a[hX]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[hX]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){hY=1;hZ=gI}else{h_=gI;h$=61;cA=2473}}else{h_=gI;h$=gn;cA=2473}if((cA|0)==2473){while(1){cA=0;if(!((h$<<24>>24|0)==13|(h$<<24>>24|0)==32|(h$<<24>>24|0)==9|(h$<<24>>24|0)==10)){break}gn=h_+1|0;h_=gn;h$=a[b+4+gn|0]|0;cA=2473}c[cq>>2]=h_;if((a[b+4+h_|0]|0)!=33){h0=h_;break}if((a[h_+1+(b+4)|0]|0)==61){hY=2;hZ=h_}else{h0=h_;break}}c[cq>>2]=hZ+2;if((sk(b,ak,e)|0)==0){cA=2478;break L3297}if((hY|0)==1){c[bV>>2]=(c[bV>>2]|0)==(c[ak>>2]|0);continue}else if((hY|0)==2){c[bV>>2]=(c[bV>>2]|0)!=(c[ak>>2]|0);continue}else{continue}}while(1){gI=h0;while(1){h1=b+4+gI|0;gn=a[h1]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[h1]|0;if(gn<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=3870;break}else{h2=gI;h3=38}}else{h2=gI;h3=gn}while(1){if(!((h3<<24>>24|0)==13|(h3<<24>>24|0)==32|(h3<<24>>24|0)==9|(h3<<24>>24|0)==10)){break}gn=h2+1|0;h2=gn;h3=a[b+4+gn|0]|0}c[cq>>2]=h2;if((a[b+4+h2|0]|0)!=38){h4=h2;break}h5=h2+1|0;c[cq>>2]=h5;if((sk(b,bn,e)|0)==0){cA=2505;break L3297}while(1){gI=c[cq>>2]|0;while(1){h6=b+4+gI|0;gn=a[h6]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[h6]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){h7=1;h8=gI}else{h9=gI;ia=61;cA=2496}}else{h9=gI;ia=gn;cA=2496}if((cA|0)==2496){while(1){cA=0;if(!((ia<<24>>24|0)==13|(ia<<24>>24|0)==32|(ia<<24>>24|0)==9|(ia<<24>>24|0)==10)){break}gn=h9+1|0;h9=gn;ia=a[b+4+gn|0]|0;cA=2496}c[cq>>2]=h9;if((a[b+4+h9|0]|0)!=33){break}if((a[h9+1+(b+4)|0]|0)==61){h7=2;h8=h9}else{break}}c[cq>>2]=h8+2;if((sk(b,aj,e)|0)==0){cA=2501;break L3297}if((h7|0)==1){c[bn>>2]=(c[bn>>2]|0)==(c[aj>>2]|0);continue}else if((h7|0)==2){c[bn>>2]=(c[bn>>2]|0)!=(c[aj>>2]|0);continue}else{continue}}c[bV>>2]=c[bn>>2]&c[bV>>2];h0=h9}if((cA|0)==3870){cA=0;c[cq>>2]=h0;h4=h0}c[ca>>2]=c[bV>>2]^c[ca>>2];hP=h4}c[co>>2]=c[ca>>2]|c[co>>2];eL=hP}if((cA|0)==2435){c[cq>>2]=hF}else if((cA|0)==2458){c[cq>>2]=hQ;cA=2462}else if((cA|0)==2478){c[cq>>2]=hW;cA=2507}else if((cA|0)==2501){c[cq>>2]=h5;cA=2505}else if((cA|0)==3868){c[cq>>2]=eL;hE=eL;cA=2423}if((cA|0)==2423){gZ=hE;L3434:while(1){gI=b+4+gZ|0;gn=a[gI]|0;if((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10){gZ=gZ+1|0;continue}c[cq>>2]=gZ;if((a[gI]|0)!=38){cA=2514;break}if((a[gZ+1+(b+4)|0]|0)!=38){cA=2514;break}ib=gZ+2|0;c[cq>>2]=ib;if((sk(b,ci,e)|0)==0){break}while(1){gI=c[cq>>2]|0;while(1){ic=b+4+gI|0;gn=a[ic]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[ic]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){id=1;ie=gI}else{ig=gI;ih=61;cA=2521}}else{ig=gI;ih=gn;cA=2521}if((cA|0)==2521){while(1){cA=0;if(!((ih<<24>>24|0)==13|(ih<<24>>24|0)==32|(ih<<24>>24|0)==9|(ih<<24>>24|0)==10)){break}gn=ig+1|0;ig=gn;ih=a[b+4+gn|0]|0;cA=2521}c[cq>>2]=ig;if((a[b+4+ig|0]|0)!=33){ii=ig;break}if((a[ig+1+(b+4)|0]|0)==61){id=2;ie=ig}else{ii=ig;break}}c[cq>>2]=ie+2;if((sk(b,ai,e)|0)==0){cA=2526;break L3434}if((id|0)==1){c[ci>>2]=(c[ci>>2]|0)==(c[ai>>2]|0);continue}else if((id|0)==2){c[ci>>2]=(c[ci>>2]|0)!=(c[ai>>2]|0);continue}else{continue}}while(1){gI=ii;while(1){ij=b+4+gI|0;gn=a[ij]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[ij]|0;if(gn<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=3863;break}else{ik=gI;il=38}}else{ik=gI;il=gn}while(1){if(!((il<<24>>24|0)==13|(il<<24>>24|0)==32|(il<<24>>24|0)==9|(il<<24>>24|0)==10)){break}gn=ik+1|0;ik=gn;il=a[b+4+gn|0]|0}c[cq>>2]=ik;if((a[b+4+ik|0]|0)!=38){im=ik;break}io=ik+1|0;c[cq>>2]=io;if((sk(b,bm,e)|0)==0){cA=2553;break L3434}while(1){gI=c[cq>>2]|0;while(1){ip=b+4+gI|0;gn=a[ip]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[ip]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){iq=1;ir=gI}else{is=gI;it=61;cA=2544}}else{is=gI;it=gn;cA=2544}if((cA|0)==2544){while(1){cA=0;if(!((it<<24>>24|0)==13|(it<<24>>24|0)==32|(it<<24>>24|0)==9|(it<<24>>24|0)==10)){break}gn=is+1|0;is=gn;it=a[b+4+gn|0]|0;cA=2544}c[cq>>2]=is;if((a[b+4+is|0]|0)!=33){break}if((a[is+1+(b+4)|0]|0)==61){iq=2;ir=is}else{break}}c[cq>>2]=ir+2;if((sk(b,ah,e)|0)==0){cA=2549;break L3434}if((iq|0)==1){c[bm>>2]=(c[bm>>2]|0)==(c[ah>>2]|0);continue}else if((iq|0)==2){c[bm>>2]=(c[bm>>2]|0)!=(c[ah>>2]|0);continue}else{continue}}c[ci>>2]=c[bm>>2]&c[ci>>2];ii=is}if((cA|0)==3863){cA=0;c[cq>>2]=ii;im=ii}while(1){gI=b+4+im|0;gn=a[gI]|0;if((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10){im=im+1|0;continue}c[cq>>2]=im;if((a[gI]|0)!=94){iu=im;break}iv=im+1|0;c[cq>>2]=iv;if((sk(b,bU,e)|0)==0){cA=2598;break L3434}while(1){gI=c[cq>>2]|0;while(1){iw=b+4+gI|0;gn=a[iw]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[iw]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){ix=1;iy=gI}else{iz=gI;iA=61;cA=2564}}else{iz=gI;iA=gn;cA=2564}if((cA|0)==2564){while(1){cA=0;if(!((iA<<24>>24|0)==13|(iA<<24>>24|0)==32|(iA<<24>>24|0)==9|(iA<<24>>24|0)==10)){break}gn=iz+1|0;iz=gn;iA=a[b+4+gn|0]|0;cA=2564}c[cq>>2]=iz;if((a[b+4+iz|0]|0)!=33){iB=iz;break}if((a[iz+1+(b+4)|0]|0)==61){ix=2;iy=iz}else{iB=iz;break}}c[cq>>2]=iy+2;if((sk(b,ag,e)|0)==0){cA=2569;break L3434}if((ix|0)==1){c[bU>>2]=(c[bU>>2]|0)==(c[ag>>2]|0);continue}else if((ix|0)==2){c[bU>>2]=(c[bU>>2]|0)!=(c[ag>>2]|0);continue}else{continue}}while(1){gI=iB;while(1){iC=b+4+gI|0;gn=a[iC]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[iC]|0;if(gn<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=3864;break}else{iD=gI;iE=38}}else{iD=gI;iE=gn}while(1){if(!((iE<<24>>24|0)==13|(iE<<24>>24|0)==32|(iE<<24>>24|0)==9|(iE<<24>>24|0)==10)){break}gn=iD+1|0;iD=gn;iE=a[b+4+gn|0]|0}c[cq>>2]=iD;if((a[b+4+iD|0]|0)!=38){iF=iD;break}iG=iD+1|0;c[cq>>2]=iG;if((sk(b,bl,e)|0)==0){cA=2596;break L3434}while(1){gI=c[cq>>2]|0;while(1){iH=b+4+gI|0;gn=a[iH]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[iH]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){iI=1;iJ=gI}else{iK=gI;iL=61;cA=2587}}else{iK=gI;iL=gn;cA=2587}if((cA|0)==2587){while(1){cA=0;if(!((iL<<24>>24|0)==13|(iL<<24>>24|0)==32|(iL<<24>>24|0)==9|(iL<<24>>24|0)==10)){break}gn=iK+1|0;iK=gn;iL=a[b+4+gn|0]|0;cA=2587}c[cq>>2]=iK;if((a[b+4+iK|0]|0)!=33){break}if((a[iK+1+(b+4)|0]|0)==61){iI=2;iJ=iK}else{break}}c[cq>>2]=iJ+2;if((sk(b,af,e)|0)==0){cA=2592;break L3434}if((iI|0)==1){c[bl>>2]=(c[bl>>2]|0)==(c[af>>2]|0);continue}else if((iI|0)==2){c[bl>>2]=(c[bl>>2]|0)!=(c[af>>2]|0);continue}else{continue}}c[bU>>2]=c[bl>>2]&c[bU>>2];iB=iK}if((cA|0)==3864){cA=0;c[cq>>2]=iB;iF=iB}c[ci>>2]=c[bU>>2]^c[ci>>2];im=iF}while(1){gI=iu;while(1){iM=b+4+gI|0;gn=a[iM]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[iM]|0;if(gn<<24>>24==124){if((a[gI+1+(b+4)|0]|0)==124){cA=3865;break}else{iN=gI;iO=124}}else{iN=gI;iO=gn}while(1){if(!((iO<<24>>24|0)==13|(iO<<24>>24|0)==32|(iO<<24>>24|0)==9|(iO<<24>>24|0)==10)){break}gn=iN+1|0;iN=gn;iO=a[b+4+gn|0]|0}c[cq>>2]=iN;if((a[b+4+iN|0]|0)!=124){iP=iN;break}iQ=iN+1|0;c[cq>>2]=iQ;if((sk(b,b9,e)|0)==0){cA=2693;break L3434}while(1){gI=c[cq>>2]|0;while(1){iR=b+4+gI|0;gn=a[iR]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[iR]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){iS=1;iT=gI}else{iU=gI;iV=61;cA=2614}}else{iU=gI;iV=gn;cA=2614}if((cA|0)==2614){while(1){cA=0;if(!((iV<<24>>24|0)==13|(iV<<24>>24|0)==32|(iV<<24>>24|0)==9|(iV<<24>>24|0)==10)){break}gn=iU+1|0;iU=gn;iV=a[b+4+gn|0]|0;cA=2614}c[cq>>2]=iU;if((a[b+4+iU|0]|0)!=33){iW=iU;break}if((a[iU+1+(b+4)|0]|0)==61){iS=2;iT=iU}else{iW=iU;break}}c[cq>>2]=iT+2;if((sk(b,ae,e)|0)==0){cA=2619;break L3434}if((iS|0)==1){c[b9>>2]=(c[b9>>2]|0)==(c[ae>>2]|0);continue}else if((iS|0)==2){c[b9>>2]=(c[b9>>2]|0)!=(c[ae>>2]|0);continue}else{continue}}while(1){gI=iW;while(1){iX=b+4+gI|0;gn=a[iX]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[iX]|0;if(gn<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=3866;break}else{iY=gI;iZ=38}}else{iY=gI;iZ=gn}while(1){if(!((iZ<<24>>24|0)==13|(iZ<<24>>24|0)==32|(iZ<<24>>24|0)==9|(iZ<<24>>24|0)==10)){break}gn=iY+1|0;iY=gn;iZ=a[b+4+gn|0]|0}c[cq>>2]=iY;if((a[b+4+iY|0]|0)!=38){i_=iY;break}i$=iY+1|0;c[cq>>2]=i$;if((sk(b,bk,e)|0)==0){cA=2646;break L3434}while(1){gI=c[cq>>2]|0;while(1){i0=b+4+gI|0;gn=a[i0]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[i0]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){i1=1;i2=gI}else{i3=gI;i4=61;cA=2637}}else{i3=gI;i4=gn;cA=2637}if((cA|0)==2637){while(1){cA=0;if(!((i4<<24>>24|0)==13|(i4<<24>>24|0)==32|(i4<<24>>24|0)==9|(i4<<24>>24|0)==10)){break}gn=i3+1|0;i3=gn;i4=a[b+4+gn|0]|0;cA=2637}c[cq>>2]=i3;if((a[b+4+i3|0]|0)!=33){break}if((a[i3+1+(b+4)|0]|0)==61){i1=2;i2=i3}else{break}}c[cq>>2]=i2+2;if((sk(b,ad,e)|0)==0){cA=2642;break L3434}if((i1|0)==1){c[bk>>2]=(c[bk>>2]|0)==(c[ad>>2]|0);continue}else if((i1|0)==2){c[bk>>2]=(c[bk>>2]|0)!=(c[ad>>2]|0);continue}else{continue}}c[b9>>2]=c[bk>>2]&c[b9>>2];iW=i3}if((cA|0)==3866){cA=0;c[cq>>2]=iW;i_=iW}while(1){gI=b+4+i_|0;gn=a[gI]|0;if((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10){i_=i_+1|0;continue}c[cq>>2]=i_;if((a[gI]|0)!=94){break}i5=i_+1|0;c[cq>>2]=i5;if((sk(b,bT,e)|0)==0){cA=2691;break L3434}while(1){gI=c[cq>>2]|0;while(1){i6=b+4+gI|0;gn=a[i6]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[i6]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){i7=1;i8=gI}else{i9=gI;ja=61;cA=2657}}else{i9=gI;ja=gn;cA=2657}if((cA|0)==2657){while(1){cA=0;if(!((ja<<24>>24|0)==13|(ja<<24>>24|0)==32|(ja<<24>>24|0)==9|(ja<<24>>24|0)==10)){break}gn=i9+1|0;i9=gn;ja=a[b+4+gn|0]|0;cA=2657}c[cq>>2]=i9;if((a[b+4+i9|0]|0)!=33){jb=i9;break}if((a[i9+1+(b+4)|0]|0)==61){i7=2;i8=i9}else{jb=i9;break}}c[cq>>2]=i8+2;if((sk(b,ac,e)|0)==0){cA=2662;break L3434}if((i7|0)==1){c[bT>>2]=(c[bT>>2]|0)==(c[ac>>2]|0);continue}else if((i7|0)==2){c[bT>>2]=(c[bT>>2]|0)!=(c[ac>>2]|0);continue}else{continue}}while(1){gI=jb;while(1){jc=b+4+gI|0;gn=a[jc]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[jc]|0;if(gn<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=3867;break}else{jd=gI;je=38}}else{jd=gI;je=gn}while(1){if(!((je<<24>>24|0)==13|(je<<24>>24|0)==32|(je<<24>>24|0)==9|(je<<24>>24|0)==10)){break}gn=jd+1|0;jd=gn;je=a[b+4+gn|0]|0}c[cq>>2]=jd;if((a[b+4+jd|0]|0)!=38){jf=jd;break}jg=jd+1|0;c[cq>>2]=jg;if((sk(b,bj,e)|0)==0){cA=2689;break L3434}while(1){gI=c[cq>>2]|0;while(1){jh=b+4+gI|0;gn=a[jh]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;gn=a[jh]|0;if(gn<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){ji=1;jj=gI}else{jk=gI;jl=61;cA=2680}}else{jk=gI;jl=gn;cA=2680}if((cA|0)==2680){while(1){cA=0;if(!((jl<<24>>24|0)==13|(jl<<24>>24|0)==32|(jl<<24>>24|0)==9|(jl<<24>>24|0)==10)){break}gn=jk+1|0;jk=gn;jl=a[b+4+gn|0]|0;cA=2680}c[cq>>2]=jk;if((a[b+4+jk|0]|0)!=33){break}if((a[jk+1+(b+4)|0]|0)==61){ji=2;jj=jk}else{break}}c[cq>>2]=jj+2;if((sk(b,ab,e)|0)==0){cA=2685;break L3434}if((ji|0)==1){c[bj>>2]=(c[bj>>2]|0)==(c[ab>>2]|0);continue}else if((ji|0)==2){c[bj>>2]=(c[bj>>2]|0)!=(c[ab>>2]|0);continue}else{continue}}c[bT>>2]=c[bj>>2]&c[bT>>2];jb=jk}if((cA|0)==3867){cA=0;c[cq>>2]=jb;jf=jb}c[b9>>2]=c[bT>>2]^c[b9>>2];i_=jf}c[ci>>2]=c[b9>>2]|c[ci>>2];iu=i_}if((cA|0)==3865){cA=0;c[cq>>2]=iu;iP=iu}if((c[co>>2]|0)==0){jm=0}else{jm=(c[ci>>2]|0)!=0|0}c[co>>2]=jm;gZ=iP}if((cA|0)==2514){eL=gZ;L3693:while(1){gI=b+4+eL|0;gn=a[gI]|0;if((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10){eL=eL+1|0;continue}c[cq>>2]=eL;gn=a[gI]|0;if(gn<<24>>24!=124){jn=eL;jo=gn;cA=3074;break}if((a[eL+1+(b+4)|0]|0)!=124){jn=eL;jo=gn;cA=3074;break}jp=eL+2|0;c[cq>>2]=jp;if((sk(b,cm,e)|0)==0){break}while(1){gn=c[cq>>2]|0;while(1){jq=b+4+gn|0;gI=a[jq]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[jq]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){jr=1;js=gn}else{jt=gn;ju=61;cA=2708}}else{jt=gn;ju=gI;cA=2708}if((cA|0)==2708){while(1){cA=0;if(!((ju<<24>>24|0)==13|(ju<<24>>24|0)==32|(ju<<24>>24|0)==9|(ju<<24>>24|0)==10)){break}gI=jt+1|0;jt=gI;ju=a[b+4+gI|0]|0;cA=2708}c[cq>>2]=jt;if((a[b+4+jt|0]|0)!=33){jv=jt;break}if((a[jt+1+(b+4)|0]|0)==61){jr=2;js=jt}else{jv=jt;break}}c[cq>>2]=js+2;if((sk(b,aa,e)|0)==0){cA=2713;break L3693}if((jr|0)==1){c[cm>>2]=(c[cm>>2]|0)==(c[aa>>2]|0);continue}else if((jr|0)==2){c[cm>>2]=(c[cm>>2]|0)!=(c[aa>>2]|0);continue}else{continue}}while(1){gn=jv;while(1){jw=b+4+gn|0;gI=a[jw]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[jw]|0;if(gI<<24>>24==38){if((a[gn+1+(b+4)|0]|0)==38){cA=3851;break}else{jx=gn;jy=38}}else{jx=gn;jy=gI}while(1){if(!((jy<<24>>24|0)==13|(jy<<24>>24|0)==32|(jy<<24>>24|0)==9|(jy<<24>>24|0)==10)){break}gI=jx+1|0;jx=gI;jy=a[b+4+gI|0]|0}c[cq>>2]=jx;if((a[b+4+jx|0]|0)!=38){jz=jx;break}jA=jx+1|0;c[cq>>2]=jA;if((sk(b,bi,e)|0)==0){cA=2740;break L3693}while(1){gn=c[cq>>2]|0;while(1){jB=b+4+gn|0;gI=a[jB]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[jB]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){jC=1;jD=gn}else{jE=gn;jF=61;cA=2731}}else{jE=gn;jF=gI;cA=2731}if((cA|0)==2731){while(1){cA=0;if(!((jF<<24>>24|0)==13|(jF<<24>>24|0)==32|(jF<<24>>24|0)==9|(jF<<24>>24|0)==10)){break}gI=jE+1|0;jE=gI;jF=a[b+4+gI|0]|0;cA=2731}c[cq>>2]=jE;if((a[b+4+jE|0]|0)!=33){break}if((a[jE+1+(b+4)|0]|0)==61){jC=2;jD=jE}else{break}}c[cq>>2]=jD+2;if((sk(b,$,e)|0)==0){cA=2736;break L3693}if((jC|0)==1){c[bi>>2]=(c[bi>>2]|0)==(c[$>>2]|0);continue}else if((jC|0)==2){c[bi>>2]=(c[bi>>2]|0)!=(c[$>>2]|0);continue}else{continue}}c[cm>>2]=c[bi>>2]&c[cm>>2];jv=jE}if((cA|0)==3851){cA=0;c[cq>>2]=jv;jz=jv}while(1){gn=b+4+jz|0;gI=a[gn]|0;if((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10){jz=jz+1|0;continue}c[cq>>2]=jz;if((a[gn]|0)!=94){jG=jz;break}jH=jz+1|0;c[cq>>2]=jH;if((sk(b,bS,e)|0)==0){cA=2785;break L3693}while(1){gn=c[cq>>2]|0;while(1){jI=b+4+gn|0;gI=a[jI]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[jI]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){jJ=1;jK=gn}else{jL=gn;jM=61;cA=2751}}else{jL=gn;jM=gI;cA=2751}if((cA|0)==2751){while(1){cA=0;if(!((jM<<24>>24|0)==13|(jM<<24>>24|0)==32|(jM<<24>>24|0)==9|(jM<<24>>24|0)==10)){break}gI=jL+1|0;jL=gI;jM=a[b+4+gI|0]|0;cA=2751}c[cq>>2]=jL;if((a[b+4+jL|0]|0)!=33){jN=jL;break}if((a[jL+1+(b+4)|0]|0)==61){jJ=2;jK=jL}else{jN=jL;break}}c[cq>>2]=jK+2;if((sk(b,_,e)|0)==0){cA=2756;break L3693}if((jJ|0)==1){c[bS>>2]=(c[bS>>2]|0)==(c[_>>2]|0);continue}else if((jJ|0)==2){c[bS>>2]=(c[bS>>2]|0)!=(c[_>>2]|0);continue}else{continue}}while(1){gn=jN;while(1){jO=b+4+gn|0;gI=a[jO]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[jO]|0;if(gI<<24>>24==38){if((a[gn+1+(b+4)|0]|0)==38){cA=3852;break}else{jP=gn;jQ=38}}else{jP=gn;jQ=gI}while(1){if(!((jQ<<24>>24|0)==13|(jQ<<24>>24|0)==32|(jQ<<24>>24|0)==9|(jQ<<24>>24|0)==10)){break}gI=jP+1|0;jP=gI;jQ=a[b+4+gI|0]|0}c[cq>>2]=jP;if((a[b+4+jP|0]|0)!=38){jR=jP;break}jS=jP+1|0;c[cq>>2]=jS;if((sk(b,bh,e)|0)==0){cA=2783;break L3693}while(1){gn=c[cq>>2]|0;while(1){jT=b+4+gn|0;gI=a[jT]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[jT]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){jU=1;jV=gn}else{jW=gn;jX=61;cA=2774}}else{jW=gn;jX=gI;cA=2774}if((cA|0)==2774){while(1){cA=0;if(!((jX<<24>>24|0)==13|(jX<<24>>24|0)==32|(jX<<24>>24|0)==9|(jX<<24>>24|0)==10)){break}gI=jW+1|0;jW=gI;jX=a[b+4+gI|0]|0;cA=2774}c[cq>>2]=jW;if((a[b+4+jW|0]|0)!=33){break}if((a[jW+1+(b+4)|0]|0)==61){jU=2;jV=jW}else{break}}c[cq>>2]=jV+2;if((sk(b,Z,e)|0)==0){cA=2779;break L3693}if((jU|0)==1){c[bh>>2]=(c[bh>>2]|0)==(c[Z>>2]|0);continue}else if((jU|0)==2){c[bh>>2]=(c[bh>>2]|0)!=(c[Z>>2]|0);continue}else{continue}}c[bS>>2]=c[bh>>2]&c[bS>>2];jN=jW}if((cA|0)==3852){cA=0;c[cq>>2]=jN;jR=jN}c[cm>>2]=c[bS>>2]^c[cm>>2];jz=jR}while(1){gn=jG;while(1){jY=b+4+gn|0;gI=a[jY]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[jY]|0;if(gI<<24>>24==124){if((a[gn+1+(b+4)|0]|0)==124){cA=3853;break}else{jZ=gn;j_=124}}else{jZ=gn;j_=gI}while(1){if(!((j_<<24>>24|0)==13|(j_<<24>>24|0)==32|(j_<<24>>24|0)==9|(j_<<24>>24|0)==10)){break}gI=jZ+1|0;jZ=gI;j_=a[b+4+gI|0]|0}c[cq>>2]=jZ;if((a[b+4+jZ|0]|0)!=124){j$=jZ;break}j0=jZ+1|0;c[cq>>2]=j0;if((sk(b,b8,e)|0)==0){cA=2880;break L3693}while(1){gn=c[cq>>2]|0;while(1){j1=b+4+gn|0;gI=a[j1]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[j1]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){j2=1;j3=gn}else{j4=gn;j5=61;cA=2801}}else{j4=gn;j5=gI;cA=2801}if((cA|0)==2801){while(1){cA=0;if(!((j5<<24>>24|0)==13|(j5<<24>>24|0)==32|(j5<<24>>24|0)==9|(j5<<24>>24|0)==10)){break}gI=j4+1|0;j4=gI;j5=a[b+4+gI|0]|0;cA=2801}c[cq>>2]=j4;if((a[b+4+j4|0]|0)!=33){j6=j4;break}if((a[j4+1+(b+4)|0]|0)==61){j2=2;j3=j4}else{j6=j4;break}}c[cq>>2]=j3+2;if((sk(b,Y,e)|0)==0){cA=2806;break L3693}if((j2|0)==1){c[b8>>2]=(c[b8>>2]|0)==(c[Y>>2]|0);continue}else if((j2|0)==2){c[b8>>2]=(c[b8>>2]|0)!=(c[Y>>2]|0);continue}else{continue}}while(1){gn=j6;while(1){j7=b+4+gn|0;gI=a[j7]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[j7]|0;if(gI<<24>>24==38){if((a[gn+1+(b+4)|0]|0)==38){cA=3854;break}else{j8=gn;j9=38}}else{j8=gn;j9=gI}while(1){if(!((j9<<24>>24|0)==13|(j9<<24>>24|0)==32|(j9<<24>>24|0)==9|(j9<<24>>24|0)==10)){break}gI=j8+1|0;j8=gI;j9=a[b+4+gI|0]|0}c[cq>>2]=j8;if((a[b+4+j8|0]|0)!=38){ka=j8;break}kb=j8+1|0;c[cq>>2]=kb;if((sk(b,bg,e)|0)==0){cA=2833;break L3693}while(1){gn=c[cq>>2]|0;while(1){kc=b+4+gn|0;gI=a[kc]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[kc]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){kd=1;ke=gn}else{kf=gn;kg=61;cA=2824}}else{kf=gn;kg=gI;cA=2824}if((cA|0)==2824){while(1){cA=0;if(!((kg<<24>>24|0)==13|(kg<<24>>24|0)==32|(kg<<24>>24|0)==9|(kg<<24>>24|0)==10)){break}gI=kf+1|0;kf=gI;kg=a[b+4+gI|0]|0;cA=2824}c[cq>>2]=kf;if((a[b+4+kf|0]|0)!=33){break}if((a[kf+1+(b+4)|0]|0)==61){kd=2;ke=kf}else{break}}c[cq>>2]=ke+2;if((sk(b,X,e)|0)==0){cA=2829;break L3693}if((kd|0)==1){c[bg>>2]=(c[bg>>2]|0)==(c[X>>2]|0);continue}else if((kd|0)==2){c[bg>>2]=(c[bg>>2]|0)!=(c[X>>2]|0);continue}else{continue}}c[b8>>2]=c[bg>>2]&c[b8>>2];j6=kf}if((cA|0)==3854){cA=0;c[cq>>2]=j6;ka=j6}while(1){gn=b+4+ka|0;gI=a[gn]|0;if((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10){ka=ka+1|0;continue}c[cq>>2]=ka;if((a[gn]|0)!=94){break}kh=ka+1|0;c[cq>>2]=kh;if((sk(b,bR,e)|0)==0){cA=2878;break L3693}while(1){gn=c[cq>>2]|0;while(1){ki=b+4+gn|0;gI=a[ki]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[ki]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){kj=1;kk=gn}else{kl=gn;km=61;cA=2844}}else{kl=gn;km=gI;cA=2844}if((cA|0)==2844){while(1){cA=0;if(!((km<<24>>24|0)==13|(km<<24>>24|0)==32|(km<<24>>24|0)==9|(km<<24>>24|0)==10)){break}gI=kl+1|0;kl=gI;km=a[b+4+gI|0]|0;cA=2844}c[cq>>2]=kl;if((a[b+4+kl|0]|0)!=33){kn=kl;break}if((a[kl+1+(b+4)|0]|0)==61){kj=2;kk=kl}else{kn=kl;break}}c[cq>>2]=kk+2;if((sk(b,W,e)|0)==0){cA=2849;break L3693}if((kj|0)==1){c[bR>>2]=(c[bR>>2]|0)==(c[W>>2]|0);continue}else if((kj|0)==2){c[bR>>2]=(c[bR>>2]|0)!=(c[W>>2]|0);continue}else{continue}}while(1){gn=kn;while(1){ko=b+4+gn|0;gI=a[ko]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[ko]|0;if(gI<<24>>24==38){if((a[gn+1+(b+4)|0]|0)==38){cA=3855;break}else{kp=gn;kq=38}}else{kp=gn;kq=gI}while(1){if(!((kq<<24>>24|0)==13|(kq<<24>>24|0)==32|(kq<<24>>24|0)==9|(kq<<24>>24|0)==10)){break}gI=kp+1|0;kp=gI;kq=a[b+4+gI|0]|0}c[cq>>2]=kp;if((a[b+4+kp|0]|0)!=38){kr=kp;break}ks=kp+1|0;c[cq>>2]=ks;if((sk(b,bf,e)|0)==0){cA=2876;break L3693}while(1){gn=c[cq>>2]|0;while(1){kt=b+4+gn|0;gI=a[kt]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[kt]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){ku=1;kv=gn}else{kw=gn;kx=61;cA=2867}}else{kw=gn;kx=gI;cA=2867}if((cA|0)==2867){while(1){cA=0;if(!((kx<<24>>24|0)==13|(kx<<24>>24|0)==32|(kx<<24>>24|0)==9|(kx<<24>>24|0)==10)){break}gI=kw+1|0;kw=gI;kx=a[b+4+gI|0]|0;cA=2867}c[cq>>2]=kw;if((a[b+4+kw|0]|0)!=33){break}if((a[kw+1+(b+4)|0]|0)==61){ku=2;kv=kw}else{break}}c[cq>>2]=kv+2;if((sk(b,V,e)|0)==0){cA=2872;break L3693}if((ku|0)==1){c[bf>>2]=(c[bf>>2]|0)==(c[V>>2]|0);continue}else if((ku|0)==2){c[bf>>2]=(c[bf>>2]|0)!=(c[V>>2]|0);continue}else{continue}}c[bR>>2]=c[bf>>2]&c[bR>>2];kn=kw}if((cA|0)==3855){cA=0;c[cq>>2]=kn;kr=kn}c[b8>>2]=c[bR>>2]^c[b8>>2];ka=kr}c[cm>>2]=c[b8>>2]|c[cm>>2];jG=ka}if((cA|0)==3853){cA=0;c[cq>>2]=jG;j$=jG}while(1){gn=b+4+j$|0;gI=a[gn]|0;if((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10){j$=j$+1|0;continue}c[cq>>2]=j$;if((a[gn]|0)!=38){break}if((a[j$+1+(b+4)|0]|0)!=38){break}ky=j$+2|0;c[cq>>2]=ky;if((sk(b,ch,e)|0)==0){cA=3065;break L3693}while(1){gn=c[cq>>2]|0;while(1){kz=b+4+gn|0;gI=a[kz]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[kz]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){kA=1;kB=gn}else{kC=gn;kD=61;cA=2891}}else{kC=gn;kD=gI;cA=2891}if((cA|0)==2891){while(1){cA=0;if(!((kD<<24>>24|0)==13|(kD<<24>>24|0)==32|(kD<<24>>24|0)==9|(kD<<24>>24|0)==10)){break}gI=kC+1|0;kC=gI;kD=a[b+4+gI|0]|0;cA=2891}c[cq>>2]=kC;if((a[b+4+kC|0]|0)!=33){kE=kC;break}if((a[kC+1+(b+4)|0]|0)==61){kA=2;kB=kC}else{kE=kC;break}}c[cq>>2]=kB+2;if((sk(b,U,e)|0)==0){cA=2896;break L3693}if((kA|0)==1){c[ch>>2]=(c[ch>>2]|0)==(c[U>>2]|0);continue}else if((kA|0)==2){c[ch>>2]=(c[ch>>2]|0)!=(c[U>>2]|0);continue}else{continue}}while(1){gn=kE;while(1){kF=b+4+gn|0;gI=a[kF]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[kF]|0;if(gI<<24>>24==38){if((a[gn+1+(b+4)|0]|0)==38){cA=3857;break}else{kG=gn;kH=38}}else{kG=gn;kH=gI}while(1){if(!((kH<<24>>24|0)==13|(kH<<24>>24|0)==32|(kH<<24>>24|0)==9|(kH<<24>>24|0)==10)){break}gI=kG+1|0;kG=gI;kH=a[b+4+gI|0]|0}c[cq>>2]=kG;if((a[b+4+kG|0]|0)!=38){kI=kG;break}kJ=kG+1|0;c[cq>>2]=kJ;if((sk(b,be,e)|0)==0){cA=2923;break L3693}while(1){gn=c[cq>>2]|0;while(1){kK=b+4+gn|0;gI=a[kK]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[kK]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){kL=1;kM=gn}else{kN=gn;kO=61;cA=2914}}else{kN=gn;kO=gI;cA=2914}if((cA|0)==2914){while(1){cA=0;if(!((kO<<24>>24|0)==13|(kO<<24>>24|0)==32|(kO<<24>>24|0)==9|(kO<<24>>24|0)==10)){break}gI=kN+1|0;kN=gI;kO=a[b+4+gI|0]|0;cA=2914}c[cq>>2]=kN;if((a[b+4+kN|0]|0)!=33){break}if((a[kN+1+(b+4)|0]|0)==61){kL=2;kM=kN}else{break}}c[cq>>2]=kM+2;if((sk(b,T,e)|0)==0){cA=2919;break L3693}if((kL|0)==1){c[be>>2]=(c[be>>2]|0)==(c[T>>2]|0);continue}else if((kL|0)==2){c[be>>2]=(c[be>>2]|0)!=(c[T>>2]|0);continue}else{continue}}c[ch>>2]=c[be>>2]&c[ch>>2];kE=kN}if((cA|0)==3857){cA=0;c[cq>>2]=kE;kI=kE}while(1){gn=b+4+kI|0;gI=a[gn]|0;if((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10){kI=kI+1|0;continue}c[cq>>2]=kI;if((a[gn]|0)!=94){kP=kI;break}kQ=kI+1|0;c[cq>>2]=kQ;if((sk(b,bQ,e)|0)==0){cA=2968;break L3693}while(1){gn=c[cq>>2]|0;while(1){kR=b+4+gn|0;gI=a[kR]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[kR]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){kS=1;kT=gn}else{kU=gn;kV=61;cA=2934}}else{kU=gn;kV=gI;cA=2934}if((cA|0)==2934){while(1){cA=0;if(!((kV<<24>>24|0)==13|(kV<<24>>24|0)==32|(kV<<24>>24|0)==9|(kV<<24>>24|0)==10)){break}gI=kU+1|0;kU=gI;kV=a[b+4+gI|0]|0;cA=2934}c[cq>>2]=kU;if((a[b+4+kU|0]|0)!=33){kW=kU;break}if((a[kU+1+(b+4)|0]|0)==61){kS=2;kT=kU}else{kW=kU;break}}c[cq>>2]=kT+2;if((sk(b,S,e)|0)==0){cA=2939;break L3693}if((kS|0)==1){c[bQ>>2]=(c[bQ>>2]|0)==(c[S>>2]|0);continue}else if((kS|0)==2){c[bQ>>2]=(c[bQ>>2]|0)!=(c[S>>2]|0);continue}else{continue}}while(1){gn=kW;while(1){kX=b+4+gn|0;gI=a[kX]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[kX]|0;if(gI<<24>>24==38){if((a[gn+1+(b+4)|0]|0)==38){cA=3858;break}else{kY=gn;kZ=38}}else{kY=gn;kZ=gI}while(1){if(!((kZ<<24>>24|0)==13|(kZ<<24>>24|0)==32|(kZ<<24>>24|0)==9|(kZ<<24>>24|0)==10)){break}gI=kY+1|0;kY=gI;kZ=a[b+4+gI|0]|0}c[cq>>2]=kY;if((a[b+4+kY|0]|0)!=38){k_=kY;break}k$=kY+1|0;c[cq>>2]=k$;if((sk(b,bd,e)|0)==0){cA=2966;break L3693}while(1){gn=c[cq>>2]|0;while(1){k0=b+4+gn|0;gI=a[k0]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[k0]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){k1=1;k2=gn}else{k3=gn;k4=61;cA=2957}}else{k3=gn;k4=gI;cA=2957}if((cA|0)==2957){while(1){cA=0;if(!((k4<<24>>24|0)==13|(k4<<24>>24|0)==32|(k4<<24>>24|0)==9|(k4<<24>>24|0)==10)){break}gI=k3+1|0;k3=gI;k4=a[b+4+gI|0]|0;cA=2957}c[cq>>2]=k3;if((a[b+4+k3|0]|0)!=33){break}if((a[k3+1+(b+4)|0]|0)==61){k1=2;k2=k3}else{break}}c[cq>>2]=k2+2;if((sk(b,R,e)|0)==0){cA=2962;break L3693}if((k1|0)==1){c[bd>>2]=(c[bd>>2]|0)==(c[R>>2]|0);continue}else if((k1|0)==2){c[bd>>2]=(c[bd>>2]|0)!=(c[R>>2]|0);continue}else{continue}}c[bQ>>2]=c[bd>>2]&c[bQ>>2];kW=k3}if((cA|0)==3858){cA=0;c[cq>>2]=kW;k_=kW}c[ch>>2]=c[bQ>>2]^c[ch>>2];kI=k_}while(1){gn=kP;while(1){k5=b+4+gn|0;gI=a[k5]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[k5]|0;if(gI<<24>>24==124){if((a[gn+1+(b+4)|0]|0)==124){cA=3859;break}else{k6=gn;k7=124}}else{k6=gn;k7=gI}while(1){if(!((k7<<24>>24|0)==13|(k7<<24>>24|0)==32|(k7<<24>>24|0)==9|(k7<<24>>24|0)==10)){break}gI=k6+1|0;k6=gI;k7=a[b+4+gI|0]|0}c[cq>>2]=k6;if((a[b+4+k6|0]|0)!=124){k8=k6;break}k9=k6+1|0;c[cq>>2]=k9;if((sk(b,b7,e)|0)==0){cA=3063;break L3693}while(1){gn=c[cq>>2]|0;while(1){la=b+4+gn|0;gI=a[la]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[la]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){lb=1;lc=gn}else{ld=gn;le=61;cA=2984}}else{ld=gn;le=gI;cA=2984}if((cA|0)==2984){while(1){cA=0;if(!((le<<24>>24|0)==13|(le<<24>>24|0)==32|(le<<24>>24|0)==9|(le<<24>>24|0)==10)){break}gI=ld+1|0;ld=gI;le=a[b+4+gI|0]|0;cA=2984}c[cq>>2]=ld;if((a[b+4+ld|0]|0)!=33){lf=ld;break}if((a[ld+1+(b+4)|0]|0)==61){lb=2;lc=ld}else{lf=ld;break}}c[cq>>2]=lc+2;if((sk(b,Q,e)|0)==0){cA=2989;break L3693}if((lb|0)==1){c[b7>>2]=(c[b7>>2]|0)==(c[Q>>2]|0);continue}else if((lb|0)==2){c[b7>>2]=(c[b7>>2]|0)!=(c[Q>>2]|0);continue}else{continue}}while(1){gn=lf;while(1){lg=b+4+gn|0;gI=a[lg]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[lg]|0;if(gI<<24>>24==38){if((a[gn+1+(b+4)|0]|0)==38){cA=3860;break}else{lh=gn;li=38}}else{lh=gn;li=gI}while(1){if(!((li<<24>>24|0)==13|(li<<24>>24|0)==32|(li<<24>>24|0)==9|(li<<24>>24|0)==10)){break}gI=lh+1|0;lh=gI;li=a[b+4+gI|0]|0}c[cq>>2]=lh;if((a[b+4+lh|0]|0)!=38){lj=lh;break}lk=lh+1|0;c[cq>>2]=lk;if((sk(b,bc,e)|0)==0){cA=3016;break L3693}while(1){gn=c[cq>>2]|0;while(1){ll=b+4+gn|0;gI=a[ll]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[ll]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){lm=1;ln=gn}else{lo=gn;lp=61;cA=3007}}else{lo=gn;lp=gI;cA=3007}if((cA|0)==3007){while(1){cA=0;if(!((lp<<24>>24|0)==13|(lp<<24>>24|0)==32|(lp<<24>>24|0)==9|(lp<<24>>24|0)==10)){break}gI=lo+1|0;lo=gI;lp=a[b+4+gI|0]|0;cA=3007}c[cq>>2]=lo;if((a[b+4+lo|0]|0)!=33){break}if((a[lo+1+(b+4)|0]|0)==61){lm=2;ln=lo}else{break}}c[cq>>2]=ln+2;if((sk(b,P,e)|0)==0){cA=3012;break L3693}if((lm|0)==1){c[bc>>2]=(c[bc>>2]|0)==(c[P>>2]|0);continue}else if((lm|0)==2){c[bc>>2]=(c[bc>>2]|0)!=(c[P>>2]|0);continue}else{continue}}c[b7>>2]=c[bc>>2]&c[b7>>2];lf=lo}if((cA|0)==3860){cA=0;c[cq>>2]=lf;lj=lf}while(1){gn=b+4+lj|0;gI=a[gn]|0;if((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10){lj=lj+1|0;continue}c[cq>>2]=lj;if((a[gn]|0)!=94){break}lq=lj+1|0;c[cq>>2]=lq;if((sk(b,bP,e)|0)==0){cA=3061;break L3693}while(1){gn=c[cq>>2]|0;while(1){lr=b+4+gn|0;gI=a[lr]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[lr]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){ls=1;lt=gn}else{lu=gn;lv=61;cA=3027}}else{lu=gn;lv=gI;cA=3027}if((cA|0)==3027){while(1){cA=0;if(!((lv<<24>>24|0)==13|(lv<<24>>24|0)==32|(lv<<24>>24|0)==9|(lv<<24>>24|0)==10)){break}gI=lu+1|0;lu=gI;lv=a[b+4+gI|0]|0;cA=3027}c[cq>>2]=lu;if((a[b+4+lu|0]|0)!=33){lw=lu;break}if((a[lu+1+(b+4)|0]|0)==61){ls=2;lt=lu}else{lw=lu;break}}c[cq>>2]=lt+2;if((sk(b,O,e)|0)==0){cA=3032;break L3693}if((ls|0)==1){c[bP>>2]=(c[bP>>2]|0)==(c[O>>2]|0);continue}else if((ls|0)==2){c[bP>>2]=(c[bP>>2]|0)!=(c[O>>2]|0);continue}else{continue}}while(1){gn=lw;while(1){lx=b+4+gn|0;gI=a[lx]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[lx]|0;if(gI<<24>>24==38){if((a[gn+1+(b+4)|0]|0)==38){cA=3861;break}else{ly=gn;lz=38}}else{ly=gn;lz=gI}while(1){if(!((lz<<24>>24|0)==13|(lz<<24>>24|0)==32|(lz<<24>>24|0)==9|(lz<<24>>24|0)==10)){break}gI=ly+1|0;ly=gI;lz=a[b+4+gI|0]|0}c[cq>>2]=ly;if((a[b+4+ly|0]|0)!=38){lA=ly;break}lB=ly+1|0;c[cq>>2]=lB;if((sk(b,bb,e)|0)==0){cA=3059;break L3693}while(1){gn=c[cq>>2]|0;while(1){lC=b+4+gn|0;gI=a[lC]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[lC]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){lD=1;lE=gn}else{lF=gn;lG=61;cA=3050}}else{lF=gn;lG=gI;cA=3050}if((cA|0)==3050){while(1){cA=0;if(!((lG<<24>>24|0)==13|(lG<<24>>24|0)==32|(lG<<24>>24|0)==9|(lG<<24>>24|0)==10)){break}gI=lF+1|0;lF=gI;lG=a[b+4+gI|0]|0;cA=3050}c[cq>>2]=lF;if((a[b+4+lF|0]|0)!=33){break}if((a[lF+1+(b+4)|0]|0)==61){lD=2;lE=lF}else{break}}c[cq>>2]=lE+2;if((sk(b,N,e)|0)==0){cA=3055;break L3693}if((lD|0)==1){c[bb>>2]=(c[bb>>2]|0)==(c[N>>2]|0);continue}else if((lD|0)==2){c[bb>>2]=(c[bb>>2]|0)!=(c[N>>2]|0);continue}else{continue}}c[bP>>2]=c[bb>>2]&c[bP>>2];lw=lF}if((cA|0)==3861){cA=0;c[cq>>2]=lw;lA=lw}c[b7>>2]=c[bP>>2]^c[b7>>2];lj=lA}c[ch>>2]=c[b7>>2]|c[ch>>2];kP=lj}if((cA|0)==3859){cA=0;c[cq>>2]=kP;k8=kP}if((c[cm>>2]|0)==0){lH=0}else{lH=(c[ch>>2]|0)!=0|0}c[cm>>2]=lH;j$=k8}if((c[co>>2]|0)==0){lI=(c[cm>>2]|0)!=0|0}else{lI=1}c[co>>2]=lI;eL=j$}if((cA|0)==2713){c[cq>>2]=jp}else if((cA|0)==2736){c[cq>>2]=jA;cA=2740}else if((cA|0)==2756){c[cq>>2]=jH;cA=2785}else if((cA|0)==2779){c[cq>>2]=jS;cA=2783}else if((cA|0)==2806){c[cq>>2]=j0;cA=2880}else if((cA|0)==2829){c[cq>>2]=kb;cA=2833}else if((cA|0)==2849){c[cq>>2]=kh;cA=2878}else if((cA|0)==2872){c[cq>>2]=ks;cA=2876}else if((cA|0)==2896){c[cq>>2]=ky;cA=3065}else if((cA|0)==2919){c[cq>>2]=kJ;cA=2923}else if((cA|0)==2939){c[cq>>2]=kQ;cA=2968}else if((cA|0)==2962){c[cq>>2]=k$;cA=2966}else if((cA|0)==2989){c[cq>>2]=k9;cA=3063}else if((cA|0)==3012){c[cq>>2]=lk;cA=3016}else if((cA|0)==3032){c[cq>>2]=lq;cA=3061}else if((cA|0)==3055){c[cq>>2]=lB;cA=3059}else if((cA|0)==3074){while(1){cA=0;if(!((jo<<24>>24|0)==13|(jo<<24>>24|0)==32|(jo<<24>>24|0)==9|(jo<<24>>24|0)==10)){break}eL=jn+1|0;jn=eL;jo=a[b+4+eL|0]|0;cA=3074}c[cq>>2]=jn;if((a[b+4+jn|0]|0)!=58){c[cq>>2]=cr;cs=0;i=f;return cs|0}eL=jn+1|0;c[cq>>2]=eL;do{if((sk(b,cp,e)|0)!=0){while(1){gZ=c[cq>>2]|0;while(1){lJ=b+4+gZ|0;gn=a[lJ]|0;if(!((gn<<24>>24|0)==13|(gn<<24>>24|0)==32|(gn<<24>>24|0)==9|(gn<<24>>24|0)==10)){break}gZ=gZ+1|0}c[cq>>2]=gZ;gn=a[lJ]|0;if(gn<<24>>24==61){if((a[gZ+1+(b+4)|0]|0)==61){lK=1;lL=gZ}else{lM=gZ;lN=61;cA=3084}}else{lM=gZ;lN=gn;cA=3084}if((cA|0)==3084){while(1){cA=0;if(!((lN<<24>>24|0)==13|(lN<<24>>24|0)==32|(lN<<24>>24|0)==9|(lN<<24>>24|0)==10)){break}gn=lM+1|0;lM=gn;lN=a[b+4+gn|0]|0;cA=3084}c[cq>>2]=lM;if((a[b+4+lM|0]|0)!=33){break}if((a[lM+1+(b+4)|0]|0)==61){lK=2;lL=lM}else{break}}c[cq>>2]=lL+2;if((sk(b,M,e)|0)==0){cA=3090;break}if((lK|0)==1){c[cp>>2]=(c[cp>>2]|0)==(c[M>>2]|0);continue}else if((lK|0)==2){c[cp>>2]=(c[cp>>2]|0)!=(c[M>>2]|0);continue}else{continue}}if((cA|0)==3090){c[cq>>2]=eL;break}gZ=lM;L4255:while(1){gn=gZ;while(1){lO=b+4+gn|0;gI=a[lO]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[lO]|0;if(gI<<24>>24==38){if((a[gn+1+(b+4)|0]|0)==38){cA=3849;break}else{lP=gn;lQ=38}}else{lP=gn;lQ=gI}while(1){if(!((lQ<<24>>24|0)==13|(lQ<<24>>24|0)==32|(lQ<<24>>24|0)==9|(lQ<<24>>24|0)==10)){break}gI=lP+1|0;lP=gI;lQ=a[b+4+gI|0]|0}c[cq>>2]=lP;if((a[b+4+lP|0]|0)!=38){lR=lP;break}lS=lP+1|0;c[cq>>2]=lS;if((sk(b,ba,e)|0)==0){cA=3118;break}while(1){gn=c[cq>>2]|0;while(1){lT=b+4+gn|0;gI=a[lT]|0;if(!((gI<<24>>24|0)==13|(gI<<24>>24|0)==32|(gI<<24>>24|0)==9|(gI<<24>>24|0)==10)){break}gn=gn+1|0}c[cq>>2]=gn;gI=a[lT]|0;if(gI<<24>>24==61){if((a[gn+1+(b+4)|0]|0)==61){lU=1;lV=gn}else{lW=gn;lX=61;cA=3109}}else{lW=gn;lX=gI;cA=3109}if((cA|0)==3109){while(1){cA=0;if(!((lX<<24>>24|0)==13|(lX<<24>>24|0)==32|(lX<<24>>24|0)==9|(lX<<24>>24|0)==10)){break}gI=lW+1|0;lW=gI;lX=a[b+4+gI|0]|0;cA=3109}c[cq>>2]=lW;if((a[b+4+lW|0]|0)!=33){break}if((a[lW+1+(b+4)|0]|0)==61){lU=2;lV=lW}else{break}}c[cq>>2]=lV+2;if((sk(b,L,e)|0)==0){cA=3114;break L4255}if((lU|0)==1){c[ba>>2]=(c[ba>>2]|0)==(c[L>>2]|0);continue}else if((lU|0)==2){c[ba>>2]=(c[ba>>2]|0)!=(c[L>>2]|0);continue}else{continue}}c[cp>>2]=c[ba>>2]&c[cp>>2];gZ=lW}if((cA|0)==3114){c[cq>>2]=lS;cA=3118}else if((cA|0)==3849){c[cq>>2]=gZ;lR=gZ}if((cA|0)==3118){c[cq>>2]=eL;break}gn=lR;L4294:while(1){gI=b+4+gn|0;f5=a[gI]|0;if((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10){gn=gn+1|0;continue}c[cq>>2]=gn;if((a[gI]|0)!=94){cA=3123;break}lY=gn+1|0;c[cq>>2]=lY;if((sk(b,bO,e)|0)==0){break}while(1){gI=c[cq>>2]|0;while(1){lZ=b+4+gI|0;f5=a[lZ]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[lZ]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){l_=1;l$=gI}else{l0=gI;l1=61;cA=3130}}else{l0=gI;l1=f5;cA=3130}if((cA|0)==3130){while(1){cA=0;if(!((l1<<24>>24|0)==13|(l1<<24>>24|0)==32|(l1<<24>>24|0)==9|(l1<<24>>24|0)==10)){break}f5=l0+1|0;l0=f5;l1=a[b+4+f5|0]|0;cA=3130}c[cq>>2]=l0;if((a[b+4+l0|0]|0)!=33){l2=l0;break}if((a[l0+1+(b+4)|0]|0)==61){l_=2;l$=l0}else{l2=l0;break}}c[cq>>2]=l$+2;if((sk(b,K,e)|0)==0){cA=3135;break L4294}if((l_|0)==1){c[bO>>2]=(c[bO>>2]|0)==(c[K>>2]|0);continue}else if((l_|0)==2){c[bO>>2]=(c[bO>>2]|0)!=(c[K>>2]|0);continue}else{continue}}while(1){gI=l2;while(1){l3=b+4+gI|0;f5=a[l3]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[l3]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=3848;break}else{l4=gI;l5=38}}else{l4=gI;l5=f5}while(1){if(!((l5<<24>>24|0)==13|(l5<<24>>24|0)==32|(l5<<24>>24|0)==9|(l5<<24>>24|0)==10)){break}f5=l4+1|0;l4=f5;l5=a[b+4+f5|0]|0}c[cq>>2]=l4;if((a[b+4+l4|0]|0)!=38){l6=l4;break}l7=l4+1|0;c[cq>>2]=l7;if((sk(b,a9,e)|0)==0){cA=3162;break L4294}while(1){gI=c[cq>>2]|0;while(1){l8=b+4+gI|0;f5=a[l8]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[l8]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){l9=1;ma=gI}else{mb=gI;mc=61;cA=3153}}else{mb=gI;mc=f5;cA=3153}if((cA|0)==3153){while(1){cA=0;if(!((mc<<24>>24|0)==13|(mc<<24>>24|0)==32|(mc<<24>>24|0)==9|(mc<<24>>24|0)==10)){break}f5=mb+1|0;mb=f5;mc=a[b+4+f5|0]|0;cA=3153}c[cq>>2]=mb;if((a[b+4+mb|0]|0)!=33){break}if((a[mb+1+(b+4)|0]|0)==61){l9=2;ma=mb}else{break}}c[cq>>2]=ma+2;if((sk(b,J,e)|0)==0){cA=3158;break L4294}if((l9|0)==1){c[a9>>2]=(c[a9>>2]|0)==(c[J>>2]|0);continue}else if((l9|0)==2){c[a9>>2]=(c[a9>>2]|0)!=(c[J>>2]|0);continue}else{continue}}c[bO>>2]=c[a9>>2]&c[bO>>2];l2=mb}if((cA|0)==3848){cA=0;c[cq>>2]=l2;l6=l2}c[cp>>2]=c[bO>>2]^c[cp>>2];gn=l6}if((cA|0)==3123){gZ=gn;L4357:while(1){gI=gZ;while(1){md=b+4+gI|0;f5=a[md]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[md]|0;if(f5<<24>>24==124){if((a[gI+1+(b+4)|0]|0)==124){cA=3845;break}else{me=gI;mf=124}}else{me=gI;mf=f5}while(1){if(!((mf<<24>>24|0)==13|(mf<<24>>24|0)==32|(mf<<24>>24|0)==9|(mf<<24>>24|0)==10)){break}f5=me+1|0;me=f5;mf=a[b+4+f5|0]|0}c[cq>>2]=me;if((a[b+4+me|0]|0)!=124){mg=me;cA=3174;break}mh=me+1|0;c[cq>>2]=mh;if((sk(b,b6,e)|0)==0){break}while(1){gI=c[cq>>2]|0;while(1){mi=b+4+gI|0;f5=a[mi]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[mi]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){mj=1;mk=gI}else{ml=gI;mm=61;cA=3181}}else{ml=gI;mm=f5;cA=3181}if((cA|0)==3181){while(1){cA=0;if(!((mm<<24>>24|0)==13|(mm<<24>>24|0)==32|(mm<<24>>24|0)==9|(mm<<24>>24|0)==10)){break}f5=ml+1|0;ml=f5;mm=a[b+4+f5|0]|0;cA=3181}c[cq>>2]=ml;if((a[b+4+ml|0]|0)!=33){mn=ml;break}if((a[ml+1+(b+4)|0]|0)==61){mj=2;mk=ml}else{mn=ml;break}}c[cq>>2]=mk+2;if((sk(b,I,e)|0)==0){cA=3186;break L4357}if((mj|0)==1){c[b6>>2]=(c[b6>>2]|0)==(c[I>>2]|0);continue}else if((mj|0)==2){c[b6>>2]=(c[b6>>2]|0)!=(c[I>>2]|0);continue}else{continue}}while(1){gI=mn;while(1){mo=b+4+gI|0;f5=a[mo]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[mo]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=3846;break}else{mp=gI;mq=38}}else{mp=gI;mq=f5}while(1){if(!((mq<<24>>24|0)==13|(mq<<24>>24|0)==32|(mq<<24>>24|0)==9|(mq<<24>>24|0)==10)){break}f5=mp+1|0;mp=f5;mq=a[b+4+f5|0]|0}c[cq>>2]=mp;if((a[b+4+mp|0]|0)!=38){mr=mp;break}ms=mp+1|0;c[cq>>2]=ms;if((sk(b,a8,e)|0)==0){cA=3213;break L4357}while(1){gI=c[cq>>2]|0;while(1){mt=b+4+gI|0;f5=a[mt]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[mt]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){mu=1;mv=gI}else{mw=gI;mx=61;cA=3204}}else{mw=gI;mx=f5;cA=3204}if((cA|0)==3204){while(1){cA=0;if(!((mx<<24>>24|0)==13|(mx<<24>>24|0)==32|(mx<<24>>24|0)==9|(mx<<24>>24|0)==10)){break}f5=mw+1|0;mw=f5;mx=a[b+4+f5|0]|0;cA=3204}c[cq>>2]=mw;if((a[b+4+mw|0]|0)!=33){break}if((a[mw+1+(b+4)|0]|0)==61){mu=2;mv=mw}else{break}}c[cq>>2]=mv+2;if((sk(b,H,e)|0)==0){cA=3209;break L4357}if((mu|0)==1){c[a8>>2]=(c[a8>>2]|0)==(c[H>>2]|0);continue}else if((mu|0)==2){c[a8>>2]=(c[a8>>2]|0)!=(c[H>>2]|0);continue}else{continue}}c[b6>>2]=c[a8>>2]&c[b6>>2];mn=mw}if((cA|0)==3846){cA=0;c[cq>>2]=mn;mr=mn}while(1){gI=b+4+mr|0;f5=a[gI]|0;if((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10){mr=mr+1|0;continue}c[cq>>2]=mr;if((a[gI]|0)!=94){break}my=mr+1|0;c[cq>>2]=my;if((sk(b,bN,e)|0)==0){cA=3258;break L4357}while(1){gI=c[cq>>2]|0;while(1){mz=b+4+gI|0;f5=a[mz]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[mz]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){mA=1;mB=gI}else{mC=gI;mD=61;cA=3224}}else{mC=gI;mD=f5;cA=3224}if((cA|0)==3224){while(1){cA=0;if(!((mD<<24>>24|0)==13|(mD<<24>>24|0)==32|(mD<<24>>24|0)==9|(mD<<24>>24|0)==10)){break}f5=mC+1|0;mC=f5;mD=a[b+4+f5|0]|0;cA=3224}c[cq>>2]=mC;if((a[b+4+mC|0]|0)!=33){mE=mC;break}if((a[mC+1+(b+4)|0]|0)==61){mA=2;mB=mC}else{mE=mC;break}}c[cq>>2]=mB+2;if((sk(b,G,e)|0)==0){cA=3229;break L4357}if((mA|0)==1){c[bN>>2]=(c[bN>>2]|0)==(c[G>>2]|0);continue}else if((mA|0)==2){c[bN>>2]=(c[bN>>2]|0)!=(c[G>>2]|0);continue}else{continue}}while(1){gI=mE;while(1){mF=b+4+gI|0;f5=a[mF]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[mF]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=3847;break}else{mG=gI;mH=38}}else{mG=gI;mH=f5}while(1){if(!((mH<<24>>24|0)==13|(mH<<24>>24|0)==32|(mH<<24>>24|0)==9|(mH<<24>>24|0)==10)){break}f5=mG+1|0;mG=f5;mH=a[b+4+f5|0]|0}c[cq>>2]=mG;if((a[b+4+mG|0]|0)!=38){mI=mG;break}mJ=mG+1|0;c[cq>>2]=mJ;if((sk(b,a7,e)|0)==0){cA=3256;break L4357}while(1){gI=c[cq>>2]|0;while(1){mK=b+4+gI|0;f5=a[mK]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[mK]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){mL=1;mM=gI}else{mN=gI;mO=61;cA=3247}}else{mN=gI;mO=f5;cA=3247}if((cA|0)==3247){while(1){cA=0;if(!((mO<<24>>24|0)==13|(mO<<24>>24|0)==32|(mO<<24>>24|0)==9|(mO<<24>>24|0)==10)){break}f5=mN+1|0;mN=f5;mO=a[b+4+f5|0]|0;cA=3247}c[cq>>2]=mN;if((a[b+4+mN|0]|0)!=33){break}if((a[mN+1+(b+4)|0]|0)==61){mL=2;mM=mN}else{break}}c[cq>>2]=mM+2;if((sk(b,F,e)|0)==0){cA=3252;break L4357}if((mL|0)==1){c[a7>>2]=(c[a7>>2]|0)==(c[F>>2]|0);continue}else if((mL|0)==2){c[a7>>2]=(c[a7>>2]|0)!=(c[F>>2]|0);continue}else{continue}}c[bN>>2]=c[a7>>2]&c[bN>>2];mE=mN}if((cA|0)==3847){cA=0;c[cq>>2]=mE;mI=mE}c[b6>>2]=c[bN>>2]^c[b6>>2];mr=mI}c[cp>>2]=c[b6>>2]|c[cp>>2];gZ=mr}if((cA|0)==3186){c[cq>>2]=mh}else if((cA|0)==3209){c[cq>>2]=ms;cA=3213}else if((cA|0)==3229){c[cq>>2]=my;cA=3258}else if((cA|0)==3252){c[cq>>2]=mJ;cA=3256}else if((cA|0)==3845){c[cq>>2]=gZ;mg=gZ;cA=3174}if((cA|0)==3174){gn=mg;L4494:while(1){gI=b+4+gn|0;f5=a[gI]|0;if((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10){gn=gn+1|0;continue}c[cq>>2]=gn;if((a[gI]|0)!=38){cA=3265;break}if((a[gn+1+(b+4)|0]|0)!=38){cA=3265;break}mP=gn+2|0;c[cq>>2]=mP;if((sk(b,cg,e)|0)==0){break}while(1){gI=c[cq>>2]|0;while(1){mQ=b+4+gI|0;f5=a[mQ]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[mQ]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){mR=1;mS=gI}else{mT=gI;mU=61;cA=3272}}else{mT=gI;mU=f5;cA=3272}if((cA|0)==3272){while(1){cA=0;if(!((mU<<24>>24|0)==13|(mU<<24>>24|0)==32|(mU<<24>>24|0)==9|(mU<<24>>24|0)==10)){break}f5=mT+1|0;mT=f5;mU=a[b+4+f5|0]|0;cA=3272}c[cq>>2]=mT;if((a[b+4+mT|0]|0)!=33){mV=mT;break}if((a[mT+1+(b+4)|0]|0)==61){mR=2;mS=mT}else{mV=mT;break}}c[cq>>2]=mS+2;if((sk(b,E,e)|0)==0){cA=3277;break L4494}if((mR|0)==1){c[cg>>2]=(c[cg>>2]|0)==(c[E>>2]|0);continue}else if((mR|0)==2){c[cg>>2]=(c[cg>>2]|0)!=(c[E>>2]|0);continue}else{continue}}while(1){gI=mV;while(1){mW=b+4+gI|0;f5=a[mW]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[mW]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=3840;break}else{mX=gI;mY=38}}else{mX=gI;mY=f5}while(1){if(!((mY<<24>>24|0)==13|(mY<<24>>24|0)==32|(mY<<24>>24|0)==9|(mY<<24>>24|0)==10)){break}f5=mX+1|0;mX=f5;mY=a[b+4+f5|0]|0}c[cq>>2]=mX;if((a[b+4+mX|0]|0)!=38){mZ=mX;break}m_=mX+1|0;c[cq>>2]=m_;if((sk(b,a6,e)|0)==0){cA=3304;break L4494}while(1){gI=c[cq>>2]|0;while(1){m$=b+4+gI|0;f5=a[m$]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[m$]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){m0=1;m1=gI}else{m2=gI;m3=61;cA=3295}}else{m2=gI;m3=f5;cA=3295}if((cA|0)==3295){while(1){cA=0;if(!((m3<<24>>24|0)==13|(m3<<24>>24|0)==32|(m3<<24>>24|0)==9|(m3<<24>>24|0)==10)){break}f5=m2+1|0;m2=f5;m3=a[b+4+f5|0]|0;cA=3295}c[cq>>2]=m2;if((a[b+4+m2|0]|0)!=33){break}if((a[m2+1+(b+4)|0]|0)==61){m0=2;m1=m2}else{break}}c[cq>>2]=m1+2;if((sk(b,D,e)|0)==0){cA=3300;break L4494}if((m0|0)==1){c[a6>>2]=(c[a6>>2]|0)==(c[D>>2]|0);continue}else if((m0|0)==2){c[a6>>2]=(c[a6>>2]|0)!=(c[D>>2]|0);continue}else{continue}}c[cg>>2]=c[a6>>2]&c[cg>>2];mV=m2}if((cA|0)==3840){cA=0;c[cq>>2]=mV;mZ=mV}while(1){gI=b+4+mZ|0;f5=a[gI]|0;if((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10){mZ=mZ+1|0;continue}c[cq>>2]=mZ;if((a[gI]|0)!=94){m4=mZ;break}m5=mZ+1|0;c[cq>>2]=m5;if((sk(b,bM,e)|0)==0){cA=3349;break L4494}while(1){gI=c[cq>>2]|0;while(1){m6=b+4+gI|0;f5=a[m6]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[m6]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){m7=1;m8=gI}else{m9=gI;na=61;cA=3315}}else{m9=gI;na=f5;cA=3315}if((cA|0)==3315){while(1){cA=0;if(!((na<<24>>24|0)==13|(na<<24>>24|0)==32|(na<<24>>24|0)==9|(na<<24>>24|0)==10)){break}f5=m9+1|0;m9=f5;na=a[b+4+f5|0]|0;cA=3315}c[cq>>2]=m9;if((a[b+4+m9|0]|0)!=33){nb=m9;break}if((a[m9+1+(b+4)|0]|0)==61){m7=2;m8=m9}else{nb=m9;break}}c[cq>>2]=m8+2;if((sk(b,C,e)|0)==0){cA=3320;break L4494}if((m7|0)==1){c[bM>>2]=(c[bM>>2]|0)==(c[C>>2]|0);continue}else if((m7|0)==2){c[bM>>2]=(c[bM>>2]|0)!=(c[C>>2]|0);continue}else{continue}}while(1){gI=nb;while(1){nc=b+4+gI|0;f5=a[nc]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[nc]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=3841;break}else{nd=gI;ne=38}}else{nd=gI;ne=f5}while(1){if(!((ne<<24>>24|0)==13|(ne<<24>>24|0)==32|(ne<<24>>24|0)==9|(ne<<24>>24|0)==10)){break}f5=nd+1|0;nd=f5;ne=a[b+4+f5|0]|0}c[cq>>2]=nd;if((a[b+4+nd|0]|0)!=38){nf=nd;break}ng=nd+1|0;c[cq>>2]=ng;if((sk(b,a5,e)|0)==0){cA=3347;break L4494}while(1){gI=c[cq>>2]|0;while(1){nh=b+4+gI|0;f5=a[nh]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[nh]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){ni=1;nj=gI}else{nk=gI;nl=61;cA=3338}}else{nk=gI;nl=f5;cA=3338}if((cA|0)==3338){while(1){cA=0;if(!((nl<<24>>24|0)==13|(nl<<24>>24|0)==32|(nl<<24>>24|0)==9|(nl<<24>>24|0)==10)){break}f5=nk+1|0;nk=f5;nl=a[b+4+f5|0]|0;cA=3338}c[cq>>2]=nk;if((a[b+4+nk|0]|0)!=33){break}if((a[nk+1+(b+4)|0]|0)==61){ni=2;nj=nk}else{break}}c[cq>>2]=nj+2;if((sk(b,B,e)|0)==0){cA=3343;break L4494}if((ni|0)==1){c[a5>>2]=(c[a5>>2]|0)==(c[B>>2]|0);continue}else if((ni|0)==2){c[a5>>2]=(c[a5>>2]|0)!=(c[B>>2]|0);continue}else{continue}}c[bM>>2]=c[a5>>2]&c[bM>>2];nb=nk}if((cA|0)==3841){cA=0;c[cq>>2]=nb;nf=nb}c[cg>>2]=c[bM>>2]^c[cg>>2];mZ=nf}while(1){gI=m4;while(1){nm=b+4+gI|0;f5=a[nm]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[nm]|0;if(f5<<24>>24==124){if((a[gI+1+(b+4)|0]|0)==124){cA=3842;break}else{nn=gI;no=124}}else{nn=gI;no=f5}while(1){if(!((no<<24>>24|0)==13|(no<<24>>24|0)==32|(no<<24>>24|0)==9|(no<<24>>24|0)==10)){break}f5=nn+1|0;nn=f5;no=a[b+4+f5|0]|0}c[cq>>2]=nn;if((a[b+4+nn|0]|0)!=124){np=nn;break}nq=nn+1|0;c[cq>>2]=nq;if((sk(b,b5,e)|0)==0){cA=3444;break L4494}while(1){gI=c[cq>>2]|0;while(1){nr=b+4+gI|0;f5=a[nr]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[nr]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){ns=1;nt=gI}else{nu=gI;nv=61;cA=3365}}else{nu=gI;nv=f5;cA=3365}if((cA|0)==3365){while(1){cA=0;if(!((nv<<24>>24|0)==13|(nv<<24>>24|0)==32|(nv<<24>>24|0)==9|(nv<<24>>24|0)==10)){break}f5=nu+1|0;nu=f5;nv=a[b+4+f5|0]|0;cA=3365}c[cq>>2]=nu;if((a[b+4+nu|0]|0)!=33){nw=nu;break}if((a[nu+1+(b+4)|0]|0)==61){ns=2;nt=nu}else{nw=nu;break}}c[cq>>2]=nt+2;if((sk(b,A,e)|0)==0){cA=3370;break L4494}if((ns|0)==1){c[b5>>2]=(c[b5>>2]|0)==(c[A>>2]|0);continue}else if((ns|0)==2){c[b5>>2]=(c[b5>>2]|0)!=(c[A>>2]|0);continue}else{continue}}while(1){gI=nw;while(1){nx=b+4+gI|0;f5=a[nx]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[nx]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=3843;break}else{ny=gI;nz=38}}else{ny=gI;nz=f5}while(1){if(!((nz<<24>>24|0)==13|(nz<<24>>24|0)==32|(nz<<24>>24|0)==9|(nz<<24>>24|0)==10)){break}f5=ny+1|0;ny=f5;nz=a[b+4+f5|0]|0}c[cq>>2]=ny;if((a[b+4+ny|0]|0)!=38){nA=ny;break}nB=ny+1|0;c[cq>>2]=nB;if((sk(b,a4,e)|0)==0){cA=3397;break L4494}while(1){gI=c[cq>>2]|0;while(1){nC=b+4+gI|0;f5=a[nC]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[nC]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){nD=1;nE=gI}else{nF=gI;nG=61;cA=3388}}else{nF=gI;nG=f5;cA=3388}if((cA|0)==3388){while(1){cA=0;if(!((nG<<24>>24|0)==13|(nG<<24>>24|0)==32|(nG<<24>>24|0)==9|(nG<<24>>24|0)==10)){break}f5=nF+1|0;nF=f5;nG=a[b+4+f5|0]|0;cA=3388}c[cq>>2]=nF;if((a[b+4+nF|0]|0)!=33){break}if((a[nF+1+(b+4)|0]|0)==61){nD=2;nE=nF}else{break}}c[cq>>2]=nE+2;if((sk(b,z,e)|0)==0){cA=3393;break L4494}if((nD|0)==1){c[a4>>2]=(c[a4>>2]|0)==(c[z>>2]|0);continue}else if((nD|0)==2){c[a4>>2]=(c[a4>>2]|0)!=(c[z>>2]|0);continue}else{continue}}c[b5>>2]=c[a4>>2]&c[b5>>2];nw=nF}if((cA|0)==3843){cA=0;c[cq>>2]=nw;nA=nw}while(1){gI=b+4+nA|0;f5=a[gI]|0;if((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10){nA=nA+1|0;continue}c[cq>>2]=nA;if((a[gI]|0)!=94){break}nH=nA+1|0;c[cq>>2]=nH;if((sk(b,bL,e)|0)==0){cA=3442;break L4494}while(1){gI=c[cq>>2]|0;while(1){nI=b+4+gI|0;f5=a[nI]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[nI]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){nJ=1;nK=gI}else{nL=gI;nM=61;cA=3408}}else{nL=gI;nM=f5;cA=3408}if((cA|0)==3408){while(1){cA=0;if(!((nM<<24>>24|0)==13|(nM<<24>>24|0)==32|(nM<<24>>24|0)==9|(nM<<24>>24|0)==10)){break}f5=nL+1|0;nL=f5;nM=a[b+4+f5|0]|0;cA=3408}c[cq>>2]=nL;if((a[b+4+nL|0]|0)!=33){nN=nL;break}if((a[nL+1+(b+4)|0]|0)==61){nJ=2;nK=nL}else{nN=nL;break}}c[cq>>2]=nK+2;if((sk(b,y,e)|0)==0){cA=3413;break L4494}if((nJ|0)==1){c[bL>>2]=(c[bL>>2]|0)==(c[y>>2]|0);continue}else if((nJ|0)==2){c[bL>>2]=(c[bL>>2]|0)!=(c[y>>2]|0);continue}else{continue}}while(1){gI=nN;while(1){nO=b+4+gI|0;f5=a[nO]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[nO]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=3844;break}else{nP=gI;nQ=38}}else{nP=gI;nQ=f5}while(1){if(!((nQ<<24>>24|0)==13|(nQ<<24>>24|0)==32|(nQ<<24>>24|0)==9|(nQ<<24>>24|0)==10)){break}f5=nP+1|0;nP=f5;nQ=a[b+4+f5|0]|0}c[cq>>2]=nP;if((a[b+4+nP|0]|0)!=38){nR=nP;break}nS=nP+1|0;c[cq>>2]=nS;if((sk(b,a3,e)|0)==0){cA=3440;break L4494}while(1){gI=c[cq>>2]|0;while(1){nT=b+4+gI|0;f5=a[nT]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[nT]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){nU=1;nV=gI}else{nW=gI;nX=61;cA=3431}}else{nW=gI;nX=f5;cA=3431}if((cA|0)==3431){while(1){cA=0;if(!((nX<<24>>24|0)==13|(nX<<24>>24|0)==32|(nX<<24>>24|0)==9|(nX<<24>>24|0)==10)){break}f5=nW+1|0;nW=f5;nX=a[b+4+f5|0]|0;cA=3431}c[cq>>2]=nW;if((a[b+4+nW|0]|0)!=33){break}if((a[nW+1+(b+4)|0]|0)==61){nU=2;nV=nW}else{break}}c[cq>>2]=nV+2;if((sk(b,x,e)|0)==0){cA=3436;break L4494}if((nU|0)==1){c[a3>>2]=(c[a3>>2]|0)==(c[x>>2]|0);continue}else if((nU|0)==2){c[a3>>2]=(c[a3>>2]|0)!=(c[x>>2]|0);continue}else{continue}}c[bL>>2]=c[a3>>2]&c[bL>>2];nN=nW}if((cA|0)==3844){cA=0;c[cq>>2]=nN;nR=nN}c[b5>>2]=c[bL>>2]^c[b5>>2];nA=nR}c[cg>>2]=c[b5>>2]|c[cg>>2];m4=nA}if((cA|0)==3842){cA=0;c[cq>>2]=m4;np=m4}if((c[cp>>2]|0)==0){nY=0}else{nY=(c[cg>>2]|0)!=0|0}c[cp>>2]=nY;gn=np}if((cA|0)==3265){gZ=gn;L4753:while(1){gI=b+4+gZ|0;f5=a[gI]|0;if((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10){gZ=gZ+1|0;continue}c[cq>>2]=gZ;if((a[gI]|0)!=124){cA=3825;break}if((a[gZ+1+(b+4)|0]|0)!=124){cA=3825;break}nZ=gZ+2|0;c[cq>>2]=nZ;if((sk(b,cl,e)|0)==0){break}while(1){gI=c[cq>>2]|0;while(1){n_=b+4+gI|0;f5=a[n_]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[n_]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){n$=1;n0=gI}else{n1=gI;n2=61;cA=3459}}else{n1=gI;n2=f5;cA=3459}if((cA|0)==3459){while(1){cA=0;if(!((n2<<24>>24|0)==13|(n2<<24>>24|0)==32|(n2<<24>>24|0)==9|(n2<<24>>24|0)==10)){break}f5=n1+1|0;n1=f5;n2=a[b+4+f5|0]|0;cA=3459}c[cq>>2]=n1;if((a[b+4+n1|0]|0)!=33){n3=n1;break}if((a[n1+1+(b+4)|0]|0)==61){n$=2;n0=n1}else{n3=n1;break}}c[cq>>2]=n0+2;if((sk(b,w,e)|0)==0){cA=3464;break L4753}if((n$|0)==1){c[cl>>2]=(c[cl>>2]|0)==(c[w>>2]|0);continue}else if((n$|0)==2){c[cl>>2]=(c[cl>>2]|0)!=(c[w>>2]|0);continue}else{continue}}while(1){gI=n3;while(1){n4=b+4+gI|0;f5=a[n4]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[n4]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=3828;break}else{n5=gI;n6=38}}else{n5=gI;n6=f5}while(1){if(!((n6<<24>>24|0)==13|(n6<<24>>24|0)==32|(n6<<24>>24|0)==9|(n6<<24>>24|0)==10)){break}f5=n5+1|0;n5=f5;n6=a[b+4+f5|0]|0}c[cq>>2]=n5;if((a[b+4+n5|0]|0)!=38){n7=n5;break}n8=n5+1|0;c[cq>>2]=n8;if((sk(b,a2,e)|0)==0){cA=3491;break L4753}while(1){gI=c[cq>>2]|0;while(1){n9=b+4+gI|0;f5=a[n9]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[n9]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){oa=1;ob=gI}else{oc=gI;od=61;cA=3482}}else{oc=gI;od=f5;cA=3482}if((cA|0)==3482){while(1){cA=0;if(!((od<<24>>24|0)==13|(od<<24>>24|0)==32|(od<<24>>24|0)==9|(od<<24>>24|0)==10)){break}f5=oc+1|0;oc=f5;od=a[b+4+f5|0]|0;cA=3482}c[cq>>2]=oc;if((a[b+4+oc|0]|0)!=33){break}if((a[oc+1+(b+4)|0]|0)==61){oa=2;ob=oc}else{break}}c[cq>>2]=ob+2;if((sk(b,v,e)|0)==0){cA=3487;break L4753}if((oa|0)==1){c[a2>>2]=(c[a2>>2]|0)==(c[v>>2]|0);continue}else if((oa|0)==2){c[a2>>2]=(c[a2>>2]|0)!=(c[v>>2]|0);continue}else{continue}}c[cl>>2]=c[a2>>2]&c[cl>>2];n3=oc}if((cA|0)==3828){cA=0;c[cq>>2]=n3;n7=n3}while(1){gI=b+4+n7|0;f5=a[gI]|0;if((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10){n7=n7+1|0;continue}c[cq>>2]=n7;if((a[gI]|0)!=94){oe=n7;break}of=n7+1|0;c[cq>>2]=of;if((sk(b,bK,e)|0)==0){cA=3536;break L4753}while(1){gI=c[cq>>2]|0;while(1){og=b+4+gI|0;f5=a[og]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[og]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){oh=1;oi=gI}else{oj=gI;ok=61;cA=3502}}else{oj=gI;ok=f5;cA=3502}if((cA|0)==3502){while(1){cA=0;if(!((ok<<24>>24|0)==13|(ok<<24>>24|0)==32|(ok<<24>>24|0)==9|(ok<<24>>24|0)==10)){break}f5=oj+1|0;oj=f5;ok=a[b+4+f5|0]|0;cA=3502}c[cq>>2]=oj;if((a[b+4+oj|0]|0)!=33){ol=oj;break}if((a[oj+1+(b+4)|0]|0)==61){oh=2;oi=oj}else{ol=oj;break}}c[cq>>2]=oi+2;if((sk(b,u,e)|0)==0){cA=3507;break L4753}if((oh|0)==1){c[bK>>2]=(c[bK>>2]|0)==(c[u>>2]|0);continue}else if((oh|0)==2){c[bK>>2]=(c[bK>>2]|0)!=(c[u>>2]|0);continue}else{continue}}while(1){gI=ol;while(1){om=b+4+gI|0;f5=a[om]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[om]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=3829;break}else{on=gI;oo=38}}else{on=gI;oo=f5}while(1){if(!((oo<<24>>24|0)==13|(oo<<24>>24|0)==32|(oo<<24>>24|0)==9|(oo<<24>>24|0)==10)){break}f5=on+1|0;on=f5;oo=a[b+4+f5|0]|0}c[cq>>2]=on;if((a[b+4+on|0]|0)!=38){op=on;break}oq=on+1|0;c[cq>>2]=oq;if((sk(b,a1,e)|0)==0){cA=3534;break L4753}while(1){gI=c[cq>>2]|0;while(1){or=b+4+gI|0;f5=a[or]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[or]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){os=1;ot=gI}else{ou=gI;ov=61;cA=3525}}else{ou=gI;ov=f5;cA=3525}if((cA|0)==3525){while(1){cA=0;if(!((ov<<24>>24|0)==13|(ov<<24>>24|0)==32|(ov<<24>>24|0)==9|(ov<<24>>24|0)==10)){break}f5=ou+1|0;ou=f5;ov=a[b+4+f5|0]|0;cA=3525}c[cq>>2]=ou;if((a[b+4+ou|0]|0)!=33){break}if((a[ou+1+(b+4)|0]|0)==61){os=2;ot=ou}else{break}}c[cq>>2]=ot+2;if((sk(b,t,e)|0)==0){cA=3530;break L4753}if((os|0)==1){c[a1>>2]=(c[a1>>2]|0)==(c[t>>2]|0);continue}else if((os|0)==2){c[a1>>2]=(c[a1>>2]|0)!=(c[t>>2]|0);continue}else{continue}}c[bK>>2]=c[a1>>2]&c[bK>>2];ol=ou}if((cA|0)==3829){cA=0;c[cq>>2]=ol;op=ol}c[cl>>2]=c[bK>>2]^c[cl>>2];n7=op}while(1){gI=oe;while(1){ow=b+4+gI|0;f5=a[ow]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[ow]|0;if(f5<<24>>24==124){if((a[gI+1+(b+4)|0]|0)==124){cA=3830;break}else{ox=gI;oy=124}}else{ox=gI;oy=f5}while(1){if(!((oy<<24>>24|0)==13|(oy<<24>>24|0)==32|(oy<<24>>24|0)==9|(oy<<24>>24|0)==10)){break}f5=ox+1|0;ox=f5;oy=a[b+4+f5|0]|0}c[cq>>2]=ox;if((a[b+4+ox|0]|0)!=124){oz=ox;break}oA=ox+1|0;c[cq>>2]=oA;if((sk(b,b4,e)|0)==0){cA=3631;break L4753}while(1){gI=c[cq>>2]|0;while(1){oB=b+4+gI|0;f5=a[oB]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[oB]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){oC=1;oD=gI}else{oE=gI;oF=61;cA=3552}}else{oE=gI;oF=f5;cA=3552}if((cA|0)==3552){while(1){cA=0;if(!((oF<<24>>24|0)==13|(oF<<24>>24|0)==32|(oF<<24>>24|0)==9|(oF<<24>>24|0)==10)){break}f5=oE+1|0;oE=f5;oF=a[b+4+f5|0]|0;cA=3552}c[cq>>2]=oE;if((a[b+4+oE|0]|0)!=33){oG=oE;break}if((a[oE+1+(b+4)|0]|0)==61){oC=2;oD=oE}else{oG=oE;break}}c[cq>>2]=oD+2;if((sk(b,s,e)|0)==0){cA=3557;break L4753}if((oC|0)==1){c[b4>>2]=(c[b4>>2]|0)==(c[s>>2]|0);continue}else if((oC|0)==2){c[b4>>2]=(c[b4>>2]|0)!=(c[s>>2]|0);continue}else{continue}}while(1){gI=oG;while(1){oH=b+4+gI|0;f5=a[oH]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[oH]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=3831;break}else{oI=gI;oJ=38}}else{oI=gI;oJ=f5}while(1){if(!((oJ<<24>>24|0)==13|(oJ<<24>>24|0)==32|(oJ<<24>>24|0)==9|(oJ<<24>>24|0)==10)){break}f5=oI+1|0;oI=f5;oJ=a[b+4+f5|0]|0}c[cq>>2]=oI;if((a[b+4+oI|0]|0)!=38){oK=oI;break}oL=oI+1|0;c[cq>>2]=oL;if((sk(b,a0,e)|0)==0){cA=3584;break L4753}while(1){gI=c[cq>>2]|0;while(1){oM=b+4+gI|0;f5=a[oM]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[oM]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){oN=1;oO=gI}else{oP=gI;oQ=61;cA=3575}}else{oP=gI;oQ=f5;cA=3575}if((cA|0)==3575){while(1){cA=0;if(!((oQ<<24>>24|0)==13|(oQ<<24>>24|0)==32|(oQ<<24>>24|0)==9|(oQ<<24>>24|0)==10)){break}f5=oP+1|0;oP=f5;oQ=a[b+4+f5|0]|0;cA=3575}c[cq>>2]=oP;if((a[b+4+oP|0]|0)!=33){break}if((a[oP+1+(b+4)|0]|0)==61){oN=2;oO=oP}else{break}}c[cq>>2]=oO+2;if((sk(b,r,e)|0)==0){cA=3580;break L4753}if((oN|0)==1){c[a0>>2]=(c[a0>>2]|0)==(c[r>>2]|0);continue}else if((oN|0)==2){c[a0>>2]=(c[a0>>2]|0)!=(c[r>>2]|0);continue}else{continue}}c[b4>>2]=c[a0>>2]&c[b4>>2];oG=oP}if((cA|0)==3831){cA=0;c[cq>>2]=oG;oK=oG}while(1){gI=b+4+oK|0;f5=a[gI]|0;if((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10){oK=oK+1|0;continue}c[cq>>2]=oK;if((a[gI]|0)!=94){break}oR=oK+1|0;c[cq>>2]=oR;if((sk(b,bJ,e)|0)==0){cA=3629;break L4753}while(1){gI=c[cq>>2]|0;while(1){oS=b+4+gI|0;f5=a[oS]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[oS]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){oT=1;oU=gI}else{oV=gI;oW=61;cA=3595}}else{oV=gI;oW=f5;cA=3595}if((cA|0)==3595){while(1){cA=0;if(!((oW<<24>>24|0)==13|(oW<<24>>24|0)==32|(oW<<24>>24|0)==9|(oW<<24>>24|0)==10)){break}f5=oV+1|0;oV=f5;oW=a[b+4+f5|0]|0;cA=3595}c[cq>>2]=oV;if((a[b+4+oV|0]|0)!=33){oX=oV;break}if((a[oV+1+(b+4)|0]|0)==61){oT=2;oU=oV}else{oX=oV;break}}c[cq>>2]=oU+2;if((sk(b,q,e)|0)==0){cA=3600;break L4753}if((oT|0)==1){c[bJ>>2]=(c[bJ>>2]|0)==(c[q>>2]|0);continue}else if((oT|0)==2){c[bJ>>2]=(c[bJ>>2]|0)!=(c[q>>2]|0);continue}else{continue}}while(1){gI=oX;while(1){oY=b+4+gI|0;f5=a[oY]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[oY]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=3832;break}else{oZ=gI;o_=38}}else{oZ=gI;o_=f5}while(1){if(!((o_<<24>>24|0)==13|(o_<<24>>24|0)==32|(o_<<24>>24|0)==9|(o_<<24>>24|0)==10)){break}f5=oZ+1|0;oZ=f5;o_=a[b+4+f5|0]|0}c[cq>>2]=oZ;if((a[b+4+oZ|0]|0)!=38){o$=oZ;break}o0=oZ+1|0;c[cq>>2]=o0;if((sk(b,a$,e)|0)==0){cA=3627;break L4753}while(1){gI=c[cq>>2]|0;while(1){o1=b+4+gI|0;f5=a[o1]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[o1]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){o2=1;o3=gI}else{o4=gI;o5=61;cA=3618}}else{o4=gI;o5=f5;cA=3618}if((cA|0)==3618){while(1){cA=0;if(!((o5<<24>>24|0)==13|(o5<<24>>24|0)==32|(o5<<24>>24|0)==9|(o5<<24>>24|0)==10)){break}f5=o4+1|0;o4=f5;o5=a[b+4+f5|0]|0;cA=3618}c[cq>>2]=o4;if((a[b+4+o4|0]|0)!=33){break}if((a[o4+1+(b+4)|0]|0)==61){o2=2;o3=o4}else{break}}c[cq>>2]=o3+2;if((sk(b,p,e)|0)==0){cA=3623;break L4753}if((o2|0)==1){c[a$>>2]=(c[a$>>2]|0)==(c[p>>2]|0);continue}else if((o2|0)==2){c[a$>>2]=(c[a$>>2]|0)!=(c[p>>2]|0);continue}else{continue}}c[bJ>>2]=c[a$>>2]&c[bJ>>2];oX=o4}if((cA|0)==3832){cA=0;c[cq>>2]=oX;o$=oX}c[b4>>2]=c[bJ>>2]^c[b4>>2];oK=o$}c[cl>>2]=c[b4>>2]|c[cl>>2];oe=oK}if((cA|0)==3830){cA=0;c[cq>>2]=oe;oz=oe}while(1){gI=b+4+oz|0;f5=a[gI]|0;if((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10){oz=oz+1|0;continue}c[cq>>2]=oz;if((a[gI]|0)!=38){break}if((a[oz+1+(b+4)|0]|0)!=38){break}o6=oz+2|0;c[cq>>2]=o6;if((sk(b,cf,e)|0)==0){cA=3816;break L4753}while(1){gI=c[cq>>2]|0;while(1){o7=b+4+gI|0;f5=a[o7]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[o7]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){o8=1;o9=gI}else{pa=gI;pb=61;cA=3642}}else{pa=gI;pb=f5;cA=3642}if((cA|0)==3642){while(1){cA=0;if(!((pb<<24>>24|0)==13|(pb<<24>>24|0)==32|(pb<<24>>24|0)==9|(pb<<24>>24|0)==10)){break}f5=pa+1|0;pa=f5;pb=a[b+4+f5|0]|0;cA=3642}c[cq>>2]=pa;if((a[b+4+pa|0]|0)!=33){pc=pa;break}if((a[pa+1+(b+4)|0]|0)==61){o8=2;o9=pa}else{pc=pa;break}}c[cq>>2]=o9+2;if((sk(b,o,e)|0)==0){cA=3647;break L4753}if((o8|0)==1){c[cf>>2]=(c[cf>>2]|0)==(c[o>>2]|0);continue}else if((o8|0)==2){c[cf>>2]=(c[cf>>2]|0)!=(c[o>>2]|0);continue}else{continue}}while(1){gI=pc;while(1){pd=b+4+gI|0;f5=a[pd]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[pd]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=3834;break}else{pe=gI;pf=38}}else{pe=gI;pf=f5}while(1){if(!((pf<<24>>24|0)==13|(pf<<24>>24|0)==32|(pf<<24>>24|0)==9|(pf<<24>>24|0)==10)){break}f5=pe+1|0;pe=f5;pf=a[b+4+f5|0]|0}c[cq>>2]=pe;if((a[b+4+pe|0]|0)!=38){pg=pe;break}ph=pe+1|0;c[cq>>2]=ph;if((sk(b,a_,e)|0)==0){cA=3674;break L4753}while(1){gI=c[cq>>2]|0;while(1){pi=b+4+gI|0;f5=a[pi]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[pi]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){pj=1;pk=gI}else{pl=gI;pm=61;cA=3665}}else{pl=gI;pm=f5;cA=3665}if((cA|0)==3665){while(1){cA=0;if(!((pm<<24>>24|0)==13|(pm<<24>>24|0)==32|(pm<<24>>24|0)==9|(pm<<24>>24|0)==10)){break}f5=pl+1|0;pl=f5;pm=a[b+4+f5|0]|0;cA=3665}c[cq>>2]=pl;if((a[b+4+pl|0]|0)!=33){break}if((a[pl+1+(b+4)|0]|0)==61){pj=2;pk=pl}else{break}}c[cq>>2]=pk+2;if((sk(b,n,e)|0)==0){cA=3670;break L4753}if((pj|0)==1){c[a_>>2]=(c[a_>>2]|0)==(c[n>>2]|0);continue}else if((pj|0)==2){c[a_>>2]=(c[a_>>2]|0)!=(c[n>>2]|0);continue}else{continue}}c[cf>>2]=c[a_>>2]&c[cf>>2];pc=pl}if((cA|0)==3834){cA=0;c[cq>>2]=pc;pg=pc}while(1){gI=b+4+pg|0;f5=a[gI]|0;if((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10){pg=pg+1|0;continue}c[cq>>2]=pg;if((a[gI]|0)!=94){pn=pg;break}po=pg+1|0;c[cq>>2]=po;if((sk(b,bI,e)|0)==0){cA=3719;break L4753}while(1){gI=c[cq>>2]|0;while(1){pp=b+4+gI|0;f5=a[pp]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[pp]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){pq=1;pr=gI}else{ps=gI;pt=61;cA=3685}}else{ps=gI;pt=f5;cA=3685}if((cA|0)==3685){while(1){cA=0;if(!((pt<<24>>24|0)==13|(pt<<24>>24|0)==32|(pt<<24>>24|0)==9|(pt<<24>>24|0)==10)){break}f5=ps+1|0;ps=f5;pt=a[b+4+f5|0]|0;cA=3685}c[cq>>2]=ps;if((a[b+4+ps|0]|0)!=33){pu=ps;break}if((a[ps+1+(b+4)|0]|0)==61){pq=2;pr=ps}else{pu=ps;break}}c[cq>>2]=pr+2;if((sk(b,m,e)|0)==0){cA=3690;break L4753}if((pq|0)==1){c[bI>>2]=(c[bI>>2]|0)==(c[m>>2]|0);continue}else if((pq|0)==2){c[bI>>2]=(c[bI>>2]|0)!=(c[m>>2]|0);continue}else{continue}}while(1){gI=pu;while(1){pv=b+4+gI|0;f5=a[pv]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[pv]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=3835;break}else{pw=gI;px=38}}else{pw=gI;px=f5}while(1){if(!((px<<24>>24|0)==13|(px<<24>>24|0)==32|(px<<24>>24|0)==9|(px<<24>>24|0)==10)){break}f5=pw+1|0;pw=f5;px=a[b+4+f5|0]|0}c[cq>>2]=pw;if((a[b+4+pw|0]|0)!=38){py=pw;break}pz=pw+1|0;c[cq>>2]=pz;if((sk(b,aZ,e)|0)==0){cA=3717;break L4753}while(1){gI=c[cq>>2]|0;while(1){pA=b+4+gI|0;f5=a[pA]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[pA]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){pB=1;pC=gI}else{pD=gI;pE=61;cA=3708}}else{pD=gI;pE=f5;cA=3708}if((cA|0)==3708){while(1){cA=0;if(!((pE<<24>>24|0)==13|(pE<<24>>24|0)==32|(pE<<24>>24|0)==9|(pE<<24>>24|0)==10)){break}f5=pD+1|0;pD=f5;pE=a[b+4+f5|0]|0;cA=3708}c[cq>>2]=pD;if((a[b+4+pD|0]|0)!=33){break}if((a[pD+1+(b+4)|0]|0)==61){pB=2;pC=pD}else{break}}c[cq>>2]=pC+2;if((sk(b,l,e)|0)==0){cA=3713;break L4753}if((pB|0)==1){c[aZ>>2]=(c[aZ>>2]|0)==(c[l>>2]|0);continue}else if((pB|0)==2){c[aZ>>2]=(c[aZ>>2]|0)!=(c[l>>2]|0);continue}else{continue}}c[bI>>2]=c[aZ>>2]&c[bI>>2];pu=pD}if((cA|0)==3835){cA=0;c[cq>>2]=pu;py=pu}c[cf>>2]=c[bI>>2]^c[cf>>2];pg=py}while(1){gI=pn;while(1){pF=b+4+gI|0;f5=a[pF]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[pF]|0;if(f5<<24>>24==124){if((a[gI+1+(b+4)|0]|0)==124){cA=3836;break}else{pG=gI;pH=124}}else{pG=gI;pH=f5}while(1){if(!((pH<<24>>24|0)==13|(pH<<24>>24|0)==32|(pH<<24>>24|0)==9|(pH<<24>>24|0)==10)){break}f5=pG+1|0;pG=f5;pH=a[b+4+f5|0]|0}c[cq>>2]=pG;if((a[b+4+pG|0]|0)!=124){pI=pG;break}pJ=pG+1|0;c[cq>>2]=pJ;if((sk(b,b3,e)|0)==0){cA=3814;break L4753}while(1){gI=c[cq>>2]|0;while(1){pK=b+4+gI|0;f5=a[pK]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[pK]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){pL=1;pM=gI}else{pN=gI;pO=61;cA=3735}}else{pN=gI;pO=f5;cA=3735}if((cA|0)==3735){while(1){cA=0;if(!((pO<<24>>24|0)==13|(pO<<24>>24|0)==32|(pO<<24>>24|0)==9|(pO<<24>>24|0)==10)){break}f5=pN+1|0;pN=f5;pO=a[b+4+f5|0]|0;cA=3735}c[cq>>2]=pN;if((a[b+4+pN|0]|0)!=33){pP=pN;break}if((a[pN+1+(b+4)|0]|0)==61){pL=2;pM=pN}else{pP=pN;break}}c[cq>>2]=pM+2;if((sk(b,k,e)|0)==0){cA=3740;break L4753}if((pL|0)==1){c[b3>>2]=(c[b3>>2]|0)==(c[k>>2]|0);continue}else if((pL|0)==2){c[b3>>2]=(c[b3>>2]|0)!=(c[k>>2]|0);continue}else{continue}}while(1){gI=pP;while(1){pQ=b+4+gI|0;f5=a[pQ]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[pQ]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=3837;break}else{pR=gI;pS=38}}else{pR=gI;pS=f5}while(1){if(!((pS<<24>>24|0)==13|(pS<<24>>24|0)==32|(pS<<24>>24|0)==9|(pS<<24>>24|0)==10)){break}f5=pR+1|0;pR=f5;pS=a[b+4+f5|0]|0}c[cq>>2]=pR;if((a[b+4+pR|0]|0)!=38){pT=pR;break}pU=pR+1|0;c[cq>>2]=pU;if((sk(b,aY,e)|0)==0){cA=3767;break L4753}while(1){gI=c[cq>>2]|0;while(1){pV=b+4+gI|0;f5=a[pV]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[pV]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){pW=1;pX=gI}else{pY=gI;pZ=61;cA=3758}}else{pY=gI;pZ=f5;cA=3758}if((cA|0)==3758){while(1){cA=0;if(!((pZ<<24>>24|0)==13|(pZ<<24>>24|0)==32|(pZ<<24>>24|0)==9|(pZ<<24>>24|0)==10)){break}f5=pY+1|0;pY=f5;pZ=a[b+4+f5|0]|0;cA=3758}c[cq>>2]=pY;if((a[b+4+pY|0]|0)!=33){break}if((a[pY+1+(b+4)|0]|0)==61){pW=2;pX=pY}else{break}}c[cq>>2]=pX+2;if((sk(b,j,e)|0)==0){cA=3763;break L4753}if((pW|0)==1){c[aY>>2]=(c[aY>>2]|0)==(c[j>>2]|0);continue}else if((pW|0)==2){c[aY>>2]=(c[aY>>2]|0)!=(c[j>>2]|0);continue}else{continue}}c[b3>>2]=c[aY>>2]&c[b3>>2];pP=pY}if((cA|0)==3837){cA=0;c[cq>>2]=pP;pT=pP}while(1){gI=b+4+pT|0;f5=a[gI]|0;if((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10){pT=pT+1|0;continue}c[cq>>2]=pT;if((a[gI]|0)!=94){break}p_=pT+1|0;c[cq>>2]=p_;if((sk(b,bH,e)|0)==0){cA=3812;break L4753}while(1){gI=c[cq>>2]|0;while(1){p$=b+4+gI|0;f5=a[p$]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[p$]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){p0=1;p1=gI}else{p2=gI;p3=61;cA=3778}}else{p2=gI;p3=f5;cA=3778}if((cA|0)==3778){while(1){cA=0;if(!((p3<<24>>24|0)==13|(p3<<24>>24|0)==32|(p3<<24>>24|0)==9|(p3<<24>>24|0)==10)){break}f5=p2+1|0;p2=f5;p3=a[b+4+f5|0]|0;cA=3778}c[cq>>2]=p2;if((a[b+4+p2|0]|0)!=33){p4=p2;break}if((a[p2+1+(b+4)|0]|0)==61){p0=2;p1=p2}else{p4=p2;break}}c[cq>>2]=p1+2;if((sk(b,h,e)|0)==0){cA=3783;break L4753}if((p0|0)==1){c[bH>>2]=(c[bH>>2]|0)==(c[h>>2]|0);continue}else if((p0|0)==2){c[bH>>2]=(c[bH>>2]|0)!=(c[h>>2]|0);continue}else{continue}}while(1){gI=p4;while(1){p5=b+4+gI|0;f5=a[p5]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[p5]|0;if(f5<<24>>24==38){if((a[gI+1+(b+4)|0]|0)==38){cA=3838;break}else{p6=gI;p7=38}}else{p6=gI;p7=f5}while(1){if(!((p7<<24>>24|0)==13|(p7<<24>>24|0)==32|(p7<<24>>24|0)==9|(p7<<24>>24|0)==10)){break}f5=p6+1|0;p6=f5;p7=a[b+4+f5|0]|0}c[cq>>2]=p6;if((a[b+4+p6|0]|0)!=38){p8=p6;break}p9=p6+1|0;c[cq>>2]=p9;if((sk(b,aX,e)|0)==0){cA=3810;break L4753}while(1){gI=c[cq>>2]|0;while(1){qa=b+4+gI|0;f5=a[qa]|0;if(!((f5<<24>>24|0)==13|(f5<<24>>24|0)==32|(f5<<24>>24|0)==9|(f5<<24>>24|0)==10)){break}gI=gI+1|0}c[cq>>2]=gI;f5=a[qa]|0;if(f5<<24>>24==61){if((a[gI+1+(b+4)|0]|0)==61){qb=1;qc=gI}else{qd=gI;qe=61;cA=3801}}else{qd=gI;qe=f5;cA=3801}if((cA|0)==3801){while(1){cA=0;if(!((qe<<24>>24|0)==13|(qe<<24>>24|0)==32|(qe<<24>>24|0)==9|(qe<<24>>24|0)==10)){break}f5=qd+1|0;qd=f5;qe=a[b+4+f5|0]|0;cA=3801}c[cq>>2]=qd;if((a[b+4+qd|0]|0)!=33){break}if((a[qd+1+(b+4)|0]|0)==61){qb=2;qc=qd}else{break}}c[cq>>2]=qc+2;if((sk(b,g,e)|0)==0){cA=3806;break L4753}if((qb|0)==1){c[aX>>2]=(c[aX>>2]|0)==(c[g>>2]|0);continue}else if((qb|0)==2){c[aX>>2]=(c[aX>>2]|0)!=(c[g>>2]|0);continue}else{continue}}c[bH>>2]=c[aX>>2]&c[bH>>2];p4=qd}if((cA|0)==3838){cA=0;c[cq>>2]=p4;p8=p4}c[b3>>2]=c[bH>>2]^c[b3>>2];pT=p8}c[cf>>2]=c[b3>>2]|c[cf>>2];pn=pT}if((cA|0)==3836){cA=0;c[cq>>2]=pn;pI=pn}if((c[cl>>2]|0)==0){qf=0}else{qf=(c[cf>>2]|0)!=0|0}c[cl>>2]=qf;oz=pI}if((c[cp>>2]|0)==0){qg=(c[cl>>2]|0)!=0|0}else{qg=1}c[cp>>2]=qg;gZ=oz}if((cA|0)==3464){c[cq>>2]=nZ}else if((cA|0)==3487){c[cq>>2]=n8;cA=3491}else if((cA|0)==3507){c[cq>>2]=of;cA=3536}else if((cA|0)==3530){c[cq>>2]=oq;cA=3534}else if((cA|0)==3557){c[cq>>2]=oA;cA=3631}else if((cA|0)==3580){c[cq>>2]=oL;cA=3584}else if((cA|0)==3600){c[cq>>2]=oR;cA=3629}else if((cA|0)==3623){c[cq>>2]=o0;cA=3627}else if((cA|0)==3647){c[cq>>2]=o6;cA=3816}else if((cA|0)==3670){c[cq>>2]=ph;cA=3674}else if((cA|0)==3690){c[cq>>2]=po;cA=3719}else if((cA|0)==3713){c[cq>>2]=pz;cA=3717}else if((cA|0)==3740){c[cq>>2]=pJ;cA=3814}else if((cA|0)==3763){c[cq>>2]=pU;cA=3767}else if((cA|0)==3783){c[cq>>2]=p_;cA=3812}else if((cA|0)==3806){c[cq>>2]=p9;cA=3810}else if((cA|0)==3825){c[d>>2]=(c[d>>2]|0)!=0?c[co>>2]|0:c[cp>>2]|0;cs=1;i=f;return cs|0}if((cA|0)==3491){c[cq>>2]=nZ}else if((cA|0)==3534){c[cq>>2]=of;cA=3536}else if((cA|0)==3584){c[cq>>2]=oA;cA=3631}else if((cA|0)==3627){c[cq>>2]=oR;cA=3629}else if((cA|0)==3674){c[cq>>2]=o6;cA=3816}else if((cA|0)==3717){c[cq>>2]=po;cA=3719}else if((cA|0)==3767){c[cq>>2]=pJ;cA=3814}else if((cA|0)==3810){c[cq>>2]=p_;cA=3812}if((cA|0)==3536){c[cq>>2]=nZ}else if((cA|0)==3629){c[cq>>2]=oA;cA=3631}else if((cA|0)==3719){c[cq>>2]=o6;cA=3816}else if((cA|0)==3812){c[cq>>2]=pJ;cA=3814}if((cA|0)==3631){c[cq>>2]=nZ}else if((cA|0)==3814){c[cq>>2]=o6;cA=3816}if((cA|0)==3816){c[cq>>2]=nZ}c[cq>>2]=eL;break}else if((cA|0)==3277){c[cq>>2]=mP}else if((cA|0)==3300){c[cq>>2]=m_;cA=3304}else if((cA|0)==3320){c[cq>>2]=m5;cA=3349}else if((cA|0)==3343){c[cq>>2]=ng;cA=3347}else if((cA|0)==3370){c[cq>>2]=nq;cA=3444}else if((cA|0)==3393){c[cq>>2]=nB;cA=3397}else if((cA|0)==3413){c[cq>>2]=nH;cA=3442}else if((cA|0)==3436){c[cq>>2]=nS;cA=3440}if((cA|0)==3304){c[cq>>2]=mP}else if((cA|0)==3347){c[cq>>2]=m5;cA=3349}else if((cA|0)==3397){c[cq>>2]=nq;cA=3444}else if((cA|0)==3440){c[cq>>2]=nH;cA=3442}if((cA|0)==3349){c[cq>>2]=mP}else if((cA|0)==3442){c[cq>>2]=nq;cA=3444}if((cA|0)==3444){c[cq>>2]=mP}c[cq>>2]=eL;break}else if((cA|0)==3213){c[cq>>2]=mh}else if((cA|0)==3256){c[cq>>2]=my;cA=3258}if((cA|0)==3258){c[cq>>2]=mh}c[cq>>2]=eL;break}else if((cA|0)==3135){c[cq>>2]=lY}else if((cA|0)==3158){c[cq>>2]=l7;cA=3162}if((cA|0)==3162){c[cq>>2]=lY}c[cq>>2]=eL}}while(0);c[cq>>2]=cr;cs=0;i=f;return cs|0}if((cA|0)==2740){c[cq>>2]=jp}else if((cA|0)==2783){c[cq>>2]=jH;cA=2785}else if((cA|0)==2833){c[cq>>2]=j0;cA=2880}else if((cA|0)==2876){c[cq>>2]=kh;cA=2878}else if((cA|0)==2923){c[cq>>2]=ky;cA=3065}else if((cA|0)==2966){c[cq>>2]=kQ;cA=2968}else if((cA|0)==3016){c[cq>>2]=k9;cA=3063}else if((cA|0)==3059){c[cq>>2]=lq;cA=3061}if((cA|0)==2785){c[cq>>2]=jp}else if((cA|0)==2878){c[cq>>2]=j0;cA=2880}else if((cA|0)==2968){c[cq>>2]=ky;cA=3065}else if((cA|0)==3061){c[cq>>2]=k9;cA=3063}if((cA|0)==2880){c[cq>>2]=jp}else if((cA|0)==3063){c[cq>>2]=ky;cA=3065}if((cA|0)==3065){c[cq>>2]=jp}c[cq>>2]=eM;break}else if((cA|0)==2526){c[cq>>2]=ib}else if((cA|0)==2549){c[cq>>2]=io;cA=2553}else if((cA|0)==2569){c[cq>>2]=iv;cA=2598}else if((cA|0)==2592){c[cq>>2]=iG;cA=2596}else if((cA|0)==2619){c[cq>>2]=iQ;cA=2693}else if((cA|0)==2642){c[cq>>2]=i$;cA=2646}else if((cA|0)==2662){c[cq>>2]=i5;cA=2691}else if((cA|0)==2685){c[cq>>2]=jg;cA=2689}if((cA|0)==2553){c[cq>>2]=ib}else if((cA|0)==2596){c[cq>>2]=iv;cA=2598}else if((cA|0)==2646){c[cq>>2]=iQ;cA=2693}else if((cA|0)==2689){c[cq>>2]=i5;cA=2691}if((cA|0)==2598){c[cq>>2]=ib}else if((cA|0)==2691){c[cq>>2]=iQ;cA=2693}if((cA|0)==2693){c[cq>>2]=ib}c[cq>>2]=eM;break}else if((cA|0)==2462){c[cq>>2]=hF}else if((cA|0)==2505){c[cq>>2]=hW;cA=2507}if((cA|0)==2507){c[cq>>2]=hF}c[cq>>2]=eM;break}else if((cA|0)==2384){c[cq>>2]=hk}else if((cA|0)==2407){c[cq>>2]=hv;cA=2411}if((cA|0)==2411){c[cq>>2]=hk}c[cq>>2]=eM}}while(0);c[cq>>2]=cr;cs=0;i=f;return cs|0}if((cA|0)==1991){c[cq>>2]=eN}else if((cA|0)==2034){c[cq>>2]=e3;cA=2036}else if((cA|0)==2084){c[cq>>2]=fo;cA=2131}else if((cA|0)==2127){c[cq>>2]=fF;cA=2129}else if((cA|0)==2174){c[cq>>2]=fW;cA=2316}else if((cA|0)==2217){c[cq>>2]=gc;cA=2219}else if((cA|0)==2267){c[cq>>2]=gx;cA=2314}else if((cA|0)==2310){c[cq>>2]=gO;cA=2312}if((cA|0)==2036){c[cq>>2]=eN}else if((cA|0)==2129){c[cq>>2]=fo;cA=2131}else if((cA|0)==2219){c[cq>>2]=fW;cA=2316}else if((cA|0)==2312){c[cq>>2]=gx;cA=2314}if((cA|0)==2131){c[cq>>2]=eN}else if((cA|0)==2314){c[cq>>2]=fW;cA=2316}if((cA|0)==2316){c[cq>>2]=eN}c[cq>>2]=cr;cs=0;i=f;return cs|0}else if((cA|0)==1893){c[cq>>2]=en;cA=1897}else if((cA|0)==1913){c[cq>>2]=et;cA=1942}else if((cA|0)==1820){c[cq>>2]=dU;cA=1849}else if((cA|0)==1800){c[cq>>2]=dN;cA=1804}else if((cA|0)==1843){c[cq>>2]=d3;cA=1847}else if((cA|0)==1777){c[cq>>2]=dC}else if((cA|0)==1936){c[cq>>2]=eE;cA=1940}if((cA|0)==1897){c[cq>>2]=ec;cA=1944}else if((cA|0)==1804){c[cq>>2]=dC}else if((cA|0)==1847){c[cq>>2]=dU;cA=1849}else if((cA|0)==1940){c[cq>>2]=et;cA=1942}if((cA|0)==1849){c[cq>>2]=dC}else if((cA|0)==1942){c[cq>>2]=ec;cA=1944}if((cA|0)==1944){c[cq>>2]=dC}c[cq>>2]=cr;cs=0;i=f;return cs|0}else if((cA|0)==1713){c[cq>>2]=c3}else if((cA|0)==1756){c[cq>>2]=dk;cA=1758}if((cA|0)==1758){c[cq>>2]=c3}c[cq>>2]=cr;cs=0;i=f;return cs|0}else if((cA|0)==1635){c[cq>>2]=cL}else if((cA|0)==1658){c[cq>>2]=cV;cA=1662}if((cA|0)==1662){c[cq>>2]=cL}c[cq>>2]=cr;cs=0;i=f;return cs|0}function sk(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+8|0;g=f|0;h=b|0;j=c[h>>2]|0;if((sl(b,d,e)|0)==0){k=0;i=f;return k|0}L5443:while(1){l=c[h>>2]|0;while(1){m=b+4+l|0;n=a[m]|0;if(!((n<<24>>24|0)==13|(n<<24>>24|0)==32|(n<<24>>24|0)==9|(n<<24>>24|0)==10)){break}l=l+1|0}c[h>>2]=l;n=a[m]|0;do{if(n<<24>>24==60){if((a[l+1+(b+4)|0]|0)!=61){o=l;p=60;q=3914;break}c[h>>2]=l+2;r=1}else{o=l;p=n;q=3914}}while(0);L5452:do{if((q|0)==3914){while(1){q=0;if(!((p<<24>>24|0)==13|(p<<24>>24|0)==32|(p<<24>>24|0)==9|(p<<24>>24|0)==10)){break}n=o+1|0;o=n;p=a[b+4+n|0]|0;q=3914}c[h>>2]=o;n=a[b+4+o|0]|0;if(n<<24>>24==60){c[h>>2]=o+1;r=2;break}else{s=o;t=n}while(1){if(!((t<<24>>24|0)==13|(t<<24>>24|0)==32|(t<<24>>24|0)==9|(t<<24>>24|0)==10)){break}n=s+1|0;s=n;t=a[b+4+n|0]|0}c[h>>2]=s;n=a[b+4+s|0]|0;do{if(n<<24>>24==62){if((a[s+1+(b+4)|0]|0)!=61){u=s;v=62;break}c[h>>2]=s+2;r=3;break L5452}else{u=s;v=n}}while(0);while(1){if(!((v<<24>>24|0)==13|(v<<24>>24|0)==32|(v<<24>>24|0)==9|(v<<24>>24|0)==10)){break}n=u+1|0;u=n;v=a[b+4+n|0]|0}c[h>>2]=u;if((a[b+4+u|0]|0)!=62){k=1;q=3936;break L5443}c[h>>2]=u+1;r=4}}while(0);if((sl(b,g,e)|0)==0){break}if((r|0)==4){c[d>>2]=(c[d>>2]|0)>>>0>(c[g>>2]|0)>>>0;continue}else if((r|0)==2){c[d>>2]=(c[d>>2]|0)>>>0<(c[g>>2]|0)>>>0;continue}else if((r|0)==3){c[d>>2]=(c[d>>2]|0)>>>0>=(c[g>>2]|0)>>>0;continue}else if((r|0)==1){c[d>>2]=(c[d>>2]|0)>>>0<=(c[g>>2]|0)>>>0;continue}else{continue}}if((q|0)==3936){i=f;return k|0}c[h>>2]=j;k=0;i=f;return k|0}function sl(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=i;i=i+24|0;g=f|0;h=f+8|0;j=f+16|0;k=b|0;l=c[k>>2]|0;if((sm(b,d,e)|0)==0){m=0;i=f;return m|0}while(1){n=c[k>>2]|0;while(1){o=b+4+n|0;p=a[o]|0;if(!((p<<24>>24|0)==13|(p<<24>>24|0)==32|(p<<24>>24|0)==9|(p<<24>>24|0)==10)){break}n=n+1|0}c[k>>2]=n;p=a[o]|0;if(p<<24>>24==43){q=1;r=n}else{s=n;t=p;while(1){if(!((t<<24>>24|0)==13|(t<<24>>24|0)==32|(t<<24>>24|0)==9|(t<<24>>24|0)==10)){break}p=s+1|0;s=p;t=a[b+4+p|0]|0}c[k>>2]=s;if((a[b+4+s|0]|0)==45){q=2;r=s}else{break}}c[k>>2]=r+1;if((sm(b,g,e)|0)==0){u=3949;break}t=c[g>>2]|0;c[d>>2]=(c[d>>2]|0)+((q|0)==1?t:-t|0)}if((u|0)==3949){c[k>>2]=l;m=0;i=f;return m|0}q=s;L5502:while(1){s=b+4+q|0;g=a[s]|0;if((g<<24>>24|0)==13|(g<<24>>24|0)==32|(g<<24>>24|0)==9|(g<<24>>24|0)==10){q=q+1|0;continue}c[k>>2]=q;g=a[s]|0;do{if(g<<24>>24==60){if((a[q+1+(b+4)|0]|0)!=60){v=q;w=60;u=3955;break}if((a[q+2+(b+4)|0]|0)!=60){v=q;w=g;u=3955;break}s=q+3|0;c[k>>2]=s;x=1;y=s}else{v=q;w=g;u=3955}}while(0);L5511:do{if((u|0)==3955){while(1){u=0;if(!((w<<24>>24|0)==13|(w<<24>>24|0)==32|(w<<24>>24|0)==9|(w<<24>>24|0)==10)){break}g=v+1|0;v=g;w=a[b+4+g|0]|0;u=3955}c[k>>2]=v;g=a[b+4+v|0]|0;do{if(g<<24>>24==62){if((a[v+1+(b+4)|0]|0)!=62){z=v;A=62;break}if((a[v+2+(b+4)|0]|0)!=62){z=v;A=g;break}s=v+3|0;c[k>>2]=s;x=2;y=s;break L5511}else{z=v;A=g}}while(0);while(1){if(!((A<<24>>24|0)==13|(A<<24>>24|0)==32|(A<<24>>24|0)==9|(A<<24>>24|0)==10)){break}g=z+1|0;z=g;A=a[b+4+g|0]|0}c[k>>2]=z;g=a[b+4+z|0]|0;do{if(g<<24>>24==60){if((a[z+1+(b+4)|0]|0)!=60){B=z;C=60;break}s=z+2|0;c[k>>2]=s;x=3;y=s;break L5511}else{B=z;C=g}}while(0);while(1){if(!((C<<24>>24|0)==13|(C<<24>>24|0)==32|(C<<24>>24|0)==9|(C<<24>>24|0)==10)){break}g=B+1|0;B=g;C=a[b+4+g|0]|0}c[k>>2]=B;if((a[b+4+B|0]|0)!=62){m=1;u=3992;break L5502}if((a[B+1+(b+4)|0]|0)!=62){m=1;u=3996;break L5502}g=B+2|0;c[k>>2]=g;x=4;y=g}}while(0);if((sm(b,j,e)|0)==0){break}while(1){g=c[k>>2]|0;while(1){D=b+4+g|0;s=a[D]|0;if(!((s<<24>>24|0)==13|(s<<24>>24|0)==32|(s<<24>>24|0)==9|(s<<24>>24|0)==10)){break}g=g+1|0}c[k>>2]=g;s=a[D]|0;if(s<<24>>24==43){E=1;F=g}else{r=g;o=s;while(1){if(!((o<<24>>24|0)==13|(o<<24>>24|0)==32|(o<<24>>24|0)==9|(o<<24>>24|0)==10)){break}s=r+1|0;r=s;o=a[b+4+s|0]|0}c[k>>2]=r;if((a[b+4+r|0]|0)==45){E=2;F=r}else{break}}c[k>>2]=F+1;if((sm(b,h,e)|0)==0){u=3976;break L5502}o=c[h>>2]|0;c[j>>2]=(c[j>>2]|0)+((E|0)==1?o:-o|0)}o=c[j>>2]&31;c[j>>2]=o;if((x|0)==1){g=c[d>>2]|0;c[d>>2]=g<<o|g>>>((32-o|0)>>>0)}else if((x|0)==4){c[d>>2]=(c[d>>2]|0)>>>(o>>>0)}else if((x|0)==2){g=c[d>>2]|0;c[d>>2]=g>>>(o>>>0)|g<<32-o}else if((x|0)==3){c[d>>2]=c[d>>2]<<o}q=c[k>>2]|0}if((u|0)==3992){i=f;return m|0}else if((u|0)==3976){c[k>>2]=y}else if((u|0)==3996){i=f;return m|0}c[k>>2]=l;m=0;i=f;return m|0}function sm(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;i=i+8|0;g=f|0;h=b|0;j=c[h>>2]|0;if((so(b,d,e)|0)==0){k=0;i=f;return k|0}L5563:while(1){l=c[h>>2]|0;while(1){m=b+4+l|0;n=a[m]|0;if(!((n<<24>>24|0)==13|(n<<24>>24|0)==32|(n<<24>>24|0)==9|(n<<24>>24|0)==10)){break}l=l+1|0}c[h>>2]=l;n=a[m]|0;do{if(n<<24>>24==42){c[h>>2]=l+1;o=1}else{p=l;q=n;while(1){if(!((q<<24>>24|0)==13|(q<<24>>24|0)==32|(q<<24>>24|0)==9|(q<<24>>24|0)==10)){break}r=p+1|0;p=r;q=a[b+4+r|0]|0}c[h>>2]=p;q=a[b+4+p|0]|0;if(q<<24>>24==47){c[h>>2]=p+1;o=2;break}else{s=p;t=q}while(1){if(!((t<<24>>24|0)==13|(t<<24>>24|0)==32|(t<<24>>24|0)==9|(t<<24>>24|0)==10)){break}q=s+1|0;s=q;t=a[b+4+q|0]|0}c[h>>2]=s;if((a[b+4+s|0]|0)!=37){k=1;u=4025;break L5563}c[h>>2]=s+1;o=3}}while(0);if((so(b,g,e)|0)==0){break}if((o|0)==1){c[d>>2]=ac(c[g>>2]|0,c[d>>2]|0)|0;continue}n=c[g>>2]|0;l=(n|0)!=0;if((o|0)==2){if(l){c[d>>2]=((c[d>>2]|0)>>>0)/(n>>>0)|0;continue}else{c[d>>2]=-1;continue}}else{if(l){c[d>>2]=((c[d>>2]|0)>>>0)%(n>>>0)|0;continue}else{c[d>>2]=0;continue}}}if((u|0)==4025){i=f;return k|0}c[h>>2]=j;k=0;i=f;return k|0}function sn(a,b){a=a|0;b=b|0;c[14166]=a;c[14164]=b;return}function so(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;f=i;i=i+256|0;g=f|0;h=b|0;j=c[h>>2]|0;k=j;while(1){l=b+4+k|0;m=a[l]|0;if(!((m<<24>>24|0)==13|(m<<24>>24|0)==32|(m<<24>>24|0)==9|(m<<24>>24|0)==10)){break}k=k+1|0}c[h>>2]=k;m=a[l]|0;do{if(m<<24>>24==33){l=k+1|0;c[h>>2]=l;n=1;o=l}else{l=k;p=m;while(1){if(!((p<<24>>24|0)==13|(p<<24>>24|0)==32|(p<<24>>24|0)==9|(p<<24>>24|0)==10)){break}q=l+1|0;l=q;p=a[b+4+q|0]|0}c[h>>2]=l;p=a[b+4+l|0]|0;if(p<<24>>24==126){q=l+1|0;c[h>>2]=q;n=2;o=q;break}else{r=l;s=p}while(1){if(!((s<<24>>24|0)==13|(s<<24>>24|0)==32|(s<<24>>24|0)==9|(s<<24>>24|0)==10)){break}p=r+1|0;r=p;s=a[b+4+p|0]|0}c[h>>2]=r;l=a[b+4+r|0]|0;if(l<<24>>24==43){p=r+1|0;c[h>>2]=p;n=3;o=p;break}else{t=r;u=l}while(1){if(!((u<<24>>24|0)==13|(u<<24>>24|0)==32|(u<<24>>24|0)==9|(u<<24>>24|0)==10)){break}l=t+1|0;t=l;u=a[b+4+l|0]|0}c[h>>2]=t;if((a[b+4+t|0]|0)!=45){n=0;o=t;break}l=t+1|0;c[h>>2]=l;n=4;o=l}}while(0);t=g|0;u=o;while(1){o=a[b+4+u|0]|0;if(!((o<<24>>24|0)==13|(o<<24>>24|0)==32|(o<<24>>24|0)==9|(o<<24>>24|0)==10)){break}u=u+1|0}c[h>>2]=u;o=u;while(1){v=b+4+o|0;r=a[v]|0;if(!((r<<24>>24|0)==13|(r<<24>>24|0)==32|(r<<24>>24|0)==9|(r<<24>>24|0)==10)){break}o=o+1|0}c[h>>2]=o;r=a[v]|0;if(((r<<24>>24)-36|0)>>>0<2){a[t]=r;w=1;y=o+1|0;z=g+1|0}else{w=0;y=o;z=t}while(1){o=a[b+4+y|0]|0;if(o<<24>>24==0){A=4056;break}if(!((o-48&255)<10|(o-97&255)<26|(o-65&255)<26|o<<24>>24==95)){A=4056;break}a[z]=o;o=w+1|0;if(o>>>0<256){w=o;y=y+1|0;z=z+1|0}else{A=4055;break}}L5640:do{if((A|0)==4055){o=(c[h>>2]|0)+(b+4)|0;sp(40352,(x=i,i=i+16|0,c[x>>2]=37264,c[x+8>>2]=o,x)|0);B=c[h>>2]|0;A=4083}else if((A|0)==4056){a[z]=0;c[h>>2]=y;if((w|0)==0){B=y;A=4083;break}o=a[t]|0;r=(o-36&255)<2;if(!r){c[h>>2]=u;v=u;while(1){C=b+4+v|0;s=a[C]|0;if(!((s<<24>>24|0)==13|(s<<24>>24|0)==32|(s<<24>>24|0)==9|(s<<24>>24|0)==10)){break}v=v+1|0}c[h>>2]=v;s=a[C]|0;do{if(s<<24>>24!=0){m=v;k=0;l=0;p=s;L5651:while(1){q=p<<24>>24;do{if((p-48&255)<10){D=q-48|0}else{if((p-97&255)<6){D=q-87|0;break}if((p-65&255)>=6){E=m;F=k;G=l;break L5651}D=q-55|0}}while(0);if(D>>>0>=e>>>0){E=m;F=k;G=l;break}q=D+(ac(l,e)|0)|0;H=k+1|0;I=m+1|0;J=a[b+4+I|0]|0;if(J<<24>>24==0){E=I;F=H;G=q;break}else{m=I;k=H;l=q;p=J}}if((F|0)==0){break}c[h>>2]=E;c[d>>2]=G;if((c[h>>2]|0)>>>0>=y>>>0){break L5640}}}while(0);c[h>>2]=y}s=r?g+1|0:t;if(o<<24>>24==36){A=4078}else{v=c[14542]|0;if((v|0)==0){K=o}else{if((b2[v&127](c[14544]|0,s,d)|0)==0){break}K=a[t]|0}if(K<<24>>24!=37){A=4078}}L5672:do{if((A|0)==4078){v=c[14534]|0;p=c[14536]|0;l=0;while(1){if(l>>>0>=v>>>0){break L5672}if((aQ(c[p+(l<<3)>>2]|0,s|0)|0)==0){break}else{l=l+1|0}}c[d>>2]=c[p+(l<<3)+4>>2];break L5640}}while(0);c[h>>2]=u;B=u;A=4083}}while(0);L5679:do{if((A|0)==4083){while(1){A=0;L=b+4+B|0;K=a[L]|0;if(!((K<<24>>24|0)==13|(K<<24>>24|0)==32|(K<<24>>24|0)==9|(K<<24>>24|0)==10)){break}B=B+1|0;A=4083}c[h>>2]=B;K=a[L]|0;do{if(K<<24>>24==40){c[h>>2]=B+1;do{if((sg(b,d,e)|0)!=0){t=c[h>>2]|0;while(1){M=b+4+t|0;g=a[M]|0;if(!((g<<24>>24|0)==13|(g<<24>>24|0)==32|(g<<24>>24|0)==9|(g<<24>>24|0)==10)){break}t=t+1|0}c[h>>2]=t;if((a[M]|0)!=41){break}c[h>>2]=t+1;break L5679}}while(0);c[h>>2]=u}else{l=B;p=K;while(1){if(!((p<<24>>24|0)==13|(p<<24>>24|0)==32|(p<<24>>24|0)==9|(p<<24>>24|0)==10)){break}g=l+1|0;l=g;p=a[b+4+g|0]|0}c[h>>2]=l;p=a[b+4+l|0]|0;if(p<<24>>24==0){break}else{N=l;O=0;P=0;Q=p}L5698:while(1){p=Q<<24>>24;do{if((Q-48&255)<10){R=p-48|0}else{if((Q-97&255)<6){R=p-87|0;break}if((Q-65&255)>=6){S=N;T=O;U=P;break L5698}R=p-55|0}}while(0);if(R>>>0>=e>>>0){S=N;T=O;U=P;break}p=R+(ac(P,e)|0)|0;t=O+1|0;g=N+1|0;y=a[b+4+g|0]|0;if(y<<24>>24==0){S=g;T=t;U=p;break}else{N=g;O=t;P=p;Q=y}}if((T|0)==0){break}c[h>>2]=S;c[d>>2]=U;break L5679}}while(0);c[h>>2]=j;V=0;i=f;return V|0}}while(0);if((n|0)==4){c[d>>2]=-(c[d>>2]|0);V=1;i=f;return V|0}else if((n|0)==1){c[d>>2]=(c[d>>2]|0)==0;V=1;i=f;return V|0}else if((n|0)==2){c[d>>2]=~c[d>>2];V=1;i=f;return V|0}else{V=1;i=f;return V|0}return 0}function sp(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+16|0;e=d|0;if((c[14164]|0)==0){c[14164]=c[o>>2]}f=e|0;g=e;c[g>>2]=b;c[g+4>>2]=0;by(c[14164]|0,a|0,f|0)|0;ay(c[14164]|0)|0;g=c[14160]|0;if((g|0)==0){i=d;return}by(g|0,a|0,f|0)|0;ay(c[14160]|0)|0;i=d;return}function sq(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=u8(a|0)|0;d=c[14164]|0;if((d|0)==0){e=c[o>>2]|0;c[14164]=e;f=e}else{f=d}aB(45,f|0)|0;ay(c[14164]|0)|0;f=c[14160]|0;if((f|0)!=0){aB(45,f|0)|0;f=c[14160]|0;ay(f|0)|0}f=c[14164]|0;if((f|0)==0){d=c[o>>2]|0;c[14164]=d;g=d}else{g=f}aG(a|0,g|0)|0;ay(c[14164]|0)|0;g=c[14160]|0;if((g|0)!=0){aG(a|0,g|0)|0;g=c[14160]|0;ay(g|0)|0}g=b+1|0;b=c[14164]|0;a=(b|0)==0;if(g>>>0<78){f=g;g=b;d=a;while(1){if(d){e=c[o>>2]|0;c[14164]=e;h=e}else{h=g}aB(45,h|0)|0;ay(c[14164]|0)|0;e=c[14160]|0;if((e|0)!=0){aB(45,e|0)|0;e=c[14160]|0;ay(e|0)|0}e=f+1|0;i=c[14164]|0;j=(i|0)==0;if(e>>>0<78){f=e;g=i;d=j}else{k=i;l=j;break}}}else{k=b;l=a}if(l){l=c[o>>2]|0;c[14164]=l;m=l}else{m=k}aB(10,m|0)|0;ay(c[14164]|0)|0;m=c[14160]|0;if((m|0)==0){return}aB(10,m|0)|0;ay(c[14160]|0)|0;return}function sr(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;f=i;i=i+16|0;g=f|0;h=e|0;j=b[h>>1]|0;do{if(j<<16>>16<0){k=2}else{l=e+16|0;m=b[l>>1]|0;if(m<<16>>16>-1){n=1;p=l;l=m;do{m=n-1|0;q=e+(m<<4)|0;r=l<<16>>16;if(l<<16>>16<256){s=vc(r|0)|0}else{s=r}r=q|0;t=b[r>>1]|0;u=t<<16>>16;if(t<<16>>16<256){v=vc(u|0)|0}else{v=u}do{if((s|0)<(v|0)){w=b[p>>1]|0;y=4156}else{if((s|0)>(v|0)){break}u=b[p>>1]|0;if(u<<16>>16>(b[r>>1]|0)){w=u;y=4156}}}while(0);if((y|0)==4156){y=0;r=p;u=e+(n<<4)+2|0;b[g>>1]=b[u>>1]|0;b[g+2>>1]=b[u+2>>1]|0;b[g+4>>1]=b[u+4>>1]|0;b[g+6>>1]=b[u+6>>1]|0;b[g+8>>1]=b[u+8>>1]|0;b[g+10>>1]=b[u+10>>1]|0;b[g+12>>1]=b[u+12>>1]|0;u=q;c[r>>2]=c[u>>2];c[r+4>>2]=c[u+4>>2];c[r+8>>2]=c[u+8>>2];c[r+12>>2]=c[u+12>>2];L5778:do{if((m|0)==0){z=e}else{u=w<<16>>16;L5780:do{if(w<<16>>16<256){r=m;while(1){t=r-1|0;A=vc(u|0)|0;B=e+(t<<4)|0;C=b[B>>1]|0;D=C<<16>>16;if(C<<16>>16<256){E=vc(D|0)|0}else{E=D}if((A|0)<(E|0)){F=e+(r<<4)|0}else{if((A|0)>(E|0)){G=r;break L5780}A=b[B>>1]|0;if(w<<16>>16<A<<16>>16){G=r;break L5780}B=e+(r<<4)|0;if(w<<16>>16>A<<16>>16){F=B}else{z=B;break L5778}}B=F;A=e+(t<<4)|0;c[B>>2]=c[A>>2];c[B+4>>2]=c[A+4>>2];c[B+8>>2]=c[A+8>>2];c[B+12>>2]=c[A+12>>2];if((t|0)==0){z=e;break L5778}else{r=t}}}else{r=m;while(1){t=r-1|0;A=e+(t<<4)|0;B=b[A>>1]|0;D=B<<16>>16;if(B<<16>>16<256){H=vc(D|0)|0}else{H=D}if((u|0)<(H|0)){I=e+(r<<4)|0}else{if((u|0)>(H|0)){G=r;break L5780}D=b[A>>1]|0;if(w<<16>>16<D<<16>>16){G=r;break L5780}A=e+(r<<4)|0;if(w<<16>>16>D<<16>>16){I=A}else{z=A;break L5778}}A=I;D=e+(t<<4)|0;c[A>>2]=c[D>>2];c[A+4>>2]=c[D+4>>2];c[A+8>>2]=c[D+8>>2];c[A+12>>2]=c[D+12>>2];if((t|0)==0){z=e;break L5778}else{r=t}}}}while(0);z=e+(G<<4)|0}}while(0);b[z>>1]=w;m=z+2|0;b[m>>1]=b[g>>1]|0;b[m+2>>1]=b[g+2>>1]|0;b[m+4>>1]=b[g+4>>1]|0;b[m+6>>1]=b[g+6>>1]|0;b[m+8>>1]=b[g+8>>1]|0;b[m+10>>1]=b[g+10>>1]|0;b[m+12>>1]=b[g+12>>1]|0}n=n+1|0;p=e+(n<<4)|0;l=b[p>>1]|0;}while(l<<16>>16>-1);l=b[h>>1]|0;if(l<<16>>16>-1){J=0;K=0;L=l}else{k=2;break}}else{J=0;K=0;L=j}do{do{if((c[e+(J<<4)+12>>2]|0)==0){M=0}else{l=c[e+(J<<4)+4>>2]|0;if(L<<16>>16<256){N=(l|0)==0?2:4}else{N=0}if((l|0)==0){O=N}else{O=N+2+(u8(l|0)|0)|0}l=c[e+(J<<4)+8>>2]|0;if((l|0)==0){M=O;break}M=O+1+(u8(l|0)|0)|0}}while(0);K=M>>>0>K>>>0?M:K;J=J+1|0;L=b[e+(J<<4)>>1]|0;}while(L<<16>>16>-1);k=K+2|0}}while(0);if((a|0)!=0){bh(49704,(x=i,i=i+8|0,c[x>>2]=a,x)|0)|0}if((d|0)!=0){bp(d|0)|0}d=b[h>>1]|0;if(d<<16>>16>-1){P=e;Q=d}else{i=f;return}do{do{if(Q<<16>>16<256){d=Q<<16>>16;bh(34400,(x=i,i=i+8|0,c[x>>2]=d,x)|0)|0;d=P+4|0;if((c[d>>2]|0)==0){R=2;S=d;break}bh(31920,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0)|0;R=4;S=d}else{bh(30488,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0)|0;R=0;S=P+4|0}}while(0);d=c[S>>2]|0;if((d|0)==0){T=R}else{bh(29560,(x=i,i=i+8|0,c[x>>2]=d,x)|0)|0;T=R+2+(u8(c[S>>2]|0)|0)|0}d=P+8|0;e=c[d>>2]|0;if((e|0)==0){U=T}else{bh(55360,(x=i,i=i+8|0,c[x>>2]=e,x)|0)|0;U=T+1+(u8(c[d>>2]|0)|0)|0}if(U>>>0<k>>>0){d=U;do{aB(32,c[o>>2]|0)|0;d=d+1|0;}while(d>>>0<k>>>0)}bp(c[P+12>>2]|0)|0;P=P+16|0;Q=b[P>>1]|0;}while(Q<<16>>16>-1);i=f;return}function ss(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0;j=i;if((d|0)==0&(f|0)==0){c[1554]=-1;k=0;i=j;return k|0}if((c[1554]|0)<0){a[6224]=0;c[1554]=0;c[1552]=1;c[14162]=0;l=0}else{l=a[6224]|0}if(l|(h|0)==0){l=c[1552]|0;if((l|0)>=(d|0)){k=-1;i=j;return k|0}c[1554]=l;c[1552]=l+1;c[g>>2]=f+(l<<2);k=0;i=j;return k|0}l=c[14162]|0;if((l|0)==0){m=4215}else{n=a[l]|0;if(n<<24>>24==0){m=4215}else{o=n}}L5865:do{if((m|0)==4215){n=c[1552]|0;if((n|0)>=(d|0)){k=-1;i=j;return k|0}c[1554]=n;l=n+1|0;c[1552]=l;p=f+(n<<2)|0;r=c[p>>2]|0;c[14162]=r;do{if((a[r]|0)==45){s=r+1|0;t=a[s]|0;if((t<<24>>24|0)==0){break}else if((t<<24>>24|0)!=45){c[14162]=s;o=a[s]|0;break L5865}s=r+2|0;if((a[s]|0)==0){a[6224]=1;if((l|0)>=(d|0)){k=-1;i=j;return k|0}c[1554]=l;c[1552]=n+2;c[g>>2]=f+(l<<2);k=0;i=j;return k|0}else{u=h}while(1){v=u|0;if((b[v>>1]|0)<=-1){break}if((aQ(c[u+4>>2]|0,s|0)|0)==0){m=4224;break}else{u=u+16|0}}do{if((m|0)==4224){if((u|0)==0){break}s=u+2|0;if(((e[s>>1]|0)+l|0)>(d|0)){t=c[q>>2]|0;w=c[f>>2]|0;bN(t|0,43816,(x=i,i=i+16|0,c[x>>2]=w,c[x+8>>2]=r,x)|0)|0;k=-3;i=j;return k|0}else{c[g>>2]=f+(l<<2);c[1552]=(c[1552]|0)+(e[s>>1]|0);c[14162]=0;k=b[v>>1]|0;i=j;return k|0}}}while(0);bN(c[q>>2]|0,47480,(x=i,i=i+16|0,c[x>>2]=c[f>>2],c[x+8>>2]=r,x)|0)|0;k=-2;i=j;return k|0}}while(0);c[g>>2]=p;c[14162]=0;k=0;i=j;return k|0}}while(0);v=o<<24>>24;o=h;while(1){y=o|0;h=b[y>>1]|0;if(h<<16>>16<=-1){break}if((h<<16>>16|0)==(v|0)){m=4233;break}else{o=o+16|0}}do{if((m|0)==4233){if((o|0)==0){break}h=c[1552]|0;u=o+2|0;if(((e[u>>1]|0)+h|0)>(d|0)){r=c[q>>2]|0;l=c[f>>2]|0;bN(r|0,37208,(x=i,i=i+16|0,c[x>>2]=l,c[x+8>>2]=v,x)|0)|0;k=-3;i=j;return k|0}else{c[g>>2]=f+(h<<2);c[1552]=(c[1552]|0)+(e[u>>1]|0);c[14162]=(c[14162]|0)+1;k=b[y>>1]|0;i=j;return k|0}}}while(0);bN(c[q>>2]|0,40288,(x=i,i=i+16|0,c[x>>2]=c[f>>2],c[x+8>>2]=v,x)|0)|0;k=-2;i=j;return k|0}function st(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+16|0;f=e|0;g=a[c]|0;if((g<<24>>24|0)==58){a[f|0]=0;h=1;i=e;return h|0}else if((g<<24>>24|0)==0){h=1;i=e;return h|0}else{a[f|0]=g;g=a[c+1|0]|0;do{if((g<<24>>24|0)==58){j=1;k=4255}else if((g<<24>>24|0)==0){l=1}else{a[f+1|0]=g;m=a[c+2|0]|0;if((m<<24>>24|0)==58){j=2;k=4255;break}else if((m<<24>>24|0)==0){l=2;break}a[f+2|0]=m;m=a[c+3|0]|0;if((m<<24>>24|0)==58){j=3;k=4255;break}else if((m<<24>>24|0)==0){l=3;break}a[f+3|0]=m;m=a[c+4|0]|0;if((m<<24>>24|0)==58){j=4;k=4255;break}else if((m<<24>>24|0)==0){l=4;break}a[f+4|0]=m;m=a[c+5|0]|0;if((m<<24>>24|0)==58){j=5;k=4255;break}else if((m<<24>>24|0)==0){l=5;break}a[f+5|0]=m;m=a[c+6|0]|0;if((m<<24>>24|0)==58){j=6;k=4255;break}else if((m<<24>>24|0)==0){l=6;break}a[f+6|0]=m;m=a[c+7|0]|0;if((m<<24>>24|0)==58){j=7;k=4255;break}else if((m<<24>>24|0)==0){l=7;break}a[f+7|0]=m;m=a[c+8|0]|0;if((m<<24>>24|0)==58){j=8;k=4255;break}else if((m<<24>>24|0)==0){l=8;break}a[f+8|0]=m;m=a[c+9|0]|0;if((m<<24>>24|0)==58){j=9;k=4255;break}else if((m<<24>>24|0)==0){l=9;break}a[f+9|0]=m;m=a[c+10|0]|0;if((m<<24>>24|0)==58){j=10;k=4255;break}else if((m<<24>>24|0)==0){l=10;break}a[f+10|0]=m;m=a[c+11|0]|0;if((m<<24>>24|0)==58){j=11;k=4255;break}else if((m<<24>>24|0)==0){l=11;break}a[f+11|0]=m;m=a[c+12|0]|0;if((m<<24>>24|0)==58){j=12;k=4255;break}else if((m<<24>>24|0)==0){l=12;break}a[f+12|0]=m;m=a[c+13|0]|0;if((m<<24>>24|0)==58){j=13;k=4255;break}else if((m<<24>>24|0)==0){l=13;break}a[f+13|0]=m;m=a[c+14|0]|0;if((m<<24>>24|0)==58){j=14;k=4255;break}else if((m<<24>>24|0)==0){l=14;break}a[f+14|0]=m;m=a[c+15|0]|0;if((m<<24>>24|0)==58){j=15;k=4255;break}else if((m<<24>>24|0)==0){l=15;break}a[f+15|0]=m;h=1;i=e;return h|0}}while(0);if((k|0)==4255){a[f+j|0]=0;l=j}if((a[c+l|0]|0)==0){h=1;i=e;return h|0}j=ax(f|0,0,0)|0;f=s3(c+(l+1)|0)|0;l=on(f,0,0,0)|0;u1(f);if((l|0)==0){h=1;i=e;return h|0}n0(l,j);do{if((d|0)!=0){f=ol(b,j)|0;if((f|0)==0){break}ok(b,f)|0;oi(f)}}while(0);if((or(b,l)|0)==0){h=0;i=e;return h|0}oi(l);h=1;i=e;return h|0}return 0}function su(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=tA(a,0,49648)|0;if((e|0)==0){f=b;i=d;return f|0}else{g=b;h=e}while(1){j=tX(h)|0;if((j|0)==0){k=4288;break}e=oO(g,j)|0;if((e|0)==0){b=t9(g,j)|0;if((b|0)==0){k=4291;break}else{l=b}}else{l=e}n4(l,0);e=n7(l)|0;sN(2,53640,43784,(x=i,i=i+16|0,c[x>>2]=e,c[x+8>>2]=j,x)|0);e=tA(a,h,49648)|0;if((e|0)==0){f=l;k=4296;break}else{g=l;h=e}}if((k|0)==4291){h=n7(g)|0;sN(0,53640,47440,(x=i,i=i+16|0,c[x>>2]=h,c[x+8>>2]=j,x)|0);oi(g);f=0;i=d;return f|0}else if((k|0)==4288){oi(g);f=0;i=d;return f|0}else if((k|0)==4296){i=d;return f|0}return 0}function sv(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;d=i;i=i+136|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;l=d+48|0;m=d+56|0;n=d+64|0;o=d+72|0;p=d+80|0;q=d+88|0;r=d+96|0;s=d+104|0;t=d+112|0;u=d+120|0;v=d+128|0;tH(a,40280,n,0)|0;tK(a,37192,v,34384)|0;tG(a,31912,s,0)|0;tG(a,30480,o,0)|0;tG(a,29552,p,0)|0;tG(a,55352,q,0)|0;do{if((tG(a,54536,r,0)|0)!=0){if((tG(a,53304,r,0)|0)==0){c[r>>2]=c[r>>2]&-512;break}if((tG(a,52656,r,0)|0)==0){c[r>>2]=c[r>>2]<<1;break}if((tG(a,51968,r,0)|0)==0){c[r>>2]=c[r>>2]<<11;break}if((tG(a,51360,r,0)|0)==0){c[r>>2]=c[r>>2]<<21;break}else{c[r>>2]=0;break}}}while(0);tJ(a,50512,t,0)|0;tJ(a,49912,u,0)|0;w=0;y=0;L5981:while(1){z=y;do{z=tA(a,z,49408)|0;if((z|0)==0){A=4350;break L5981}B=tX(z)|0;}while((B|0)==0);u1(w);C=s3(B)|0;if((C|0)==0){w=0;y=z;continue}D=aZ(C|0,48928)|0;if((D|0)==0){w=C;y=z;continue}av(D|0)|0;D=c[v>>2]|0;L5989:do{if((aQ(D|0,48448)|0)==0){E=uk(C,c[r>>2]|0,c[o>>2]|0,c[p>>2]|0,c[q>>2]|0,c[t>>2]|0)|0}else{if((aQ(D|0,48024)|0)==0){E=oU(C,c[s>>2]|0,0,c[t>>2]|0)|0;break}if((aQ(D|0,47184)|0)==0){E=oz(C,c[t>>2]|0)|0;break}if((aQ(D|0,46768)|0)==0){E=oG(C,c[t>>2]|0)|0;break}if((aQ(D|0,46336)|0)==0){E=oM(C,c[t>>2]|0)|0;break}if((aQ(D|0,46016)|0)==0){F=c[o>>2]|0;G=c[p>>2]|0;H=c[q>>2]|0;I=c[t>>2]|0;c[h>>2]=I;J=ug(F,G,H,I)|0;if((J|0)==0){w=C;y=z;continue L5981}else{K=0}while(1){I=tz(a,K,46016)|0;if((I|0)==0){E=J;break L5989}tG(I,31912,j,0)|0;tG(I,39016,k,0)|0;tG(I,38800,l,0)|0;tK(I,49408,m,0)|0;tJ(I,50512,h,0)|0;H=c[m>>2]|0;if((H|0)==0){A=4328;break}G=s3(H)|0;H=(uf(J,G,c[j>>2]|0,0,c[k>>2]|0,c[l>>2]|0,c[h>>2]|0)|0)==0;u1(G);if(H){K=I}else{A=4330;break}}if((A|0)==4328){A=0;oi(J);w=C;y=z;continue L5981}else if((A|0)==4330){A=0;oi(J);w=C;y=z;continue L5981}}if((aQ(D|0,45680)|0)==0){E=ob(C,1,c[t>>2]|0)|0;break}if((aQ(D|0,45400)|0)==0){E=ob(C,2,c[t>>2]|0)|0;break}if((aQ(D|0,45120)|0)==0){E=ob(C,3,c[t>>2]|0)|0;break}if((aQ(D|0,44792)|0)==0){E=ob(C,4,c[t>>2]|0)|0;break}if((aQ(D|0,44480)|0)==0){E=ob(C,4,c[t>>2]|0)|0;break}if((aQ(D|0,44240)|0)==0){E=ob(C,5,c[t>>2]|0)|0;break}if((aQ(D|0,43600)|0)==0){E=ob(C,0,c[t>>2]|0)|0;break}if((aQ(D|0,43312)|0)==0){E=ob(C,12,c[t>>2]|0)|0;break}if((aQ(D|0,34384)|0)!=0){w=C;y=z;continue L5981}E=on(C,c[s>>2]|0,0,c[t>>2]|0)|0}}while(0);if((E|0)==0){w=C;y=z}else{break}}if((A|0)==4350){c[b>>2]=0;u1(w);if((c[u>>2]|0)!=0){L=0;i=d;return L|0}sL(0,42968,(x=i,i=i+8|0,c[x>>2]=c[n>>2],x)|0);L=1;i=d;return L|0}n0(E,c[n>>2]|0);do{if((c[o>>2]|0)==0){if((c[p>>2]|0)!=0){A=4355;break}if((c[q>>2]|0)!=0){A=4355}}else{A=4355}}while(0);if((A|0)==4355){w=n8(E)|0;y=c[o>>2]|0;o=c[p>>2]|0;p=c[q>>2]|0;n5(E,w,y,o,p)|0}p=c[v>>2]|0;v=c[E+28>>2]|0;o=E+32|0;y=c[o>>2]|0;w=E+36|0;q=c[w>>2]|0;s=E+40|0;K=c[s>>2]|0;h=(c[t>>2]|0)!=0?42280:41976;sN(2,53640,42608,(x=i,i=i+64|0,c[x>>2]=c[n>>2],c[x+8>>2]=p,c[x+16>>2]=v,c[x+24>>2]=y,c[x+32>>2]=q,c[x+40>>2]=K,c[x+48>>2]=h,c[x+56>>2]=C,x)|0);u1(C);tG(a,40696,e,0)|0;tG(a,40048,f,0)|0;tG(a,39736,g,0)|0;C=c[e>>2]|0;if((C|0)==0){M=c[o>>2]|0}else{M=C}c[e>>2]=M;C=c[f>>2]|0;if((C|0)==0){N=c[w>>2]|0}else{N=C}c[f>>2]=N;C=c[g>>2]|0;if((C|0)==0){O=c[s>>2]|0}else{O=C}c[g>>2]=O;n6(E,M,N,O);do{if((c[o>>2]|0)==(c[e>>2]|0)){if((c[w>>2]|0)!=(c[f>>2]|0)){A=4365;break}if((c[s>>2]|0)!=(c[g>>2]|0)){A=4365}}else{A=4365}}while(0);if((A|0)==4365){A=n7(E)|0;g=c[E+44>>2]|0;s=c[E+48>>2]|0;f=c[E+52>>2]|0;sN(2,53640,39336,(x=i,i=i+32|0,c[x>>2]=A,c[x+8>>2]=g,c[x+16>>2]=s,c[x+24>>2]=f,x)|0)}f=su(a,E)|0;if((f|0)!=0){c[b>>2]=f;L=0;i=d;return L|0}c[b>>2]=0;if((c[u>>2]|0)!=0){L=0;i=d;return L|0}sL(0,41360,(x=i,i=i+8|0,c[x>>2]=c[n>>2],x)|0);L=1;i=d;return L|0}function sw(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+16|0;d=b|0;e=b+8|0;f=oq()|0;g=tz(a,0,40976)|0;if((g|0)==0){i=b;return f|0}else{h=g}do{tH(h,40280,e,0)|0;do{if((ol(f,c[e>>2]|0)|0)==0){g=(sv(h,d)|0)==0;j=c[d>>2]|0;if(!(g&(j|0)!=0)){break}or(f,j)|0}}while(0);h=tz(a,h,40976)|0;}while((h|0)!=0);i=b;return f|0}function sx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+32|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=(d|0)!=0;if(k){c[d>>2]=0}l=tz(b,0,49528)|0;if((l|0)==0){m=0;i=e;return m|0}L6093:do{if(k){n=l;while(1){tK(n,53624,f,0)|0;if((tG(n,47432,h,0)|0)!=0){tG(n,43776,h,0)|0}do{if((tG(n,40272,j,0)|0)==0){c[j>>2]=c[j>>2]<<20}else{if((tG(n,37184,j,0)|0)==0){c[j>>2]=c[j>>2]<<10;break}else{tG(n,34376,j,65536)|0;break}}}while(0);tH(n,31896,g,0)|0;o=s3(c[f>>2]|0)|0;p=c[j>>2]|0;q=(o|0)==0;sN(2,30464,29512,(x=i,i=i+24|0,c[x>>2]=c[h>>2],c[x+8>>2]=p,c[x+16>>2]=q?55336:o,x)|0);p=ng(c[h>>2]|0,c[j>>2]|0,1)|0;if((p|0)==0){r=o;s=4409;break L6093}nA(p,c[g>>2]&255);np(p,0);nD(a,p,1);if((c[h>>2]|0)==0){c[d>>2]=p}if(!q){if((sF(p,o)|0)!=0){t=o;s=4412;break L6093}}u1(o);o=tz(b,n,49528)|0;if((o|0)==0){m=0;break}else{n=o}}i=e;return m|0}else{n=l;while(1){tK(n,53624,f,0)|0;if((tG(n,47432,h,0)|0)!=0){tG(n,43776,h,0)|0}do{if((tG(n,40272,j,0)|0)==0){c[j>>2]=c[j>>2]<<20}else{if((tG(n,37184,j,0)|0)==0){c[j>>2]=c[j>>2]<<10;break}else{tG(n,34376,j,65536)|0;break}}}while(0);tH(n,31896,g,0)|0;o=s3(c[f>>2]|0)|0;p=c[j>>2]|0;q=(o|0)==0;sN(2,30464,29512,(x=i,i=i+24|0,c[x>>2]=c[h>>2],c[x+8>>2]=p,c[x+16>>2]=q?55336:o,x)|0);p=ng(c[h>>2]|0,c[j>>2]|0,1)|0;if((p|0)==0){r=o;s=4409;break L6093}nA(p,c[g>>2]&255);np(p,0);nD(a,p,1);if(!q){if((sF(p,o)|0)!=0){t=o;s=4412;break L6093}}u1(o);o=tz(b,n,49528)|0;if((o|0)==0){m=0;break}else{n=o}}i=e;return m|0}}while(0);if((s|0)==4409){sL(0,54488,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);u1(r);m=1;i=e;return m|0}else if((s|0)==4412){sL(0,53264,(x=i,i=i+8|0,c[x>>2]=t,x)|0);u1(t);m=1;i=e;return m|0}return 0}function sy(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+32|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=tz(b,0,52648)|0;if((j|0)==0){k=0;i=d;return k|0}else{l=j}while(1){tK(l,53624,e,0)|0;if((tG(l,47432,g,0)|0)!=0){tG(l,43776,g,0)|0}do{if((tG(l,40272,h,0)|0)==0){c[h>>2]=c[h>>2]<<20}else{if((tG(l,37184,h,0)|0)==0){c[h>>2]=c[h>>2]<<10;break}else{tG(l,34376,h,65536)|0;break}}}while(0);tH(l,31896,f,0)|0;m=s3(c[e>>2]|0)|0;j=c[h>>2]|0;n=(m|0)!=0;sN(2,51960,29512,(x=i,i=i+24|0,c[x>>2]=c[g>>2],c[x+8>>2]=j,c[x+16>>2]=n?m:55336,x)|0);j=ng(c[g>>2]|0,c[h>>2]|0,1)|0;if((j|0)==0){o=4429;break}nA(j,c[f>>2]&255);np(j,1);nD(a,j,1);if(n){if((sF(j,m)|0)!=0){o=4432;break}}u1(m);j=tz(b,l,52648)|0;if((j|0)==0){k=0;o=4435;break}else{l=j}}if((o|0)==4435){i=d;return k|0}else if((o|0)==4432){sL(0,51328,(x=i,i=i+8|0,c[x>>2]=m,x)|0);u1(m);k=1;i=d;return k|0}else if((o|0)==4429){sL(0,54488,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);u1(m);k=1;i=d;return k|0}return 0}function sz(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0;d=i;i=i+72|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=d+32|0;k=d+40|0;l=d+48|0;m=d+56|0;n=d+64|0;o=tz(a,0,49440)|0;tK(o,53600,m,47416)|0;p=(o|0)==0;L6162:do{if((b|0)==0){L6170:do{if(!p){q=o;while(1){r=c[m>>2]|0;if((aQ(r|0,47416)|0)==0){s=q;break L6162}if((aQ(r|0,49400)|0)==0){break}r=tz(a,q,49440)|0;tK(r,53600,m,47416)|0;if((r|0)==0){break L6170}else{q=r}}if((q|0)!=0){s=q;break L6162}}}while(0);c[m>>2]=47416;s=0}else{L6164:do{if(p){t=0}else{r=o;while(1){if((aQ(b|0,c[m>>2]|0)|0)==0){t=r;break L6164}u=tz(a,r,49440)|0;tK(u,53600,m,47416)|0;if((u|0)==0){t=0;break}else{r=u}}}}while(0);c[m>>2]=b;s=t}}while(0);tK(s,43752,n,0)|0;tH(s,40240,h,4)|0;tH(s,37152,j,3)|0;tH(s,34352,f,512)|0;tH(s,31888,g,384)|0;tH(s,30456,e,1)|0;t=k|0;tI(s,29488,t,1)|0;b=k+4|0;tI(s,55320,b,1)|0;k=l|0;tI(s,54472,k,1)|0;a=l+4|0;tI(s,53248,a,1)|0;l=c[n>>2]|0;o=c[h>>2]|0;p=c[j>>2]|0;r=c[f>>2]|0;q=c[g>>2]|0;u=c[e>>2]|0;v=c[t>>2]|0;w=c[b>>2]|0;y=c[k>>2]|0;z=c[a>>2]|0;sN(2,52632,51872,(x=i,i=i+88|0,c[x>>2]=c[m>>2],c[x+8>>2]=(l|0)!=0?l:51320,c[x+16>>2]=o,c[x+24>>2]=p,c[x+32>>2]=r,c[x+40>>2]=q,c[x+48>>2]=u,c[x+56>>2]=v,c[x+64>>2]=w,c[x+72>>2]=y,c[x+80>>2]=z,x)|0);z=c[m>>2]|0;L6178:do{if((aQ(z|0,50504)|0)==0){sL(0,49864,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0)}else{do{if((aQ(z|0,49400)|0)==0){m=uU(s)|0;if((m|0)!=0){A=m;break}sL(0,48888,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);break L6178}else{if((aQ(z|0,47416)|0)!=0){sL(0,47984,(x=i,i=i+8|0,c[x>>2]=z,x)|0);break L6178}m=uD(s)|0;if((m|0)!=0){A=m;break}sL(0,48408,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);break L6178}}while(0);m=c[n>>2]|0;if((m|0)!=0){uJ(A,m)|0}uw(A,c[e>>2]|0);uv(A,c[f>>2]|0,c[g>>2]|0);ux(A,c[h>>2]|0,c[j>>2]|0);uu(A,c[t>>2]|0,c[b>>2]|0,c[k>>2]|0,c[a>>2]|0);B=A;i=d;return B|0}}while(0);sL(0,47160,(x=i,i=i+1|0,i=i+7>>3<<3,c[x>>2]=0,x)|0);B=0;i=d;return B|0}function sA(){c[14450]=0;return}function sB(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=c[14450]|0;if(e>>>0>15){f=1;return f|0}c[57808+(e*12|0)>>2]=a;c[57812+(e*12|0)>>2]=(b|0)!=0;c[57816+(e*12|0)>>2]=d;c[14450]=e+1;f=0;return f|0}function sC(c,f,g){c=c|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;h=i;i=i+280|0;j=h|0;k=h+8|0;l=h+16|0;m=l+1|0;n=l+2|0;o=l|0;p=l+260|0;q=l+4|0;r=l+5|0;s=0;t=1;L6203:while(1){L6205:while(1){u=aT(c|0)|0;if((u|0)==(-1|0)){v=0;w=4505;break L6203}else if((u|0)==13|(u|0)==10){continue}else if((u|0)!=58){while(1){u=aT(c|0)|0;if((u|0)==(-1|0)|(u|0)==13|(u|0)==10){continue L6205}}}if((sD(c,m)|0)!=0){v=0;w=4497;break L6203}if((sD(c,j)|0)!=0){v=0;w=4503;break L6203}if((sD(c,k)|0)!=0){v=0;w=4498;break L6203}b[n>>1]=(d[j]|0)<<8|(d[k]|0);if((sD(c,o)|0)==0){x=0}else{v=0;w=4507;break L6203}while(1){if(x>>>0>=(d[m]|0)>>>0){break}if((sD(c,l+4+x|0)|0)==0){x=x+1|0}else{v=0;w=4504;break L6203}}if((sD(c,p)|0)!=0){v=0;w=4499;break L6203}do{u=aT(c|0)|0}while(!((u|0)==(-1|0)|(u|0)==13|(u|0)==10));u=a[p]|0;y=a[m]|0;z=e[n>>1]|0;A=y&255;B=a[o]|0;C=z+A+(z>>>8)+(B&255)&255;D=y<<24>>24==0;if(D){E=C}else{F=0;G=C;while(1){C=(a[l+4+F|0]|0)+G&255;H=F+1|0;if(H>>>0<A>>>0){F=H;G=C}else{E=C;break}}}if(u<<24>>24!=(-E&255)<<24>>24){v=1;w=4502;break L6203}if((B<<24>>24|0)==2){w=4493;break}else if((B<<24>>24|0)==1){v=0;w=4501;break L6203}else if((B<<24>>24|0)==4){w=4491;break}else if((B<<24>>24|0)!=0){continue}if(D){continue}if(t){G=0;while(1){b3[g&63](f,G+s+z|0,a[l+4+G|0]|0);F=G+1|0;if(F>>>0<A>>>0){G=F}else{continue L6205}}}else{G=0;while(1){b3[g&63](f,(z+G&65535)+s|0,a[l+4+G|0]|0);D=G+1|0;if(D>>>0<A>>>0){G=D}else{continue L6205}}}}if((w|0)==4493){w=0;if(y<<24>>24!=2){v=1;w=4500;break}s=((d[q]|0)<<8|(d[r]|0))<<4;t=0;continue}else if((w|0)==4491){w=0;if(y<<24>>24!=2){v=1;w=4506;break}s=((d[q]|0)<<8|(d[r]|0))<<16;t=1;continue}}if((w|0)==4507){i=h;return v|0}else if((w|0)==4504){i=h;return v|0}else if((w|0)==4505){i=h;return v|0}else if((w|0)==4500){i=h;return v|0}else if((w|0)==4501){i=h;return v|0}else if((w|0)==4498){i=h;return v|0}else if((w|0)==4499){i=h;return v|0}else if((w|0)==4506){i=h;return v|0}else if((w|0)==4502){i=h;return v|0}else if((w|0)==4503){i=h;return v|0}else if((w|0)==4497){i=h;return v|0}return 0}function sD(b,c){b=b|0;c=c|0;var e=0,f=0;a[c]=0;e=aT(b|0)|0;do{if((e-48|0)>>>0<10){a[c]=((d[c]|0)<<4|e+208)&255}else{if((e-65|0)>>>0<6){a[c]=((d[c]|0)<<4|e+201)&255;break}if((e-97|0)>>>0<6){a[c]=((d[c]|0)<<4|e+169)&255;break}else{f=1;return f|0}}}while(0);e=aT(b|0)|0;if((e-48|0)>>>0<10){a[c]=((d[c]|0)<<4|e+208)&255;f=0;return f|0}if((e-65|0)>>>0<6){a[c]=((d[c]|0)<<4|e+201)&255;f=0;return f|0}if((e-97|0)>>>0>=6){f=1;return f|0}a[c]=((d[c]|0)<<4|e+169)&255;f=0;return f|0}function sE(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;f=i;i=i+272|0;g=f|0;h=g|0;j=g+8|0;k=g+1|0;l=g+4|0;m=g+268|0;L6274:while(1){n=aT(b|0)|0;L6276:do{if((n|0)==83){o=aT(b|0)|0;do{if((o-48|0)>>>0<10){p=o+208&255}else{if((o-65|0)>>>0<6){p=o+201&255;break}if((o-97|0)>>>0>=6){break L6276}p=o+169&255}}while(0);a[h]=p;o=c[5880+((p&255)<<2)>>2]|0;c[j>>2]=o;q=aT(b|0)|0;do{if((q-48|0)>>>0<10){r=q+208&255}else{if((q-65|0)>>>0<6){r=q+201&255;break}if((q-97|0)>>>0>=6){s=0;t=4607;break L6274}r=q+169&255}}while(0);q=aT(b|0)|0;do{if((q-48|0)>>>0<10){u=q+208&255}else{if((q-65|0)>>>0<6){u=q+201&255;break}if((q-97|0)>>>0>=6){s=0;t=4599;break L6274}u=q+169&255}}while(0);q=u&15|r<<4;a[k]=q;v=q&255;q=o+1|0;if(v>>>0<q>>>0){s=0;t=4600;break L6274}w=v-q&255;a[k]=w;c[l>>2]=0;q=0;v=0;do{x=aT(b|0)|0;do{if((x-48|0)>>>0<10){y=x+208&255}else{if((x-65|0)>>>0<6){y=x+201&255;break}if((x-97|0)>>>0>=6){s=0;t=4604;break L6274}y=x+169&255}}while(0);x=aT(b|0)|0;do{if((x-48|0)>>>0<10){z=x+208&255}else{if((x-65|0)>>>0<6){z=x+201&255;break}if((x-97|0)>>>0>=6){s=0;t=4598;break L6274}z=x+169&255}}while(0);v=(z&15|y<<4)&255|v<<8;c[l>>2]=v;q=q+1|0;}while(q>>>0<o>>>0);if(w<<24>>24==0){A=0}else{o=0;while(1){q=g+12+o|0;v=aT(b|0)|0;do{if((v-48|0)>>>0<10){B=v+208&255}else{if((v-65|0)>>>0<6){B=v+201&255;break}if((v-97|0)>>>0>=6){s=0;t=4605;break L6274}B=v+169&255}}while(0);v=aT(b|0)|0;do{if((v-48|0)>>>0<10){C=v+208&255}else{if((v-65|0)>>>0<6){C=v+201&255;break}if((v-97|0)>>>0>=6){s=0;t=4601;break L6274}C=v+169&255}}while(0);a[q]=C&15|B<<4;v=o+1|0;x=a[k]|0;if(v>>>0<(x&255)>>>0){o=v}else{A=x;break}}}o=aT(b|0)|0;do{if((o-48|0)>>>0<10){D=o+208&255}else{if((o-65|0)>>>0<6){D=o+201&255;break}if((o-97|0)>>>0>=6){s=0;t=4602;break L6274}D=o+169&255}}while(0);o=aT(b|0)|0;do{if((o-48|0)>>>0<10){E=o+208&255}else{if((o-65|0)>>>0<6){E=o+201&255;break}if((o-97|0)>>>0>=6){s=0;t=4608;break L6274}E=o+169&255}}while(0);o=E&15|D<<4;a[m]=o;do{w=aT(b|0)|0}while(!((w|0)==(-1|0)|(w|0)==13|(w|0)==10));w=A&255;x=c[l>>2]|0;v=(c[j>>2]|0)+1+w+x+(x>>>8)+(x>>>16)+(x>>>24)&255;F=A<<24>>24==0;if(F){G=v}else{H=0;I=v;while(1){v=(a[g+12+H|0]|0)+I&255;J=H+1|0;if(J>>>0<w>>>0){H=J;I=v}else{G=v;break}}}if(o<<24>>24!=~G<<24>>24){s=1;t=4597;break L6274}I=a[h]|0;if((I<<24>>24|0)==9|(I<<24>>24|0)==8|(I<<24>>24|0)==7){s=0;t=4606;break L6274}else if(!((I<<24>>24|0)==1|(I<<24>>24|0)==2|(I<<24>>24|0)==3)){continue L6274}if(F){continue L6274}else{K=0}while(1){b3[e&63](d,x+K|0,a[g+12+K|0]|0);I=K+1|0;if(I>>>0<w>>>0){K=I}else{continue L6274}}}else if((n|0)==(-1|0)){s=0;t=4603;break L6274}else if((n|0)==13|(n|0)==10){continue L6274}}while(0);while(1){n=aT(b|0)|0;if((n|0)==(-1|0)|(n|0)==13|(n|0)==10){continue L6274}}}if((t|0)==4597){i=f;return s|0}else if((t|0)==4598){i=f;return s|0}else if((t|0)==4599){i=f;return s|0}else if((t|0)==4600){i=f;return s|0}else if((t|0)==4601){i=f;return s|0}else if((t|0)==4602){i=f;return s|0}else if((t|0)==4603){i=f;return s|0}else if((t|0)==4604){i=f;return s|0}else if((t|0)==4605){i=f;return s|0}else if((t|0)==4606){i=f;return s|0}else if((t|0)==4607){i=f;return s|0}else if((t|0)==4608){i=f;return s|0}return 0}function sF(a,b){a=a|0;b=b|0;var d=0,e=0;d=aZ(b|0,49208)|0;if((d|0)==0){e=1;return e|0}bK(c[a+44>>2]|0,1,c[a+40>>2]|0,d|0)|0;av(d|0)|0;e=0;return e|0}function sG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;sN(2,53584,40200,(x=i,i=i+16|0,c[x>>2]=b,c[x+8>>2]=d,x)|0);f=aZ(b|0,49208|0)|0;if((f|0)==0){g=1;i=e;return g|0}b=aT(f|0)|0;if((b|0)!=-1){h=d;d=b&255;while(1){nI(a,h,d);b=aT(f|0)|0;if((b|0)==-1){break}else{h=h+1|0;d=b&255}}}av(f|0)|0;g=0;i=e;return g|0}function sH(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;if((d|0)==0){h=1;i=g;return h|0}if((e|0)==0){j=d;k=0;l=4625}else{if((aQ(e|0,37144)|0)==0){j=d;k=0;l=4625}else{m=e}}do{if((l|0)==4625){while(1){l=0;e=a[d+k|0]|0;if((e<<24>>24|0)==0){break}else if((e<<24>>24|0)==46){e=k+1|0;j=d+e|0;k=e;l=4625;continue}else{j=j;k=k+1|0;l=4625;continue}}if((ve(j|0,34344)|0)==0){m=34344;break}if((ve(j|0,31880)|0)==0){m=34344;break}if((ve(j|0,30448)|0)==0){m=30448;break}if((ve(j|0,29480)|0)==0){m=55312;break}else{h=1}i=g;return h|0}}while(0);if((aQ(m|0,55312)|0)==0){h=sG(b,d,f)|0;i=g;return h|0}if((aQ(m|0,34344)|0)==0){sN(2,53584,47392,(x=i,i=i+8|0,c[x>>2]=d,x)|0);f=aZ(d|0,49208)|0;if((f|0)==0){h=1;i=g;return h|0}j=sC(f,b,40)|0;av(f|0)|0;h=j;i=g;return h|0}if((aQ(m|0,30448)|0)!=0){h=1;i=g;return h|0}sN(2,53584,43728,(x=i,i=i+8|0,c[x>>2]=d,x)|0);m=aZ(d|0,49208)|0;if((m|0)==0){h=1;i=g;return h|0}d=sE(m,b,40)|0;av(m|0)|0;h=d;i=g;return h|0}function sI(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+24|0;e=d|0;f=d+8|0;g=d+16|0;h=0;j=0;L6436:while(1){k=h;do{k=tz(b,k,54464)|0;if((k|0)==0){break L6436}tK(k,53240,e,55312)|0;tK(k,52624,f,0)|0;if((tG(k,51864,g,0)|0)!=0){tG(k,51304,g,0)|0}l=c[f>>2]|0;}while((l|0)==0);m=s3(l)|0;if((sH(a,m,c[e>>2]|0,c[g>>2]|0)|0)==0){n=j}else{sL(0,50464,(x=i,i=i+8|0,c[x>>2]=m,x)|0);n=1}u1(m);h=k;j=n}i=d;return j|0}function sJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=aZ(a|0,49088)|0;if((d|0)==0){e=1;return e|0}a=c[14450]|0;if(a>>>0>15){av(d|0)|0;e=1;return e|0}else{c[57808+(a*12|0)>>2]=d;c[57812+(a*12|0)>>2]=1;c[57816+(a*12|0)>>2]=b;c[14450]=a+1;e=0;return e|0}return 0}function sK(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=c[14450]|0;e=0;while(1){if(e>>>0>=d>>>0){f=4672;break}if((c[57808+(e*12|0)>>2]|0)==(a|0)){break}else{e=e+1|0}}if((f|0)==4672){return}c[57816+(e*12|0)>>2]=b;return}function sL(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+16|0;f=e|0;g=c[14450]|0;if((g|0)==0){i=e;return}h=f|0;j=f;f=0;k=g;while(1){if((c[57816+(f*12|0)>>2]|0)>>>0<a>>>0){l=k}else{c[j>>2]=d;c[j+4>>2]=0;g=57808+(f*12|0)|0;m=c[g>>2]|0;by(m|0,b|0,h|0)|0;m=c[g>>2]|0;ay(m|0)|0;l=c[14450]|0}m=f+1|0;if(m>>>0<l>>>0){f=m;k=l}else{break}}i=e;return}function sM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=c[14450]|0;if((e|0)==0){return}else{f=0;g=e}while(1){if((c[57816+(f*12|0)>>2]|0)>>>0<a>>>0){h=g}else{e=57808+(f*12|0)|0;i=c[e>>2]|0;by(i|0,b|0,d|0)|0;i=c[e>>2]|0;ay(i|0)|0;h=c[14450]|0}i=f+1|0;if(i>>>0<h>>>0){f=i;g=h}else{break}}return}function sN(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+16|0;g=f|0;h=(b|0)==0?58248:b;b=c[14450]|0;if((b|0)==0){i=f;return}j=g|0;k=g;g=0;l=b;while(1){if((c[57816+(g*12|0)>>2]|0)>>>0<a>>>0){m=l}else{c[k>>2]=e;c[k+4>>2]=0;b=57808+(g*12|0)|0;n=c[b>>2]|0;bN(n|0,47360,(x=i,i=i+8|0,c[x>>2]=h,x)|0)|0;n=c[b>>2]|0;by(n|0,d|0,j|0)|0;n=c[b>>2]|0;ay(n|0)|0;m=c[14450]|0}n=g+1|0;if(n>>>0<m>>>0){g=n;l=m}else{break}}i=f;return}function sO(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c[d+40>>2]=0;b[d+44>>1]=0;e=d+48|0;c[e>>2]=0;f=d+52|0;c[f>>2]=0;a[d+56|0]=0;c[d+60>>2]=0;u6(d|0,0,38);d=u2(0,120)|0;g=d;if((d|0)==0){return}c[f>>2]=g;f=6328;d=10;h=c[e>>2]|0;while(1){i=f|0;L6501:do{if((h|0)==0){j=0}else{k=h;while(1){l=k-1|0;m=g+(l*12|0)|0;if((aQ(c[i>>2]|0,c[m>>2]|0)|0)>-1){j=k;break L6501}n=g+(k*12|0)|0;o=m;c[n>>2]=c[o>>2];c[n+4>>2]=c[o+4>>2];c[n+8>>2]=c[o+8>>2];if((l|0)==0){j=0;break}else{k=l}}}}while(0);i=g+(j*12|0)|0;k=f;c[i>>2]=c[k>>2];c[i+4>>2]=c[k+4>>2];c[i+8>>2]=c[k+8>>2];k=h+1|0;c[e>>2]=k;i=d-1|0;if((i|0)==0){break}else{f=f+12|0;d=i;h=k}}return}function sP(a,b,d){a=a|0;b=b|0;d=d|0;c[a>>2]=d;c[a+4>>2]=b;return}function sQ(a,b,d){a=a|0;b=b|0;d=d|0;c[a+8>>2]=d;c[a+12>>2]=b;return}function sR(a,b,d){a=a|0;b=b|0;d=d|0;c[a+16>>2]=b;c[a+20>>2]=d;return}function sS(a,b,d){a=a|0;b=b|0;d=d|0;c[a+24>>2]=b;c[a+28>>2]=d;return}function sT(a,b){a=a|0;b=b|0;c[a+32>>2]=b;return}function sU(b,c){b=b|0;c=c|0;a[b+56|0]=(c|0)!=0|0;return}function sV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=a+52|0;f=a+48|0;a=u2(c[e>>2]|0,((c[f>>2]|0)+d|0)*12|0)|0;g=a;if((a|0)==0){h=1;return h|0}c[e>>2]=g;if((d|0)==0){h=0;return h|0}e=b;b=d;d=c[f>>2]|0;while(1){a=e|0;L15:do{if((d|0)==0){i=0}else{j=d;while(1){k=j-1|0;l=g+(k*12|0)|0;if((aQ(c[a>>2]|0,c[l>>2]|0)|0)>-1){i=j;break L15}m=g+(j*12|0)|0;n=l;c[m>>2]=c[n>>2];c[m+4>>2]=c[n+4>>2];c[m+8>>2]=c[n+8>>2];if((k|0)==0){i=0;break}else{j=k}}}}while(0);a=g+(i*12|0)|0;j=e;c[a>>2]=c[j>>2];c[a+4>>2]=c[j+4>>2];c[a+8>>2]=c[j+8>>2];j=d+1|0;c[f>>2]=j;a=b-1|0;if((a|0)==0){h=0;break}else{e=e+12|0;b=a;d=j}}return h|0}function sW(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=a+52|0;d=a+48|0;a=u2(c[b>>2]|0,((c[d>>2]|0)*12|0)+48|0)|0;e=a;if((a|0)==0){f=1;return f|0}c[b>>2]=e;b=c[d>>2]|0;if((b|0)==0){c[a>>2]=c[1570];c[a+4>>2]=c[1571];c[a+8>>2]=c[1572];a=b+1|0;c[d>>2]=a;g=a;h=26}else{a=c[1570]|0;i=b;while(1){j=i-1|0;k=e+(j*12|0)|0;if((aQ(a|0,c[k>>2]|0)|0)>-1){l=i;break}m=e+(i*12|0)|0;n=k;c[m>>2]=c[n>>2];c[m+4>>2]=c[n+4>>2];c[m+8>>2]=c[n+8>>2];if((j|0)==0){l=0;break}else{i=j}}i=e+(l*12|0)|0;c[i>>2]=c[1570];c[i+4>>2]=c[1571];c[i+8>>2]=c[1572];i=b+1|0;c[d>>2]=i;if((i|0)==0){o=0}else{g=i;h=26}}L32:do{if((h|0)==26){i=c[1573]|0;l=g;while(1){a=l-1|0;j=e+(a*12|0)|0;if((aQ(i|0,c[j>>2]|0)|0)>-1){o=l;break L32}n=e+(l*12|0)|0;m=j;c[n>>2]=c[m>>2];c[n+4>>2]=c[m+4>>2];c[n+8>>2]=c[m+8>>2];if((a|0)==0){o=0;break}else{l=a}}}}while(0);g=e+(o*12|0)|0;c[g>>2]=c[1573];c[g+4>>2]=c[6296>>2];c[g+8>>2]=c[6300>>2];g=b+2|0;c[d>>2]=g;L38:do{if((g|0)==0){p=0}else{o=c[1576]|0;h=g;while(1){l=h-1|0;i=e+(l*12|0)|0;if((aQ(o|0,c[i>>2]|0)|0)>-1){p=h;break L38}a=e+(h*12|0)|0;m=i;c[a>>2]=c[m>>2];c[a+4>>2]=c[m+4>>2];c[a+8>>2]=c[m+8>>2];if((l|0)==0){p=0;break}else{h=l}}}}while(0);g=e+(p*12|0)|0;c[g>>2]=c[1576];c[g+4>>2]=c[6308>>2];c[g+8>>2]=c[6312>>2];g=b+3|0;c[d>>2]=g;L44:do{if((g|0)==0){q=0}else{p=c[1579]|0;h=g;while(1){o=h-1|0;l=e+(o*12|0)|0;if((aQ(p|0,c[l>>2]|0)|0)>-1){q=h;break L44}m=e+(h*12|0)|0;a=l;c[m>>2]=c[a>>2];c[m+4>>2]=c[a+4>>2];c[m+8>>2]=c[a+8>>2];if((o|0)==0){q=0;break}else{h=o}}}}while(0);g=e+(q*12|0)|0;c[g>>2]=c[1579];c[g+4>>2]=c[6320>>2];c[g+8>>2]=c[6324>>2];c[d>>2]=b+4;f=0;return f|0}function sX(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=a[b]|0;if(d<<24>>24==0){e=0;return e|0}else{f=b;g=d}while(1){if((aQ(f|0,c|0)|0)==0){e=1;h=47;break}else{i=f;j=g}while(1){if((j<<24>>24|0)==46|(j<<24>>24|0)==0){break}d=i+1|0;i=d;j=a[d]|0}d=j<<24>>24==46?i+1|0:i;b=a[d]|0;if(b<<24>>24==0){e=0;h=48;break}else{f=d;g=b}}if((h|0)==47){return e|0}else if((h|0)==48){return e|0}return 0}function sY(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+8|0;f=e|0;g=ax(b|0,f|0,0)|0;h=c[f>>2]|0;do{if((h|0)==(b|0)){j=1}else{if((a[h]|0)!=0){j=1;break}c[d>>2]=g;j=0}}while(0);i=e;return j|0}function sZ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+8|0;f=e|0;g=aA(b|0,f|0,0)|0;h=c[f>>2]|0;do{if((h|0)==(b|0)){j=1}else{if((a[h]|0)!=0){j=1;break}c[d>>2]=g;j=0}}while(0);i=e;return j|0}function s_(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;i=i+8|0;f=e|0;do{if((b|0)==0){g=59}else{if((a[b]|0)==0){g=59;break}if((aQ(b|0,48608)|0)==0){c[d>>2]=1;h=0;break}if((aQ(b|0,53520)|0)==0){c[d>>2]=0;h=0;break}j=ax(b|0,f|0,0)|0;k=c[f>>2]|0;if((k|0)==(b|0)){h=1;break}if((a[k]|0)!=0){h=1;break}c[d>>2]=(j|0)!=0;h=0}}while(0);if((g|0)==59){c[d>>2]=0;h=0}i=e;return h|0}function s$(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+16|0;h=g|0;j=g+8|0;k=c[b>>2]|0;c[j>>2]=k;l=s8(k,e,j)|0;e=s6(l,47304,47304)|0;k=ax(e|0,h|0,0)|0;m=c[h>>2]|0;do{if((m|0)!=(e|0)){if((a[m]|0)!=0){break}c[d>>2]=k;u1(l);c[b>>2]=s7(c[j>>2]|0,f)|0;n=0;i=g;return n|0}}while(0);u1(l);n=1;i=g;return n|0}function s0(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+8|0;g=f|0;if((s$(a,g,d,e)|0)!=0){h=1;i=f;return h|0}c[b>>2]=c[g>>2];h=0;i=f;return h|0}function s1(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=u8(b|0)|0;while(1){if((e|0)==0){f=0;break}g=e-1|0;if((a[b+g|0]|0)==47){e=g}else{h=83;break}}do{if((h|0)==83){if((e|0)==1){if((a[b]|0)==46){f=0;break}}else if((e|0)==0){f=0;break}g=u0(e+1|0)|0;if((g|0)==0){i=1;return i|0}else{u7(g|0,b|0,e)|0;a[g+e|0]=0;f=g;break}}}while(0);e=u2(c[14430]|0,(c[14432]<<2)+4|0)|0;b=e;if((e|0)==0){u1(f);i=1;return i|0}e=c[14432]|0;if((d|0)==0){if((e|0)!=0){d=e;while(1){h=d-1|0;c[b+(d<<2)>>2]=c[b+(h<<2)>>2];if((h|0)==0){break}else{d=h}}}c[b>>2]=f}else{c[b+(e<<2)>>2]=f}c[14432]=e+1;c[14430]=b;i=0;return i|0}function s2(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=a[b]|0;if((d<<24>>24|0)==43){e=1;f=b+1|0}else if((d<<24>>24|0)==45){e=0;f=b+1|0}else if((d<<24>>24|0)==61){d=b+1|0;g=c[14430]|0;if((c[14432]|0)==0){h=g}else{i=0;j=g;while(1){u1(c[j+(i<<2)>>2]|0);g=i+1|0;k=c[14430]|0;if(g>>>0<(c[14432]|0)>>>0){i=g;j=k}else{h=k;break}}}u1(h);c[14432]=0;c[14430]=0;e=1;f=d}else{e=1;f=b}return s1(f,e)|0}function s3(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((b|0)==0){d=0;return d|0}e=u8(b|0)|0;f=u0(e+1|0)|0;if((f|0)==0){d=0;return d|0}u7(f|0,b|0,e)|0;a[f+e|0]=0;if((a[f]|0)==47|(c[14432]|0)==0){d=f;return d|0}else{g=0}while(1){e=c[(c[14430]|0)+(g<<2)>>2]|0;if((e|0)==0){b=u8(f|0)|0;h=u0(b+1|0)|0;if((h|0)==0){i=114;break}u7(h|0,f|0,b)|0;a[h+b|0]=0;j=h}else{h=u8(e|0)|0;b=u8(f|0)|0;k=b+h|0;l=u0(k+2|0)|0;if((l|0)==0){i=114;break}u7(l|0,e|0,h)|0;a[l+h|0]=47;e=l+(h+1)|0;u7(e|0,f|0,b)|0;a[l+(k+1)|0]=0;j=l}m=aZ(j|0,48584)|0;if((m|0)!=0){i=116;break}u1(j);l=g+1|0;if(l>>>0<(c[14432]|0)>>>0){g=l}else{d=f;i=124;break}}if((i|0)==114){u1(f);d=0;return d|0}else if((i|0)==116){av(m|0)|0;u1(f);d=j;return d|0}else if((i|0)==124){return d|0}return 0}function s4(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=0;while(1){e=tA(b,d,53504)|0;if((e|0)==0){f=0;g=136;break}h=tX(e)|0;if((h|0)==0){f=1;g=137;break}i=a[h]|0;if((i<<24>>24|0)==43){j=1;k=h+1|0}else if((i<<24>>24|0)==45){j=0;k=h+1|0}else if((i<<24>>24|0)==61){i=h+1|0;l=c[14430]|0;if((c[14432]|0)==0){m=l}else{n=0;o=l;while(1){u1(c[o+(n<<2)>>2]|0);l=n+1|0;p=c[14430]|0;if(l>>>0<(c[14432]|0)>>>0){n=l;o=p}else{m=p;break}}}u1(m);c[14432]=0;c[14430]=0;j=1;k=i}else{j=1;k=h}if((s1(k,j)|0)==0){d=e}else{f=1;g=138;break}}if((g|0)==138){return f|0}else if((g|0)==136){return f|0}else if((g|0)==137){return f|0}return 0}function s5(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;if((b|0)==0){d=0}else{d=u8(b|0)|0}if((c|0)==0){e=0}else{e=u8(c|0)|0}f=e+d|0;g=u0(f+1|0)|0;if((g|0)==0){h=0;return h|0}if((d|0)!=0){u7(g|0,b|0,d)|0}if((e|0)!=0){b=g+d|0;u7(b|0,c|0,e)|0}a[g+f|0]=0;h=g;return h|0}function s6(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((b|0)==0){e=0;return e|0}L199:do{if((c|0)==0){f=b}else{g=b;while(1){h=a[g]|0;if(h<<24>>24==0){f=g;break L199}if((aX(c|0,h<<24>>24|0)|0)==0){f=g;break}else{g=g+1|0}}}}while(0);if((d|0)==0){e=f;return e|0}c=u8(f|0)|0;while(1){if((c|0)==0){i=0;break}b=c-1|0;if((aX(d|0,a[f+b|0]|0)|0)==0){i=c;break}else{c=b}}a[f+i|0]=0;e=f;return e|0}function s7(b,c){b=b|0;c=c|0;var d=0,e=0,f=0;L213:do{if((b|0)==0){d=0}else{if((c|0)==0){d=b;break}else{e=b}while(1){f=a[e]|0;if(f<<24>>24==0){d=e;break L213}if((aX(c|0,f<<24>>24|0)|0)==0){d=e;break}else{e=e+1|0}}}}while(0);return d|0}function s8(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if((b|0)==0){f=0;return f|0}else{g=0}while(1){h=a[b+g|0]|0;i=h<<24>>24==0;if(i){j=172;break}k=g+1|0;if((aX(d|0,h<<24>>24|0)|0)==0){g=k}else{l=k;break}}if((j|0)==172){l=g+1|0}j=u0(l)|0;if((j|0)==0){m=0}else{L230:do{if((g|0)==0){n=0}else{d=0;while(1){k=a[b+d|0]|0;if(k<<24>>24==0){n=d;break L230}a[j+d|0]=k;k=d+1|0;if(k>>>0<g>>>0){d=k}else{n=k;break}}}}while(0);a[j+n|0]=0;m=j}if((c[e>>2]|0)==0){f=m;return f|0}c[e>>2]=b+(i?g:l);f=m;return f|0}function s9(a){a=a|0;var b=0,d=0;b=i;i=i+8|0;d=b|0;c[d>>2]=(a>>>0)/1e6|0;c[d+4>>2]=((a>>>0)%1e6|0)*1e3|0;a=br(d|0,0)|0;i=b;return a|0}function ta(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;i=i+8|0;d=b|0;if((bx(d|0,0)|0)!=0){e=0;i=b;return e|0}f=((c[d>>2]|0)*1e6|0)+(c[d+4>>2]|0)|0;d=f-(c[a>>2]|0)|0;c[a>>2]=f;e=d;i=b;return e|0}function tb(b,c){b=b|0;c=c|0;if(a[6200]|0){return}a[6200]=1;return}function tc(){if(a[6200]|0){return}a[6200]=1;return}function td(b){b=b|0;if((b|0)!=0){c[b>>2]=0}if(a[6200]|0){return}a[6200]=1;return}function te(a){a=a|0;c[a>>2]=0;c[a+1028>>2]=0;c[a+1032>>2]=0;c[a+1040>>2]=0;c[a+1044>>2]=0;return}function tf(a,b){a=a|0;b=b|0;c[a+1044>>2]=b;return}function tg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=i;i=i+1304|0;d=c|0;te(d);tf(d,b);if((th(d,a,c+1048|0)|0)!=0){ti(d,48464,1);tl(d);e=1;i=c;return e|0}if((tn(d,0)|0)<<24>>24==0){tl(d);e=0;i=c;return e|0}else{ti(d,48464,1);tl(d);e=1;i=c;return e|0}return 0}function th(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0;e=i;i=i+32|0;f=e|0;g=e+16|0;if((tr(a,d,256)|0)==0){h=0;i=e;return h|0}j=f+8|0;k=f+12|0;l=g+8|0;L280:while(1){if((aQ(d|0,30416)|0)==0){if((tr(a,d,256)|0)==0){h=1;m=284;break}}L285:do{if((tw(a,29424)|0)==0){if((tw(a,54400)|0)!=0){tN(g,0);if((tY(a,b,g)|0)!=0){m=233;break L280}if((c[l>>2]|0)==0){m=233;break L280}if((tF(b,d,0)|0)==0){n=tF(b,d,1)|0;if((n|0)==0){m=233;break L280}tS(n,g)}tO(g);break}if((tw(a,53200)|0)!=0){n=tF(b,d,1)|0;if((n|0)==0){h=1;m=295;break L280}if((tY(a,b,n)|0)!=0){h=1;m=287;break L280}if((c[n+8>>2]|0)==0){h=1;m=288;break L280}else{break}}if((aQ(d|0,52592)|0)!=0){if((aQ(d|0,51832)|0)!=0){h=1;m=306;break L280}if((ts(a,d,256)|0)==0){h=1;m=307;break L280}if((tm(a,d,0,1)|0)==0){break}else{m=276;break L280}}tN(f,0);if((tY(a,b,f)|0)!=0){m=241;break L280}if((c[j>>2]|0)==1){if((c[k>>2]|0)==0){m=244}else{o=b;p=1}}else{m=244}if((m|0)==244){m=0;o=0;p=0}tO(f);if((tw(a,29424)|0)==0){h=1;m=298;break L280}if((o|0)==0){n=tx(0)|0;if((n|0)==0){h=1;m=292;break L280}c[n+4>>2]=b;r=th(a,n,d)|0;ty(n);s=r}else{s=th(a,o,d)|0}if((s|0)!=0){h=1;m=293;break L280}if((tw(a,55256)|0)==0){h=1;m=294;break L280}else{t=p}while(1){if((tu(a,49744)|0)==0){break L285}if((tu(a,52592)|0)==0){break}tN(f,0);if((tY(a,b,f)|0)!=0){m=255;break L280}do{if((c[j>>2]|0)==1){if((c[k>>2]|0)==0){u=0;break}u=(t|0)!=0?0:b}else{u=0}}while(0);r=(u|0)==0;n=r?t:1;tO(f);if((tw(a,29424)|0)==0){h=1;m=291;break L280}if(r){r=tx(0)|0;if((r|0)==0){h=1;m=299;break L280}c[r+4>>2]=b;v=th(a,r,d)|0;ty(r);w=v}else{w=th(a,u,d)|0}if((w|0)!=0){h=1;m=300;break L280}if((tw(a,55256)|0)==0){h=1;m=301;break L280}else{t=n}}n=(t|0)!=0?0:b;if((tw(a,29424)|0)==0){h=1;m=302;break L280}if((n|0)==0){v=tx(0)|0;if((v|0)==0){h=1;m=303;break L280}c[v+4>>2]=b;r=th(a,v,d)|0;ty(v);y=r}else{y=th(a,n,d)|0}if((y|0)!=0){h=1;m=304;break L280}if((tw(a,55256)|0)==0){h=1;m=305;break L280}}else{n=tB(b,d,1)|0;if((n|0)==0){h=1;m=285;break L280}if((th(a,n,d)|0)!=0){h=1;m=289;break L280}if((tw(a,55256)|0)==0){h=1;m=286;break L280}}}while(0);tw(a,50408)|0;if((tr(a,d,256)|0)==0){h=0;m=309;break}}if((m|0)==255){tO(f);h=1;i=e;return h|0}else if((m|0)==233){tO(g);h=1;i=e;return h|0}else if((m|0)==241){tO(f);h=1;i=e;return h|0}else if((m|0)==276){f=a+1040|0;g=c[f>>2]|0;if((g|0)==0){z=0}else{z=c[g+4>>2]|0}g=a+1028|0;a=(c[g>>2]|0)+1|0;bN(c[q>>2]|0,43664,(x=i,i=i+24|0,c[x>>2]=(z|0)==0?47248:z,c[x+8>>2]=a,c[x+16>>2]=51240,x)|0)|0;aB(10,c[q>>2]|0)|0;a=c[f>>2]|0;if((a|0)==0){A=0}else{A=c[a+4>>2]|0}a=(c[g>>2]|0)+1|0;bN(c[q>>2]|0,43664,(x=i,i=i+24|0,c[x>>2]=(A|0)==0?47248:A,c[x+8>>2]=a,c[x+16>>2]=d,x)|0)|0;aB(10,c[q>>2]|0)|0;h=1;i=e;return h|0}else if((m|0)==284){i=e;return h|0}else if((m|0)==285){i=e;return h|0}else if((m|0)==286){i=e;return h|0}else if((m|0)==287){i=e;return h|0}else if((m|0)==288){i=e;return h|0}else if((m|0)==289){i=e;return h|0}else if((m|0)==291){i=e;return h|0}else if((m|0)==292){i=e;return h|0}else if((m|0)==293){i=e;return h|0}else if((m|0)==294){i=e;return h|0}else if((m|0)==295){i=e;return h|0}else if((m|0)==298){i=e;return h|0}else if((m|0)==299){i=e;return h|0}else if((m|0)==300){i=e;return h|0}else if((m|0)==301){i=e;return h|0}else if((m|0)==302){i=e;return h|0}else if((m|0)==303){i=e;return h|0}else if((m|0)==304){i=e;return h|0}else if((m|0)==305){i=e;return h|0}else if((m|0)==306){i=e;return h|0}else if((m|0)==307){i=e;return h|0}else if((m|0)==309){i=e;return h|0}return 0}function ti(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=c[a+1040>>2]|0;if((f|0)==0){g=0}else{g=c[f+4>>2]|0}f=(c[a+1028>>2]|0)+1|0;bN(c[q>>2]|0,43664,(x=i,i=i+24|0,c[x>>2]=(g|0)==0?47248:g,c[x+8>>2]=f,c[x+16>>2]=b,x)|0)|0;L388:do{if((d|0)!=0){b=c[q>>2]|0;aC(40104,2,1,b|0)|0;b=0;while(1){f=tn(a,b)|0;if((f<<24>>24|0)==13|(f<<24>>24|0)==10){h=316;break}else if((f<<24>>24|0)==0){h=315;break}aB(f<<24>>24|0,c[q>>2]|0)|0;b=b+1|0;if(b>>>0>=64){break L388}}if((h|0)==316){b=c[q>>2]|0;aC(34232,4,1,b|0)|0;break}else if((h|0)==315){aC(37040,5,1,c[q>>2]|0)|0;break}}}while(0);aB(10,c[q>>2]|0)|0;i=e;return}function tj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=i;i=i+1304|0;e=d|0;te(e);do{if((tm(e,c,b,0)|0)==0){if((th(e,a,d+1048|0)|0)!=0){ti(e,48464,1);tl(e);f=1;break}if((tn(e,0)|0)<<24>>24==0){tl(e);f=0;break}else{ti(e,48464,1);tl(e);f=1;break}}else{ty(a);f=1}}while(0);i=d;return f|0}function tk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=aZ(b|0,53472|0)|0;if((c|0)==0){d=1;return d|0}e=tj(a,c,b)|0;av(c|0)|0;d=e;return d|0}function tl(a){a=a|0;var b=0,d=0;if((a|0)==0){return}b=c[a+1040>>2]|0;if((b|0)==0){return}else{d=b}while(1){b=c[d>>2]|0;if((c[d+12>>2]|0)!=0){a=c[d+8>>2]|0;av(a|0)|0}u1(c[d+4>>2]|0);u1(d);if((b|0)==0){break}else{d=b}}return}function tm(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=u0(24)|0;if((g|0)==0){h=1;return h|0}i=g;u6(g|0,0,16);j=b+1040|0;k=c[j>>2]|0;do{if((k|0)==0){l=u8(d|0)|0;m=u0(l+1|0)|0;if((m|0)==0){n=i;o=356;break}u7(m|0,d|0,l)|0;a[m+l|0]=0;p=m}else{m=c[k+4>>2]|0;L431:do{if((a[d]|0)==47|(m|0)==0){q=0}else{l=u8(m|0)|0;while(1){if((l|0)==0){r=0;break}s=l-1|0;if((a[m+s|0]|0)==47){l=s}else{r=l;break}}while(1){if((r|0)==0){q=0;break L431}l=r-1|0;if((a[m+l|0]|0)==47){q=r;break}else{r=l}}}}while(0);l=u8(d|0)|0;s=l+q|0;t=u0(s+1|0)|0;if((t|0)==0){u=0}else{if((q|0)!=0){u7(t|0,m|0,q)|0}v=t+q|0;u7(v|0,d|0,l)|0;a[t+s|0]=0;u=t}c[k+16>>2]=c[b+1028>>2];c[(c[j>>2]|0)+20>>2]=c[b+1032>>2];if((u|0)==0){n=i;o=356}else{p=u}}}while(0);if((o|0)==356){while(1){o=0;u=c[n>>2]|0;if((c[n+12>>2]|0)!=0){k=c[n+8>>2]|0;av(k|0)|0}u1(c[n+4>>2]|0);u1(n);if((u|0)==0){h=1;break}else{n=u;o=356}}return h|0}c[g+4>>2]=p;do{if((e|0)==0){o=aZ(p|0,48272)|0;c[g+8>>2]=o;if((o|0)==0){w=i}else{x=0;break}while(1){o=c[w>>2]|0;if((c[w+12>>2]|0)!=0){n=c[w+8>>2]|0;av(n|0)|0}u1(c[w+4>>2]|0);u1(w);if((o|0)==0){h=1;break}else{w=o}}return h|0}else{c[g+8>>2]=e;x=(f|0)!=0|0}}while(0);c[g+12>>2]=x;c[g>>2]=c[j>>2];c[j>>2]=i;c[b+1028>>2]=0;c[b+1032>>2]=0;h=0;return h|0}function tn(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;if(b>>>0>255){d=0;return d|0}e=a|0;L471:do{if((c[e>>2]|0)>>>0<=b>>>0){while(1){f=(to(a)|0)<<24>>24;c[a+4+(c[e>>2]<<2)>>2]=f;f=c[e>>2]|0;if((c[a+4+(f<<2)>>2]|0)==0){d=0;break}g=f+1|0;c[e>>2]=g;if(g>>>0>b>>>0){break L471}}return d|0}}while(0);d=c[a+4+(b<<2)>>2]&255;return d|0}function to(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=b+1040|0;e=c[d>>2]|0;if((e|0)==0){f=b+1044|0;g=c[f>>2]|0;if((g|0)==0){h=0;return h|0}i=a[g]|0;if(i<<24>>24==0){h=0;return h|0}c[f>>2]=g+1;h=i;return h|0}i=b+1028|0;g=b+1032|0;b=e;while(1){j=aT(c[b+8>>2]|0)|0;if((j|0)!=-1){k=383;break}e=c[d>>2]|0;if((e|0)==0){h=0;k=393;break}f=e|0;c[d>>2]=c[f>>2];c[f>>2]=0;if((c[e+12>>2]|0)!=0){f=c[e+8>>2]|0;av(f|0)|0}u1(c[e+4>>2]|0);u1(e);e=c[d>>2]|0;if((e|0)==0){h=0;k=398;break}c[i>>2]=c[e+16>>2];c[g>>2]=c[e+20>>2];b=e}if((k|0)==383){h=j&255;return h|0}else if((k|0)==393){return h|0}else if((k|0)==398){return h|0}return 0}function tp(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=a|0;e=c[d>>2]|0;if(e>>>0>b>>>0){if((b|0)==0){f=0}else{g=a+1032|0;h=a+1028|0;i=a+1036|0;j=0;while(1){k=c[a+4+(j<<2)>>2]&255;do{if(k<<24>>24!=0){c[g>>2]=(c[g>>2]|0)+1;if((k<<24>>24|0)==13){c[h>>2]=(c[h>>2]|0)+1;c[i>>2]=1;break}else if((k<<24>>24|0)==10){if((c[i>>2]|0)==0){c[h>>2]=(c[h>>2]|0)+1}c[i>>2]=0;break}else{c[i>>2]=0;break}}}while(0);k=j+1|0;if(k>>>0<b>>>0){j=k}else{f=b;break}}}do{c[a+4+(f-b<<2)>>2]=c[a+4+(f<<2)>>2];f=f+1|0;l=c[d>>2]|0;}while(f>>>0<l>>>0);c[d>>2]=l-b;return}if((e|0)==0){m=0}else{l=a+1032|0;f=a+1028|0;j=a+1036|0;i=0;while(1){h=c[a+4+(i<<2)>>2]&255;do{if(h<<24>>24!=0){c[l>>2]=(c[l>>2]|0)+1;if((h<<24>>24|0)==13){c[f>>2]=(c[f>>2]|0)+1;c[j>>2]=1;break}else if((h<<24>>24|0)==10){if((c[j>>2]|0)==0){c[f>>2]=(c[f>>2]|0)+1}c[j>>2]=0;break}else{c[j>>2]=0;break}}}while(0);h=i+1|0;if(h>>>0<e>>>0){i=h}else{m=e;break}}}c[d>>2]=0;if((m|0)==(b|0)){return}d=a+1032|0;e=a+1028|0;i=a+1036|0;j=b-m|0;do{m=to(a)|0;do{if(m<<24>>24!=0){c[d>>2]=(c[d>>2]|0)+1;if((m<<24>>24|0)==10){if((c[i>>2]|0)==0){c[e>>2]=(c[e>>2]|0)+1}c[i>>2]=0;break}else if((m<<24>>24|0)==13){c[e>>2]=(c[e>>2]|0)+1;c[i>>2]=1;break}else{c[i>>2]=0;break}}}while(0);j=j-1|0;}while((j|0)!=0);return}function tq(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=a|0;d=a+4|0;e=a+8|0;f=0;L556:while(1){g=f;h=c[b>>2]|0;L558:while(1){if((h|0)==0){while(1){i=(to(a)|0)<<24>>24;c[a+4+(c[b>>2]<<2)>>2]=i;i=c[b>>2]|0;if((c[a+4+(i<<2)>>2]|0)==0){j=468;break L556}k=i+1|0;c[b>>2]=k;if((k|0)!=0){l=k;break}}}else{l=h}k=c[d>>2]&255;if((k<<24>>24|0)==32|(k<<24>>24|0)==9|(k<<24>>24|0)==13|(k<<24>>24|0)==10){j=442;break}else if((k<<24>>24|0)==35){i=l;while(1){if((i|0)==0){while(1){m=(to(a)|0)<<24>>24;c[a+4+(c[b>>2]<<2)>>2]=m;m=c[b>>2]|0;if((c[a+4+(m<<2)>>2]|0)==0){g=1;h=m;continue L558}n=m+1|0;c[b>>2]=n;if((n|0)!=0){break}}}n=c[d>>2]&255;if(n<<24>>24==0){f=1;continue L556}tp(a,1);if((n<<24>>24|0)==10){f=1;continue L556}else if((n<<24>>24|0)==13){break}i=c[b>>2]|0}if((c[b>>2]|0)!=0){break}while(1){i=(to(a)|0)<<24>>24;c[a+4+(c[b>>2]<<2)>>2]=i;i=c[b>>2]|0;if((c[a+4+(i<<2)>>2]|0)==0){g=1;h=i;continue L558}n=i+1|0;c[b>>2]=n;if((n|0)!=0){break L558}}}else if((k<<24>>24|0)!=47){j=469;break L556}if(l>>>0<=1){do{n=(to(a)|0)<<24>>24;c[a+4+(c[b>>2]<<2)>>2]=n;n=c[b>>2]|0;if((c[a+4+(n<<2)>>2]|0)==0){j=470;break L556}i=n+1|0;c[b>>2]=i;}while(i>>>0<=1)}if((c[e>>2]&255)<<24>>24!=42){j=471;break L556}tp(a,2);k=0;i=0;while(1){if((c[b>>2]|0)==0){while(1){n=(to(a)|0)<<24>>24;c[a+4+(c[b>>2]<<2)>>2]=n;n=c[b>>2]|0;if((c[a+4+(n<<2)>>2]|0)==0){g=1;h=n;continue L558}m=n+1|0;c[b>>2]=m;if((m|0)!=0){break}}}m=c[d>>2]&255;if(m<<24>>24==0){f=1;continue L556}tp(a,1);if(!(k<<24>>24==42&m<<24>>24==47)){n=k<<24>>24==47&m<<24>>24==42;k=n?0:m;i=(n&1)+i|0;continue}if((i|0)==0){f=1;continue L556}k=0;i=i-1|0}}if((j|0)==442){j=0;tp(a,1);f=1;continue}if((c[d>>2]&255)<<24>>24!=10){f=1;continue}tp(a,1);f=1}if((j|0)==470){return g|0}else if((j|0)==471){return g|0}else if((j|0)==468){return g|0}else if((j|0)==469){return g|0}return 0}function tr(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;tq(b)|0;f=b|0;L608:do{if((c[f>>2]|0)==0){while(1){g=(to(b)|0)<<24>>24;c[b+4+(c[f>>2]<<2)>>2]=g;g=c[f>>2]|0;if((c[b+4+(g<<2)>>2]|0)==0){h=0;break L608}i=g+1|0;c[f>>2]=i;if((i|0)!=0){j=475;break}}}else{j=475}}while(0);if((j|0)==475){h=c[b+4>>2]&255}do{if(!((h-97&255)<26|(h-65&255)<26)){if((h<<24>>24|0)==95|(h<<24>>24|0)==36){break}else{k=0}return k|0}}while(0);L619:do{if((e|0)==0){l=0}else{j=0;i=h;L620:while(1){g=j+1|0;m=d+j|0;a[m]=i;L622:do{if(g>>>0>255){n=0}else{if((c[f>>2]|0)>>>0<=g>>>0){do{o=(to(b)|0)<<24>>24;c[b+4+(c[f>>2]<<2)>>2]=o;o=c[f>>2]|0;if((c[b+4+(o<<2)>>2]|0)==0){n=0;break L622}p=o+1|0;c[f>>2]=p;}while(p>>>0<=g>>>0)}n=c[b+4+(g<<2)>>2]&255}}while(0);do{if(!((n-97&255)<26|(n-65&255)<26|n<<24>>24==95|(n-48&255)<10)){if((n<<24>>24|0)==45){if((a[m]|0)==91&g>>>0<e>>>0){j=g;i=n;continue L620}else{l=g;break L619}}else if((n<<24>>24|0)==43){if((a[m]|0)==91&g>>>0<e>>>0){j=g;i=n;continue L620}else{l=g;break L619}}else if((n<<24>>24|0)==93|(n<<24>>24|0)==91|(n<<24>>24|0)==46){break}else{l=g;break L619}}}while(0);if(g>>>0<e>>>0){j=g;i=n}else{l=g;break}}}}while(0);if(l>>>0>=e>>>0){k=0;return k|0}a[d+l|0]=0;tp(b,l);k=1;return k|0}function ts(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;tq(b)|0;f=b|0;L642:do{if((c[f>>2]|0)==0){while(1){g=(to(b)|0)<<24>>24;c[b+4+(c[f>>2]<<2)>>2]=g;g=c[f>>2]|0;if((c[b+4+(g<<2)>>2]|0)==0){h=0;break}i=g+1|0;c[f>>2]=i;if((i|0)!=0){break L642}}return h|0}}while(0);if((c[b+4>>2]&255)<<24>>24!=34|(e|0)==0){h=0;return h|0}else{j=1;k=0}L650:while(1){if(j>>>0>255){h=1;l=544;break}i=c[f>>2]|0;if(i>>>0>j>>>0){m=i}else{while(1){i=(to(b)|0)<<24>>24;c[b+4+(c[f>>2]<<2)>>2]=i;i=c[f>>2]|0;if((c[b+4+(i<<2)>>2]|0)==0){h=1;l=548;break L650}g=i+1|0;c[f>>2]=g;if(g>>>0>j>>>0){m=g;break}}}g=c[b+4+(j<<2)>>2]&255;L658:do{if((g<<24>>24|0)==34){l=537;break L650}else if((g<<24>>24|0)==92){i=j+1|0;if(i>>>0>255){n=j;o=92;break}if(m>>>0>i>>>0){p=m}else{while(1){q=(to(b)|0)<<24>>24;c[b+4+(c[f>>2]<<2)>>2]=q;q=c[f>>2]|0;if((c[b+4+(q<<2)>>2]|0)==0){n=j;o=92;break L658}r=q+1|0;c[f>>2]=r;if(r>>>0>i>>>0){p=r;break}}}r=c[b+4+(i<<2)>>2]<<24>>24;if((r|0)==114){n=i;o=13;break}else if((r|0)==118){n=i;o=11;break}else if((r|0)==97){n=i;o=7;break}else if((r|0)==98){n=i;o=8;break}else if((r|0)==92){n=i;o=92;break}else if((r|0)==34){n=i;o=34;break}else if((r|0)==102){n=i;o=12;break}else if((r|0)==110){n=i;o=10;break}else if((r|0)==120){r=j+2|0;if(r>>>0>255){h=0;l=551;break L650}if(p>>>0>r>>>0){s=p}else{while(1){q=(to(b)|0)<<24>>24;c[b+4+(c[f>>2]<<2)>>2]=q;q=c[f>>2]|0;if((c[b+4+(q<<2)>>2]|0)==0){h=0;l=546;break L650}t=q+1|0;c[f>>2]=t;if(t>>>0>r>>>0){s=t;break}}}i=c[b+4+(r<<2)>>2]&255;t=i-48&255;do{if((t&255)<10){u=t}else{if((i-97&255)<6){u=i-87&255;break}if((i-65&255)>=6){h=0;l=545;break L650}u=i-55&255}}while(0);i=j+3|0;if(i>>>0>255){h=0;l=541;break L650}if(s>>>0<=i>>>0){do{t=(to(b)|0)<<24>>24;c[b+4+(c[f>>2]<<2)>>2]=t;t=c[f>>2]|0;if((c[b+4+(t<<2)>>2]|0)==0){h=0;l=550;break L650}r=t+1|0;c[f>>2]=r;}while(r>>>0<=i>>>0)}r=c[b+4+(i<<2)>>2]&255;t=r-48&255;do{if((t&255)<10){v=t}else{if((r-97&255)<6){v=r-87&255;break}if((r-65&255)>=6){h=0;l=542;break L650}v=r-55&255}}while(0);n=i;o=v+(u<<4)&255;break}else{n=j;o=92;break}}else if((g<<24>>24|0)==0){h=1;l=549;break L650}else{n=j;o=g}}while(0);g=k+1|0;a[d+k|0]=o;if(g>>>0<e>>>0){j=n+1|0;k=g}else{h=0;l=547;break}}if((l|0)==537){a[d+k|0]=0;tp(b,j+1|0);h=1;return h|0}else if((l|0)==541){return h|0}else if((l|0)==542){return h|0}else if((l|0)==544){return h|0}else if((l|0)==545){return h|0}else if((l|0)==546){return h|0}else if((l|0)==547){return h|0}else if((l|0)==548){return h|0}else if((l|0)==549){return h|0}else if((l|0)==550){return h|0}else if((l|0)==551){return h|0}return 0}function tt(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;tq(b)|0;e=b|0;f=0;while(1){g=d+f|0;if((a[g]|0)==0){h=1;i=561;break}L720:do{if(f>>>0>255){j=0}else{if((c[e>>2]|0)>>>0<=f>>>0){do{k=(to(b)|0)<<24>>24;c[b+4+(c[e>>2]<<2)>>2]=k;k=c[e>>2]|0;if((c[b+4+(k<<2)>>2]|0)==0){j=0;break L720}l=k+1|0;c[e>>2]=l;}while(l>>>0<=f>>>0)}j=c[b+4+(f<<2)>>2]&255}}while(0);if(j<<24>>24==(a[g]|0)){f=f+1|0}else{h=0;i=562;break}}if((i|0)==562){return h|0}else if((i|0)==561){return h|0}return 0}function tu(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;tq(b)|0;e=b|0;f=0;while(1){g=d+f|0;h=(a[g]|0)==0;L734:do{if(f>>>0>255){i=0}else{if((c[e>>2]|0)>>>0<=f>>>0){do{j=(to(b)|0)<<24>>24;c[b+4+(c[e>>2]<<2)>>2]=j;j=c[e>>2]|0;if((c[b+4+(j<<2)>>2]|0)==0){i=0;break L734}k=j+1|0;c[e>>2]=k;}while(k>>>0<=f>>>0)}i=c[b+4+(f<<2)>>2]&255}}while(0);if(h){break}if(i<<24>>24==(a[g]|0)){f=f+1|0}else{l=0;m=574;break}}if((m|0)==574){return l|0}if((i-97&255)<26|(i-65&255)<26|i<<24>>24==95|(i-48&255)<10){l=0;return l|0}tp(b,f);l=1;return l|0}function tv(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;i=c[b>>2]|0;c[e>>2]=0;c[f>>2]=1;c[g>>2]=0;c[h>>2]=0;j=a[i]|0;do{if((j-97&255)>=26){if((j-65&255)<26|j<<24>>24==95){break}else{k=1}return k|0}}while(0);a[d]=j;j=i+1|0;l=a[j]|0;do{if(l<<24>>24==0){m=j;n=i;o=1}else{p=1;q=i;r=j;s=l;while(1){if((s-97&255)>=26){if(!((s-65&255)<26|s<<24>>24==95|(s-48&255)<10)){t=p;u=q;v=r;break}}w=p+1|0;a[d+p|0]=s;x=r+1|0;y=a[x]|0;if(y<<24>>24!=0&w>>>0<256){p=w;q=r;r=x;s=y}else{t=w;u=r;v=x;break}}if(t>>>0>255){k=1}else{m=v;n=u;o=t;break}return k|0}}while(0);a[d+o|0]=0;o=a[m]|0;if((o<<24>>24|0)==46){c[b>>2]=n+2;k=0;return k|0}else if((o<<24>>24|0)==0){c[b>>2]=m;k=0;return k|0}else if((o<<24>>24|0)==91){o=n+2|0;m=a[o]|0;if((m<<24>>24|0)==45){c[h>>2]=1;z=n+3|0}else if((m<<24>>24|0)==43){c[g>>2]=1;z=n+3|0}else{if((m-48&255)>=10){k=1;return k|0}n=o;o=m;m=c[e>>2]|0;while(1){g=(o<<24>>24)-48+(m*10|0)|0;c[e>>2]=g;h=n+1|0;d=a[h]|0;if((d-48&255)<10){n=h;o=d;m=g}else{z=h;break}}}if((a[z]|0)!=93){k=1;return k|0}m=z+1|0;c[b>>2]=(a[m]|0)==46?z+2|0:m;c[f>>2]=0;k=0;return k|0}else{k=1;return k|0}return 0}function tw(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;tq(b)|0;e=b|0;f=0;while(1){g=d+f|0;if((a[g]|0)==0){break}L789:do{if(f>>>0>255){h=0}else{if((c[e>>2]|0)>>>0<=f>>>0){do{i=(to(b)|0)<<24>>24;c[b+4+(c[e>>2]<<2)>>2]=i;i=c[e>>2]|0;if((c[b+4+(i<<2)>>2]|0)==0){h=0;break L789}j=i+1|0;c[e>>2]=j;}while(j>>>0<=f>>>0)}h=c[b+4+(f<<2)>>2]&255}}while(0);if(h<<24>>24==(a[g]|0)){f=f+1|0}else{k=0;l=614;break}}if((l|0)==614){return k|0}tp(b,f);k=1;return k|0}function tx(a){a=a|0;var b=0,d=0;b=u0(28)|0;if((b|0)==0){d=0;return d|0}c[b>>2]=0;c[b+4>>2]=0;c[b+8>>2]=bu(((a|0)==0?58224:a)|0)|0;u6(b+12|0,0,16);d=b;return d|0}function ty(a){a=a|0;var b=0;if((a|0)==0){return}else{b=a}while(1){a=c[b>>2]|0;tR(c[b+20>>2]|0);ty(c[b+12>>2]|0);u1(c[b+8>>2]|0);u1(b);if((a|0)==0){break}else{b=a}}return}function tz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;do{if((b|0)==0){if((a|0)==0){e=0;break}f=a+12|0;g=630}else{f=b|0;g=630}}while(0);L817:do{if((g|0)==630){b=c[f>>2]|0;if((b|0)==0){e=0;break}if((d|0)==0){e=b;break}else{h=b}while(1){if((aQ(c[h+8>>2]|0,d|0)|0)==0){e=h;break L817}b=c[h>>2]|0;if((b|0)==0){e=0;break}else{h=b}}}}while(0);return e|0}function tA(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;do{if((b|0)==0){if((a|0)==0){e=0;return e|0}else{f=a+20|0;break}}else{f=b|0}}while(0);b=c[f>>2]|0;if((b|0)==0|(d|0)==0){e=0;return e|0}else{g=b}while(1){if((aQ(c[g+4>>2]|0,d|0)|0)==0){e=g;h=644;break}b=c[g>>2]|0;if((b|0)==0){e=0;h=646;break}else{g=b}}if((h|0)==644){return e|0}else if((h|0)==646){return e|0}return 0}function tB(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;f=i;i=i+296|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=f+32|0;c[g>>2]=d;if((b|0)==0){m=0;i=f;return m|0}n=f+40|0;o=(e|0)==0;p=(e|0)!=0;e=1;q=b;b=d;L844:while(1){if((a[b]|0)==0){m=q;r=695;break}if((tv(g,n,l,h,j,k)|0)!=0){m=0;r=691;break}d=(a[c[g>>2]|0]|0)==0?e:0;L848:do{if((c[j>>2]|0)==0){if(!((d|0)==0|o)){if((c[h>>2]|0)!=0){r=654;break}}if((c[k>>2]|0)!=0){s=q+12|0;t=c[s>>2]|0;if((t|0)==0){u=0}else{v=0;w=t;while(1){t=(aQ(c[w+8>>2]|0,n|0)|0)==0?w:v;x=c[w>>2]|0;if((x|0)==0){u=t;break}else{v=t;w=x}}}if(!(p&(u|0)==0)){y=u;break}w=u0(28)|0;if((w|0)==0){m=0;r=699;break L844}v=w;c[w>>2]=0;x=w+4|0;c[x>>2]=0;c[w+8>>2]=bu(n|0)|0;u6(w+12|0,0,16);if((q|0)==0){y=v;break}c[x>>2]=q;if((c[s>>2]|0)==0){c[s>>2]=v;z=q+16|0}else{x=q+16|0;c[c[x>>2]>>2]=v;z=x}c[z>>2]=v;y=v;break}v=c[l>>2]|0;x=q+12|0;w=c[x>>2]|0;if((w|0)==0){A=v}else{t=v;v=w;while(1){if((aQ(c[v+8>>2]|0,n|0)|0)==0){if((t|0)==0){y=v;break L848}B=t-1|0}else{B=t}w=c[v>>2]|0;if((w|0)==0){A=B;break}else{t=B;v=w}}}if(o){m=0;r=693;break L844}v=q+16|0;if((q|0)==0){t=A;while(1){s=u0(28)|0;if((s|0)==0){C=0}else{c[s>>2]=0;c[s+4>>2]=0;c[s+8>>2]=bu(n|0)|0;u6(s+12|0,0,16);C=s}if((t|0)==0){y=C;break L848}if((C|0)==0){m=0;r=694;break L844}else{t=t-1|0}}}else{D=A}while(1){t=(D|0)==0;s=u0(28)|0;if((s|0)==0){E=0}else{w=s;c[s>>2]=0;F=s+4|0;c[F>>2]=0;c[s+8>>2]=bu(n|0)|0;u6(s+12|0,0,16);c[F>>2]=q;if((c[x>>2]|0)==0){c[x>>2]=w}else{c[c[v>>2]>>2]=w}c[v>>2]=w;E=w}if(t){y=E;break L848}if((E|0)==0){m=0;r=697;break L844}else{D=D-1|0}}}else{r=654}}while(0);do{if((r|0)==654){r=0;v=u0(28)|0;if((v|0)==0){m=0;r=696;break L844}x=v;c[v>>2]=0;t=v+4|0;c[t>>2]=0;c[v+8>>2]=bu(n|0)|0;u6(v+12|0,0,16);if((q|0)==0){y=x;break}c[t>>2]=q;t=q+12|0;if((c[t>>2]|0)==0){c[t>>2]=x;G=q+16|0}else{t=q+16|0;c[c[t>>2]>>2]=x;G=t}c[G>>2]=x;y=x}}while(0);if((y|0)==0){m=0;r=698;break}e=d;q=y;b=c[g>>2]|0}if((r|0)==691){i=f;return m|0}else if((r|0)==693){i=f;return m|0}else if((r|0)==694){i=f;return m|0}else if((r|0)==695){i=f;return m|0}else if((r|0)==696){i=f;return m|0}else if((r|0)==697){i=f;return m|0}else if((r|0)==698){i=f;return m|0}else if((r|0)==699){i=f;return m|0}return 0}function tC(a){a=a|0;c[a>>2]=0;c[a+4>>2]=0;c[a+8>>2]=0;return}function tD(a,b){a=a|0;b=b|0;var d=0;if((c[a+8>>2]|0)!=1){d=1;return d|0}c[b>>2]=c[a+12>>2];d=0;return d|0}function tE(a,b){a=a|0;b=b|0;var d=0;if((c[a+8>>2]|0)!=1){d=1;return d|0}c[b>>2]=c[a+12>>2]&65535;d=0;return d|0}function tF(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;f=i;i=i+296|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=f+32|0;c[g>>2]=d;if((b|0)==0){m=0;i=f;return m|0}n=f+40|0;o=(e|0)==0;p=(e|0)!=0;e=1;q=b;b=d;L927:while(1){if((a[b]|0)==0){m=0;r=792;break}if((tv(g,n,l,h,j,k)|0)!=0){m=0;r=805;break}s=(c[j>>2]|0)==0;if((a[c[g>>2]|0]|0)==0){r=716;break}L932:do{if(s){if((c[k>>2]|0)!=0){d=q+12|0;t=c[d>>2]|0;if((t|0)==0){u=0}else{v=0;w=t;while(1){t=(aQ(c[w+8>>2]|0,n|0)|0)==0?w:v;x=c[w>>2]|0;if((x|0)==0){u=t;break}else{v=t;w=x}}}if(!(p&(u|0)==0)){y=u;break}w=u0(28)|0;if((w|0)==0){m=0;r=789;break L927}v=w;c[w>>2]=0;x=w+4|0;c[x>>2]=0;c[w+8>>2]=bu(n|0)|0;u6(w+12|0,0,16);if((q|0)==0){y=v;break}c[x>>2]=q;if((c[d>>2]|0)==0){c[d>>2]=v;z=q+16|0}else{x=q+16|0;c[c[x>>2]>>2]=v;z=x}c[z>>2]=v;y=v;break}v=c[l>>2]|0;x=q+12|0;w=c[x>>2]|0;if((w|0)==0){A=v}else{t=v;v=w;while(1){if((aQ(c[v+8>>2]|0,n|0)|0)==0){if((t|0)==0){y=v;break L932}B=t-1|0}else{B=t}w=c[v>>2]|0;if((w|0)==0){A=B;break}else{t=B;v=w}}}if(o){m=0;r=804;break L927}v=q+16|0;if((q|0)==0){t=A;while(1){d=u0(28)|0;if((d|0)==0){C=0}else{c[d>>2]=0;c[d+4>>2]=0;c[d+8>>2]=bu(n|0)|0;u6(d+12|0,0,16);C=d}if((t|0)==0){y=C;break L932}if((C|0)==0){m=0;r=793;break L927}else{t=t-1|0}}}else{D=A}while(1){t=(D|0)==0;d=u0(28)|0;if((d|0)==0){E=0}else{w=d;c[d>>2]=0;F=d+4|0;c[F>>2]=0;c[d+8>>2]=bu(n|0)|0;u6(d+12|0,0,16);c[F>>2]=q;if((c[x>>2]|0)==0){c[x>>2]=w}else{c[c[v>>2]>>2]=w}c[v>>2]=w;E=w}if(t){y=E;break L932}if((E|0)==0){m=0;r=800;break L927}else{D=D-1|0}}}else{v=u0(28)|0;if((v|0)==0){m=0;r=791;break L927}x=v;c[v>>2]=0;t=v+4|0;c[t>>2]=0;c[v+8>>2]=bu(n|0)|0;u6(v+12|0,0,16);if((q|0)==0){y=x;break}c[t>>2]=q;t=q+12|0;if((c[t>>2]|0)==0){c[t>>2]=x;G=q+16|0}else{t=q+16|0;c[c[t>>2]>>2]=x;G=t}c[G>>2]=x;y=x}}while(0);if((y|0)==0){m=0;r=810;break}e=0;q=y;b=c[g>>2]|0}if((r|0)==716){do{if(s){if(!((e|0)==0|o)){if((c[h>>2]|0)!=0){break}}if((c[k>>2]|0)!=0){g=q+20|0;b=c[g>>2]|0;if((b|0)==0){H=0}else{y=0;G=b;while(1){b=(aQ(c[G+4>>2]|0,n|0)|0)==0?G:y;D=c[G>>2]|0;if((D|0)==0){H=b;break}else{y=b;G=D}}}if(!(p&(H|0)==0)){m=H;i=f;return m|0}G=tQ(n)|0;if((G|0)==0){m=0;i=f;return m|0}if((q|0)==0){m=G;i=f;return m|0}if((c[g>>2]|0)==0){c[g>>2]=G;I=q+24|0}else{y=q+24|0;c[c[y>>2]>>2]=G;I=y}c[I>>2]=G;m=G;i=f;return m|0}G=c[l>>2]|0;y=q+20|0;D=c[y>>2]|0;L1011:do{if((D|0)==0){J=G}else{b=G;E=D;while(1){if((aQ(c[E+4>>2]|0,n|0)|0)==0){if((b|0)==0){m=E;break}K=b-1|0}else{K=b}A=c[E>>2]|0;if((A|0)==0){J=K;break L1011}else{b=K;E=A}}i=f;return m|0}}while(0);if(o){m=0;i=f;return m|0}D=q+24|0;if((q|0)==0){G=J;while(1){g=tQ(n)|0;if((G|0)==0){m=g;r=802;break}if((g|0)==0){m=0;r=794;break}else{G=G-1|0}}if((r|0)==794){i=f;return m|0}else if((r|0)==802){i=f;return m|0}}else{L=J}while(1){G=(L|0)==0;g=tQ(n)|0;if((g|0)==0){M=0}else{if((c[y>>2]|0)==0){c[y>>2]=g}else{c[c[D>>2]>>2]=g}c[D>>2]=g;M=g}if(G){m=M;r=795;break}if((M|0)==0){m=0;r=796;break}else{L=L-1|0}}if((r|0)==795){i=f;return m|0}else if((r|0)==796){i=f;return m|0}}}while(0);L=tQ(n)|0;if((L|0)==0){m=0;i=f;return m|0}if((q|0)==0){m=L;i=f;return m|0}n=q+20|0;if((c[n>>2]|0)==0){c[n>>2]=L;N=q+24|0}else{n=q+24|0;c[c[n>>2]>>2]=L;N=n}c[N>>2]=L;m=L;i=f;return m|0}else if((r|0)==789){i=f;return m|0}else if((r|0)==791){i=f;return m|0}else if((r|0)==792){i=f;return m|0}else if((r|0)==793){i=f;return m|0}else if((r|0)==800){i=f;return m|0}else if((r|0)==804){i=f;return m|0}else if((r|0)==805){i=f;return m|0}else if((r|0)==810){i=f;return m|0}return 0}function tG(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;c[d>>2]=e;e=tF(a,b,0)|0;if((e|0)==0){f=1;return f|0}f=(tD(e,d)|0)!=0|0;return f|0}function tH(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;c[d>>2]=e;e=tF(a,b,0)|0;if((e|0)==0){f=1;return f|0}f=(tE(e,d)|0)!=0|0;return f|0}function tI(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;c[d>>2]=e;e=tF(a,b,0)|0;if((e|0)==0){f=1;return f|0}f=(tV(e,d)|0)!=0|0;return f|0}function tJ(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;c[d>>2]=(e|0)!=0;e=tF(a,b,0)|0;if((e|0)==0){f=1;return f|0}f=(tW(e,d)|0)!=0|0;return f|0}function tK(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;c[d>>2]=e;e=tF(a,b,0)|0;do{if((e|0)==0){f=1}else{b=tX(e)|0;if((b|0)==0){f=0;break}c[d>>2]=b;f=0}}while(0);return f|0}function tL(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=(d|0)!=0;if(g){h=u8(d|0)|0}else{h=0}i=(e|0)!=0;if(i){j=u8(e|0)|0}else{j=0}k=(f|0)!=0;if(k){l=u8(f|0)|0}else{l=0}m=b|0;n=h+1+j+l+(c[m>>2]|0)|0;o=b+4|0;p=c[o>>2]|0;do{if(n>>>0>=p>>>0){q=(p|0)==0?256:p;while(1){if(n>>>0<q>>>0){break}else{q=q<<1}}r=b+8|0;s=u2(c[r>>2]|0,q)|0;if((s|0)==0){t=1;return t|0}else{c[o>>2]=q;c[r>>2]=s;break}}}while(0);if(g){g=(c[b+8>>2]|0)+(c[m>>2]|0)|0;u7(g|0,d|0,h)|0}if(i){i=(c[b+8>>2]|0)+((c[m>>2]|0)+h)|0;u7(i|0,e|0,j)|0}if(k){k=b+8|0;e=j+h|0;i=(c[k>>2]|0)+(e+(c[m>>2]|0))|0;u7(i|0,f|0,l)|0;u=e;v=k}else{u=j+h|0;v=b+8|0}b=u+l+(c[m>>2]|0)|0;c[m>>2]=b;a[(c[v>>2]|0)+b|0]=0;t=0;return t|0}function tM(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=a+8|0;a=tg(b,c[e>>2]|0)|0;if((d|0)==0){return a|0}u1(c[e>>2]|0);return a|0}function tN(a,b){a=a|0;b=b|0;var d=0;c[a>>2]=0;d=a+4|0;c[d>>2]=0;c[a+8>>2]=0;if((b|0)==0){return}c[d>>2]=bu(b|0)|0;return}function tO(a){a=a|0;var b=0;if((a|0)==0){return}b=a+8|0;if((c[b>>2]|0)==2){u1(c[a+12>>2]|0)}c[b>>2]=0;u1(c[a+4>>2]|0);return}function tP(a){a=a|0;var b=0;b=a+8|0;if((c[b>>2]|0)!=2){c[b>>2]=0;return}u1(c[a+12>>2]|0);c[b>>2]=0;return}function tQ(a){a=a|0;var b=0,d=0,e=0,f=0;b=u0(16)|0;d=b;if((b|0)==0){e=0;return e|0}c[b>>2]=0;f=b+4|0;c[f>>2]=0;c[b+8>>2]=0;if((a|0)==0){e=d;return e|0}c[f>>2]=bu(a|0)|0;e=d;return e|0}function tR(a){a=a|0;var b=0,d=0;if((a|0)==0){return}else{b=a}while(1){a=c[b>>2]|0;d=b+8|0;if((c[d>>2]|0)==2){u1(c[b+12>>2]|0)}c[d>>2]=0;u1(c[b+4>>2]|0);u1(b);if((a|0)==0){break}else{b=a}}return}function tS(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=c[b+8>>2]|0;if((d|0)==1){e=c[b+12>>2]|0;f=a+8|0;g=a+12|0;if((c[f>>2]|0)==2){u1(c[g>>2]|0)}c[f>>2]=1;c[g>>2]=e;return}else if((d|0)==2){d=c[b+12>>2]|0;b=a+8|0;e=a+12|0;if((c[b>>2]|0)==2){u1(c[e>>2]|0)}c[b>>2]=2;c[e>>2]=bu(d|0)|0;return}else{d=a+8|0;if((c[d>>2]|0)==2){u1(c[a+12>>2]|0)}c[d>>2]=0;return}}function tT(a,b){a=a|0;b=b|0;var d=0,e=0;d=a+8|0;e=a+12|0;if((c[d>>2]|0)==2){u1(c[e>>2]|0)}c[d>>2]=1;c[e>>2]=b;return}function tU(a,b){a=a|0;b=b|0;var d=0,e=0;d=a+8|0;e=a+12|0;if((c[d>>2]|0)==2){u1(c[e>>2]|0)}c[d>>2]=2;c[e>>2]=bu(b|0)|0;return}function tV(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;if((c[a+8>>2]|0)!=1){d=1;return d|0}e=c[a+12>>2]|0;if((e|0)<0){f=-(-e&2147483647)|0}else{f=e}if((f+32767|0)>>>0>65534){d=1;return d|0}c[b>>2]=f;d=0;return d|0}function tW(a,b){a=a|0;b=b|0;var d=0;if((c[a+8>>2]|0)!=1){d=1;return d|0}c[b>>2]=(c[a+12>>2]|0)!=0;d=0;return d|0}function tX(a){a=a|0;var b=0;if((c[a+8>>2]|0)!=2){b=0;return b|0}b=c[a+12>>2]|0;return b|0}function tY(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+16|0;f=e|0;do{if((tZ(a,b,d)|0)==0){if((tw(a,48048)|0)==0){g=0;break}tN(f,0);if((c[d+8>>2]|0)==1){if((c[d+12>>2]|0)==0){h=936}else{j=f;k=d}}else{h=936}if((h|0)==936){j=d;k=f}if((tZ(a,b,k)|0)!=0){tO(f);g=1;break}if((tw(a,53416)|0)==0){tO(f);g=1;break}else{l=(tZ(a,b,j)|0)!=0;tO(f);g=l&1;break}}else{g=1}}while(0);i=e;return g|0}function tZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+16|0;f=e|0;if((t_(a,b,d)|0)!=0){g=1;i=e;return g|0}if((tw(a,47224)|0)==0){g=0;i=e;return g|0}h=d+8|0;j=f+8|0;k=d+12|0;d=k;l=f+12|0;m=k|0;while(1){tN(f,0);if((t_(a,b,f)|0)!=0){n=947;break}k=c[h>>2]|0;if(!((k|0)==(c[j>>2]|0)&(k|0)==1)){n=949;break}if((c[d>>2]|0)==0){o=(c[l>>2]|0)!=0|0}else{o=1}c[m>>2]=o;tO(f);if((tw(a,47224)|0)==0){g=0;n=957;break}}if((n|0)==949){tO(f);g=1;i=e;return g|0}else if((n|0)==947){tO(f);g=1;i=e;return g|0}else if((n|0)==957){i=e;return g|0}return 0}function t_(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+16|0;f=e|0;if((t$(a,b,d)|0)!=0){g=1;i=e;return g|0}if((tw(a,43648)|0)==0){g=0;i=e;return g|0}h=d+8|0;j=f+8|0;k=d+12|0;d=k;l=k|0;k=f+12|0;while(1){tN(f,0);if((t$(a,b,f)|0)!=0){m=963;break}n=c[h>>2]|0;if(!((n|0)==(c[j>>2]|0)&(n|0)==1)){m=965;break}if((c[d>>2]|0)==0){o=0}else{o=(c[k>>2]|0)!=0|0}c[l>>2]=o;tO(f);if((tw(a,43648)|0)==0){g=0;m=974;break}}if((m|0)==963){tO(f);g=1;i=e;return g|0}else if((m|0)==974){i=e;return g|0}else if((m|0)==965){tO(f);g=1;i=e;return g|0}return 0}function t$(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+16|0;f=e|0;L1261:do{if((t0(a,b,d)|0)==0){if((tt(a,47224)|0)!=0){g=0;break}h=d+8|0;j=f+8|0;k=d+12|0;l=k;m=f+12|0;n=k|0;while(1){if((tw(a,40080)|0)==0){g=0;break L1261}tN(f,0);if((t0(a,b,f)|0)!=0){o=980;break}k=c[h>>2]|0;if(!((k|0)==(c[j>>2]|0)&(k|0)==1)){o=982;break}c[n>>2]=c[m>>2]|c[l>>2];tO(f);if((tt(a,47224)|0)!=0){g=0;break L1261}}if((o|0)==980){tO(f);g=1;break}else if((o|0)==982){tO(f);g=1;break}}else{g=1}}while(0);i=e;return g|0}function t0(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+16|0;f=e|0;L1274:do{if((t1(a,b,d)|0)==0){if((tt(a,37016)|0)!=0){g=0;break}h=d+8|0;j=f+8|0;k=d+12|0;l=k;m=f+12|0;n=k|0;while(1){if((tw(a,34208)|0)==0){g=0;break L1274}tN(f,0);if((t1(a,b,f)|0)!=0){o=990;break}k=c[h>>2]|0;if(!((k|0)==(c[j>>2]|0)&(k|0)==1)){o=992;break}c[n>>2]=c[m>>2]^c[l>>2];tO(f);if((tt(a,37016)|0)!=0){g=0;break L1274}}if((o|0)==990){tO(f);g=1;break}else if((o|0)==992){tO(f);g=1;break}}else{g=1}}while(0);i=e;return g|0}function t1(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+16|0;f=e|0;L1287:do{if((t2(a,b,d)|0)==0){if((tt(a,43648)|0)!=0){g=0;break}h=d+8|0;j=f+8|0;k=d+12|0;l=k;m=f+12|0;n=k|0;while(1){if((tw(a,31808)|0)==0){g=0;break L1287}tN(f,0);if((t2(a,b,f)|0)!=0){o=1e3;break}k=c[h>>2]|0;if(!((k|0)==(c[j>>2]|0)&(k|0)==1)){o=1002;break}c[n>>2]=c[m>>2]&c[l>>2];tO(f);if((tt(a,43648)|0)!=0){g=0;break L1287}}if((o|0)==1e3){tO(f);g=1;break}else if((o|0)==1002){tO(f);g=1;break}}else{g=1}}while(0);i=e;return g|0}function t2(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+16|0;f=e|0;if((t3(a,b,d)|0)!=0){g=1;i=e;return g|0}h=d+8|0;j=f+8|0;k=d+12|0;l=k;m=f+12|0;n=k|0;k=d+12|0;o=f+12|0;L1303:while(1){if((tw(a,30408)|0)==0){if((tw(a,29416)|0)==0){g=0;p=1023;break}else{q=2}}else{q=1}tN(f,0);if((t3(a,b,f)|0)!=0){p=1010;break}do{if((q|0)==2){r=c[h>>2]|0;if((r|0)!=(c[j>>2]|0)){p=1020;break L1303}if((r|0)==1){c[n>>2]=(c[l>>2]|0)!=(c[m>>2]|0);break}else if((r|0)==2){tT(d,(aQ(c[k>>2]|0,c[o>>2]|0)|0)!=0|0);break}else{p=1020;break L1303}}else if((q|0)==1){r=c[h>>2]|0;if((r|0)!=(c[j>>2]|0)){p=1020;break L1303}if((r|0)==1){c[n>>2]=(c[l>>2]|0)==(c[m>>2]|0);break}else if((r|0)==2){tT(d,(aQ(c[k>>2]|0,c[o>>2]|0)|0)==0|0);break}else{p=1020;break L1303}}else{p=1020;break L1303}}while(0);tO(f)}if((p|0)==1023){i=e;return g|0}else if((p|0)==1010){tO(f);g=1;i=e;return g|0}else if((p|0)==1020){tO(f);g=1;i=e;return g|0}return 0}function t3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+16|0;f=e|0;if((t4(a,b,d)|0)!=0){g=1;i=e;return g|0}h=d+8|0;j=f+8|0;k=d+12|0;l=k;m=f+12|0;n=k|0;k=d+12|0;o=f+12|0;L1331:while(1){do{if((tw(a,55248)|0)==0){if((tw(a,54392)|0)!=0){p=4;break}if((tw(a,53192)|0)!=0){p=1;break}if((tw(a,52584)|0)==0){g=0;q=1055;break L1331}else{p=3}}else{p=2}}while(0);tN(f,0);if((t4(a,b,f)|0)!=0){q=1034;break}do{if((p|0)==4){r=c[h>>2]|0;if((r|0)!=(c[j>>2]|0)){q=1052;break L1331}if((r|0)==1){c[n>>2]=(c[l>>2]|0)>>>0>=(c[m>>2]|0)>>>0;break}else if((r|0)==2){tT(d,(aQ(c[k>>2]|0,c[o>>2]|0)|0)>>>31^1);break}else{q=1052;break L1331}}else if((p|0)==1){r=c[h>>2]|0;if((r|0)!=(c[j>>2]|0)){q=1052;break L1331}if((r|0)==1){c[n>>2]=(c[l>>2]|0)>>>0<(c[m>>2]|0)>>>0;break}else if((r|0)==2){tT(d,(aQ(c[k>>2]|0,c[o>>2]|0)|0)>>>31);break}else{q=1052;break L1331}}else if((p|0)==3){r=c[h>>2]|0;if((r|0)!=(c[j>>2]|0)){q=1052;break L1331}if((r|0)==2){tT(d,(aQ(c[k>>2]|0,c[o>>2]|0)|0)>0|0);break}else if((r|0)==1){c[n>>2]=(c[l>>2]|0)>>>0>(c[m>>2]|0)>>>0;break}else{q=1052;break L1331}}else if((p|0)==2){r=c[h>>2]|0;if((r|0)!=(c[j>>2]|0)){q=1052;break L1331}if((r|0)==1){c[n>>2]=(c[l>>2]|0)>>>0<=(c[m>>2]|0)>>>0;break}else if((r|0)==2){tT(d,(aQ(c[k>>2]|0,c[o>>2]|0)|0)<1|0);break}else{q=1052;break L1331}}else{q=1052;break L1331}}while(0);tO(f)}if((q|0)==1034){tO(f);g=1;i=e;return g|0}else if((q|0)==1055){i=e;return g|0}else if((q|0)==1052){tO(f);g=1;i=e;return g|0}return 0}function t4(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+16|0;f=e|0;if((t5(a,b,d)|0)!=0){g=1;i=e;return g|0}h=d+8|0;j=f+8|0;k=d+12|0;d=k;l=f+12|0;m=k|0;while(1){if((tw(a,51824)|0)==0){if((tw(a,51232)|0)==0){g=0;n=1075;break}else{o=2}}else{o=1}tN(f,0);if((t5(a,b,f)|0)!=0){n=1064;break}if((o|0)==1){k=c[h>>2]|0;if(!((k|0)==(c[j>>2]|0)&(k|0)==1)){n=1070;break}p=c[d>>2]<<(c[l>>2]&31)}else if((o|0)==2){k=c[h>>2]|0;if(!((k|0)==(c[j>>2]|0)&(k|0)==1)){n=1070;break}p=(c[d>>2]|0)>>>((c[l>>2]&31)>>>0)}else{n=1070;break}c[m>>2]=p;tO(f)}if((n|0)==1075){i=e;return g|0}else if((n|0)==1070){tO(f);g=1;i=e;return g|0}else if((n|0)==1064){tO(f);g=1;i=e;return g|0}return 0}function t5(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0;f=i;i=i+48|0;g=f+32|0;if((t6(b,d,e)|0)!=0){h=1;i=f;return h|0}j=f|0;k=e+8|0;l=g+8|0;m=e+12|0;n=m;o=g+12|0;p=m|0;m=e+12|0;q=g+12|0;while(1){if((tw(b,50400)|0)==0){if((tw(b,49736)|0)==0){h=0;r=1120;break}else{s=2}}else{s=1}tN(g,0);if((t6(b,d,g)|0)!=0){r=1082;break}if((s|0)==2){t=c[k>>2]|0;if(!((t|0)==(c[l>>2]|0)&(t|0)==1)){r=1109;break}c[p>>2]=(c[n>>2]|0)-(c[o>>2]|0);tO(g);continue}else if((s|0)!=1){r=1109;break}t=c[k>>2]|0;u=c[l>>2]|0;v=(t|0)==1;w=(u|0)==1;if(v&w){c[p>>2]=(c[o>>2]|0)+(c[n>>2]|0);tO(g);continue}y=(t|0)==2;t=(u|0)==2;if(y&t){u=c[m>>2]|0;z=c[q>>2]|0;A=u8(u|0)|0;B=u8(z|0)|0;C=B+A|0;D=u0(C+1|0)|0;if((D|0)==0){r=1112;break}if((A|0)!=0){u7(D|0,u|0,A)|0}if((B|0)!=0){u=D+A|0;u7(u|0,z|0,B)|0}a[D+C|0]=0;tU(e,D);u1(D);tO(g);continue}if(y&w){w=c[o>>2]|0;a2(j|0,49280,(x=i,i=i+8|0,c[x>>2]=w,x)|0)|0;w=c[m>>2]|0;y=u8(w|0)|0;D=u8(j|0)|0;C=D+y|0;B=u0(C+1|0)|0;if((B|0)==0){r=1113;break}if((y|0)!=0){u7(B|0,w|0,y)|0}if((D|0)!=0){w=B+y|0;u7(w|0,j|0,D)|0}a[B+C|0]=0;tU(e,B);u1(B);tO(g);continue}if(!(v&t)){r=1111;break}a2(j|0,49280,(x=i,i=i+8|0,c[x>>2]=c[n>>2],x)|0)|0;t=c[q>>2]|0;v=u8(j|0)|0;B=u8(t|0)|0;C=B+v|0;D=u0(C+1|0)|0;if((D|0)==0){r=1110;break}if((v|0)!=0){u7(D|0,j|0,v)|0}if((B|0)!=0){w=D+v|0;u7(w|0,t|0,B)|0}a[D+C|0]=0;tU(e,D);u1(D);tO(g)}if((r|0)==1110){tO(g);h=1;i=f;return h|0}else if((r|0)==1111){tO(g);h=1;i=f;return h|0}else if((r|0)==1112){tO(g);h=1;i=f;return h|0}else if((r|0)==1082){tO(g);h=1;i=f;return h|0}else if((r|0)==1109){tO(g);h=1;i=f;return h|0}else if((r|0)==1113){tO(g);h=1;i=f;return h|0}else if((r|0)==1120){i=f;return h|0}return 0}function t6(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+16|0;f=e|0;if((t7(a,b,d)|0)!=0){g=1;i=e;return g|0}h=d+8|0;j=f+8|0;k=d+12|0;d=k;l=f+12|0;m=k|0;L1452:while(1){do{if((tw(a,48816)|0)==0){if((tw(a,48344)|0)!=0){n=2;break}if((tw(a,47944)|0)==0){g=0;o=1143;break L1452}else{n=3}}else{n=1}}while(0);tN(f,0);if((t7(a,b,f)|0)!=0){o=1129;break}if((n|0)==3){k=c[h>>2]|0;if(!((k|0)==(c[j>>2]|0)&(k|0)==1)){o=1139;break}k=c[l>>2]|0;if((k|0)==0){o=1139;break}c[m>>2]=((c[d>>2]|0)>>>0)%(k>>>0)|0}else if((n|0)==2){k=c[h>>2]|0;if(!((k|0)==(c[j>>2]|0)&(k|0)==1)){o=1139;break}k=c[l>>2]|0;if((k|0)==0){o=1139;break}c[m>>2]=((c[d>>2]|0)>>>0)/(k>>>0)|0}else if((n|0)==1){k=c[h>>2]|0;if(!((k|0)==(c[j>>2]|0)&(k|0)==1)){o=1139;break}c[m>>2]=ac(c[l>>2]|0,c[d>>2]|0)|0}else{o=1139;break}tO(f)}if((o|0)==1143){i=e;return g|0}else if((o|0)==1129){tO(f);g=1;i=e;return g|0}else if((o|0)==1139){tO(f);g=1;i=e;return g|0}return 0}function t7(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0;do{if((tw(b,50400)|0)==0){if((tw(b,49736)|0)!=0){f=2;break}if((tw(b,47120)|0)!=0){f=3;break}f=(tw(b,46720)|0)==0?0:4}else{f=1}}while(0);if((t8(b,d,e)|0)!=0){g=1;return g|0}if((f|0)==4){d=c[e+8>>2]|0;if((d|0)==2){tT(e,(a[c[e+12>>2]|0]|0)==0|0);g=0;return g|0}else if((d|0)==1){d=e+12|0;c[d>>2]=(c[d>>2]|0)==0;g=0;return g|0}else{g=1;return g|0}}else if((f|0)==2){if((c[e+8>>2]|0)!=1){g=1;return g|0}d=e+12|0;c[d>>2]=-(c[d>>2]|0);g=0;return g|0}else if((f|0)==3){if((c[e+8>>2]|0)!=1){g=1;return g|0}d=e+12|0;c[d>>2]=~c[d>>2];g=0;return g|0}else if((f|0)==1){g=(c[e+8>>2]|0)!=1|0;return g|0}else{g=0;return g|0}return 0}function t8(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+256|0;g=f|0;if((tw(b,45944)|0)!=0){if((tY(b,d,e)|0)!=0){h=1;i=f;return h|0}tq(b)|0;h=(tw(b,45640)|0)==0|0;i=f;return h|0}j=g|0;if((ts(b,j,256)|0)!=0){tU(e,j);h=0;i=f;return h|0}if((tr(b,j,256)|0)!=0){if((aQ(j|0,45360)|0)==0){if((t8(b,d,e)|0)!=0){h=1;i=f;return h|0}tT(e,(c[e+8>>2]|0)!=0|0);h=0;i=f;return h|0}if((aQ(j|0,45072)|0)==0){tT(e,1);h=0;i=f;return h|0}if((aQ(j|0,44760)|0)==0){tT(e,0);h=0;i=f;return h|0}L1534:do{if((d|0)!=0){k=g+((a[j]|0)==36)|0;l=d;while(1){m=tF(l,k,0)|0;if((m|0)!=0){break}l=c[l+4>>2]|0;if((l|0)==0){break L1534}}tS(e,m);h=0;i=f;return h|0}}while(0);tP(e);h=0;i=f;return h|0}if((tw(b,44456)|0)==0){n=(tw(b,44216)|0)==0?10:2}else{n=16}m=tn(b,0)|0;if(m<<24>>24==0){h=1;i=f;return h|0}else{o=1;p=0;q=m}L1549:while(1){m=q<<24>>24;do{if((q-48&255)<10){r=m-48|0}else{if((q-97&255)<6){r=m-87|0;break}if((q-65&255)>=6){s=1201;break L1549}r=m-55|0}}while(0);if(r>>>0>=n>>>0){s=1201;break}m=r+(ac(p,n)|0)|0;tp(b,1);d=tn(b,0)|0;if(d<<24>>24==0){t=m;break}else{o=0;p=m;q=d}}do{if((s|0)==1201){if((o|0)!=0){h=1;i=f;return h|0}if((q<<24>>24|0)==107|(q<<24>>24|0)==75){tp(b,1);t=p<<10;break}else if((q<<24>>24|0)==109|(q<<24>>24|0)==77){tp(b,1);t=p<<20;break}else if((q<<24>>24|0)==103|(q<<24>>24|0)==71){tp(b,1);t=p<<30;break}else{t=p;break}}}while(0);tT(e,t);h=0;i=f;return h|0}function t9(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;i=i+32|0;e=d|0;f=u0(104)|0;if((f|0)==0){g=0;i=d;return g|0}h=f;j=a;u7(f|0,j|0,68)|0;n2(h,5);c[f+4>>2]=96;c[f+8>>2]=24;c[f+12>>2]=70;c[f+16>>2]=16;c[f+20>>2]=56;c[f+60>>2]=0;c[f+64>>2]=f;c[f+68>>2]=a;a=f+28|0;j=((c[a>>2]|0)+7|0)>>>3;k=f+100|0;c[k>>2]=j;l=u0(j)|0;j=f+96|0;c[j>>2]=l;if((l|0)==0){u1(f);g=0;i=d;return g|0}l=aZ(b|0,47744)|0;m=f+72|0;c[m>>2]=l;L1579:do{if((l|0)==0){n=aZ(b|0,53368)|0;c[m>>2]=n;if((n|0)==0){o=1235;break}n=e|0;p=((c[a>>2]|0)+7|0)>>>3;c[k>>2]=p;q=f+80|0;c[q>>2]=20;c[q+4>>2]=0;r=f+88|0;c[r>>2]=p+531&1073741312;c[r+4>>2]=0;nX(n,0,1129273120);nX(n,4,0);nX(n,8,c[a>>2]|0);nX(n,12,c[q>>2]|0);nX(n,16,c[r>>2]|0);do{if((oe(c[m>>2]|0,n,0,0,20,0)|0)==0){u6(c[j>>2]|0,0,c[k>>2]|0);if((oe(c[m>>2]|0,c[j>>2]|0,c[q>>2]|0,c[q+4>>2]|0,c[k>>2]|0,0)|0)!=0){break}r=c[m>>2]|0;ay(r|0)|0;o=1236;break L1579}}while(0);q=c[m>>2]|0;av(q|0)|0;o=1235}else{q=e|0;do{if((od(l,q,0,0,20,0)|0)==0){if((nW(q,0)|0)!=1129273120){break}if((nW(q,4)|0)!=0){break}n=nW(q,8)|0;if((n|0)!=(c[a>>2]|0)){break}n=f+80|0;c[n>>2]=nW(q,12)|0;c[n+4>>2]=0;r=f+88|0;c[r>>2]=nW(q,16)|0;c[r+4>>2]=0;if((od(c[m>>2]|0,c[j>>2]|0,c[n>>2]|0,c[n+4>>2]|0,c[k>>2]|0,0)|0)==0){o=1236;break L1579}}}while(0);q=c[m>>2]|0;av(q|0)|0;o=1235}}while(0);if((o|0)==1235){u1(c[j>>2]|0);u1(f);g=0;i=d;return g|0}else if((o|0)==1236){oj(h,b);g=h;i=d;return g|0}return 0}function ua(a){a=a|0;var b=0;b=c[a+64>>2]|0;oi(c[b+68>>2]|0);av(c[b+72>>2]|0)|0;u1(c[b+96>>2]|0);u1(b);return}function ub(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 1}function uc(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;h=c[b+64>>2]|0;i=b+28|0;b=h+68|0;j=h+72|0;if((g|0)==0){k=0;return k|0}l=f;m=h+88|0;n=vf(c[m>>2]|0,c[m+4>>2]|0,l<<9|0>>>23,0<<9|l>>>23)|0;l=h+96|0;h=f;f=g;g=e;e=G;m=n;while(1){if(h>>>0>=(c[i>>2]|0)>>>0){k=1;o=1268;break}n=h>>>3;p=128>>>((h&7)>>>0);q=c[l>>2]|0;r=(d[q+n|0]&p|0)!=0;L1607:do{if(f>>>0<2){s=1}else{t=r<<31>>31;u=f-1|0;if((u|0)==0){s=1;break}v=n;w=p&255;x=u;u=1;while(1){L1612:do{if(w<<24>>24==1){y=v+1|0;if(x>>>0>7){z=x;A=y;B=u;while(1){if((a[q+A|0]|0)!=t<<24>>24){C=-128;D=z;E=A;F=B;break L1612}H=z-8|0;I=B+8|0;J=A+1|0;if(H>>>0>7){z=H;A=J;B=I}else{K=H;L=J;M=I;break}}}else{K=x;L=y;M=u}if((K|0)==0){s=M;break L1607}else{C=-128;D=K;E=L;F=M}}else{C=(w&255)>>>1;D=x;E=v;F=u}}while(0);if((a[q+E|0]&C)<<24>>24!=0^r){s=F;break L1607}B=F+1|0;A=D-1|0;if((A|0)==0){s=B;break}else{v=E;w=C;x=A;u=B}}}}while(0);if(r){q=s<<9;p=q;n=0;if((od(c[j>>2]|0,g,m,e,p,n)|0)==0){N=q;O=n;P=p}else{k=1;o=1267;break}}else{if((oo(c[b>>2]|0,g,h,s)|0)!=0){k=1;o=1266;break}p=s<<9;N=p;O=0;P=p}p=vf(P,O,m,e)|0;if((f|0)==(s|0)){k=0;o=1264;break}else{h=s+h|0;f=f-s|0;g=g+N|0;e=G;m=p}}if((o|0)==1264){return k|0}else if((o|0)==1266){return k|0}else if((o|0)==1267){return k|0}else if((o|0)==1268){return k|0}return 0}function ud(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;if((a[b+56|0]|0)!=0){h=1;return h|0}i=c[b+64>>2]|0;L1637:do{if((g|0)==0){j=i+72|0}else{k=f;l=i+88|0;m=vf(c[l>>2]|0,c[l+4>>2]|0,k<<9|0>>>23,0<<9|k>>>23)|0;k=b+28|0;l=i+96|0;n=i+72|0;o=i+80|0;p=f;q=g;r=e;s=G;t=m;while(1){if(p>>>0>=(c[k>>2]|0)>>>0){h=1;u=1298;break}m=p>>>3;v=128>>>((p&7)>>>0);w=c[l>>2]|0;x=w+m|0;y=d[x]|0;z=(y&v|0)!=0;L1642:do{if(q>>>0<2){A=1}else{B=z<<31>>31;C=q-1|0;if((C|0)==0){A=1;break}D=m;E=v&255;F=C;C=1;while(1){L1647:do{if(E<<24>>24==1){H=D+1|0;if(F>>>0>7){I=F;J=H;K=C;while(1){if((a[w+J|0]|0)!=B<<24>>24){L=-128;M=I;N=J;O=K;break L1647}P=I-8|0;Q=K+8|0;R=J+1|0;if(P>>>0>7){I=P;J=R;K=Q}else{S=P;T=R;U=Q;break}}}else{S=F;T=H;U=C}if((S|0)==0){A=U;break L1642}else{L=-128;M=S;N=T;O=U}}else{L=(E&255)>>>1;M=F;N=D;O=C}}while(0);if((a[w+N|0]&L)<<24>>24!=0^z){A=O;break L1642}K=O+1|0;J=M-1|0;if((J|0)==0){A=K;break}else{D=N;E=L;F=J;C=K}}}}while(0);if(!z){w=p-1+A|0;C=w>>>3;F=128>>>((w&7)>>>0);w=v+255|v;E=F+255^255|F;do{if((m|0)==(C|0)){a[x]=(y|E&w)&255}else{a[x]=(y|w)&255;F=(c[l>>2]|0)+C|0;a[F]=(d[F]|E)&255;F=m+1|0;if(F>>>0<C>>>0){V=F}else{break}do{a[(c[l>>2]|0)+V|0]=-1;V=V+1|0;}while(V>>>0<C>>>0)}}while(0);E=c[n>>2]|0;w=(c[l>>2]|0)+m|0;y=vf(c[o>>2]|0,c[o+4>>2]|0,m,0)|0;x=G;v=1-m+C|0;z=0;oe(E,w,y,x,v,z)|0}z=A<<9;v=z;x=0;if((oe(c[n>>2]|0,r,t,s,v,x)|0)!=0){h=1;u=1295;break}y=vf(v,x,t,s)|0;if((q|0)==(A|0)){j=n;break L1637}else{p=A+p|0;q=q-A|0;r=r+z|0;s=G;t=y}}if((u|0)==1295){return h|0}else if((u|0)==1298){return h|0}}}while(0);ay(c[j>>2]|0)|0;h=0;return h|0}function ue(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;f=i;i=i+4096|0;if((aQ(e|0,47200)|0)!=0){g=1;i=f;return g|0}e=c[b+64>>2]|0;b=e+100|0;h=c[b>>2]|0;do{if((h|0)==0){j=e+72|0;k=0}else{l=e+96|0;m=f|0;n=e+68|0;o=e+88|0;p=e+72|0;q=0;r=0;s=0;t=h;while(1){u=a[(c[l>>2]|0)+r|0]|0;if(u<<24>>24==0){v=q;w=s;x=t}else{y=q;z=s;A=r<<3;B=u;while(1){if(B<<24>>24>-1){u=A;C=B;while(1){D=C<<1;E=u+1|0;if(D<<24>>24>-1){u=E;C=D}else{F=E;H=D;break}}}else{F=A;H=B}C=0;u=H;do{C=C+1|0;u=u<<1;}while(u<<24>>24<=-1);L1693:do{if((C|0)==0){I=1}else{D=F;E=vf(c[o>>2]|0,c[o+4>>2]|0,D<<9|0>>>23,0<<9|D>>>23)|0;D=F;J=C;K=G;L=E;while(1){E=J>>>0>8?8:J;M=E<<9;N=M;O=0;if((od(c[p>>2]|0,m,L,K,N,O)|0)!=0){I=0;break L1693}if((op(c[n>>2]|0,m,D,E)|0)!=0){I=0;break L1693}u6(m|0,0,M|0);if((oe(c[p>>2]|0,m,L,K,N,O)|0)!=0){I=0;break L1693}if((E|0)!=0){M=0;do{P=M+D|0;Q=(c[l>>2]|0)+(P>>>3)|0;a[Q]=(128>>>((P&7)>>>0)^255)&(d[Q]|0)&255;M=M+1|0;}while(M>>>0<E>>>0)}M=vf(N,O,L,K)|0;if((J|0)==(E|0)){I=1;break}else{D=E+D|0;J=J-E|0;K=G;L=M}}}}while(0);R=I?y:1;S=(I?C:0)+z|0;if(u<<24>>24==0){break}else{y=R;z=S;A=C+F|0;B=u}}v=R;w=S;x=c[b>>2]|0}B=r+1|0;if(B>>>0<x>>>0){q=v;r=B;s=w;t=x}else{break}}if((w|0)==0){j=p;k=v;break}t=e+80|0;if((oe(c[p>>2]|0,c[l>>2]|0,c[t>>2]|0,c[t+4>>2]|0,x,0)|0)==0){t=c[p>>2]|0;ay(t|0)|0;j=p;k=v;break}else{g=1;i=f;return g|0}}}while(0);ay(c[j>>2]|0)|0;g=k;i=f;return g|0}function uf(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;if((h|0)==0){i=aZ(b|0,53360)|0}else{i=aZ(b|0,47728)|0}if((i|0)==0){j=1;return j|0}b=c[a+64>>2]|0;a=b+68|0;k=c[a>>2]|0;l=b+72|0;c[l+(k<<5)>>2]=f;c[l+(k<<5)+4>>2]=g;g=l+(k<<5)+8|0;c[g>>2]=d;c[g+4>>2]=e;c[l+(k<<5)+16>>2]=i;c[l+(k<<5)+20>>2]=1;c[l+(k<<5)+24>>2]=(h|0)!=0;c[a>>2]=k+1;j=0;return j|0}function ug(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=u0(584)|0;if((f|0)==0){g=0;return g|0}h=f;oh(h,f,0,a,b,d);n4(h,e);c[f+4>>2]=78;c[f+8>>2]=60;c[f+12>>2]=56;c[f+68>>2]=0;g=h;return g|0}function uh(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=c[a+64>>2]|0;a=b+68|0;d=c[a>>2]|0;if((d|0)==0){u1(b);return}e=b+72|0;f=0;g=d;while(1){if((c[e+(f<<5)+20>>2]|0)==0){h=g}else{d=c[e+(f<<5)+16>>2]|0;av(d|0)|0;h=c[a>>2]|0}d=f+1|0;if(d>>>0<h>>>0){f=d;g=h}else{break}}u1(b);return}function ui(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;if((e+d|0)>>>0>(c[a+28>>2]|0)>>>0){f=1;return f|0}if((e|0)==0){f=0;return f|0}g=a+64|0;a=c[g>>2]|0;h=a+72|0;i=e;e=d;d=b;b=a;while(1){a=c[b+68>>2]|0;if((a|0)==0){j=1359;break}k=b+72|0;l=0;m=0;while(1){n=c[k+(l<<5)>>2]|0;if(n>>>0>e>>>0){o=n>>>0<(c[k+(m<<5)>>2]|0)>>>0?l:m}else{if((e-n|0)>>>0<(c[k+(l<<5)+4>>2]|0)>>>0){p=l;break}else{o=m}}n=l+1|0;if(n>>>0<a>>>0){l=n;m=o}else{j=1358;break}}if((j|0)==1358){j=0;if((c[k+(o<<5)>>2]|0)>>>0>e>>>0){p=o}else{j=1359;break}}m=c[h+(p<<5)>>2]|0;if(m>>>0>e>>>0){l=m-e|0;a=l>>>0>i>>>0?i:l;l=a<<9;u6(d|0,-2|0,l|0);q=l;r=a}else{a=e-m|0;m=(c[h+(p<<5)+4>>2]|0)-a|0;l=m>>>0>i>>>0?i:m;m=h+(p<<5)+8|0;n=a;a=vf(c[m>>2]|0,c[m+4>>2]|0,n<<9|0>>>23,0<<9|n>>>23)|0;n=l;m=n<<9|0>>>23;if((od(c[h+(p<<5)+16>>2]|0,d,a,G,m,0<<9|n>>>23)|0)==0){q=m;r=l}else{f=1;j=1370;break}}if((i|0)==(r|0)){f=0;j=1368;break}i=i-r|0;e=r+e|0;d=d+q|0;b=c[g>>2]|0}if((j|0)==1359){u6(d|0,-2|0,i<<9|0);f=0;return f|0}else if((j|0)==1370){return f|0}else if((j|0)==1368){return f|0}return 0}function uj(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((e+d|0)>>>0>(c[a+28>>2]|0)>>>0){f=1;return f|0}g=a+64|0;a=c[g>>2]|0;h=a+72|0;if((e|0)==0){f=0;return f|0}else{i=e;j=d;k=b;l=a}while(1){a=c[l+68>>2]|0;if((a|0)==0){f=0;m=1392;break}b=l+72|0;d=0;e=0;while(1){n=c[b+(d<<5)>>2]|0;if(n>>>0>j>>>0){o=n>>>0<(c[b+(e<<5)>>2]|0)>>>0?d:e}else{if((j-n|0)>>>0<(c[b+(d<<5)+4>>2]|0)>>>0){p=d;break}else{o=e}}n=d+1|0;if(n>>>0<a>>>0){d=n;e=o}else{m=1379;break}}if((m|0)==1379){m=0;if((c[b+(o<<5)>>2]|0)>>>0>j>>>0){p=o}else{f=0;m=1394;break}}e=c[h+(p<<5)>>2]|0;if(e>>>0>j>>>0){d=e-j|0;a=d>>>0>i>>>0?i:d;q=a<<9;r=a}else{if((c[h+(p<<5)+24>>2]|0)!=0){f=1;m=1393;break}a=j-e|0;e=(c[h+(p<<5)+4>>2]|0)-a|0;d=e>>>0>i>>>0?i:e;e=h+(p<<5)+8|0;n=a;a=vf(c[e>>2]|0,c[e+4>>2]|0,n<<9|0>>>23,0<<9|n>>>23)|0;n=d;e=n<<9|0>>>23;s=h+(p<<5)+16|0;if((oe(c[s>>2]|0,k,a,G,e,0<<9|n>>>23)|0)!=0){f=1;m=1391;break}n=c[s>>2]|0;ay(n|0)|0;q=e;r=d}if((i|0)==(r|0)){f=0;m=1389;break}i=i-r|0;j=r+j|0;k=k+q|0;l=c[g>>2]|0}if((m|0)==1392){return f|0}else if((m|0)==1393){return f|0}else if((m|0)==1394){return f|0}else if((m|0)==1391){return f|0}else if((m|0)==1389){return f|0}return 0}function uk(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;h=u0(72)|0;if((h|0)==0){i=0;return i|0}j=h;oh(j,h,b,d,e,f);n2(j,2);n4(j,g);c[h+4>>2]=74;c[h+8>>2]=58;c[h+12>>2]=4;g=h+28|0;f=c[g>>2]<<9;e=u0(f)|0;d=h+68|0;c[d>>2]=e;if((e|0)==0){u1(h);i=0;return i|0}u6(e|0,0,f|0);if((a|0)==0){i=j;return i|0}f=aZ(a|0,47664)|0;do{if((f|0)!=0){e=c[g>>2]|0;b=od(f,c[d>>2]|0,0,0,e<<9|0>>>23,0<<9|e>>>23)|0;av(f|0)|0;if((b|0)!=0){break}oj(j,a);i=j;return i|0}}while(0);u1(c[d>>2]|0);u1(h);i=0;return i|0}function ul(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function um(a){a=a|0;return 0}function un(a,b,c){a=a|0;b=b|0;c=c|0;return-1|0}function uo(a){a=a|0;return}function up(a){a=a|0;return}function uq(a){a=a|0;var b=0,d=0,e=0,f=0;b=7224;while(1){d=c[b+4>>2]|0;if((d|0)==0){e=0;f=1418;break}if((c[b>>2]|0)==(a|0)){e=d;f=1419;break}else{b=b+8|0}}if((f|0)==1418){return e|0}else if((f|0)==1419){return e|0}return 0}function ur(a,b,d){a=a|0;b=b|0;d=d|0;c[a+4>>2]=b;c[a+8>>2]=d;return}function us(a,b,d){a=a|0;b=b|0;d=d|0;c[a+12>>2]=b;c[a+16>>2]=d;return}function ut(a,b,d){a=a|0;b=b|0;d=d|0;c[a+20>>2]=b;c[a+24>>2]=d;return}function uu(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;c[a+100>>2]=b;c[a+104>>2]=d;c[a+108>>2]=0;c[a+112>>2]=e;c[a+116>>2]=f;c[a+120>>2]=0;return}function uv(a,b,d){a=a|0;b=b|0;d=d|0;c[a+92>>2]=b;c[a+96>>2]=d;return}function uw(a,b){a=a|0;b=b|0;c[a+80>>2]=(b|0)==0?1:b;c[a+132>>2]=0;c[a+136>>2]=0;c[a+140>>2]=c[a+64>>2];c[a+144>>2]=c[a+68>>2];return}function ux(a,b,d){a=a|0;b=b|0;d=d|0;c[a+84>>2]=b;c[a+88>>2]=d;return}function uy(a){a=a|0;var b=0;b=c[a+64>>2]|0;u1(c[b+68>>2]|0);u1(b);return}function uz(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;if((e+d|0)>>>0>(c[a+28>>2]|0)>>>0){f=1;return f|0}g=(c[(c[a+64>>2]|0)+68>>2]|0)+(d<<9)|0;d=e<<9;u7(b|0,g|0,d)|0;f=0;return f|0}function uA(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;if((a[b+56|0]|0)!=0){g=1;return g|0}if((f+e|0)>>>0>(c[b+28>>2]|0)>>>0){g=1;return g|0}h=(c[(c[b+64>>2]|0)+68>>2]|0)+(e<<9)|0;e=f<<9;u7(h|0,d|0,e)|0;g=0;return g|0}function uB(a){a=a|0;var b=0,d=0,e=0,f=0;b=7224;while(1){d=c[b+4>>2]|0;if((d|0)==0){e=0;f=1445;break}if((ve(d|0,a|0)|0)==0){break}else{b=b+8|0}}if((f|0)==1445){return e|0}e=c[b>>2]|0;return e|0}function uC(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+32|0;g=f|0;h=b;while(1){b=a[h]|0;if(!((b<<24>>24|0)==32|(b<<24>>24|0)==9)){j=h;k=0;l=b;break}h=h+1|0}while(1){if((l<<24>>24|0)==0|(l<<24>>24|0)==61|(l<<24>>24|0)==32){break}h=j+1|0;b=k+1|0;a[g+k|0]=l;if(b>>>0>=32){m=1;n=1465;break}j=h;k=b;l=a[h]|0}if((n|0)==1465){i=f;return m|0}if(k>>>0>31){m=1;i=f;return m|0}a[g+k|0]=0;k=j;while(1){j=a[k]|0;if((j<<24>>24|0)==61){o=k;n=1457;break}else if((j<<24>>24|0)!=32){p=k;break}k=k+1|0}if((n|0)==1457){while(1){n=0;k=o+1|0;if((a[k]|0)==32){o=k;n=1457}else{p=k;break}}}c[d>>2]=ax(g|0,0,0)|0;g=7224;while(1){d=c[g+4>>2]|0;if((d|0)==0){q=0;break}if((ve(d|0,p|0)|0)==0){n=1461;break}else{g=g+8|0}}if((n|0)==1461){q=c[g>>2]|0}c[e>>2]=q;m=0;i=f;return m|0}function uD(a){a=a|0;var b=0,d=0;a=u0(152)|0;if((a|0)==0){b=0;return b|0}d=a;uF(d,a);c[a+28>>2]=16;c[a+32>>2]=4;c[a+36>>2]=104;c[a+40>>2]=46;c[a+44>>2]=24;c[a+48>>2]=60;b=d;return b|0}function uE(a){a=a|0;if((a|0)==0){return}u1(a);return}function uF(a,b){a=a|0;b=b|0;c[a>>2]=b;u6(a+4|0,0,28);u6(a+40|0,0,16);c[a+56>>2]=1;u6(a+60|0,0,20);c[a+80>>2]=1;c[a+84>>2]=4;c[a+88>>2]=3;c[a+92>>2]=320;c[a+96>>2]=240;c[a+100>>2]=1;c[a+104>>2]=1;c[a+108>>2]=0;c[a+112>>2]=1;c[a+116>>2]=1;u6(a+120|0,0,32);return}function uG(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=a+52|0;if((c[e>>2]|0)!=0){f=0;return f|0}g=c[a+32>>2]|0;do{if((g|0)!=0){if((b2[g&127](c[a>>2]|0,b,d)|0)==0){break}else{f=1}return f|0}}while(0);c[e>>2]=1;f=0;return f|0}function uH(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+256|0;f=e|0;if((d|0)==0){g=1488}else{if((a[d]|0)==0){g=1488}else{h=d}}if((g|0)==1488){g=f|0;f=b+148|0;d=c[f>>2]|0;a2(g|0,46816,(x=i,i=i+8|0,c[x>>2]=d,x)|0)|0;c[f>>2]=(c[f>>2]|0)+1;h=g}g=aZ(h|0,53104)|0;if((g|0)==0){j=1;i=e;return j|0}h=c[b+64>>2]|0;f=c[b+68>>2]|0;d=ac(h*3|0,f)|0;bN(g|0,47040,(x=i,i=i+24|0,c[x>>2]=h,c[x+8>>2]=f,c[x+16>>2]=255,x)|0)|0;f=aC(c[b+76>>2]|0,1,d|0,g|0)|0;av(g|0)|0;j=(f|0)!=(d|0)|0;i=e;return j|0}function uI(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;if((aQ(b|0,43520)|0)==0){e=uB(d)|0;if((e|0)==0){f=0;return f|0}c[a+56>>2]=e;f=0;return f|0}if((aQ(b|0,39960)|0)==0){uH(a,d)|0;f=0;return f|0}e=c[a+40>>2]|0;if((e|0)==0){f=-1;return f|0}f=b2[e&127](c[a>>2]|0,b,d)|0;return f|0}function uJ(a,b){a=a|0;b=b|0;var d=0,e=0;d=uB(b)|0;if((d|0)==0){e=1;return e|0}c[a+56>>2]=d;e=0;return e|0}function uK(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if((b|0)==0|(d|0)==0){u1(c[a+76>>2]|0);u6(a+64|0,0,16);return}e=a+64|0;do{if((c[e>>2]|0)==(b|0)){if((c[a+68>>2]|0)!=(d|0)){break}return}}while(0);f=ac(b*3|0,d)|0;g=a+72|0;do{if((c[g>>2]|0)!=(f|0)){h=a+76|0;i=u2(c[h>>2]|0,f)|0;if((i|0)==0){return}else{c[h>>2]=i;c[g>>2]=f;break}}}while(0);c[e>>2]=b;c[a+68>>2]=d;c[a+132>>2]=0;c[a+136>>2]=0;c[a+140>>2]=b;c[a+144>>2]=d;return}function uL(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=a+64|0;g=(c[f>>2]|0)*3|0;h=c[a+76>>2]|0;i=h+(ac(g,d)|0)|0;L1953:do{if((e|0)==0){j=0;k=d;l=b;m=i}else{h=e;n=d;o=b;p=i;while(1){if((va(p|0,o|0,g|0)|0)!=0){j=h;k=n;l=o;m=p;break L1953}q=o+g|0;r=p+g|0;s=n+1|0;t=h-1|0;if((t|0)==0){j=0;k=s;l=q;m=r;break}else{h=t;n=s;o=q;p=r}}}}while(0);i=ac(j,g)|0;b=j;while(1){if((b|0)==0){u=1541;break}j=i-g|0;if((va(m+j|0,l+j|0,g|0)|0)==0){i=j;b=b-1|0}else{break}}if((u|0)==1541){return}u=ac(b,g)|0;u7(m|0,l|0,u)|0;c[a+132>>2]=0;c[a+140>>2]=c[f>>2];f=a+144|0;u=c[f>>2]|0;l=a+136|0;if((u|0)==0){c[l>>2]=k;c[f>>2]=b;return}a=c[l>>2]|0;if(k>>>0<a>>>0){m=u-k+a|0;c[f>>2]=m;c[l>>2]=k;v=k;w=m}else{v=a;w=u}u=b+k|0;if(u>>>0<=(w+v|0)>>>0){return}c[f>>2]=u-v;return}function uM(a){a=a|0;var b=0;if((c[a+140>>2]|0)==0){return}if((c[a+144>>2]|0)==0){return}b=c[a+44>>2]|0;if((b|0)!=0){b0[b&127](c[a>>2]|0)}u6(a+132|0,0,16);return}function uN(a){a=a|0;var b=0;b=c[a+48>>2]|0;if((b|0)==0){return}b0[b&127](c[a>>2]|0);return}function uO(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=c[a+8>>2]|0;if((e|0)==0){f=1;return f|0}f=b2[e&127](c[a+4>>2]|0,b,d)|0;return f|0}function uP(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;do{if((b|0)==1){e=(c[a+56>>2]|0)==(d|0);f=a+60|0;g=c[f>>2]|0;if(e){h=g^1;c[f>>2]=h;i=h}else{i=g}g=a+60|0;if((i&1|0)!=0){if(e){return}uR(a,3,d);return}do{if((d|0)==75){e=i|4;c[g>>2]=e;j=e}else if((d|0)==16){if((i&12|0)!=0){j=i;break}e=a+40|0;h=c[e>>2]|0;do{if((h|0)!=0){f=c[a>>2]|0;b2[h&127](f,36920,58192)|0;f=c[e>>2]|0;if((f|0)==0){break}k=c[a>>2]|0;b2[f&127](k,31720,30384)|0}}while(0);e=c[a+8>>2]|0;if((e|0)==0){return}b2[e&127](c[a+4>>2]|0,29384,55216)|0;return}else if((d|0)==71){e=i|8;c[g>>2]=e;j=e}else{j=i}}while(0);if((j&12|0)!=12){break}e=c[a+40>>2]|0;if((e|0)==0){l=j}else{h=c[a>>2]|0;b2[e&127](h,36920,58192)|0;l=c[g>>2]|0}c[g>>2]=l&-13}else if((b|0)==2){h=a+60|0;e=c[h>>2]|0;if((e&1|0)==0){if((d|0)==16){return}else if((d|0)==75){c[h>>2]=e&-5;break}else if((d|0)==71){c[h>>2]=e&-9;break}else{break}}else{if((c[a+56>>2]|0)==(d|0)){return}c[h>>2]=e&-2;return}}}while(0);uR(a,b,d);return}function uQ(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=c[a+92>>2]|0;h=a+96|0;i=1;while(1){if((ac(i,b)|0)>>>0>=g>>>0){break}j=ac(i,d)|0;if(j>>>0<(c[h>>2]|0)>>>0){i=i+1|0}else{break}}h=a+80|0;g=i-1|0;c[e>>2]=g+(c[h>>2]|0);i=g+(c[h>>2]|0)|0;c[f>>2]=i;h=a+84|0;g=c[h>>2]|0;if((g|0)==0){return}j=a+88|0;a=c[j>>2]|0;if((a|0)==0){return}k=ac(c[e>>2]|0,b)|0;l=ac(i,d)|0;m=((ac(l,g)|0)>>>0)/(a>>>0)|0;n=((ac(k,a)|0)>>>0)/(g>>>0)|0;g=l+d|0;if(g>>>0<=n>>>0){l=g;g=i;do{g=g+1|0;l=l+d|0;}while(l>>>0<=n>>>0);c[f>>2]=g}g=k+b|0;if(g>>>0>m>>>0){o=k;p=g}else{k=g;g=c[e>>2]|0;while(1){q=g+1|0;r=k+b|0;if(r>>>0>m>>>0){break}else{k=r;g=q}}c[e>>2]=q;o=k;p=r}if(o>>>0>=m>>>0){return}r=ac(c[j>>2]|0,p-m|0)|0;if(r>>>0>=(ac(c[h>>2]|0,m-o|0)|0)>>>0){return}c[e>>2]=(c[e>>2]|0)+1;return}function uR(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;do{if((b|0)==3){if((d|0)==32){e=a+40|0;f=c[e>>2]|0;do{if((f|0)!=0){g=a|0;h=c[g>>2]|0;b2[f&127](h,36920,58192)|0;h=c[e>>2]|0;if((h|0)==0){break}i=c[g>>2]|0;b2[h&127](i,31720,30384)|0}}while(0);e=c[a+8>>2]|0;if((e|0)==0){return}f=c[a+4>>2]|0;b2[e&127](f,29384,55216)|0;return}else if((d|0)==20){f=c[a+8>>2]|0;if((f|0)==0){return}b2[f&127](c[a+4>>2]|0,54352,52552)|0;return}else if((d|0)==25){f=c[a+8>>2]|0;if((f|0)==0){return}b2[f&127](c[a+4>>2]|0,54352,49256)|0;return}else if((d|0)==47){uH(a,0)|0;return}else if((d|0)==105|(d|0)==87){f=a+80|0;e=(c[f>>2]|0)+1|0;c[f>>2]=(e|0)==0?1:e;c[a+132>>2]=0;c[a+136>>2]=0;c[a+140>>2]=c[a+64>>2];c[a+144>>2]=c[a+68>>2];return}else if((d|0)==107|(d|0)==94){e=a+80|0;f=c[e>>2]|0;if(f>>>0<=1){return}i=f-1|0;c[e>>2]=(i|0)==0?1:i;c[a+132>>2]=0;c[a+136>>2]=0;c[a+140>>2]=c[a+64>>2];c[a+144>>2]=c[a+68>>2];return}else if((d|0)==106|(d|0)==90){i=c[a+8>>2]|0;if((i|0)==0){return}b2[i&127](c[a+4>>2]|0,46280,45928)|0;return}else if((d|0)==18){i=c[a+8>>2]|0;if((i|0)==0){return}b2[i&127](c[a+4>>2]|0,54352,55216)|0;return}else if((d|0)==21){i=c[a+8>>2]|0;if((i|0)==0){return}b2[i&127](c[a+4>>2]|0,54352,51800)|0;return}else if((d|0)==65){i=a+40|0;e=c[i>>2]|0;do{if((e|0)!=0){f=a|0;h=c[f>>2]|0;b2[e&127](h,36920,58192)|0;h=c[i>>2]|0;if((h|0)==0){break}g=c[f>>2]|0;b2[h&127](g,31720,30384)|0}}while(0);i=c[a+8>>2]|0;if((i|0)==0){return}b2[i&127](c[a+4>>2]|0,47920,55216)|0;return}else if((d|0)==24){i=c[a+8>>2]|0;if((i|0)==0){return}b2[i&127](c[a+4>>2]|0,54352,49720)|0;return}else if((d|0)==27){i=c[a+8>>2]|0;if((i|0)==0){return}b2[i&127](c[a+4>>2]|0,54352,30384)|0;return}else if((d|0)==19){i=c[a+8>>2]|0;if((i|0)==0){return}b2[i&127](c[a+4>>2]|0,54352,53168)|0;return}else if((d|0)==50){i=c[a+40>>2]|0;if((i|0)==0){return}b2[i&127](c[a>>2]|0,48320,58192)|0;return}else if((d|0)==22){i=c[a+8>>2]|0;if((i|0)==0){return}b2[i&127](c[a+4>>2]|0,54352,51208)|0;return}else if((d|0)==108|(d|0)==92){i=c[a+8>>2]|0;if((i|0)==0){return}b2[i&127](c[a+4>>2]|0,46280,45624)|0;return}else if((d|0)==35){i=c[a+8>>2]|0;if((i|0)==0){return}b2[i&127](c[a+4>>2]|0,46696,55216)|0;return}else if((d|0)==41){i=c[a+8>>2]|0;if((i|0)==0){return}b2[i&127](c[a+4>>2]|0,47088,58192)|0;return}else if((d|0)==23){i=c[a+8>>2]|0;if((i|0)==0){return}b2[i&127](c[a+4>>2]|0,54352,50384)|0;return}else if((d|0)==49){i=c[a+40>>2]|0;if((i|0)==0){return}b2[i&127](c[a>>2]|0,48784,58192)|0;return}else{break}}}while(0);i=c[a+16>>2]|0;if((i|0)==0){return}b3[i&63](c[a+12>>2]|0,b,d);return}function uS(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=ac(c[a+100>>2]|0,b)|0;b=a+108|0;g=f+(c[b>>2]|0)|0;f=c[a+104>>2]|0;h=(g|0)/(f|0)|0;c[b>>2]=g-(ac(h,f)|0);f=ac(c[a+112>>2]|0,d)|0;d=a+120|0;g=f+(c[d>>2]|0)|0;f=c[a+116>>2]|0;b=(g|0)/(f|0)|0;c[d>>2]=g-(ac(b,f)|0);f=c[a+24>>2]|0;if((f|0)==0){return}b8[f&7](c[a+20>>2]|0,h,b,e);return}function uT(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=(g|0)==1;if(i&(h|0)==1){j=d;return j|0}k=ac(g,e)|0;l=ac(ac(f*3|0,k)|0,h)|0;m=b+124|0;n=b+128|0;b=c[n>>2]|0;do{if(l>>>0>(c[m>>2]|0)>>>0){o=u2(b,l)|0;if((o|0)==0){j=0;return j|0}else{c[n>>2]=o;c[m>>2]=l;p=o;break}}else{if((b|0)==0){j=0}else{p=b;break}return j|0}}while(0);if(i){i=e*3|0;if((f|0)==0){j=p;return j|0}if(h>>>0<=1){b=d;l=p;m=0;while(1){u7(l|0,b|0,i)|0;n=m+1|0;if(n>>>0<f>>>0){b=b+i|0;l=l+i|0;m=n}else{j=p;break}}return j|0}m=ac(i,h)|0;l=d;b=p;n=0;while(1){u7(b|0,l|0,i)|0;o=1;q=b;while(1){r=q+i|0;u7(r|0,q|0,i)|0;s=o+1|0;if(s>>>0<h>>>0){o=s;q=r}else{break}}q=n+1|0;if(q>>>0<f>>>0){l=l+i|0;b=b+m|0;n=q}else{j=p;break}}return j|0}if((g|0)!=2){n=e*3|0;m=ac(n,g)|0;if((f|0)==0){j=p;return j|0}b=(e|0)==0;i=(g|0)==0;l=h>>>0>1;q=-m|0;o=ac((h*3|0)-3|0,k)|0;r=g*3|0;s=k*3|0;k=d;t=p;u=0;while(1){if(b){v=k;w=t}else{if(i){x=t}else{y=k;z=t;A=0;while(1){B=y+1|0;C=y+2|0;D=0;E=z;while(1){a[E]=a[y]|0;a[E+1|0]=a[B]|0;a[E+2|0]=a[C]|0;F=D+1|0;if(F>>>0<g>>>0){D=F;E=E+3|0}else{break}}E=A+1|0;if(E>>>0<e>>>0){y=y+3|0;z=z+r|0;A=E}else{break}}x=t+s|0}v=k+n|0;w=x}if(l){A=1;z=w;while(1){y=z+q|0;u7(z|0,y|0,m)|0;y=A+1|0;if(y>>>0<h>>>0){A=y;z=z+m|0}else{break}}G=w+o|0}else{G=w}z=u+1|0;if(z>>>0<f>>>0){k=v;t=G;u=z}else{j=p;break}}return j|0}u=e*6|0;if((f|0)==0){j=p;return j|0}G=h>>>0>1;t=-u|0;if((e|0)==0){if(G){H=0}else{j=p;return j|0}while(1){v=1;k=p;while(1){w=k+t|0;u7(k|0,w|0,u)|0;w=v+1|0;if(w>>>0<h>>>0){v=w;k=k+u|0}else{break}}k=H+1|0;if(k>>>0<f>>>0){H=k}else{j=p;break}}return j|0}H=e*3|0;k=ac(u,h)|0;v=d;d=p;w=0;while(1){o=v;m=d;q=0;while(1){a[m]=a[o]|0;l=o+1|0;a[m+1|0]=a[l]|0;x=o+2|0;a[m+2|0]=a[x]|0;a[m+3|0]=a[o]|0;a[m+4|0]=a[l]|0;a[m+5|0]=a[x]|0;x=q+1|0;if(x>>>0<e>>>0){o=o+3|0;m=m+6|0;q=x}else{break}}q=v+H|0;m=d+u|0;if(G){o=1;x=m;while(1){l=x+t|0;u7(x|0,l|0,u)|0;l=o+1|0;if(l>>>0<h>>>0){o=l;x=x+u|0}else{break}}I=d+k|0}else{I=m}x=w+1|0;if(x>>>0<f>>>0){v=q;d=I;w=x}else{j=p;break}}return j|0}function uU(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=i;i=i+32|0;e=d|0;f=d+8|0;g=d+16|0;h=d+24|0;j=u0(208)|0;if((j|0)==0){k=0;i=d;return k|0}l=j;uF(l,j);c[j+28>>2]=12;c[j+32>>2]=54;c[j+36>>2]=170;c[j+40>>2]=86;c[j+44>>2]=58;c[j+48>>2]=68;u6(j+152|0,0,16);tJ(b,46528,g,0)|0;a[j+168|0]=(c[g>>2]|0)!=0|0;g=j+180|0;tH(b,53064,g,0)|0;m=c[g>>2]|0;c[j+184>>2]=m;c[j+188>>2]=m;c[j+192>>2]=m;a[j+196|0]=0;c[j+172>>2]=0;c[j+176>>2]=0;tJ(b,47024,h,0)|0;a[j+197|0]=(c[h>>2]|0)!=0|0;h=j+200|0;c[h>>2]=0;m=j+204|0;j=u0(864)|0;g=j;c[m>>2]=g;if((j|0)!=0){n=j;c[n>>2]=27;c[n+4>>2]=1;n=j+8|0;c[n>>2]=1082;c[n+4>>2]=2;n=2;j=g;while(1){g=9416+(n<<3)|0;o=j+(n<<3)|0;p=c[g+4>>2]|0;c[o>>2]=c[g>>2];c[o+4>>2]=p;p=n+1|0;if(p>>>0>=108){break}n=p;j=c[m>>2]|0}c[h>>2]=108}j=tA(b,0,43512)|0;if((j|0)==0){k=l;i=d;return k|0}else{q=j}while(1){j=tX(q)|0;do{if((j|0)!=0){if((uC(j,e,f)|0)!=0){break}n=c[e>>2]|0;p=c[f>>2]|0;o=c[h>>2]|0;g=c[m>>2]|0;r=0;while(1){if(r>>>0>=o>>>0){break}if((c[g+(r<<3)>>2]|0)==(n|0)){s=1777;break}else{r=r+1|0}}if((s|0)==1777){s=0;c[g+(r<<3)+4>>2]=p;break}t=u2(g,(o<<3)+8|0)|0;u=t;if((t|0)==0){break}t=c[h>>2]|0;c[u+(t<<3)>>2]=n;c[u+(t<<3)+4>>2]=p;c[m>>2]=u;c[h>>2]=t+1}}while(0);j=tA(b,q,43512)|0;if((j|0)==0){k=l;break}else{q=j}}i=d;return k|0}function uV(a){a=a|0;u1(a);return}function uW(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f|0;h=f+8|0;j=(b|0)==0|(e|0)==0;k=j?480:e;e=j?640:b;uQ(a|0,e,k,g,h);b=(c[a+188>>2]|0)+(c[a+180>>2]|0)|0;j=(c[a+192>>2]|0)+(c[a+184>>2]|0)|0;do{if((aJ(32)|0)==0){if((bt(32)|0)<0){l=1}else{break}i=f;return l|0}}while(0);c[a+172>>2]=d[(c[(bq()|0)+8>>2]|0)+9|0]|0;c[a+176>>2]=0;bz(49712,49712);bo(500,30)|0;m;m=b+(ac(c[g>>2]|0,e)|0)|0;u$(a,m,j+(ac(c[h>>2]|0,k)|0)|0)|0;l=0;i=f;return l|0}function uX(b){b=b|0;var d=0;a[b+196|0]=0;a4(1)|0;d;d=b+152|0;b=c[d>>2]|0;if((b|0)==0){return 0}bY(b|0);c[d>>2]=0;return 0}function uY(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=(e|0)==0?58184:e;if((aQ(d|0,55200)|0)==0){a[b+196|0]=1;a4(0)|0;g;h=0;return h|0}if((aQ(d|0,54336)|0)==0){a[b+196|0]=0;a4(1)|0;i;h=0;return h|0}if((aQ(d|0,53152)|0)==0){bz(f|0,f|0);h=0;return h|0}if((aQ(d|0,52528)|0)==0){i=ax(f|0,0,0)|0;c[b+180>>2]=i;c[b+188>>2]=i;uZ(b);h=0;return h|0}if((aQ(d|0,51776)|0)==0){c[b+184>>2]=ax(f|0,0,0)|0;c[b+192>>2]=c[b+180>>2];uZ(b);h=0;return h|0}if((aQ(d|0,51184)|0)==0){i=b+168|0;g=(a[i]|0)==0;e=c[b+152>>2]|0;if((e|0)!=0){bL(e|0)|0}a[i]=g&1;h=0;return h|0}if((aQ(d|0,50368)|0)!=0){h=-1;return h|0}d=(aA(f|0,0,0)|0)!=0;f=b+168|0;if(!(d^(a[f]|0)!=0)){h=0;return h|0}g=c[b+152>>2]|0;if((g|0)!=0){bL(g|0)|0}a[f]=d&1;h=0;return h|0}function uZ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+32|0;d=b|0;e=b+16|0;f=b+24|0;g=a|0;h=a+64|0;j=a+68|0;uQ(g,c[h>>2]|0,c[j>>2]|0,e,f);k=ac(c[h>>2]|0,c[e>>2]|0)|0;l=ac(c[j>>2]|0,c[f>>2]|0)|0;m=a+180|0;n=a+184|0;if((u$(a,(c[m>>2]|0)+k+(c[a+188>>2]|0)|0,(c[n>>2]|0)+l+(c[a+192>>2]|0)|0)|0)!=0){i=b;return}l=uT(g,c[a+76>>2]|0,c[h>>2]|0,c[j>>2]|0,c[e>>2]|0,c[f>>2]|0)|0;j=c[e>>2]|0;e=ac(c[a+132>>2]|0,j)|0;h=c[f>>2]|0;f=ac(c[a+136>>2]|0,h)|0;g=ac(c[a+140>>2]|0,j)|0;j=ac(c[a+144>>2]|0,h)|0;h=bg(l+(((ac(f,k)|0)+e|0)*3|0)|0,g|0,j|0,24,k*3|0|0,255,65280,16711680,0)|0;c[d>>2]=(c[m>>2]|0)+e;c[d+4>>2]=(c[n>>2]|0)+f;if((h|0)==0){i=b;return}f=a+152|0;if((bT(h|0,0,c[f>>2]|0,d|0)|0)!=0){d=c[q>>2]|0;aC(30360,16,1,d|0)|0}bY(h|0);bs(c[f>>2]|0)|0;i=b;return}function u_(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;e=i;i=i+48|0;f=e|0;if((ba(f|0)|0)==0){i=e;return}g=f|0;h=f+16|0;j=d+200|0;k=d+204|0;l=d+197|0;m=d|0;n=f+20|0;o=d+196|0;p=d+168|0;r=d+152|0;s=f+8|0;t=d+164|0;u=d+24|0;d=f+20|0;v=f+24|0;w=0;do{y=c[g>>2]|0;L2359:do{if((y|0)==768){z=c[h>>2]|0;if((z|0)==1094){uH(m,0)|0;break}else if((z|0)==96){A=1838}do{if((A|0)==1838){A=0;if((b[n>>1]&64)==0){break}a[o]=0;a4(1)|0;B;if((a[p]|0)!=0){C=c[r>>2]|0;if((C|0)!=0){bL(C|0)|0}a[p]=0}uO(m,34120,36912)|0;break L2359}}while(0);C=c[j>>2]|0;D=0;while(1){if(D>>>0>=C>>>0){A=1847;break}E=c[k>>2]|0;if((c[E+(D<<3)>>2]|0)==(z|0)){break}else{D=D+1|0}}if((A|0)==1847){A=0;C=c[q>>2]|0;bN(C|0,31696,(x=i,i=i+8|0,c[x>>2]=z,x)|0)|0;break}C=c[E+(D<<3)+4>>2]|0;F=(C|0)==0;if((a[l]|0)!=0|F){G=c[q>>2]|0;bN(G|0,31696,(x=i,i=i+8|0,c[x>>2]=z,x)|0)|0;if(F){break}}uP(m,1,C);if((z|0)!=1107){break}uP(m,2,C)}else if((y|0)==769){C=c[h>>2]|0;F=c[j>>2]|0;G=0;while(1){if(G>>>0>=F>>>0){break L2359}H=c[k>>2]|0;if((c[H+(G<<3)>>2]|0)==(C|0)){break}else{G=G+1|0}}F=c[H+(G<<3)+4>>2]|0;if((C|0)==1094|(F|0)==0){break}if((C|0)==1107){uP(m,1,F)}uP(m,2,F)}else if((y|0)==256){a[o]=0;a4(1)|0;I;uO(m,39944,36912)|0}else if((y|0)==1024){F=c[d>>2]|0;z=c[v>>2]|0;if((a[o]|0)==0){break}if((c[u>>2]|0)==0){break}D=(az(0,0)|0)&255;J=D&1;uS(m,F,z,(D&4|0)==0?J:J|2)}else if((y|0)==1026){J=a[s]|0;D=J&255;if((D|0)==0){break}else if((D|0)==2){K=2}else{K=J<<24>>24==3?1:D-1|0}D=c[t>>2]&~(1<<K);c[t>>2]=D;if((a[o]|0)==0){a[o]=1;a4(0)|0;L;break}if((c[u>>2]|0)==0){break}uS(m,0,0,D)}else if((y|0)==1025){D=a[s]|0;J=D&255;if((J|0)==2){M=2}else if((J|0)==0){break}else{M=D<<24>>24==3?1:J-1|0}J=c[t>>2]|1<<M;c[t>>2]=J;if((a[o]|0)==0){break}if((c[u>>2]|0)==0){break}uS(m,0,0,J)}}while(0);w=w+1|0;}while((ba(f|0)|0)!=0&w>>>0<8);i=e;return}function u$(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=b+152|0;g=c[f>>2]|0;if((g|0)!=0){do{if((c[b+156>>2]|0)==(d|0)){if((c[b+160>>2]|0)==(e|0)){h=0}else{break}return h|0}}while(0);bY(g|0)}c[f>>2]=0;g=(a[b+168|0]|0)==0?134217729:142606337;i=c[b+172>>2]|0;if((i|0)==2){j=bk(d|0,e|0,16,g|0)|0;c[f>>2]=j;c[b+176>>2]=2;k=j;l=1886}else if((i|0)==4){i=bk(d|0,e|0,32,g|0)|0;c[f>>2]=i;c[b+176>>2]=4;k=i;l=1886}else{l=1887}if((l|0)==1886){if((k|0)==0){l=1887}}do{if((l|0)==1887){k=bk(d|0,e|0,16,g|0)|0;c[f>>2]=k;c[b+176>>2]=2;if((k|0)==0){h=1}else{break}return h|0}}while(0);c[b+156>>2]=d;c[b+160>>2]=e;h=0;return h|0}
function u0(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0;do{if(a>>>0<245){if(a>>>0<11){b=16}else{b=a+11&-8}d=b>>>3;e=c[14568]|0;f=e>>>(d>>>0);if((f&3|0)!=0){g=(f&1^1)+d|0;h=g<<1;i=58312+(h<<2)|0;j=58312+(h+2<<2)|0;h=c[j>>2]|0;k=h+8|0;l=c[k>>2]|0;do{if((i|0)==(l|0)){c[14568]=e&~(1<<g)}else{if(l>>>0<(c[14572]|0)>>>0){bM();return 0}m=l+12|0;if((c[m>>2]|0)==(h|0)){c[m>>2]=i;c[j>>2]=l;break}else{bM();return 0}}}while(0);l=g<<3;c[h+4>>2]=l|3;j=h+(l|4)|0;c[j>>2]=c[j>>2]|1;n=k;return n|0}if(b>>>0<=(c[14570]|0)>>>0){o=b;break}if((f|0)!=0){j=2<<d;l=f<<d&(j|-j);j=(l&-l)-1|0;l=j>>>12&16;i=j>>>(l>>>0);j=i>>>5&8;m=i>>>(j>>>0);i=m>>>2&4;p=m>>>(i>>>0);m=p>>>1&2;q=p>>>(m>>>0);p=q>>>1&1;r=(j|l|i|m|p)+(q>>>(p>>>0))|0;p=r<<1;q=58312+(p<<2)|0;m=58312+(p+2<<2)|0;p=c[m>>2]|0;i=p+8|0;l=c[i>>2]|0;do{if((q|0)==(l|0)){c[14568]=e&~(1<<r)}else{if(l>>>0<(c[14572]|0)>>>0){bM();return 0}j=l+12|0;if((c[j>>2]|0)==(p|0)){c[j>>2]=q;c[m>>2]=l;break}else{bM();return 0}}}while(0);l=r<<3;m=l-b|0;c[p+4>>2]=b|3;q=p;e=q+b|0;c[q+(b|4)>>2]=m|1;c[q+l>>2]=m;l=c[14570]|0;if((l|0)!=0){q=c[14573]|0;d=l>>>3;l=d<<1;f=58312+(l<<2)|0;k=c[14568]|0;h=1<<d;do{if((k&h|0)==0){c[14568]=k|h;s=f;t=58312+(l+2<<2)|0}else{d=58312+(l+2<<2)|0;g=c[d>>2]|0;if(g>>>0>=(c[14572]|0)>>>0){s=g;t=d;break}bM();return 0}}while(0);c[t>>2]=q;c[s+12>>2]=q;c[q+8>>2]=s;c[q+12>>2]=f}c[14570]=m;c[14573]=e;n=i;return n|0}l=c[14569]|0;if((l|0)==0){o=b;break}h=(l&-l)-1|0;l=h>>>12&16;k=h>>>(l>>>0);h=k>>>5&8;p=k>>>(h>>>0);k=p>>>2&4;r=p>>>(k>>>0);p=r>>>1&2;d=r>>>(p>>>0);r=d>>>1&1;g=c[58576+((h|l|k|p|r)+(d>>>(r>>>0))<<2)>>2]|0;r=g;d=g;p=(c[g+4>>2]&-8)-b|0;while(1){g=c[r+16>>2]|0;if((g|0)==0){k=c[r+20>>2]|0;if((k|0)==0){break}else{u=k}}else{u=g}g=(c[u+4>>2]&-8)-b|0;k=g>>>0<p>>>0;r=u;d=k?u:d;p=k?g:p}r=d;i=c[14572]|0;if(r>>>0<i>>>0){bM();return 0}e=r+b|0;m=e;if(r>>>0>=e>>>0){bM();return 0}e=c[d+24>>2]|0;f=c[d+12>>2]|0;do{if((f|0)==(d|0)){q=d+20|0;g=c[q>>2]|0;if((g|0)==0){k=d+16|0;l=c[k>>2]|0;if((l|0)==0){v=0;break}else{w=l;x=k}}else{w=g;x=q}while(1){q=w+20|0;g=c[q>>2]|0;if((g|0)!=0){w=g;x=q;continue}q=w+16|0;g=c[q>>2]|0;if((g|0)==0){break}else{w=g;x=q}}if(x>>>0<i>>>0){bM();return 0}else{c[x>>2]=0;v=w;break}}else{q=c[d+8>>2]|0;if(q>>>0<i>>>0){bM();return 0}g=q+12|0;if((c[g>>2]|0)!=(d|0)){bM();return 0}k=f+8|0;if((c[k>>2]|0)==(d|0)){c[g>>2]=f;c[k>>2]=q;v=f;break}else{bM();return 0}}}while(0);L2508:do{if((e|0)!=0){f=d+28|0;i=58576+(c[f>>2]<<2)|0;do{if((d|0)==(c[i>>2]|0)){c[i>>2]=v;if((v|0)!=0){break}c[14569]=c[14569]&~(1<<c[f>>2]);break L2508}else{if(e>>>0<(c[14572]|0)>>>0){bM();return 0}q=e+16|0;if((c[q>>2]|0)==(d|0)){c[q>>2]=v}else{c[e+20>>2]=v}if((v|0)==0){break L2508}}}while(0);if(v>>>0<(c[14572]|0)>>>0){bM();return 0}c[v+24>>2]=e;f=c[d+16>>2]|0;do{if((f|0)!=0){if(f>>>0<(c[14572]|0)>>>0){bM();return 0}else{c[v+16>>2]=f;c[f+24>>2]=v;break}}}while(0);f=c[d+20>>2]|0;if((f|0)==0){break}if(f>>>0<(c[14572]|0)>>>0){bM();return 0}else{c[v+20>>2]=f;c[f+24>>2]=v;break}}}while(0);if(p>>>0<16){e=p+b|0;c[d+4>>2]=e|3;f=r+(e+4)|0;c[f>>2]=c[f>>2]|1}else{c[d+4>>2]=b|3;c[r+(b|4)>>2]=p|1;c[r+(p+b)>>2]=p;f=c[14570]|0;if((f|0)!=0){e=c[14573]|0;i=f>>>3;f=i<<1;q=58312+(f<<2)|0;k=c[14568]|0;g=1<<i;do{if((k&g|0)==0){c[14568]=k|g;y=q;z=58312+(f+2<<2)|0}else{i=58312+(f+2<<2)|0;l=c[i>>2]|0;if(l>>>0>=(c[14572]|0)>>>0){y=l;z=i;break}bM();return 0}}while(0);c[z>>2]=e;c[y+12>>2]=e;c[e+8>>2]=y;c[e+12>>2]=q}c[14570]=p;c[14573]=m}f=d+8|0;if((f|0)==0){o=b;break}else{n=f}return n|0}else{if(a>>>0>4294967231){o=-1;break}f=a+11|0;g=f&-8;k=c[14569]|0;if((k|0)==0){o=g;break}r=-g|0;i=f>>>8;do{if((i|0)==0){A=0}else{if(g>>>0>16777215){A=31;break}f=(i+1048320|0)>>>16&8;l=i<<f;h=(l+520192|0)>>>16&4;j=l<<h;l=(j+245760|0)>>>16&2;B=14-(h|f|l)+(j<<l>>>15)|0;A=g>>>((B+7|0)>>>0)&1|B<<1}}while(0);i=c[58576+(A<<2)>>2]|0;L2556:do{if((i|0)==0){C=0;D=r;E=0}else{if((A|0)==31){F=0}else{F=25-(A>>>1)|0}d=0;m=r;p=i;q=g<<F;e=0;while(1){B=c[p+4>>2]&-8;l=B-g|0;if(l>>>0<m>>>0){if((B|0)==(g|0)){C=p;D=l;E=p;break L2556}else{G=p;H=l}}else{G=d;H=m}l=c[p+20>>2]|0;B=c[p+16+(q>>>31<<2)>>2]|0;j=(l|0)==0|(l|0)==(B|0)?e:l;if((B|0)==0){C=G;D=H;E=j;break}else{d=G;m=H;p=B;q=q<<1;e=j}}}}while(0);if((E|0)==0&(C|0)==0){i=2<<A;r=k&(i|-i);if((r|0)==0){o=g;break}i=(r&-r)-1|0;r=i>>>12&16;e=i>>>(r>>>0);i=e>>>5&8;q=e>>>(i>>>0);e=q>>>2&4;p=q>>>(e>>>0);q=p>>>1&2;m=p>>>(q>>>0);p=m>>>1&1;I=c[58576+((i|r|e|q|p)+(m>>>(p>>>0))<<2)>>2]|0}else{I=E}if((I|0)==0){J=D;K=C}else{p=I;m=D;q=C;while(1){e=(c[p+4>>2]&-8)-g|0;r=e>>>0<m>>>0;i=r?e:m;e=r?p:q;r=c[p+16>>2]|0;if((r|0)!=0){p=r;m=i;q=e;continue}r=c[p+20>>2]|0;if((r|0)==0){J=i;K=e;break}else{p=r;m=i;q=e}}}if((K|0)==0){o=g;break}if(J>>>0>=((c[14570]|0)-g|0)>>>0){o=g;break}q=K;m=c[14572]|0;if(q>>>0<m>>>0){bM();return 0}p=q+g|0;k=p;if(q>>>0>=p>>>0){bM();return 0}e=c[K+24>>2]|0;i=c[K+12>>2]|0;do{if((i|0)==(K|0)){r=K+20|0;d=c[r>>2]|0;if((d|0)==0){j=K+16|0;B=c[j>>2]|0;if((B|0)==0){L=0;break}else{M=B;N=j}}else{M=d;N=r}while(1){r=M+20|0;d=c[r>>2]|0;if((d|0)!=0){M=d;N=r;continue}r=M+16|0;d=c[r>>2]|0;if((d|0)==0){break}else{M=d;N=r}}if(N>>>0<m>>>0){bM();return 0}else{c[N>>2]=0;L=M;break}}else{r=c[K+8>>2]|0;if(r>>>0<m>>>0){bM();return 0}d=r+12|0;if((c[d>>2]|0)!=(K|0)){bM();return 0}j=i+8|0;if((c[j>>2]|0)==(K|0)){c[d>>2]=i;c[j>>2]=r;L=i;break}else{bM();return 0}}}while(0);L2606:do{if((e|0)!=0){i=K+28|0;m=58576+(c[i>>2]<<2)|0;do{if((K|0)==(c[m>>2]|0)){c[m>>2]=L;if((L|0)!=0){break}c[14569]=c[14569]&~(1<<c[i>>2]);break L2606}else{if(e>>>0<(c[14572]|0)>>>0){bM();return 0}r=e+16|0;if((c[r>>2]|0)==(K|0)){c[r>>2]=L}else{c[e+20>>2]=L}if((L|0)==0){break L2606}}}while(0);if(L>>>0<(c[14572]|0)>>>0){bM();return 0}c[L+24>>2]=e;i=c[K+16>>2]|0;do{if((i|0)!=0){if(i>>>0<(c[14572]|0)>>>0){bM();return 0}else{c[L+16>>2]=i;c[i+24>>2]=L;break}}}while(0);i=c[K+20>>2]|0;if((i|0)==0){break}if(i>>>0<(c[14572]|0)>>>0){bM();return 0}else{c[L+20>>2]=i;c[i+24>>2]=L;break}}}while(0);do{if(J>>>0<16){e=J+g|0;c[K+4>>2]=e|3;i=q+(e+4)|0;c[i>>2]=c[i>>2]|1}else{c[K+4>>2]=g|3;c[q+(g|4)>>2]=J|1;c[q+(J+g)>>2]=J;i=J>>>3;if(J>>>0<256){e=i<<1;m=58312+(e<<2)|0;r=c[14568]|0;j=1<<i;do{if((r&j|0)==0){c[14568]=r|j;O=m;P=58312+(e+2<<2)|0}else{i=58312+(e+2<<2)|0;d=c[i>>2]|0;if(d>>>0>=(c[14572]|0)>>>0){O=d;P=i;break}bM();return 0}}while(0);c[P>>2]=k;c[O+12>>2]=k;c[q+(g+8)>>2]=O;c[q+(g+12)>>2]=m;break}e=p;j=J>>>8;do{if((j|0)==0){Q=0}else{if(J>>>0>16777215){Q=31;break}r=(j+1048320|0)>>>16&8;i=j<<r;d=(i+520192|0)>>>16&4;B=i<<d;i=(B+245760|0)>>>16&2;l=14-(d|r|i)+(B<<i>>>15)|0;Q=J>>>((l+7|0)>>>0)&1|l<<1}}while(0);j=58576+(Q<<2)|0;c[q+(g+28)>>2]=Q;c[q+(g+20)>>2]=0;c[q+(g+16)>>2]=0;m=c[14569]|0;l=1<<Q;if((m&l|0)==0){c[14569]=m|l;c[j>>2]=e;c[q+(g+24)>>2]=j;c[q+(g+12)>>2]=e;c[q+(g+8)>>2]=e;break}if((Q|0)==31){R=0}else{R=25-(Q>>>1)|0}l=J<<R;m=c[j>>2]|0;while(1){if((c[m+4>>2]&-8|0)==(J|0)){break}S=m+16+(l>>>31<<2)|0;j=c[S>>2]|0;if((j|0)==0){T=2043;break}else{l=l<<1;m=j}}if((T|0)==2043){if(S>>>0<(c[14572]|0)>>>0){bM();return 0}else{c[S>>2]=e;c[q+(g+24)>>2]=m;c[q+(g+12)>>2]=e;c[q+(g+8)>>2]=e;break}}l=m+8|0;j=c[l>>2]|0;i=c[14572]|0;if(m>>>0<i>>>0){bM();return 0}if(j>>>0<i>>>0){bM();return 0}else{c[j+12>>2]=e;c[l>>2]=e;c[q+(g+8)>>2]=j;c[q+(g+12)>>2]=m;c[q+(g+24)>>2]=0;break}}}while(0);q=K+8|0;if((q|0)==0){o=g;break}else{n=q}return n|0}}while(0);K=c[14570]|0;if(o>>>0<=K>>>0){S=K-o|0;J=c[14573]|0;if(S>>>0>15){R=J;c[14573]=R+o;c[14570]=S;c[R+(o+4)>>2]=S|1;c[R+K>>2]=S;c[J+4>>2]=o|3}else{c[14570]=0;c[14573]=0;c[J+4>>2]=K|3;S=J+(K+4)|0;c[S>>2]=c[S>>2]|1}n=J+8|0;return n|0}J=c[14571]|0;if(o>>>0<J>>>0){S=J-o|0;c[14571]=S;J=c[14574]|0;K=J;c[14574]=K+o;c[K+(o+4)>>2]=S|1;c[J+4>>2]=o|3;n=J+8|0;return n|0}do{if((c[14514]|0)==0){J=bJ(8)|0;if((J-1&J|0)==0){c[14516]=J;c[14515]=J;c[14517]=-1;c[14518]=2097152;c[14519]=0;c[14679]=0;c[14514]=(bZ(0)|0)&-16^1431655768;break}else{bM();return 0}}}while(0);J=o+48|0;S=c[14516]|0;K=o+47|0;R=S+K|0;Q=-S|0;S=R&Q;if(S>>>0<=o>>>0){n=0;return n|0}O=c[14678]|0;do{if((O|0)!=0){P=c[14676]|0;L=P+S|0;if(L>>>0<=P>>>0|L>>>0>O>>>0){n=0}else{break}return n|0}}while(0);L2698:do{if((c[14679]&4|0)==0){O=c[14574]|0;L2700:do{if((O|0)==0){T=2073}else{L=O;P=58720;while(1){U=P|0;M=c[U>>2]|0;if(M>>>0<=L>>>0){V=P+4|0;if((M+(c[V>>2]|0)|0)>>>0>L>>>0){break}}M=c[P+8>>2]|0;if((M|0)==0){T=2073;break L2700}else{P=M}}if((P|0)==0){T=2073;break}L=R-(c[14571]|0)&Q;if(L>>>0>=2147483647){W=0;break}m=bA(L|0)|0;e=(m|0)==((c[U>>2]|0)+(c[V>>2]|0)|0);X=e?m:-1;Y=e?L:0;Z=m;_=L;T=2082}}while(0);do{if((T|0)==2073){O=bA(0)|0;if((O|0)==-1){W=0;break}g=O;L=c[14515]|0;m=L-1|0;if((m&g|0)==0){$=S}else{$=S-g+(m+g&-L)|0}L=c[14676]|0;g=L+$|0;if(!($>>>0>o>>>0&$>>>0<2147483647)){W=0;break}m=c[14678]|0;if((m|0)!=0){if(g>>>0<=L>>>0|g>>>0>m>>>0){W=0;break}}m=bA($|0)|0;g=(m|0)==(O|0);X=g?O:-1;Y=g?$:0;Z=m;_=$;T=2082}}while(0);L2720:do{if((T|0)==2082){m=-_|0;if((X|0)!=-1){aa=Y;ab=X;T=2093;break L2698}do{if((Z|0)!=-1&_>>>0<2147483647&_>>>0<J>>>0){g=c[14516]|0;O=K-_+g&-g;if(O>>>0>=2147483647){ac=_;break}if((bA(O|0)|0)==-1){bA(m|0)|0;W=Y;break L2720}else{ac=O+_|0;break}}else{ac=_}}while(0);if((Z|0)==-1){W=Y}else{aa=ac;ab=Z;T=2093;break L2698}}}while(0);c[14679]=c[14679]|4;ad=W;T=2090}else{ad=0;T=2090}}while(0);do{if((T|0)==2090){if(S>>>0>=2147483647){break}W=bA(S|0)|0;Z=bA(0)|0;if(!((Z|0)!=-1&(W|0)!=-1&W>>>0<Z>>>0)){break}ac=Z-W|0;Z=ac>>>0>(o+40|0)>>>0;Y=Z?W:-1;if((Y|0)!=-1){aa=Z?ac:ad;ab=Y;T=2093}}}while(0);do{if((T|0)==2093){ad=(c[14676]|0)+aa|0;c[14676]=ad;if(ad>>>0>(c[14677]|0)>>>0){c[14677]=ad}ad=c[14574]|0;L2740:do{if((ad|0)==0){S=c[14572]|0;if((S|0)==0|ab>>>0<S>>>0){c[14572]=ab}c[14680]=ab;c[14681]=aa;c[14683]=0;c[14577]=c[14514];c[14576]=-1;S=0;do{Y=S<<1;ac=58312+(Y<<2)|0;c[58312+(Y+3<<2)>>2]=ac;c[58312+(Y+2<<2)>>2]=ac;S=S+1|0;}while(S>>>0<32);S=ab+8|0;if((S&7|0)==0){ae=0}else{ae=-S&7}S=aa-40-ae|0;c[14574]=ab+ae;c[14571]=S;c[ab+(ae+4)>>2]=S|1;c[ab+(aa-36)>>2]=40;c[14575]=c[14518]}else{S=58720;while(1){af=c[S>>2]|0;ag=S+4|0;ah=c[ag>>2]|0;if((ab|0)==(af+ah|0)){T=2105;break}ac=c[S+8>>2]|0;if((ac|0)==0){break}else{S=ac}}do{if((T|0)==2105){if((c[S+12>>2]&8|0)!=0){break}ac=ad;if(!(ac>>>0>=af>>>0&ac>>>0<ab>>>0)){break}c[ag>>2]=ah+aa;ac=c[14574]|0;Y=(c[14571]|0)+aa|0;Z=ac;W=ac+8|0;if((W&7|0)==0){ai=0}else{ai=-W&7}W=Y-ai|0;c[14574]=Z+ai;c[14571]=W;c[Z+(ai+4)>>2]=W|1;c[Z+(Y+4)>>2]=40;c[14575]=c[14518];break L2740}}while(0);if(ab>>>0<(c[14572]|0)>>>0){c[14572]=ab}S=ab+aa|0;Y=58720;while(1){aj=Y|0;if((c[aj>>2]|0)==(S|0)){T=2115;break}Z=c[Y+8>>2]|0;if((Z|0)==0){break}else{Y=Z}}do{if((T|0)==2115){if((c[Y+12>>2]&8|0)!=0){break}c[aj>>2]=ab;S=Y+4|0;c[S>>2]=(c[S>>2]|0)+aa;S=ab+8|0;if((S&7|0)==0){ak=0}else{ak=-S&7}S=ab+(aa+8)|0;if((S&7|0)==0){al=0}else{al=-S&7}S=ab+(al+aa)|0;Z=S;W=ak+o|0;ac=ab+W|0;_=ac;K=S-(ab+ak)-o|0;c[ab+(ak+4)>>2]=o|3;do{if((Z|0)==(c[14574]|0)){J=(c[14571]|0)+K|0;c[14571]=J;c[14574]=_;c[ab+(W+4)>>2]=J|1}else{if((Z|0)==(c[14573]|0)){J=(c[14570]|0)+K|0;c[14570]=J;c[14573]=_;c[ab+(W+4)>>2]=J|1;c[ab+(J+W)>>2]=J;break}J=aa+4|0;X=c[ab+(J+al)>>2]|0;if((X&3|0)==1){$=X&-8;V=X>>>3;L2785:do{if(X>>>0<256){U=c[ab+((al|8)+aa)>>2]|0;Q=c[ab+(aa+12+al)>>2]|0;R=58312+(V<<1<<2)|0;do{if((U|0)!=(R|0)){if(U>>>0<(c[14572]|0)>>>0){bM();return 0}if((c[U+12>>2]|0)==(Z|0)){break}bM();return 0}}while(0);if((Q|0)==(U|0)){c[14568]=c[14568]&~(1<<V);break}do{if((Q|0)==(R|0)){am=Q+8|0}else{if(Q>>>0<(c[14572]|0)>>>0){bM();return 0}m=Q+8|0;if((c[m>>2]|0)==(Z|0)){am=m;break}bM();return 0}}while(0);c[U+12>>2]=Q;c[am>>2]=U}else{R=S;m=c[ab+((al|24)+aa)>>2]|0;P=c[ab+(aa+12+al)>>2]|0;do{if((P|0)==(R|0)){O=al|16;g=ab+(J+O)|0;L=c[g>>2]|0;if((L|0)==0){e=ab+(O+aa)|0;O=c[e>>2]|0;if((O|0)==0){an=0;break}else{ao=O;ap=e}}else{ao=L;ap=g}while(1){g=ao+20|0;L=c[g>>2]|0;if((L|0)!=0){ao=L;ap=g;continue}g=ao+16|0;L=c[g>>2]|0;if((L|0)==0){break}else{ao=L;ap=g}}if(ap>>>0<(c[14572]|0)>>>0){bM();return 0}else{c[ap>>2]=0;an=ao;break}}else{g=c[ab+((al|8)+aa)>>2]|0;if(g>>>0<(c[14572]|0)>>>0){bM();return 0}L=g+12|0;if((c[L>>2]|0)!=(R|0)){bM();return 0}e=P+8|0;if((c[e>>2]|0)==(R|0)){c[L>>2]=P;c[e>>2]=g;an=P;break}else{bM();return 0}}}while(0);if((m|0)==0){break}P=ab+(aa+28+al)|0;U=58576+(c[P>>2]<<2)|0;do{if((R|0)==(c[U>>2]|0)){c[U>>2]=an;if((an|0)!=0){break}c[14569]=c[14569]&~(1<<c[P>>2]);break L2785}else{if(m>>>0<(c[14572]|0)>>>0){bM();return 0}Q=m+16|0;if((c[Q>>2]|0)==(R|0)){c[Q>>2]=an}else{c[m+20>>2]=an}if((an|0)==0){break L2785}}}while(0);if(an>>>0<(c[14572]|0)>>>0){bM();return 0}c[an+24>>2]=m;R=al|16;P=c[ab+(R+aa)>>2]|0;do{if((P|0)!=0){if(P>>>0<(c[14572]|0)>>>0){bM();return 0}else{c[an+16>>2]=P;c[P+24>>2]=an;break}}}while(0);P=c[ab+(J+R)>>2]|0;if((P|0)==0){break}if(P>>>0<(c[14572]|0)>>>0){bM();return 0}else{c[an+20>>2]=P;c[P+24>>2]=an;break}}}while(0);aq=ab+(($|al)+aa)|0;ar=$+K|0}else{aq=Z;ar=K}J=aq+4|0;c[J>>2]=c[J>>2]&-2;c[ab+(W+4)>>2]=ar|1;c[ab+(ar+W)>>2]=ar;J=ar>>>3;if(ar>>>0<256){V=J<<1;X=58312+(V<<2)|0;P=c[14568]|0;m=1<<J;do{if((P&m|0)==0){c[14568]=P|m;as=X;at=58312+(V+2<<2)|0}else{J=58312+(V+2<<2)|0;U=c[J>>2]|0;if(U>>>0>=(c[14572]|0)>>>0){as=U;at=J;break}bM();return 0}}while(0);c[at>>2]=_;c[as+12>>2]=_;c[ab+(W+8)>>2]=as;c[ab+(W+12)>>2]=X;break}V=ac;m=ar>>>8;do{if((m|0)==0){au=0}else{if(ar>>>0>16777215){au=31;break}P=(m+1048320|0)>>>16&8;$=m<<P;J=($+520192|0)>>>16&4;U=$<<J;$=(U+245760|0)>>>16&2;Q=14-(J|P|$)+(U<<$>>>15)|0;au=ar>>>((Q+7|0)>>>0)&1|Q<<1}}while(0);m=58576+(au<<2)|0;c[ab+(W+28)>>2]=au;c[ab+(W+20)>>2]=0;c[ab+(W+16)>>2]=0;X=c[14569]|0;Q=1<<au;if((X&Q|0)==0){c[14569]=X|Q;c[m>>2]=V;c[ab+(W+24)>>2]=m;c[ab+(W+12)>>2]=V;c[ab+(W+8)>>2]=V;break}if((au|0)==31){av=0}else{av=25-(au>>>1)|0}Q=ar<<av;X=c[m>>2]|0;while(1){if((c[X+4>>2]&-8|0)==(ar|0)){break}aw=X+16+(Q>>>31<<2)|0;m=c[aw>>2]|0;if((m|0)==0){T=2188;break}else{Q=Q<<1;X=m}}if((T|0)==2188){if(aw>>>0<(c[14572]|0)>>>0){bM();return 0}else{c[aw>>2]=V;c[ab+(W+24)>>2]=X;c[ab+(W+12)>>2]=V;c[ab+(W+8)>>2]=V;break}}Q=X+8|0;m=c[Q>>2]|0;$=c[14572]|0;if(X>>>0<$>>>0){bM();return 0}if(m>>>0<$>>>0){bM();return 0}else{c[m+12>>2]=V;c[Q>>2]=V;c[ab+(W+8)>>2]=m;c[ab+(W+12)>>2]=X;c[ab+(W+24)>>2]=0;break}}}while(0);n=ab+(ak|8)|0;return n|0}}while(0);Y=ad;W=58720;while(1){ax=c[W>>2]|0;if(ax>>>0<=Y>>>0){ay=c[W+4>>2]|0;az=ax+ay|0;if(az>>>0>Y>>>0){break}}W=c[W+8>>2]|0}W=ax+(ay-39)|0;if((W&7|0)==0){aA=0}else{aA=-W&7}W=ax+(ay-47+aA)|0;ac=W>>>0<(ad+16|0)>>>0?Y:W;W=ac+8|0;_=ab+8|0;if((_&7|0)==0){aB=0}else{aB=-_&7}_=aa-40-aB|0;c[14574]=ab+aB;c[14571]=_;c[ab+(aB+4)>>2]=_|1;c[ab+(aa-36)>>2]=40;c[14575]=c[14518];c[ac+4>>2]=27;c[W>>2]=c[14680];c[W+4>>2]=c[58724>>2];c[W+8>>2]=c[58728>>2];c[W+12>>2]=c[58732>>2];c[14680]=ab;c[14681]=aa;c[14683]=0;c[14682]=W;W=ac+28|0;c[W>>2]=7;if((ac+32|0)>>>0<az>>>0){_=W;while(1){W=_+4|0;c[W>>2]=7;if((_+8|0)>>>0<az>>>0){_=W}else{break}}}if((ac|0)==(Y|0)){break}_=ac-ad|0;W=Y+(_+4)|0;c[W>>2]=c[W>>2]&-2;c[ad+4>>2]=_|1;c[Y+_>>2]=_;W=_>>>3;if(_>>>0<256){K=W<<1;Z=58312+(K<<2)|0;S=c[14568]|0;m=1<<W;do{if((S&m|0)==0){c[14568]=S|m;aC=Z;aD=58312+(K+2<<2)|0}else{W=58312+(K+2<<2)|0;Q=c[W>>2]|0;if(Q>>>0>=(c[14572]|0)>>>0){aC=Q;aD=W;break}bM();return 0}}while(0);c[aD>>2]=ad;c[aC+12>>2]=ad;c[ad+8>>2]=aC;c[ad+12>>2]=Z;break}K=ad;m=_>>>8;do{if((m|0)==0){aE=0}else{if(_>>>0>16777215){aE=31;break}S=(m+1048320|0)>>>16&8;Y=m<<S;ac=(Y+520192|0)>>>16&4;W=Y<<ac;Y=(W+245760|0)>>>16&2;Q=14-(ac|S|Y)+(W<<Y>>>15)|0;aE=_>>>((Q+7|0)>>>0)&1|Q<<1}}while(0);m=58576+(aE<<2)|0;c[ad+28>>2]=aE;c[ad+20>>2]=0;c[ad+16>>2]=0;Z=c[14569]|0;Q=1<<aE;if((Z&Q|0)==0){c[14569]=Z|Q;c[m>>2]=K;c[ad+24>>2]=m;c[ad+12>>2]=ad;c[ad+8>>2]=ad;break}if((aE|0)==31){aF=0}else{aF=25-(aE>>>1)|0}Q=_<<aF;Z=c[m>>2]|0;while(1){if((c[Z+4>>2]&-8|0)==(_|0)){break}aG=Z+16+(Q>>>31<<2)|0;m=c[aG>>2]|0;if((m|0)==0){T=2223;break}else{Q=Q<<1;Z=m}}if((T|0)==2223){if(aG>>>0<(c[14572]|0)>>>0){bM();return 0}else{c[aG>>2]=K;c[ad+24>>2]=Z;c[ad+12>>2]=ad;c[ad+8>>2]=ad;break}}Q=Z+8|0;_=c[Q>>2]|0;m=c[14572]|0;if(Z>>>0<m>>>0){bM();return 0}if(_>>>0<m>>>0){bM();return 0}else{c[_+12>>2]=K;c[Q>>2]=K;c[ad+8>>2]=_;c[ad+12>>2]=Z;c[ad+24>>2]=0;break}}}while(0);ad=c[14571]|0;if(ad>>>0<=o>>>0){break}_=ad-o|0;c[14571]=_;ad=c[14574]|0;Q=ad;c[14574]=Q+o;c[Q+(o+4)>>2]=_|1;c[ad+4>>2]=o|3;n=ad+8|0;return n|0}}while(0);c[(bB()|0)>>2]=12;n=0;return n|0}function u1(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;if((a|0)==0){return}b=a-8|0;d=b;e=c[14572]|0;if(b>>>0<e>>>0){bM()}f=c[a-4>>2]|0;g=f&3;if((g|0)==1){bM()}h=f&-8;i=a+(h-8)|0;j=i;L2957:do{if((f&1|0)==0){k=c[b>>2]|0;if((g|0)==0){return}l=-8-k|0;m=a+l|0;n=m;o=k+h|0;if(m>>>0<e>>>0){bM()}if((n|0)==(c[14573]|0)){p=a+(h-4)|0;if((c[p>>2]&3|0)!=3){q=n;r=o;break}c[14570]=o;c[p>>2]=c[p>>2]&-2;c[a+(l+4)>>2]=o|1;c[i>>2]=o;return}p=k>>>3;if(k>>>0<256){k=c[a+(l+8)>>2]|0;s=c[a+(l+12)>>2]|0;t=58312+(p<<1<<2)|0;do{if((k|0)!=(t|0)){if(k>>>0<e>>>0){bM()}if((c[k+12>>2]|0)==(n|0)){break}bM()}}while(0);if((s|0)==(k|0)){c[14568]=c[14568]&~(1<<p);q=n;r=o;break}do{if((s|0)==(t|0)){u=s+8|0}else{if(s>>>0<e>>>0){bM()}v=s+8|0;if((c[v>>2]|0)==(n|0)){u=v;break}bM()}}while(0);c[k+12>>2]=s;c[u>>2]=k;q=n;r=o;break}t=m;p=c[a+(l+24)>>2]|0;v=c[a+(l+12)>>2]|0;do{if((v|0)==(t|0)){w=a+(l+20)|0;x=c[w>>2]|0;if((x|0)==0){y=a+(l+16)|0;z=c[y>>2]|0;if((z|0)==0){A=0;break}else{B=z;C=y}}else{B=x;C=w}while(1){w=B+20|0;x=c[w>>2]|0;if((x|0)!=0){B=x;C=w;continue}w=B+16|0;x=c[w>>2]|0;if((x|0)==0){break}else{B=x;C=w}}if(C>>>0<e>>>0){bM()}else{c[C>>2]=0;A=B;break}}else{w=c[a+(l+8)>>2]|0;if(w>>>0<e>>>0){bM()}x=w+12|0;if((c[x>>2]|0)!=(t|0)){bM()}y=v+8|0;if((c[y>>2]|0)==(t|0)){c[x>>2]=v;c[y>>2]=w;A=v;break}else{bM()}}}while(0);if((p|0)==0){q=n;r=o;break}v=a+(l+28)|0;m=58576+(c[v>>2]<<2)|0;do{if((t|0)==(c[m>>2]|0)){c[m>>2]=A;if((A|0)!=0){break}c[14569]=c[14569]&~(1<<c[v>>2]);q=n;r=o;break L2957}else{if(p>>>0<(c[14572]|0)>>>0){bM()}k=p+16|0;if((c[k>>2]|0)==(t|0)){c[k>>2]=A}else{c[p+20>>2]=A}if((A|0)==0){q=n;r=o;break L2957}}}while(0);if(A>>>0<(c[14572]|0)>>>0){bM()}c[A+24>>2]=p;t=c[a+(l+16)>>2]|0;do{if((t|0)!=0){if(t>>>0<(c[14572]|0)>>>0){bM()}else{c[A+16>>2]=t;c[t+24>>2]=A;break}}}while(0);t=c[a+(l+20)>>2]|0;if((t|0)==0){q=n;r=o;break}if(t>>>0<(c[14572]|0)>>>0){bM()}else{c[A+20>>2]=t;c[t+24>>2]=A;q=n;r=o;break}}else{q=d;r=h}}while(0);d=q;if(d>>>0>=i>>>0){bM()}A=a+(h-4)|0;e=c[A>>2]|0;if((e&1|0)==0){bM()}do{if((e&2|0)==0){if((j|0)==(c[14574]|0)){B=(c[14571]|0)+r|0;c[14571]=B;c[14574]=q;c[q+4>>2]=B|1;if((q|0)==(c[14573]|0)){c[14573]=0;c[14570]=0}if(B>>>0<=(c[14575]|0)>>>0){return}u3(0)|0;return}if((j|0)==(c[14573]|0)){B=(c[14570]|0)+r|0;c[14570]=B;c[14573]=q;c[q+4>>2]=B|1;c[d+B>>2]=B;return}B=(e&-8)+r|0;C=e>>>3;L3062:do{if(e>>>0<256){u=c[a+h>>2]|0;g=c[a+(h|4)>>2]|0;b=58312+(C<<1<<2)|0;do{if((u|0)!=(b|0)){if(u>>>0<(c[14572]|0)>>>0){bM()}if((c[u+12>>2]|0)==(j|0)){break}bM()}}while(0);if((g|0)==(u|0)){c[14568]=c[14568]&~(1<<C);break}do{if((g|0)==(b|0)){D=g+8|0}else{if(g>>>0<(c[14572]|0)>>>0){bM()}f=g+8|0;if((c[f>>2]|0)==(j|0)){D=f;break}bM()}}while(0);c[u+12>>2]=g;c[D>>2]=u}else{b=i;f=c[a+(h+16)>>2]|0;t=c[a+(h|4)>>2]|0;do{if((t|0)==(b|0)){p=a+(h+12)|0;v=c[p>>2]|0;if((v|0)==0){m=a+(h+8)|0;k=c[m>>2]|0;if((k|0)==0){E=0;break}else{F=k;G=m}}else{F=v;G=p}while(1){p=F+20|0;v=c[p>>2]|0;if((v|0)!=0){F=v;G=p;continue}p=F+16|0;v=c[p>>2]|0;if((v|0)==0){break}else{F=v;G=p}}if(G>>>0<(c[14572]|0)>>>0){bM()}else{c[G>>2]=0;E=F;break}}else{p=c[a+h>>2]|0;if(p>>>0<(c[14572]|0)>>>0){bM()}v=p+12|0;if((c[v>>2]|0)!=(b|0)){bM()}m=t+8|0;if((c[m>>2]|0)==(b|0)){c[v>>2]=t;c[m>>2]=p;E=t;break}else{bM()}}}while(0);if((f|0)==0){break}t=a+(h+20)|0;u=58576+(c[t>>2]<<2)|0;do{if((b|0)==(c[u>>2]|0)){c[u>>2]=E;if((E|0)!=0){break}c[14569]=c[14569]&~(1<<c[t>>2]);break L3062}else{if(f>>>0<(c[14572]|0)>>>0){bM()}g=f+16|0;if((c[g>>2]|0)==(b|0)){c[g>>2]=E}else{c[f+20>>2]=E}if((E|0)==0){break L3062}}}while(0);if(E>>>0<(c[14572]|0)>>>0){bM()}c[E+24>>2]=f;b=c[a+(h+8)>>2]|0;do{if((b|0)!=0){if(b>>>0<(c[14572]|0)>>>0){bM()}else{c[E+16>>2]=b;c[b+24>>2]=E;break}}}while(0);b=c[a+(h+12)>>2]|0;if((b|0)==0){break}if(b>>>0<(c[14572]|0)>>>0){bM()}else{c[E+20>>2]=b;c[b+24>>2]=E;break}}}while(0);c[q+4>>2]=B|1;c[d+B>>2]=B;if((q|0)!=(c[14573]|0)){H=B;break}c[14570]=B;return}else{c[A>>2]=e&-2;c[q+4>>2]=r|1;c[d+r>>2]=r;H=r}}while(0);r=H>>>3;if(H>>>0<256){d=r<<1;e=58312+(d<<2)|0;A=c[14568]|0;E=1<<r;do{if((A&E|0)==0){c[14568]=A|E;I=e;J=58312+(d+2<<2)|0}else{r=58312+(d+2<<2)|0;h=c[r>>2]|0;if(h>>>0>=(c[14572]|0)>>>0){I=h;J=r;break}bM()}}while(0);c[J>>2]=q;c[I+12>>2]=q;c[q+8>>2]=I;c[q+12>>2]=e;return}e=q;I=H>>>8;do{if((I|0)==0){K=0}else{if(H>>>0>16777215){K=31;break}J=(I+1048320|0)>>>16&8;d=I<<J;E=(d+520192|0)>>>16&4;A=d<<E;d=(A+245760|0)>>>16&2;r=14-(E|J|d)+(A<<d>>>15)|0;K=H>>>((r+7|0)>>>0)&1|r<<1}}while(0);I=58576+(K<<2)|0;c[q+28>>2]=K;c[q+20>>2]=0;c[q+16>>2]=0;r=c[14569]|0;d=1<<K;do{if((r&d|0)==0){c[14569]=r|d;c[I>>2]=e;c[q+24>>2]=I;c[q+12>>2]=q;c[q+8>>2]=q}else{if((K|0)==31){L=0}else{L=25-(K>>>1)|0}A=H<<L;J=c[I>>2]|0;while(1){if((c[J+4>>2]&-8|0)==(H|0)){break}M=J+16+(A>>>31<<2)|0;E=c[M>>2]|0;if((E|0)==0){N=2402;break}else{A=A<<1;J=E}}if((N|0)==2402){if(M>>>0<(c[14572]|0)>>>0){bM()}else{c[M>>2]=e;c[q+24>>2]=J;c[q+12>>2]=q;c[q+8>>2]=q;break}}A=J+8|0;B=c[A>>2]|0;E=c[14572]|0;if(J>>>0<E>>>0){bM()}if(B>>>0<E>>>0){bM()}else{c[B+12>>2]=e;c[A>>2]=e;c[q+8>>2]=B;c[q+12>>2]=J;c[q+24>>2]=0;break}}}while(0);q=(c[14576]|0)-1|0;c[14576]=q;if((q|0)==0){O=58728}else{return}while(1){q=c[O>>2]|0;if((q|0)==0){break}else{O=q+8|0}}c[14576]=-1;return}function u2(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;if((a|0)==0){d=u0(b)|0;return d|0}if(b>>>0>4294967231){c[(bB()|0)>>2]=12;d=0;return d|0}if(b>>>0<11){e=16}else{e=b+11&-8}f=u4(a-8|0,e)|0;if((f|0)!=0){d=f+8|0;return d|0}f=u0(b)|0;if((f|0)==0){d=0;return d|0}e=c[a-4>>2]|0;g=(e&-8)-((e&3|0)==0?8:4)|0;e=g>>>0<b>>>0?g:b;u7(f|0,a|0,e)|0;u1(a);d=f;return d|0}function u3(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;do{if((c[14514]|0)==0){b=bJ(8)|0;if((b-1&b|0)==0){c[14516]=b;c[14515]=b;c[14517]=-1;c[14518]=2097152;c[14519]=0;c[14679]=0;c[14514]=(bZ(0)|0)&-16^1431655768;break}else{bM();return 0}}}while(0);if(a>>>0>=4294967232){d=0;return d|0}b=c[14574]|0;if((b|0)==0){d=0;return d|0}e=c[14571]|0;do{if(e>>>0>(a+40|0)>>>0){f=c[14516]|0;g=ac((((-40-a-1+e+f|0)>>>0)/(f>>>0)|0)-1|0,f)|0;h=b;i=58720;while(1){j=c[i>>2]|0;if(j>>>0<=h>>>0){if((j+(c[i+4>>2]|0)|0)>>>0>h>>>0){k=i;break}}j=c[i+8>>2]|0;if((j|0)==0){k=0;break}else{i=j}}if((c[k+12>>2]&8|0)!=0){break}i=bA(0)|0;h=k+4|0;if((i|0)!=((c[k>>2]|0)+(c[h>>2]|0)|0)){break}j=bA(-(g>>>0>2147483646?-2147483648-f|0:g)|0)|0;l=bA(0)|0;if(!((j|0)!=-1&l>>>0<i>>>0)){break}j=i-l|0;if((i|0)==(l|0)){break}c[h>>2]=(c[h>>2]|0)-j;c[14676]=(c[14676]|0)-j;h=c[14574]|0;m=(c[14571]|0)-j|0;j=h;n=h+8|0;if((n&7|0)==0){o=0}else{o=-n&7}n=m-o|0;c[14574]=j+o;c[14571]=n;c[j+(o+4)>>2]=n|1;c[j+(m+4)>>2]=40;c[14575]=c[14518];d=(i|0)!=(l|0)|0;return d|0}}while(0);if((c[14571]|0)>>>0<=(c[14575]|0)>>>0){d=0;return d|0}c[14575]=-1;d=0;return d|0}function u4(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=a+4|0;e=c[d>>2]|0;f=e&-8;g=a;h=g+f|0;i=h;j=c[14572]|0;if(g>>>0<j>>>0){bM();return 0}k=e&3;if(!((k|0)!=1&g>>>0<h>>>0)){bM();return 0}l=g+(f|4)|0;m=c[l>>2]|0;if((m&1|0)==0){bM();return 0}if((k|0)==0){if(b>>>0<256){n=0;return n|0}do{if(f>>>0>=(b+4|0)>>>0){if((f-b|0)>>>0>c[14516]<<1>>>0){break}else{n=a}return n|0}}while(0);n=0;return n|0}if(f>>>0>=b>>>0){k=f-b|0;if(k>>>0<=15){n=a;return n|0}c[d>>2]=e&1|b|2;c[g+(b+4)>>2]=k|3;c[l>>2]=c[l>>2]|1;u5(g+b|0,k);n=a;return n|0}if((i|0)==(c[14574]|0)){k=(c[14571]|0)+f|0;if(k>>>0<=b>>>0){n=0;return n|0}l=k-b|0;c[d>>2]=e&1|b|2;c[g+(b+4)>>2]=l|1;c[14574]=g+b;c[14571]=l;n=a;return n|0}if((i|0)==(c[14573]|0)){l=(c[14570]|0)+f|0;if(l>>>0<b>>>0){n=0;return n|0}k=l-b|0;if(k>>>0>15){c[d>>2]=e&1|b|2;c[g+(b+4)>>2]=k|1;c[g+l>>2]=k;o=g+(l+4)|0;c[o>>2]=c[o>>2]&-2;p=g+b|0;q=k}else{c[d>>2]=e&1|l|2;e=g+(l+4)|0;c[e>>2]=c[e>>2]|1;p=0;q=0}c[14570]=q;c[14573]=p;n=a;return n|0}if((m&2|0)!=0){n=0;return n|0}p=(m&-8)+f|0;if(p>>>0<b>>>0){n=0;return n|0}q=p-b|0;e=m>>>3;L3283:do{if(m>>>0<256){l=c[g+(f+8)>>2]|0;k=c[g+(f+12)>>2]|0;o=58312+(e<<1<<2)|0;do{if((l|0)!=(o|0)){if(l>>>0<j>>>0){bM();return 0}if((c[l+12>>2]|0)==(i|0)){break}bM();return 0}}while(0);if((k|0)==(l|0)){c[14568]=c[14568]&~(1<<e);break}do{if((k|0)==(o|0)){r=k+8|0}else{if(k>>>0<j>>>0){bM();return 0}s=k+8|0;if((c[s>>2]|0)==(i|0)){r=s;break}bM();return 0}}while(0);c[l+12>>2]=k;c[r>>2]=l}else{o=h;s=c[g+(f+24)>>2]|0;t=c[g+(f+12)>>2]|0;do{if((t|0)==(o|0)){u=g+(f+20)|0;v=c[u>>2]|0;if((v|0)==0){w=g+(f+16)|0;x=c[w>>2]|0;if((x|0)==0){y=0;break}else{z=x;A=w}}else{z=v;A=u}while(1){u=z+20|0;v=c[u>>2]|0;if((v|0)!=0){z=v;A=u;continue}u=z+16|0;v=c[u>>2]|0;if((v|0)==0){break}else{z=v;A=u}}if(A>>>0<j>>>0){bM();return 0}else{c[A>>2]=0;y=z;break}}else{u=c[g+(f+8)>>2]|0;if(u>>>0<j>>>0){bM();return 0}v=u+12|0;if((c[v>>2]|0)!=(o|0)){bM();return 0}w=t+8|0;if((c[w>>2]|0)==(o|0)){c[v>>2]=t;c[w>>2]=u;y=t;break}else{bM();return 0}}}while(0);if((s|0)==0){break}t=g+(f+28)|0;l=58576+(c[t>>2]<<2)|0;do{if((o|0)==(c[l>>2]|0)){c[l>>2]=y;if((y|0)!=0){break}c[14569]=c[14569]&~(1<<c[t>>2]);break L3283}else{if(s>>>0<(c[14572]|0)>>>0){bM();return 0}k=s+16|0;if((c[k>>2]|0)==(o|0)){c[k>>2]=y}else{c[s+20>>2]=y}if((y|0)==0){break L3283}}}while(0);if(y>>>0<(c[14572]|0)>>>0){bM();return 0}c[y+24>>2]=s;o=c[g+(f+16)>>2]|0;do{if((o|0)!=0){if(o>>>0<(c[14572]|0)>>>0){bM();return 0}else{c[y+16>>2]=o;c[o+24>>2]=y;break}}}while(0);o=c[g+(f+20)>>2]|0;if((o|0)==0){break}if(o>>>0<(c[14572]|0)>>>0){bM();return 0}else{c[y+20>>2]=o;c[o+24>>2]=y;break}}}while(0);if(q>>>0<16){c[d>>2]=p|c[d>>2]&1|2;y=g+(p|4)|0;c[y>>2]=c[y>>2]|1;n=a;return n|0}else{c[d>>2]=c[d>>2]&1|b|2;c[g+(b+4)>>2]=q|3;d=g+(p|4)|0;c[d>>2]=c[d>>2]|1;u5(g+b|0,q);n=a;return n|0}return 0}function u5(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;d=a;e=d+b|0;f=e;g=c[a+4>>2]|0;L3359:do{if((g&1|0)==0){h=c[a>>2]|0;if((g&3|0)==0){return}i=d+(-h|0)|0;j=i;k=h+b|0;l=c[14572]|0;if(i>>>0<l>>>0){bM()}if((j|0)==(c[14573]|0)){m=d+(b+4)|0;if((c[m>>2]&3|0)!=3){n=j;o=k;break}c[14570]=k;c[m>>2]=c[m>>2]&-2;c[d+(4-h)>>2]=k|1;c[e>>2]=k;return}m=h>>>3;if(h>>>0<256){p=c[d+(8-h)>>2]|0;q=c[d+(12-h)>>2]|0;r=58312+(m<<1<<2)|0;do{if((p|0)!=(r|0)){if(p>>>0<l>>>0){bM()}if((c[p+12>>2]|0)==(j|0)){break}bM()}}while(0);if((q|0)==(p|0)){c[14568]=c[14568]&~(1<<m);n=j;o=k;break}do{if((q|0)==(r|0)){s=q+8|0}else{if(q>>>0<l>>>0){bM()}t=q+8|0;if((c[t>>2]|0)==(j|0)){s=t;break}bM()}}while(0);c[p+12>>2]=q;c[s>>2]=p;n=j;o=k;break}r=i;m=c[d+(24-h)>>2]|0;t=c[d+(12-h)>>2]|0;do{if((t|0)==(r|0)){u=16-h|0;v=d+(u+4)|0;w=c[v>>2]|0;if((w|0)==0){x=d+u|0;u=c[x>>2]|0;if((u|0)==0){y=0;break}else{z=u;A=x}}else{z=w;A=v}while(1){v=z+20|0;w=c[v>>2]|0;if((w|0)!=0){z=w;A=v;continue}v=z+16|0;w=c[v>>2]|0;if((w|0)==0){break}else{z=w;A=v}}if(A>>>0<l>>>0){bM()}else{c[A>>2]=0;y=z;break}}else{v=c[d+(8-h)>>2]|0;if(v>>>0<l>>>0){bM()}w=v+12|0;if((c[w>>2]|0)!=(r|0)){bM()}x=t+8|0;if((c[x>>2]|0)==(r|0)){c[w>>2]=t;c[x>>2]=v;y=t;break}else{bM()}}}while(0);if((m|0)==0){n=j;o=k;break}t=d+(28-h)|0;l=58576+(c[t>>2]<<2)|0;do{if((r|0)==(c[l>>2]|0)){c[l>>2]=y;if((y|0)!=0){break}c[14569]=c[14569]&~(1<<c[t>>2]);n=j;o=k;break L3359}else{if(m>>>0<(c[14572]|0)>>>0){bM()}i=m+16|0;if((c[i>>2]|0)==(r|0)){c[i>>2]=y}else{c[m+20>>2]=y}if((y|0)==0){n=j;o=k;break L3359}}}while(0);if(y>>>0<(c[14572]|0)>>>0){bM()}c[y+24>>2]=m;r=16-h|0;t=c[d+r>>2]|0;do{if((t|0)!=0){if(t>>>0<(c[14572]|0)>>>0){bM()}else{c[y+16>>2]=t;c[t+24>>2]=y;break}}}while(0);t=c[d+(r+4)>>2]|0;if((t|0)==0){n=j;o=k;break}if(t>>>0<(c[14572]|0)>>>0){bM()}else{c[y+20>>2]=t;c[t+24>>2]=y;n=j;o=k;break}}else{n=a;o=b}}while(0);a=c[14572]|0;if(e>>>0<a>>>0){bM()}y=d+(b+4)|0;z=c[y>>2]|0;do{if((z&2|0)==0){if((f|0)==(c[14574]|0)){A=(c[14571]|0)+o|0;c[14571]=A;c[14574]=n;c[n+4>>2]=A|1;if((n|0)!=(c[14573]|0)){return}c[14573]=0;c[14570]=0;return}if((f|0)==(c[14573]|0)){A=(c[14570]|0)+o|0;c[14570]=A;c[14573]=n;c[n+4>>2]=A|1;c[n+A>>2]=A;return}A=(z&-8)+o|0;s=z>>>3;L3458:do{if(z>>>0<256){g=c[d+(b+8)>>2]|0;t=c[d+(b+12)>>2]|0;h=58312+(s<<1<<2)|0;do{if((g|0)!=(h|0)){if(g>>>0<a>>>0){bM()}if((c[g+12>>2]|0)==(f|0)){break}bM()}}while(0);if((t|0)==(g|0)){c[14568]=c[14568]&~(1<<s);break}do{if((t|0)==(h|0)){B=t+8|0}else{if(t>>>0<a>>>0){bM()}m=t+8|0;if((c[m>>2]|0)==(f|0)){B=m;break}bM()}}while(0);c[g+12>>2]=t;c[B>>2]=g}else{h=e;m=c[d+(b+24)>>2]|0;l=c[d+(b+12)>>2]|0;do{if((l|0)==(h|0)){i=d+(b+20)|0;p=c[i>>2]|0;if((p|0)==0){q=d+(b+16)|0;v=c[q>>2]|0;if((v|0)==0){C=0;break}else{D=v;E=q}}else{D=p;E=i}while(1){i=D+20|0;p=c[i>>2]|0;if((p|0)!=0){D=p;E=i;continue}i=D+16|0;p=c[i>>2]|0;if((p|0)==0){break}else{D=p;E=i}}if(E>>>0<a>>>0){bM()}else{c[E>>2]=0;C=D;break}}else{i=c[d+(b+8)>>2]|0;if(i>>>0<a>>>0){bM()}p=i+12|0;if((c[p>>2]|0)!=(h|0)){bM()}q=l+8|0;if((c[q>>2]|0)==(h|0)){c[p>>2]=l;c[q>>2]=i;C=l;break}else{bM()}}}while(0);if((m|0)==0){break}l=d+(b+28)|0;g=58576+(c[l>>2]<<2)|0;do{if((h|0)==(c[g>>2]|0)){c[g>>2]=C;if((C|0)!=0){break}c[14569]=c[14569]&~(1<<c[l>>2]);break L3458}else{if(m>>>0<(c[14572]|0)>>>0){bM()}t=m+16|0;if((c[t>>2]|0)==(h|0)){c[t>>2]=C}else{c[m+20>>2]=C}if((C|0)==0){break L3458}}}while(0);if(C>>>0<(c[14572]|0)>>>0){bM()}c[C+24>>2]=m;h=c[d+(b+16)>>2]|0;do{if((h|0)!=0){if(h>>>0<(c[14572]|0)>>>0){bM()}else{c[C+16>>2]=h;c[h+24>>2]=C;break}}}while(0);h=c[d+(b+20)>>2]|0;if((h|0)==0){break}if(h>>>0<(c[14572]|0)>>>0){bM()}else{c[C+20>>2]=h;c[h+24>>2]=C;break}}}while(0);c[n+4>>2]=A|1;c[n+A>>2]=A;if((n|0)!=(c[14573]|0)){F=A;break}c[14570]=A;return}else{c[y>>2]=z&-2;c[n+4>>2]=o|1;c[n+o>>2]=o;F=o}}while(0);o=F>>>3;if(F>>>0<256){z=o<<1;y=58312+(z<<2)|0;C=c[14568]|0;b=1<<o;do{if((C&b|0)==0){c[14568]=C|b;G=y;H=58312+(z+2<<2)|0}else{o=58312+(z+2<<2)|0;d=c[o>>2]|0;if(d>>>0>=(c[14572]|0)>>>0){G=d;H=o;break}bM()}}while(0);c[H>>2]=n;c[G+12>>2]=n;c[n+8>>2]=G;c[n+12>>2]=y;return}y=n;G=F>>>8;do{if((G|0)==0){I=0}else{if(F>>>0>16777215){I=31;break}H=(G+1048320|0)>>>16&8;z=G<<H;b=(z+520192|0)>>>16&4;C=z<<b;z=(C+245760|0)>>>16&2;o=14-(b|H|z)+(C<<z>>>15)|0;I=F>>>((o+7|0)>>>0)&1|o<<1}}while(0);G=58576+(I<<2)|0;c[n+28>>2]=I;c[n+20>>2]=0;c[n+16>>2]=0;o=c[14569]|0;z=1<<I;if((o&z|0)==0){c[14569]=o|z;c[G>>2]=y;c[n+24>>2]=G;c[n+12>>2]=n;c[n+8>>2]=n;return}if((I|0)==31){J=0}else{J=25-(I>>>1)|0}I=F<<J;J=c[G>>2]|0;while(1){if((c[J+4>>2]&-8|0)==(F|0)){break}K=J+16+(I>>>31<<2)|0;G=c[K>>2]|0;if((G|0)==0){L=2708;break}else{I=I<<1;J=G}}if((L|0)==2708){if(K>>>0<(c[14572]|0)>>>0){bM()}c[K>>2]=y;c[n+24>>2]=J;c[n+12>>2]=n;c[n+8>>2]=n;return}K=J+8|0;L=c[K>>2]|0;I=c[14572]|0;if(J>>>0<I>>>0){bM()}if(L>>>0<I>>>0){bM()}c[L+12>>2]=y;c[K>>2]=y;c[n+8>>2]=L;c[n+12>>2]=J;c[n+24>>2]=0;return}function u6(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=b+e|0;if((e|0)>=20){d=d&255;e=b&3;g=d|d<<8|d<<16|d<<24;h=f&~3;if(e){e=b+4-e|0;while((b|0)<(e|0)){a[b]=d;b=b+1|0}}while((b|0)<(h|0)){c[b>>2]=g;b=b+4|0}}while((b|0)<(f|0)){a[b]=d;b=b+1|0}}function u7(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=b|0;if((b&3)==(d&3)){while(b&3){if((e|0)==0)return f|0;a[b]=a[d]|0;b=b+1|0;d=d+1|0;e=e-1|0}while((e|0)>=4){c[b>>2]=c[d>>2];b=b+4|0;d=d+4|0;e=e-4|0}}while((e|0)>0){a[b]=a[d]|0;b=b+1|0;d=d+1|0;e=e-1|0}return f|0}function u8(b){b=b|0;var c=0;c=b;while(a[c]|0){c=c+1|0}return c-b|0}function u9(b,c){b=b|0;c=c|0;var d=0,e=0;d=b+(u8(b)|0)|0;do{a[d+e|0]=a[c+e|0];e=e+1|0}while(a[c+(e-1)|0]|0);return b|0}function va(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0,g=0;while((e|0)<(c|0)){f=d[a+e|0]|0;g=d[b+e|0]|0;if((f|0)!=(g|0))return((f|0)>(g|0)?1:-1)|0;e=e+1|0}return 0}function vb(b,c){b=b|0;c=c|0;var d=0;do{a[b+d|0]=a[c+d|0];d=d+1|0}while(a[c+(d-1)|0]|0);return b|0}function vc(a){a=a|0;if((a|0)<65)return a|0;if((a|0)>90)return a|0;return a-65+97|0}function vd(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;while(e>>>0<d>>>0){f=vc(a[b+e|0]|0)|0;g=vc(a[c+e|0]|0)|0;if((f|0)==(g|0)&(f|0)==0)return 0;if((f|0)==0)return-1;if((g|0)==0)return 1;if((f|0)==(g|0)){e=e+1|0;continue}else{return(f>>>0>g>>>0?1:-1)|0}}return 0}function ve(a,b){a=a|0;b=b|0;return vd(a,b,-1)|0}function vf(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=a+c>>>0;return(G=b+d+(e>>>0<a>>>0|0)>>>0,e|0)|0}function vg(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=b-d>>>0;e=b-d-(c>>>0>a>>>0|0)>>>0;return(G=e,a-c>>>0|0)|0}function vh(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){G=b<<c|(a&(1<<c)-1<<32-c)>>>32-c;return a<<c}G=a<<c-32;return 0}function vi(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){G=b>>>c;return a>>>c|(b&(1<<c)-1)<<32-c}G=0;return b>>>c-32|0}function vj(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){G=b>>c;return a>>>c|(b&(1<<c)-1)<<32-c}G=(b|0)<0?-1:0;return b>>c-32|0}function vk(b){b=b|0;var c=0;c=a[n+(b>>>24)|0]|0;if((c|0)<8)return c|0;c=a[n+(b>>16&255)|0]|0;if((c|0)<8)return c+8|0;c=a[n+(b>>8&255)|0]|0;if((c|0)<8)return c+16|0;return(a[n+(b&255)|0]|0)+24|0}function vl(b){b=b|0;var c=0;c=a[m+(b&255)|0]|0;if((c|0)<8)return c|0;c=a[m+(b>>8&255)|0]|0;if((c|0)<8)return c+8|0;c=a[m+(b>>16&255)|0]|0;if((c|0)<8)return c+16|0;return(a[m+(b>>>24)|0]|0)+24|0}function vm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a&65535;d=b&65535;e=ac(d,c)|0;f=a>>>16;a=(e>>>16)+(ac(d,f)|0)|0;d=b>>>16;b=ac(d,c)|0;return(G=(a>>>16)+(ac(d,f)|0)+(((a&65535)+b|0)>>>16)|0,a+b<<16|e&65535|0)|0}function vn(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b>>31|((b|0)<0?-1:0)<<1;f=((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1;g=d>>31|((d|0)<0?-1:0)<<1;h=((d|0)<0?-1:0)>>31|((d|0)<0?-1:0)<<1;i=vg(e^a,f^b,e,f)|0;b=G;a=g^e;e=h^f;f=vg((vs(i,b,vg(g^c,h^d,g,h)|0,G,0)|0)^a,G^e,a,e)|0;return(G=G,f)|0}function vo(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+8|0;g=f|0;h=b>>31|((b|0)<0?-1:0)<<1;j=((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1;k=e>>31|((e|0)<0?-1:0)<<1;l=((e|0)<0?-1:0)>>31|((e|0)<0?-1:0)<<1;m=vg(h^a,j^b,h,j)|0;b=G;a=vg(k^d,l^e,k,l)|0;vs(m,b,a,G,g)|0;a=vg(c[g>>2]^h,c[g+4>>2]^j,h,j)|0;j=G;i=f;return(G=j,a)|0}function vp(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=a;a=c;c=vm(e,a)|0;f=G;return(G=(ac(b,a)|0)+(ac(d,e)|0)+f|f&0,c|0|0)|0}function vq(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=vs(a,b,c,d,0)|0;return(G=G,e)|0}function vr(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;i=i+8|0;g=f|0;vs(a,b,d,e,g)|0;i=f;return(G=c[g+4>>2]|0,c[g>>2]|0)|0}function vs(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0;g=a;h=b;i=h;j=d;k=e;l=k;if((i|0)==0){m=(f|0)!=0;if((l|0)==0){if(m){c[f>>2]=(g>>>0)%(j>>>0);c[f+4>>2]=0}n=0;o=(g>>>0)/(j>>>0)>>>0;return(G=n,o)|0}else{if(!m){n=0;o=0;return(G=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=b&0;n=0;o=0;return(G=n,o)|0}}m=(l|0)==0;do{if((j|0)==0){if(m){if((f|0)!=0){c[f>>2]=(i>>>0)%(j>>>0);c[f+4>>2]=0}n=0;o=(i>>>0)/(j>>>0)>>>0;return(G=n,o)|0}if((g|0)==0){if((f|0)!=0){c[f>>2]=0;c[f+4>>2]=(i>>>0)%(l>>>0)}n=0;o=(i>>>0)/(l>>>0)>>>0;return(G=n,o)|0}p=l-1|0;if((p&l|0)==0){if((f|0)!=0){c[f>>2]=a|0;c[f+4>>2]=p&i|b&0}n=0;o=i>>>((vl(l|0)|0)>>>0);return(G=n,o)|0}p=(vk(l|0)|0)-(vk(i|0)|0)|0;if(p>>>0<=30){q=p+1|0;r=31-p|0;s=q;t=i<<r|g>>>(q>>>0);u=i>>>(q>>>0);v=0;w=g<<r;break}if((f|0)==0){n=0;o=0;return(G=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=h|b&0;n=0;o=0;return(G=n,o)|0}else{if(!m){r=(vk(l|0)|0)-(vk(i|0)|0)|0;if(r>>>0<=31){q=r+1|0;p=31-r|0;x=r-31>>31;s=q;t=g>>>(q>>>0)&x|i<<p;u=i>>>(q>>>0)&x;v=0;w=g<<p;break}if((f|0)==0){n=0;o=0;return(G=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=h|b&0;n=0;o=0;return(G=n,o)|0}p=j-1|0;if((p&j|0)!=0){x=(vk(j|0)|0)+33-(vk(i|0)|0)|0;q=64-x|0;r=32-x|0;y=r>>31;z=x-32|0;A=z>>31;s=x;t=r-1>>31&i>>>(z>>>0)|(i<<r|g>>>(x>>>0))&A;u=A&i>>>(x>>>0);v=g<<q&y;w=(i<<q|g>>>(z>>>0))&y|g<<r&x-33>>31;break}if((f|0)!=0){c[f>>2]=p&g;c[f+4>>2]=0}if((j|0)==1){n=h|b&0;o=a|0|0;return(G=n,o)|0}else{p=vl(j|0)|0;n=i>>>(p>>>0)|0;o=i<<32-p|g>>>(p>>>0)|0;return(G=n,o)|0}}}while(0);if((s|0)==0){B=w;C=v;D=u;E=t;F=0;H=0}else{g=d|0|0;d=k|e&0;e=vf(g,d,-1,-1)|0;k=G;i=w;w=v;v=u;u=t;t=s;s=0;while(1){I=w>>>31|i<<1;J=s|w<<1;j=u<<1|i>>>31|0;a=u>>>31|v<<1|0;vg(e,k,j,a)|0;b=G;h=b>>31|((b|0)<0?-1:0)<<1;K=h&1;L=vg(j,a,h&g,(((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1)&d)|0;M=G;b=t-1|0;if((b|0)==0){break}else{i=I;w=J;v=M;u=L;t=b;s=K}}B=I;C=J;D=M;E=L;F=0;H=K}K=C;C=0;if((f|0)!=0){c[f>>2]=E;c[f+4>>2]=D}n=(K|0)>>>31|(B|C)<<1|(C<<1|K>>>31)&0|F;o=(K<<1|0>>>31)&-2|H;return(G=n,o)|0}function vt(a,b){a=a|0;b=b|0;return b_[a&511](b|0)|0}function vu(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b$[a&3](b|0,c|0,d|0,e|0,f|0)}function vv(a,b){a=a|0;b=b|0;b0[a&127](b|0)}function vw(a,b,c){a=a|0;b=b|0;c=c|0;b1[a&511](b|0,c|0)}function vx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return b2[a&127](b|0,c|0,d|0)|0}function vy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b3[a&63](b|0,c|0,d|0)}function vz(a){a=a|0;b4[a&7]()}function vA(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return b5[a&127](b|0,c|0,d|0,e|0)|0}function vB(a,b,c){a=a|0;b=b|0;c=c|0;return b6[a&63](b|0,c|0)|0}function vC(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return b7[a&7](b|0,c|0,d|0,e|0,f|0)|0}function vD(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;b8[a&7](b|0,c|0,d|0,e|0)}function vE(a){a=a|0;ad(0);return 0}function vF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ad(1)}function vG(a){a=a|0;ad(2)}function vH(a,b){a=a|0;b=b|0;ad(3)}function vI(a,b,c){a=a|0;b=b|0;c=c|0;ad(4);return 0}function vJ(a,b,c){a=a|0;b=b|0;c=c|0;ad(5)}function vK(){ad(6)}function vL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ad(7);return 0}function vM(a,b){a=a|0;b=b|0;ad(8);return 0}function vN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ad(9);return 0}function vO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ad(10)}
// EMSCRIPTEN_END_FUNCS
var b_=[vE,vE,kn,vE,lt,vE,lE,vE,jh,vE,lk,vE,jk,vE,kZ,vE,lh,vE,k5,vE,jG,vE,jw,vE,kv,vE,jN,vE,kR,vE,iU,vE,k_,vE,lw,vE,k7,vE,k6,vE,jz,vE,kA,vE,iX,vE,ja,vE,rE,vE,lc,vE,jn,vE,jS,vE,lo,vE,kO,vE,k2,vE,ki,vE,ln,vE,le,vE,kC,vE,pt,vE,kd,vE,ku,vE,j3,vE,i2,vE,kg,vE,lp,vE,lG,vE,iW,vE,lD,vE,jD,vE,i9,vE,jH,vE,js,vE,k4,vE,lA,vE,iS,vE,um,vE,ks,vE,j6,vE,kb,vE,jm,vE,i_,vE,jy,vE,kl,vE,lu,vE,jj,vE,kD,vE,jW,vE,kP,vE,i3,vE,jf,vE,km,vE,lx,vE,ld,vE,k1,vE,jC,vE,jR,vE,k3,vE,iR,vE,je,vE,k9,vE,jx,vE,lI,vE,iV,vE,j5,vE,jZ,vE,jo,vE,k$,vE,kF,vE,uX,vE,lY,vE,kL,vE,kE,vE,kQ,vE,rG,vE,ls,vE,j4,vE,j7,vE,kh,vE,i7,vE,kB,vE,kp,vE,lJ,vE,jB,vE,lK,vE,jQ,vE,k8,vE,kq,vE,kU,vE,lr,vE,kG,vE,lH,vE,kM,vE,jg,vE,lb,vE,iN,vE,kf,vE,lg,vE,i5,vE,jY,vE,jI,vE,lC,vE,ka,vE,k0,vE,i6,vE,j_,vE,jp,vE,kY,vE,i$,vE,kk,vE,jA,vE,jP,vE,jV,vE,kr,vE,kT,vE,jE,vE,jM,vE,iT,vE,jO,vE,jX,vE,ko,vE,j1,vE,lv,vE,ll,vE,ly,vE,lL,vE,kX,vE,jq,vE,i0,vE,kH,vE,pl,vE,lm,vE,jt,vE,lX,vE,j2,vE,iM,vE,j8,vE,ji,vE,kt,vE,jU,vE,lq,vE,o9,vE,pp,vE,pj,vE,i8,vE,j0,vE,jl,vE,lB,vE,i1,vE,iZ,vE,lf,vE,ju,vE,ke,vE,kI,vE,iP,vE,jc,vE,ky,vE,kV,vE,j$,vE,mz,vE,j9,vE,jr,vE,la,vE,kj,vE,kW,vE,jT,vE,kx,vE,jL,vE,kc,vE,kK,vE,kN,vE,kw,vE,i4,vE,lF,vE,iY,vE,lz,vE,kS,vE,lj,vE,iO,vE,jF,vE,jJ,vE,kJ,vE,jd,vE,kz,vE,jv,vE,jb,vE,jK,vE,iQ,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE,vE];var b$=[vF,vF,fj,vF];var b0=[vG,vG,cL,vG,cN,vG,eV,vG,rH,vG,pm,vG,uV,vG,cr,vG,uE,vG,oC,vG,r0,vG,pk,vG,uo,vG,cM,vG,pq,vG,e4,vG,oV,vG,cA,vG,eU,vG,e3,vG,dU,vG,eY,vG,cS,vG,pa,vG,r_,vG,nU,vG,e6,vG,cR,vG,cT,vG,uZ,vG,up,vG,r2,vG,e1,vG,eX,vG,u_,vG,e7,vG,fb,vG,uy,vG,ow,vG,uh,vG,eT,vG,pu,vG,ea,vG,d9,vG,e2,vG,e_,vG,oJ,vG,rF,vG,ua,vG,eZ,vG,e5,vG,e8,vG,vG,vG,vG,vG,vG,vG,vG,vG,vG,vG,vG,vG,vG,vG,vG,vG,vG,vG,vG,vG,vG,vG,vG,vG];var b1=[vH,vH,hn,vH,hy,vH,hf,vH,fQ,vH,gf,vH,f0,vH,gj,vH,fX,vH,gz,vH,gW,vH,gF,vH,hs,vH,gs,vH,fY,vH,he,vH,g8,vH,hI,vH,hF,vH,f9,vH,g3,vH,h$,vH,dT,vH,hg,vH,f1,vH,hN,vH,gk,vH,gI,vH,hm,vH,gy,vH,gR,vH,g4,vH,gG,vH,g$,vH,c2,vH,fW,vH,gu,vH,hX,vH,hY,vH,ha,vH,cJ,vH,gQ,vH,hZ,vH,fT,vH,g6,vH,gh,vH,hK,vH,f8,vH,dS,vH,f2,vH,f5,vH,hA,vH,fZ,vH,hj,vH,f7,vH,g9,vH,gm,vH,hQ,vH,dC,vH,gx,vH,hG,vH,hL,vH,gv,vH,cH,vH,fV,vH,cq,vH,gU,vH,gw,vH,hW,vH,ge,vH,dz,vH,gq,vH,f4,vH,hB,vH,hE,vH,hu,vH,gA,vH,gO,vH,r$,vH,hP,vH,hV,vH,gJ,vH,dx,vH,mF,vH,hT,vH,gX,vH,gY,vH,hH,vH,hM,vH,ga,vH,f3,vH,d_,vH,fU,vH,gC,vH,hl,vH,fS,vH,gp,vH,gd,vH,h2,vH,hh,vH,hv,vH,dR,vH,r4,vH,g2,vH,gP,vH,hO,vH,gK,vH,h1,vH,gZ,vH,hS,vH,dQ,vH,hb,vH,h0,vH,gB,vH,fR,vH,g5,vH,hx,vH,gc,vH,ht,vH,dX,vH,hp,vH,gt,vH,dM,vH,gM,vH,hC,vH,f6,vH,mA,vH,g1,vH,fh,vH,hk,vH,gL,vH,gV,vH,hR,vH,gb,vH,hi,vH,f_,vH,fg,vH,f$,vH,gH,vH,hq,vH,g_,vH,hD,vH,gS,vH,hd,vH,dY,vH,dZ,vH,h3,vH,r1,vH,go,vH,ho,vH,hz,vH,gi,vH,gN,vH,gr,vH,gg,vH,fi,vH,g0,vH,h_,vH,hr,vH,hU,vH,hJ,vH,gE,vH,gT,vH,c3,vH,gD,vH,hc,vH,g7,vH,hw,vH,gl,vH,gn,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH,vH];var b2=[vI,vI,eu,vI,ul,vI,eq,vI,ph,vI,eC,vI,er,vI,d1,vI,oP,vI,ey,vI,ej,vI,pb,vI,oF,vI,rC,vI,em,vI,d2,vI,et,vI,pc,vI,rS,vI,oY,vI,rT,vI,eA,vI,ei,vI,un,vI,pv,vI,pd,vI,ev,vI,uW,vI,ue,vI,pn,vI,r3,vI,eD,vI,oa,vI,eB,vI,po,vI,ex,vI,cO,vI,eh,vI,ps,vI,es,vI,ek,vI,ez,vI,rI,vI,uY,vI,en,vI,cU,vI,pr,vI,cs,vI,el,vI,ep,vI,eo,vI,ew,vI,vI,vI,vI,vI,vI,vI,vI,vI,vI,vI,vI,vI,vI,vI,vI,vI,vI,vI,vI,vI,vI,vI,vI,vI];var b3=[vJ,vJ,mK,vJ,d7,vJ,nl,vJ,nk,vJ,rK,vJ,eg,vJ,nK,vJ,c_,vJ,nM,vJ,nm,vJ,mL,vJ,dB,vJ,nL,vJ,mJ,vJ,dW,vJ,eR,vJ,dO,vJ,eW,vJ,d8,vJ,nI,vJ,vJ,vJ,vJ,vJ,vJ,vJ,vJ,vJ,vJ,vJ,vJ,vJ,vJ,vJ,vJ,vJ,vJ,vJ,vJ,vJ,vJ,vJ];var b4=[vK,vK,d0,vK,c$,vK,vK,vK];var b5=[vL,vL,n9,vL,uA,vL,rJ,vL,oE,vL,me,vL,oN,vL,oL,vL,ub,vL,mk,vL,nV,vL,l7,vL,uc,vL,mb,vL,l8,vL,mc,vL,ox,vL,oy,vL,oX,vL,mf,vL,mh,vL,mg,vL,ma,vL,ml,vL,rD,vL,ou,vL,md,vL,oD,vL,uj,vL,uz,vL,ui,vL,l9,vL,mi,vL,mj,vL,oK,vL,ud,vL,oW,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL,vL];var b6=[vM,vM,d5,vM,mG,vM,nj,vM,eH,vM,mI,vM,nG,vM,c0,vM,pe,vM,d6,vM,nh,vM,o$,vM,nH,vM,d4,vM,nF,vM,eQ,vM,mH,vM,dV,vM,pf,vM,c5,vM,oZ,vM,ni,vM,vM,vM,vM,vM,vM,vM,vM,vM,vM,vM,vM,vM,vM,vM,vM,vM,vM,vM,vM,vM];var b7=[vN,vN,o_,vN,pg,vN,vN,vN];var b8=[vO,vO,ct,vO,dP,vO,cP,vO];return{_memcmp:va,_strncasecmp:vd,_strcat:u9,_free:u1,_main:eb,_realloc:u2,_tolower:vc,_strlen:u8,_memset:u6,_malloc:u0,_memcpy:u7,_strcasecmp:ve,_strcpy:vb,runPostSets:cp,stackAlloc:b9,stackSave:ca,stackRestore:cb,setThrew:cc,setTempRet0:cf,setTempRet1:cg,setTempRet2:ch,setTempRet3:ci,setTempRet4:cj,setTempRet5:ck,setTempRet6:cl,setTempRet7:cm,setTempRet8:cn,setTempRet9:co,dynCall_ii:vt,dynCall_viiiii:vu,dynCall_vi:vv,dynCall_vii:vw,dynCall_iiii:vx,dynCall_viii:vy,dynCall_v:vz,dynCall_iiiii:vA,dynCall_iii:vB,dynCall_iiiiii:vC,dynCall_viiii:vD}})
// EMSCRIPTEN_END_ASM
({ "Math": Math, "Int8Array": Int8Array, "Int16Array": Int16Array, "Int32Array": Int32Array, "Uint8Array": Uint8Array, "Uint16Array": Uint16Array, "Uint32Array": Uint32Array, "Float32Array": Float32Array, "Float64Array": Float64Array }, { "abort": abort, "assert": assert, "asmPrintInt": asmPrintInt, "asmPrintFloat": asmPrintFloat, "min": Math_min, "invoke_ii": invoke_ii, "invoke_viiiii": invoke_viiiii, "invoke_vi": invoke_vi, "invoke_vii": invoke_vii, "invoke_iiii": invoke_iiii, "invoke_viii": invoke_viii, "invoke_v": invoke_v, "invoke_iiiii": invoke_iiiii, "invoke_iii": invoke_iii, "invoke_iiiiii": invoke_iiiiii, "invoke_viiii": invoke_viiii, "_llvm_lifetime_end": _llvm_lifetime_end, "_lseek": _lseek, "_fclose": _fclose, "_SDL_EventState": _SDL_EventState, "_strtoul": _strtoul, "_fflush": _fflush, "_SDL_GetMouseState": _SDL_GetMouseState, "_strtol": _strtol, "_fputc": _fputc, "_fwrite": _fwrite, "_ptsname": _ptsname, "_send": _send, "_tcflush": _tcflush, "_fputs": _fputs, "_emscripten_cancel_main_loop": _emscripten_cancel_main_loop, "_SDL_UnlockAudio": _SDL_UnlockAudio, "_SDL_WasInit": _SDL_WasInit, "_read": _read, "_fileno": _fileno, "_fsync": _fsync, "_signal": _signal, "_SDL_PauseAudio": _SDL_PauseAudio, "_SDL_LockAudio": _SDL_LockAudio, "_strcmp": _strcmp, "_strncmp": _strncmp, "_snprintf": _snprintf, "_fgetc": _fgetc, "_atexit": _atexit, "_close": _close, "_tcsetattr": _tcsetattr, "_strchr": _strchr, "_tcgetattr": _tcgetattr, "_fopen": _fopen, "___setErrNo": ___setErrNo, "_grantpt": _grantpt, "_ftell": _ftell, "_exit": _exit, "_sprintf": _sprintf, "_fcntl": _fcntl, "_SDL_ShowCursor": _SDL_ShowCursor, "_gmtime": _gmtime, "_symlink": _symlink, "_localtime_r": _localtime_r, "_ftruncate": _ftruncate, "_recv": _recv, "_SDL_PollEvent": _SDL_PollEvent, "_SDL_Init": _SDL_Init, "__exit": __exit, "_SDL_WM_GrabInput": _SDL_WM_GrabInput, "_llvm_va_end": _llvm_va_end, "_tzset": _tzset, "_SDL_CreateRGBSurfaceFrom": _SDL_CreateRGBSurfaceFrom, "_printf": _printf, "_unlockpt": _unlockpt, "_pread": _pread, "_SDL_SetVideoMode": _SDL_SetVideoMode, "_poll": _poll, "_open": _open, "_usleep": _usleep, "_SDL_EnableKeyRepeat": _SDL_EnableKeyRepeat, "_puts": _puts, "_SDL_GetVideoInfo": _SDL_GetVideoInfo, "_nanosleep": _nanosleep, "_SDL_Flip": _SDL_Flip, "_SDL_InitSubSystem": _SDL_InitSubSystem, "_strdup": _strdup, "_SDL_GetError": _SDL_GetError, "__formatString": __formatString, "_gettimeofday": _gettimeofday, "_vfprintf": _vfprintf, "_SDL_WM_SetCaption": _SDL_WM_SetCaption, "_sbrk": _sbrk, "___errno_location": ___errno_location, "_SDL_CloseAudio": _SDL_CloseAudio, "_isspace": _isspace, "_llvm_lifetime_start": _llvm_lifetime_start, "__parseInt": __parseInt, "_SDL_OpenAudio": _SDL_OpenAudio, "_localtime": _localtime, "_gmtime_r": _gmtime_r, "_sysconf": _sysconf, "_fread": _fread, "_SDL_WM_ToggleFullScreen": _SDL_WM_ToggleFullScreen, "_abort": _abort, "_fprintf": _fprintf, "_tan": _tan, "__reallyNegative": __reallyNegative, "_posix_openpt": _posix_openpt, "_fseek": _fseek, "_write": _write, "_SDL_UpperBlit": _SDL_UpperBlit, "_truncate": _truncate, "_emscripten_set_main_loop": _emscripten_set_main_loop, "_unlink": _unlink, "_pwrite": _pwrite, "_SDL_FreeSurface": _SDL_FreeSurface, "_time": _time, "STACKTOP": STACKTOP, "STACK_MAX": STACK_MAX, "tempDoublePtr": tempDoublePtr, "ABORT": ABORT, "cttz_i8": cttz_i8, "ctlz_i8": ctlz_i8, "NaN": NaN, "Infinity": Infinity, "_stdout": _stdout, "_stdin": _stdin, "_stderr": _stderr }, buffer);
var _memcmp = Module["_memcmp"] = asm["_memcmp"];
var _strncasecmp = Module["_strncasecmp"] = asm["_strncasecmp"];
var _strcat = Module["_strcat"] = asm["_strcat"];
var _free = Module["_free"] = asm["_free"];
var _main = Module["_main"] = asm["_main"];
var _realloc = Module["_realloc"] = asm["_realloc"];
var _tolower = Module["_tolower"] = asm["_tolower"];
var _strlen = Module["_strlen"] = asm["_strlen"];
var _memset = Module["_memset"] = asm["_memset"];
var _malloc = Module["_malloc"] = asm["_malloc"];
var _memcpy = Module["_memcpy"] = asm["_memcpy"];
var _strcasecmp = Module["_strcasecmp"] = asm["_strcasecmp"];
var _strcpy = Module["_strcpy"] = asm["_strcpy"];
var runPostSets = Module["runPostSets"] = asm["runPostSets"];
var dynCall_ii = Module["dynCall_ii"] = asm["dynCall_ii"];
var dynCall_viiiii = Module["dynCall_viiiii"] = asm["dynCall_viiiii"];
var dynCall_vi = Module["dynCall_vi"] = asm["dynCall_vi"];
var dynCall_vii = Module["dynCall_vii"] = asm["dynCall_vii"];
var dynCall_iiii = Module["dynCall_iiii"] = asm["dynCall_iiii"];
var dynCall_viii = Module["dynCall_viii"] = asm["dynCall_viii"];
var dynCall_v = Module["dynCall_v"] = asm["dynCall_v"];
var dynCall_iiiii = Module["dynCall_iiiii"] = asm["dynCall_iiiii"];
var dynCall_iii = Module["dynCall_iii"] = asm["dynCall_iii"];
var dynCall_iiiiii = Module["dynCall_iiiiii"] = asm["dynCall_iiiiii"];
var dynCall_viiii = Module["dynCall_viiii"] = asm["dynCall_viiii"];
Runtime.stackAlloc = function(size) { return asm['stackAlloc'](size) };
Runtime.stackSave = function() { return asm['stackSave']() };
Runtime.stackRestore = function(top) { asm['stackRestore'](top) };
// TODO: strip out parts of this we do not need
//======= begin closure i64 code =======
// Copyright 2009 The Closure Library Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS-IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
/**
 * @fileoverview Defines a Long class for representing a 64-bit two's-complement
 * integer value, which faithfully simulates the behavior of a Java "long". This
 * implementation is derived from LongLib in GWT.
 *
 */
var i64Math = (function() { // Emscripten wrapper
  var goog = { math: {} };
  /**
   * Constructs a 64-bit two's-complement integer, given its low and high 32-bit
   * values as *signed* integers.  See the from* functions below for more
   * convenient ways of constructing Longs.
   *
   * The internal representation of a long is the two given signed, 32-bit values.
   * We use 32-bit pieces because these are the size of integers on which
   * Javascript performs bit-operations.  For operations like addition and
   * multiplication, we split each number into 16-bit pieces, which can easily be
   * multiplied within Javascript's floating-point representation without overflow
   * or change in sign.
   *
   * In the algorithms below, we frequently reduce the negative case to the
   * positive case by negating the input(s) and then post-processing the result.
   * Note that we must ALWAYS check specially whether those values are MIN_VALUE
   * (-2^63) because -MIN_VALUE == MIN_VALUE (since 2^63 cannot be represented as
   * a positive number, it overflows back into a negative).  Not handling this
   * case would often result in infinite recursion.
   *
   * @param {number} low  The low (signed) 32 bits of the long.
   * @param {number} high  The high (signed) 32 bits of the long.
   * @constructor
   */
  goog.math.Long = function(low, high) {
    /**
     * @type {number}
     * @private
     */
    this.low_ = low | 0;  // force into 32 signed bits.
    /**
     * @type {number}
     * @private
     */
    this.high_ = high | 0;  // force into 32 signed bits.
  };
  // NOTE: Common constant values ZERO, ONE, NEG_ONE, etc. are defined below the
  // from* methods on which they depend.
  /**
   * A cache of the Long representations of small integer values.
   * @type {!Object}
   * @private
   */
  goog.math.Long.IntCache_ = {};
  /**
   * Returns a Long representing the given (32-bit) integer value.
   * @param {number} value The 32-bit integer in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromInt = function(value) {
    if (-128 <= value && value < 128) {
      var cachedObj = goog.math.Long.IntCache_[value];
      if (cachedObj) {
        return cachedObj;
      }
    }
    var obj = new goog.math.Long(value | 0, value < 0 ? -1 : 0);
    if (-128 <= value && value < 128) {
      goog.math.Long.IntCache_[value] = obj;
    }
    return obj;
  };
  /**
   * Returns a Long representing the given value, provided that it is a finite
   * number.  Otherwise, zero is returned.
   * @param {number} value The number in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromNumber = function(value) {
    if (isNaN(value) || !isFinite(value)) {
      return goog.math.Long.ZERO;
    } else if (value <= -goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MIN_VALUE;
    } else if (value + 1 >= goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MAX_VALUE;
    } else if (value < 0) {
      return goog.math.Long.fromNumber(-value).negate();
    } else {
      return new goog.math.Long(
          (value % goog.math.Long.TWO_PWR_32_DBL_) | 0,
          (value / goog.math.Long.TWO_PWR_32_DBL_) | 0);
    }
  };
  /**
   * Returns a Long representing the 64-bit integer that comes by concatenating
   * the given high and low bits.  Each is assumed to use 32 bits.
   * @param {number} lowBits The low 32-bits.
   * @param {number} highBits The high 32-bits.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromBits = function(lowBits, highBits) {
    return new goog.math.Long(lowBits, highBits);
  };
  /**
   * Returns a Long representation of the given string, written using the given
   * radix.
   * @param {string} str The textual representation of the Long.
   * @param {number=} opt_radix The radix in which the text is written.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromString = function(str, opt_radix) {
    if (str.length == 0) {
      throw Error('number format error: empty string');
    }
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }
    if (str.charAt(0) == '-') {
      return goog.math.Long.fromString(str.substring(1), radix).negate();
    } else if (str.indexOf('-') >= 0) {
      throw Error('number format error: interior "-" character: ' + str);
    }
    // Do several (8) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 8));
    var result = goog.math.Long.ZERO;
    for (var i = 0; i < str.length; i += 8) {
      var size = Math.min(8, str.length - i);
      var value = parseInt(str.substring(i, i + size), radix);
      if (size < 8) {
        var power = goog.math.Long.fromNumber(Math.pow(radix, size));
        result = result.multiply(power).add(goog.math.Long.fromNumber(value));
      } else {
        result = result.multiply(radixToPower);
        result = result.add(goog.math.Long.fromNumber(value));
      }
    }
    return result;
  };
  // NOTE: the compiler should inline these constant values below and then remove
  // these variables, so there should be no runtime penalty for these.
  /**
   * Number used repeated below in calculations.  This must appear before the
   * first call to any from* function below.
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_16_DBL_ = 1 << 16;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_24_DBL_ = 1 << 24;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_32_DBL_ =
      goog.math.Long.TWO_PWR_16_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_31_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ / 2;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_48_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_64_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_32_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_63_DBL_ =
      goog.math.Long.TWO_PWR_64_DBL_ / 2;
  /** @type {!goog.math.Long} */
  goog.math.Long.ZERO = goog.math.Long.fromInt(0);
  /** @type {!goog.math.Long} */
  goog.math.Long.ONE = goog.math.Long.fromInt(1);
  /** @type {!goog.math.Long} */
  goog.math.Long.NEG_ONE = goog.math.Long.fromInt(-1);
  /** @type {!goog.math.Long} */
  goog.math.Long.MAX_VALUE =
      goog.math.Long.fromBits(0xFFFFFFFF | 0, 0x7FFFFFFF | 0);
  /** @type {!goog.math.Long} */
  goog.math.Long.MIN_VALUE = goog.math.Long.fromBits(0, 0x80000000 | 0);
  /**
   * @type {!goog.math.Long}
   * @private
   */
  goog.math.Long.TWO_PWR_24_ = goog.math.Long.fromInt(1 << 24);
  /** @return {number} The value, assuming it is a 32-bit integer. */
  goog.math.Long.prototype.toInt = function() {
    return this.low_;
  };
  /** @return {number} The closest floating-point representation to this value. */
  goog.math.Long.prototype.toNumber = function() {
    return this.high_ * goog.math.Long.TWO_PWR_32_DBL_ +
           this.getLowBitsUnsigned();
  };
  /**
   * @param {number=} opt_radix The radix in which the text should be written.
   * @return {string} The textual representation of this value.
   */
  goog.math.Long.prototype.toString = function(opt_radix) {
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }
    if (this.isZero()) {
      return '0';
    }
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        // We need to change the Long value before it can be negated, so we remove
        // the bottom-most digit in this base and then recurse to do the rest.
        var radixLong = goog.math.Long.fromNumber(radix);
        var div = this.div(radixLong);
        var rem = div.multiply(radixLong).subtract(this);
        return div.toString(radix) + rem.toInt().toString(radix);
      } else {
        return '-' + this.negate().toString(radix);
      }
    }
    // Do several (6) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 6));
    var rem = this;
    var result = '';
    while (true) {
      var remDiv = rem.div(radixToPower);
      var intval = rem.subtract(remDiv.multiply(radixToPower)).toInt();
      var digits = intval.toString(radix);
      rem = remDiv;
      if (rem.isZero()) {
        return digits + result;
      } else {
        while (digits.length < 6) {
          digits = '0' + digits;
        }
        result = '' + digits + result;
      }
    }
  };
  /** @return {number} The high 32-bits as a signed value. */
  goog.math.Long.prototype.getHighBits = function() {
    return this.high_;
  };
  /** @return {number} The low 32-bits as a signed value. */
  goog.math.Long.prototype.getLowBits = function() {
    return this.low_;
  };
  /** @return {number} The low 32-bits as an unsigned value. */
  goog.math.Long.prototype.getLowBitsUnsigned = function() {
    return (this.low_ >= 0) ?
        this.low_ : goog.math.Long.TWO_PWR_32_DBL_ + this.low_;
  };
  /**
   * @return {number} Returns the number of bits needed to represent the absolute
   *     value of this Long.
   */
  goog.math.Long.prototype.getNumBitsAbs = function() {
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        return 64;
      } else {
        return this.negate().getNumBitsAbs();
      }
    } else {
      var val = this.high_ != 0 ? this.high_ : this.low_;
      for (var bit = 31; bit > 0; bit--) {
        if ((val & (1 << bit)) != 0) {
          break;
        }
      }
      return this.high_ != 0 ? bit + 33 : bit + 1;
    }
  };
  /** @return {boolean} Whether this value is zero. */
  goog.math.Long.prototype.isZero = function() {
    return this.high_ == 0 && this.low_ == 0;
  };
  /** @return {boolean} Whether this value is negative. */
  goog.math.Long.prototype.isNegative = function() {
    return this.high_ < 0;
  };
  /** @return {boolean} Whether this value is odd. */
  goog.math.Long.prototype.isOdd = function() {
    return (this.low_ & 1) == 1;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long equals the other.
   */
  goog.math.Long.prototype.equals = function(other) {
    return (this.high_ == other.high_) && (this.low_ == other.low_);
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long does not equal the other.
   */
  goog.math.Long.prototype.notEquals = function(other) {
    return (this.high_ != other.high_) || (this.low_ != other.low_);
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than the other.
   */
  goog.math.Long.prototype.lessThan = function(other) {
    return this.compare(other) < 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than or equal to the other.
   */
  goog.math.Long.prototype.lessThanOrEqual = function(other) {
    return this.compare(other) <= 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than the other.
   */
  goog.math.Long.prototype.greaterThan = function(other) {
    return this.compare(other) > 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than or equal to the other.
   */
  goog.math.Long.prototype.greaterThanOrEqual = function(other) {
    return this.compare(other) >= 0;
  };
  /**
   * Compares this Long with the given one.
   * @param {goog.math.Long} other Long to compare against.
   * @return {number} 0 if they are the same, 1 if the this is greater, and -1
   *     if the given one is greater.
   */
  goog.math.Long.prototype.compare = function(other) {
    if (this.equals(other)) {
      return 0;
    }
    var thisNeg = this.isNegative();
    var otherNeg = other.isNegative();
    if (thisNeg && !otherNeg) {
      return -1;
    }
    if (!thisNeg && otherNeg) {
      return 1;
    }
    // at this point, the signs are the same, so subtraction will not overflow
    if (this.subtract(other).isNegative()) {
      return -1;
    } else {
      return 1;
    }
  };
  /** @return {!goog.math.Long} The negation of this value. */
  goog.math.Long.prototype.negate = function() {
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.MIN_VALUE;
    } else {
      return this.not().add(goog.math.Long.ONE);
    }
  };
  /**
   * Returns the sum of this and the given Long.
   * @param {goog.math.Long} other Long to add to this one.
   * @return {!goog.math.Long} The sum of this and the given Long.
   */
  goog.math.Long.prototype.add = function(other) {
    // Divide each number into 4 chunks of 16 bits, and then sum the chunks.
    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;
    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;
    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 + b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 + b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 + b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 + b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };
  /**
   * Returns the difference of this and the given Long.
   * @param {goog.math.Long} other Long to subtract from this.
   * @return {!goog.math.Long} The difference of this and the given Long.
   */
  goog.math.Long.prototype.subtract = function(other) {
    return this.add(other.negate());
  };
  /**
   * Returns the product of this and the given long.
   * @param {goog.math.Long} other Long to multiply with this.
   * @return {!goog.math.Long} The product of this and the other.
   */
  goog.math.Long.prototype.multiply = function(other) {
    if (this.isZero()) {
      return goog.math.Long.ZERO;
    } else if (other.isZero()) {
      return goog.math.Long.ZERO;
    }
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return other.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return this.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    }
    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().multiply(other.negate());
      } else {
        return this.negate().multiply(other).negate();
      }
    } else if (other.isNegative()) {
      return this.multiply(other.negate()).negate();
    }
    // If both longs are small, use float multiplication
    if (this.lessThan(goog.math.Long.TWO_PWR_24_) &&
        other.lessThan(goog.math.Long.TWO_PWR_24_)) {
      return goog.math.Long.fromNumber(this.toNumber() * other.toNumber());
    }
    // Divide each long into 4 chunks of 16 bits, and then add up 4x4 products.
    // We can skip products that would overflow.
    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;
    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;
    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 * b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 * b00;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c16 += a00 * b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 * b00;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a16 * b16;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a00 * b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 * b00 + a32 * b16 + a16 * b32 + a00 * b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };
  /**
   * Returns this Long divided by the given one.
   * @param {goog.math.Long} other Long by which to divide.
   * @return {!goog.math.Long} This Long divided by the given one.
   */
  goog.math.Long.prototype.div = function(other) {
    if (other.isZero()) {
      throw Error('division by zero');
    } else if (this.isZero()) {
      return goog.math.Long.ZERO;
    }
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      if (other.equals(goog.math.Long.ONE) ||
          other.equals(goog.math.Long.NEG_ONE)) {
        return goog.math.Long.MIN_VALUE;  // recall that -MIN_VALUE == MIN_VALUE
      } else if (other.equals(goog.math.Long.MIN_VALUE)) {
        return goog.math.Long.ONE;
      } else {
        // At this point, we have |other| >= 2, so |this/other| < |MIN_VALUE|.
        var halfThis = this.shiftRight(1);
        var approx = halfThis.div(other).shiftLeft(1);
        if (approx.equals(goog.math.Long.ZERO)) {
          return other.isNegative() ? goog.math.Long.ONE : goog.math.Long.NEG_ONE;
        } else {
          var rem = this.subtract(other.multiply(approx));
          var result = approx.add(rem.div(other));
          return result;
        }
      }
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.ZERO;
    }
    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().div(other.negate());
      } else {
        return this.negate().div(other).negate();
      }
    } else if (other.isNegative()) {
      return this.div(other.negate()).negate();
    }
    // Repeat the following until the remainder is less than other:  find a
    // floating-point that approximates remainder / other *from below*, add this
    // into the result, and subtract it from the remainder.  It is critical that
    // the approximate value is less than or equal to the real value so that the
    // remainder never becomes negative.
    var res = goog.math.Long.ZERO;
    var rem = this;
    while (rem.greaterThanOrEqual(other)) {
      // Approximate the result of division. This may be a little greater or
      // smaller than the actual value.
      var approx = Math.max(1, Math.floor(rem.toNumber() / other.toNumber()));
      // We will tweak the approximate result by changing it in the 48-th digit or
      // the smallest non-fractional digit, whichever is larger.
      var log2 = Math.ceil(Math.log(approx) / Math.LN2);
      var delta = (log2 <= 48) ? 1 : Math.pow(2, log2 - 48);
      // Decrease the approximation until it is smaller than the remainder.  Note
      // that if it is too large, the product overflows and is negative.
      var approxRes = goog.math.Long.fromNumber(approx);
      var approxRem = approxRes.multiply(other);
      while (approxRem.isNegative() || approxRem.greaterThan(rem)) {
        approx -= delta;
        approxRes = goog.math.Long.fromNumber(approx);
        approxRem = approxRes.multiply(other);
      }
      // We know the answer can't be zero... and actually, zero would cause
      // infinite recursion since we would make no progress.
      if (approxRes.isZero()) {
        approxRes = goog.math.Long.ONE;
      }
      res = res.add(approxRes);
      rem = rem.subtract(approxRem);
    }
    return res;
  };
  /**
   * Returns this Long modulo the given one.
   * @param {goog.math.Long} other Long by which to mod.
   * @return {!goog.math.Long} This Long modulo the given one.
   */
  goog.math.Long.prototype.modulo = function(other) {
    return this.subtract(this.div(other).multiply(other));
  };
  /** @return {!goog.math.Long} The bitwise-NOT of this value. */
  goog.math.Long.prototype.not = function() {
    return goog.math.Long.fromBits(~this.low_, ~this.high_);
  };
  /**
   * Returns the bitwise-AND of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to AND.
   * @return {!goog.math.Long} The bitwise-AND of this and the other.
   */
  goog.math.Long.prototype.and = function(other) {
    return goog.math.Long.fromBits(this.low_ & other.low_,
                                   this.high_ & other.high_);
  };
  /**
   * Returns the bitwise-OR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to OR.
   * @return {!goog.math.Long} The bitwise-OR of this and the other.
   */
  goog.math.Long.prototype.or = function(other) {
    return goog.math.Long.fromBits(this.low_ | other.low_,
                                   this.high_ | other.high_);
  };
  /**
   * Returns the bitwise-XOR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to XOR.
   * @return {!goog.math.Long} The bitwise-XOR of this and the other.
   */
  goog.math.Long.prototype.xor = function(other) {
    return goog.math.Long.fromBits(this.low_ ^ other.low_,
                                   this.high_ ^ other.high_);
  };
  /**
   * Returns this Long with bits shifted to the left by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the left by the given amount.
   */
  goog.math.Long.prototype.shiftLeft = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var low = this.low_;
      if (numBits < 32) {
        var high = this.high_;
        return goog.math.Long.fromBits(
            low << numBits,
            (high << numBits) | (low >>> (32 - numBits)));
      } else {
        return goog.math.Long.fromBits(0, low << (numBits - 32));
      }
    }
  };
  /**
   * Returns this Long with bits shifted to the right by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount.
   */
  goog.math.Long.prototype.shiftRight = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >> numBits);
      } else {
        return goog.math.Long.fromBits(
            high >> (numBits - 32),
            high >= 0 ? 0 : -1);
      }
    }
  };
  /**
   * Returns this Long with bits shifted to the right by the given amount, with
   * the new top bits matching the current sign bit.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount, with
   *     zeros placed into the new leading bits.
   */
  goog.math.Long.prototype.shiftRightUnsigned = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >>> numBits);
      } else if (numBits == 32) {
        return goog.math.Long.fromBits(high, 0);
      } else {
        return goog.math.Long.fromBits(high >>> (numBits - 32), 0);
      }
    }
  };
  //======= begin jsbn =======
  var navigator = { appName: 'Modern Browser' }; // polyfill a little
  // Copyright (c) 2005  Tom Wu
  // All Rights Reserved.
  // http://www-cs-students.stanford.edu/~tjw/jsbn/
  /*
   * Copyright (c) 2003-2005  Tom Wu
   * All Rights Reserved.
   *
   * Permission is hereby granted, free of charge, to any person obtaining
   * a copy of this software and associated documentation files (the
   * "Software"), to deal in the Software without restriction, including
   * without limitation the rights to use, copy, modify, merge, publish,
   * distribute, sublicense, and/or sell copies of the Software, and to
   * permit persons to whom the Software is furnished to do so, subject to
   * the following conditions:
   *
   * The above copyright notice and this permission notice shall be
   * included in all copies or substantial portions of the Software.
   *
   * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
   * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
   * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
   *
   * IN NO EVENT SHALL TOM WU BE LIABLE FOR ANY SPECIAL, INCIDENTAL,
   * INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY DAMAGES WHATSOEVER
   * RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER OR NOT ADVISED OF
   * THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF LIABILITY, ARISING OUT
   * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   *
   * In addition, the following condition applies:
   *
   * All redistributions must retain an intact copy of this copyright notice
   * and disclaimer.
   */
  // Basic JavaScript BN library - subset useful for RSA encryption.
  // Bits per digit
  var dbits;
  // JavaScript engine analysis
  var canary = 0xdeadbeefcafe;
  var j_lm = ((canary&0xffffff)==0xefcafe);
  // (public) Constructor
  function BigInteger(a,b,c) {
    if(a != null)
      if("number" == typeof a) this.fromNumber(a,b,c);
      else if(b == null && "string" != typeof a) this.fromString(a,256);
      else this.fromString(a,b);
  }
  // return new, unset BigInteger
  function nbi() { return new BigInteger(null); }
  // am: Compute w_j += (x*this_i), propagate carries,
  // c is initial carry, returns final carry.
  // c < 3*dvalue, x < 2*dvalue, this_i < dvalue
  // We need to select the fastest one that works in this environment.
  // am1: use a single mult and divide to get the high bits,
  // max digit bits should be 26 because
  // max internal value = 2*dvalue^2-2*dvalue (< 2^53)
  function am1(i,x,w,j,c,n) {
    while(--n >= 0) {
      var v = x*this[i++]+w[j]+c;
      c = Math.floor(v/0x4000000);
      w[j++] = v&0x3ffffff;
    }
    return c;
  }
  // am2 avoids a big mult-and-extract completely.
  // Max digit bits should be <= 30 because we do bitwise ops
  // on values up to 2*hdvalue^2-hdvalue-1 (< 2^31)
  function am2(i,x,w,j,c,n) {
    var xl = x&0x7fff, xh = x>>15;
    while(--n >= 0) {
      var l = this[i]&0x7fff;
      var h = this[i++]>>15;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x7fff)<<15)+w[j]+(c&0x3fffffff);
      c = (l>>>30)+(m>>>15)+xh*h+(c>>>30);
      w[j++] = l&0x3fffffff;
    }
    return c;
  }
  // Alternately, set max digit bits to 28 since some
  // browsers slow down when dealing with 32-bit numbers.
  function am3(i,x,w,j,c,n) {
    var xl = x&0x3fff, xh = x>>14;
    while(--n >= 0) {
      var l = this[i]&0x3fff;
      var h = this[i++]>>14;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x3fff)<<14)+w[j]+c;
      c = (l>>28)+(m>>14)+xh*h;
      w[j++] = l&0xfffffff;
    }
    return c;
  }
  if(j_lm && (navigator.appName == "Microsoft Internet Explorer")) {
    BigInteger.prototype.am = am2;
    dbits = 30;
  }
  else if(j_lm && (navigator.appName != "Netscape")) {
    BigInteger.prototype.am = am1;
    dbits = 26;
  }
  else { // Mozilla/Netscape seems to prefer am3
    BigInteger.prototype.am = am3;
    dbits = 28;
  }
  BigInteger.prototype.DB = dbits;
  BigInteger.prototype.DM = ((1<<dbits)-1);
  BigInteger.prototype.DV = (1<<dbits);
  var BI_FP = 52;
  BigInteger.prototype.FV = Math.pow(2,BI_FP);
  BigInteger.prototype.F1 = BI_FP-dbits;
  BigInteger.prototype.F2 = 2*dbits-BI_FP;
  // Digit conversions
  var BI_RM = "0123456789abcdefghijklmnopqrstuvwxyz";
  var BI_RC = new Array();
  var rr,vv;
  rr = "0".charCodeAt(0);
  for(vv = 0; vv <= 9; ++vv) BI_RC[rr++] = vv;
  rr = "a".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  rr = "A".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  function int2char(n) { return BI_RM.charAt(n); }
  function intAt(s,i) {
    var c = BI_RC[s.charCodeAt(i)];
    return (c==null)?-1:c;
  }
  // (protected) copy this to r
  function bnpCopyTo(r) {
    for(var i = this.t-1; i >= 0; --i) r[i] = this[i];
    r.t = this.t;
    r.s = this.s;
  }
  // (protected) set from integer value x, -DV <= x < DV
  function bnpFromInt(x) {
    this.t = 1;
    this.s = (x<0)?-1:0;
    if(x > 0) this[0] = x;
    else if(x < -1) this[0] = x+DV;
    else this.t = 0;
  }
  // return bigint initialized to value
  function nbv(i) { var r = nbi(); r.fromInt(i); return r; }
  // (protected) set from string and radix
  function bnpFromString(s,b) {
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 256) k = 8; // byte array
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else { this.fromRadix(s,b); return; }
    this.t = 0;
    this.s = 0;
    var i = s.length, mi = false, sh = 0;
    while(--i >= 0) {
      var x = (k==8)?s[i]&0xff:intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-") mi = true;
        continue;
      }
      mi = false;
      if(sh == 0)
        this[this.t++] = x;
      else if(sh+k > this.DB) {
        this[this.t-1] |= (x&((1<<(this.DB-sh))-1))<<sh;
        this[this.t++] = (x>>(this.DB-sh));
      }
      else
        this[this.t-1] |= x<<sh;
      sh += k;
      if(sh >= this.DB) sh -= this.DB;
    }
    if(k == 8 && (s[0]&0x80) != 0) {
      this.s = -1;
      if(sh > 0) this[this.t-1] |= ((1<<(this.DB-sh))-1)<<sh;
    }
    this.clamp();
    if(mi) BigInteger.ZERO.subTo(this,this);
  }
  // (protected) clamp off excess high words
  function bnpClamp() {
    var c = this.s&this.DM;
    while(this.t > 0 && this[this.t-1] == c) --this.t;
  }
  // (public) return string representation in given radix
  function bnToString(b) {
    if(this.s < 0) return "-"+this.negate().toString(b);
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else return this.toRadix(b);
    var km = (1<<k)-1, d, m = false, r = "", i = this.t;
    var p = this.DB-(i*this.DB)%k;
    if(i-- > 0) {
      if(p < this.DB && (d = this[i]>>p) > 0) { m = true; r = int2char(d); }
      while(i >= 0) {
        if(p < k) {
          d = (this[i]&((1<<p)-1))<<(k-p);
          d |= this[--i]>>(p+=this.DB-k);
        }
        else {
          d = (this[i]>>(p-=k))&km;
          if(p <= 0) { p += this.DB; --i; }
        }
        if(d > 0) m = true;
        if(m) r += int2char(d);
      }
    }
    return m?r:"0";
  }
  // (public) -this
  function bnNegate() { var r = nbi(); BigInteger.ZERO.subTo(this,r); return r; }
  // (public) |this|
  function bnAbs() { return (this.s<0)?this.negate():this; }
  // (public) return + if this > a, - if this < a, 0 if equal
  function bnCompareTo(a) {
    var r = this.s-a.s;
    if(r != 0) return r;
    var i = this.t;
    r = i-a.t;
    if(r != 0) return (this.s<0)?-r:r;
    while(--i >= 0) if((r=this[i]-a[i]) != 0) return r;
    return 0;
  }
  // returns bit length of the integer x
  function nbits(x) {
    var r = 1, t;
    if((t=x>>>16) != 0) { x = t; r += 16; }
    if((t=x>>8) != 0) { x = t; r += 8; }
    if((t=x>>4) != 0) { x = t; r += 4; }
    if((t=x>>2) != 0) { x = t; r += 2; }
    if((t=x>>1) != 0) { x = t; r += 1; }
    return r;
  }
  // (public) return the number of bits in "this"
  function bnBitLength() {
    if(this.t <= 0) return 0;
    return this.DB*(this.t-1)+nbits(this[this.t-1]^(this.s&this.DM));
  }
  // (protected) r = this << n*DB
  function bnpDLShiftTo(n,r) {
    var i;
    for(i = this.t-1; i >= 0; --i) r[i+n] = this[i];
    for(i = n-1; i >= 0; --i) r[i] = 0;
    r.t = this.t+n;
    r.s = this.s;
  }
  // (protected) r = this >> n*DB
  function bnpDRShiftTo(n,r) {
    for(var i = n; i < this.t; ++i) r[i-n] = this[i];
    r.t = Math.max(this.t-n,0);
    r.s = this.s;
  }
  // (protected) r = this << n
  function bnpLShiftTo(n,r) {
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<cbs)-1;
    var ds = Math.floor(n/this.DB), c = (this.s<<bs)&this.DM, i;
    for(i = this.t-1; i >= 0; --i) {
      r[i+ds+1] = (this[i]>>cbs)|c;
      c = (this[i]&bm)<<bs;
    }
    for(i = ds-1; i >= 0; --i) r[i] = 0;
    r[ds] = c;
    r.t = this.t+ds+1;
    r.s = this.s;
    r.clamp();
  }
  // (protected) r = this >> n
  function bnpRShiftTo(n,r) {
    r.s = this.s;
    var ds = Math.floor(n/this.DB);
    if(ds >= this.t) { r.t = 0; return; }
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<bs)-1;
    r[0] = this[ds]>>bs;
    for(var i = ds+1; i < this.t; ++i) {
      r[i-ds-1] |= (this[i]&bm)<<cbs;
      r[i-ds] = this[i]>>bs;
    }
    if(bs > 0) r[this.t-ds-1] |= (this.s&bm)<<cbs;
    r.t = this.t-ds;
    r.clamp();
  }
  // (protected) r = this - a
  function bnpSubTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]-a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c -= a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c -= a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c -= a.s;
    }
    r.s = (c<0)?-1:0;
    if(c < -1) r[i++] = this.DV+c;
    else if(c > 0) r[i++] = c;
    r.t = i;
    r.clamp();
  }
  // (protected) r = this * a, r != this,a (HAC 14.12)
  // "this" should be the larger one if appropriate.
  function bnpMultiplyTo(a,r) {
    var x = this.abs(), y = a.abs();
    var i = x.t;
    r.t = i+y.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < y.t; ++i) r[i+x.t] = x.am(0,y[i],r,i,0,x.t);
    r.s = 0;
    r.clamp();
    if(this.s != a.s) BigInteger.ZERO.subTo(r,r);
  }
  // (protected) r = this^2, r != this (HAC 14.16)
  function bnpSquareTo(r) {
    var x = this.abs();
    var i = r.t = 2*x.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < x.t-1; ++i) {
      var c = x.am(i,x[i],r,2*i,0,1);
      if((r[i+x.t]+=x.am(i+1,2*x[i],r,2*i+1,c,x.t-i-1)) >= x.DV) {
        r[i+x.t] -= x.DV;
        r[i+x.t+1] = 1;
      }
    }
    if(r.t > 0) r[r.t-1] += x.am(i,x[i],r,2*i,0,1);
    r.s = 0;
    r.clamp();
  }
  // (protected) divide this by m, quotient and remainder to q, r (HAC 14.20)
  // r != q, this != m.  q or r may be null.
  function bnpDivRemTo(m,q,r) {
    var pm = m.abs();
    if(pm.t <= 0) return;
    var pt = this.abs();
    if(pt.t < pm.t) {
      if(q != null) q.fromInt(0);
      if(r != null) this.copyTo(r);
      return;
    }
    if(r == null) r = nbi();
    var y = nbi(), ts = this.s, ms = m.s;
    var nsh = this.DB-nbits(pm[pm.t-1]);	// normalize modulus
    if(nsh > 0) { pm.lShiftTo(nsh,y); pt.lShiftTo(nsh,r); }
    else { pm.copyTo(y); pt.copyTo(r); }
    var ys = y.t;
    var y0 = y[ys-1];
    if(y0 == 0) return;
    var yt = y0*(1<<this.F1)+((ys>1)?y[ys-2]>>this.F2:0);
    var d1 = this.FV/yt, d2 = (1<<this.F1)/yt, e = 1<<this.F2;
    var i = r.t, j = i-ys, t = (q==null)?nbi():q;
    y.dlShiftTo(j,t);
    if(r.compareTo(t) >= 0) {
      r[r.t++] = 1;
      r.subTo(t,r);
    }
    BigInteger.ONE.dlShiftTo(ys,t);
    t.subTo(y,y);	// "negative" y so we can replace sub with am later
    while(y.t < ys) y[y.t++] = 0;
    while(--j >= 0) {
      // Estimate quotient digit
      var qd = (r[--i]==y0)?this.DM:Math.floor(r[i]*d1+(r[i-1]+e)*d2);
      if((r[i]+=y.am(0,qd,r,j,0,ys)) < qd) {	// Try it out
        y.dlShiftTo(j,t);
        r.subTo(t,r);
        while(r[i] < --qd) r.subTo(t,r);
      }
    }
    if(q != null) {
      r.drShiftTo(ys,q);
      if(ts != ms) BigInteger.ZERO.subTo(q,q);
    }
    r.t = ys;
    r.clamp();
    if(nsh > 0) r.rShiftTo(nsh,r);	// Denormalize remainder
    if(ts < 0) BigInteger.ZERO.subTo(r,r);
  }
  // (public) this mod a
  function bnMod(a) {
    var r = nbi();
    this.abs().divRemTo(a,null,r);
    if(this.s < 0 && r.compareTo(BigInteger.ZERO) > 0) a.subTo(r,r);
    return r;
  }
  // Modular reduction using "classic" algorithm
  function Classic(m) { this.m = m; }
  function cConvert(x) {
    if(x.s < 0 || x.compareTo(this.m) >= 0) return x.mod(this.m);
    else return x;
  }
  function cRevert(x) { return x; }
  function cReduce(x) { x.divRemTo(this.m,null,x); }
  function cMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  function cSqrTo(x,r) { x.squareTo(r); this.reduce(r); }
  Classic.prototype.convert = cConvert;
  Classic.prototype.revert = cRevert;
  Classic.prototype.reduce = cReduce;
  Classic.prototype.mulTo = cMulTo;
  Classic.prototype.sqrTo = cSqrTo;
  // (protected) return "-1/this % 2^DB"; useful for Mont. reduction
  // justification:
  //         xy == 1 (mod m)
  //         xy =  1+km
  //   xy(2-xy) = (1+km)(1-km)
  // x[y(2-xy)] = 1-k^2m^2
  // x[y(2-xy)] == 1 (mod m^2)
  // if y is 1/x mod m, then y(2-xy) is 1/x mod m^2
  // should reduce x and y(2-xy) by m^2 at each step to keep size bounded.
  // JS multiply "overflows" differently from C/C++, so care is needed here.
  function bnpInvDigit() {
    if(this.t < 1) return 0;
    var x = this[0];
    if((x&1) == 0) return 0;
    var y = x&3;		// y == 1/x mod 2^2
    y = (y*(2-(x&0xf)*y))&0xf;	// y == 1/x mod 2^4
    y = (y*(2-(x&0xff)*y))&0xff;	// y == 1/x mod 2^8
    y = (y*(2-(((x&0xffff)*y)&0xffff)))&0xffff;	// y == 1/x mod 2^16
    // last step - calculate inverse mod DV directly;
    // assumes 16 < DB <= 32 and assumes ability to handle 48-bit ints
    y = (y*(2-x*y%this.DV))%this.DV;		// y == 1/x mod 2^dbits
    // we really want the negative inverse, and -DV < y < DV
    return (y>0)?this.DV-y:-y;
  }
  // Montgomery reduction
  function Montgomery(m) {
    this.m = m;
    this.mp = m.invDigit();
    this.mpl = this.mp&0x7fff;
    this.mph = this.mp>>15;
    this.um = (1<<(m.DB-15))-1;
    this.mt2 = 2*m.t;
  }
  // xR mod m
  function montConvert(x) {
    var r = nbi();
    x.abs().dlShiftTo(this.m.t,r);
    r.divRemTo(this.m,null,r);
    if(x.s < 0 && r.compareTo(BigInteger.ZERO) > 0) this.m.subTo(r,r);
    return r;
  }
  // x/R mod m
  function montRevert(x) {
    var r = nbi();
    x.copyTo(r);
    this.reduce(r);
    return r;
  }
  // x = x/R mod m (HAC 14.32)
  function montReduce(x) {
    while(x.t <= this.mt2)	// pad x so am has enough room later
      x[x.t++] = 0;
    for(var i = 0; i < this.m.t; ++i) {
      // faster way of calculating u0 = x[i]*mp mod DV
      var j = x[i]&0x7fff;
      var u0 = (j*this.mpl+(((j*this.mph+(x[i]>>15)*this.mpl)&this.um)<<15))&x.DM;
      // use am to combine the multiply-shift-add into one call
      j = i+this.m.t;
      x[j] += this.m.am(0,u0,x,i,0,this.m.t);
      // propagate carry
      while(x[j] >= x.DV) { x[j] -= x.DV; x[++j]++; }
    }
    x.clamp();
    x.drShiftTo(this.m.t,x);
    if(x.compareTo(this.m) >= 0) x.subTo(this.m,x);
  }
  // r = "x^2/R mod m"; x != r
  function montSqrTo(x,r) { x.squareTo(r); this.reduce(r); }
  // r = "xy/R mod m"; x,y != r
  function montMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  Montgomery.prototype.convert = montConvert;
  Montgomery.prototype.revert = montRevert;
  Montgomery.prototype.reduce = montReduce;
  Montgomery.prototype.mulTo = montMulTo;
  Montgomery.prototype.sqrTo = montSqrTo;
  // (protected) true iff this is even
  function bnpIsEven() { return ((this.t>0)?(this[0]&1):this.s) == 0; }
  // (protected) this^e, e < 2^32, doing sqr and mul with "r" (HAC 14.79)
  function bnpExp(e,z) {
    if(e > 0xffffffff || e < 1) return BigInteger.ONE;
    var r = nbi(), r2 = nbi(), g = z.convert(this), i = nbits(e)-1;
    g.copyTo(r);
    while(--i >= 0) {
      z.sqrTo(r,r2);
      if((e&(1<<i)) > 0) z.mulTo(r2,g,r);
      else { var t = r; r = r2; r2 = t; }
    }
    return z.revert(r);
  }
  // (public) this^e % m, 0 <= e < 2^32
  function bnModPowInt(e,m) {
    var z;
    if(e < 256 || m.isEven()) z = new Classic(m); else z = new Montgomery(m);
    return this.exp(e,z);
  }
  // protected
  BigInteger.prototype.copyTo = bnpCopyTo;
  BigInteger.prototype.fromInt = bnpFromInt;
  BigInteger.prototype.fromString = bnpFromString;
  BigInteger.prototype.clamp = bnpClamp;
  BigInteger.prototype.dlShiftTo = bnpDLShiftTo;
  BigInteger.prototype.drShiftTo = bnpDRShiftTo;
  BigInteger.prototype.lShiftTo = bnpLShiftTo;
  BigInteger.prototype.rShiftTo = bnpRShiftTo;
  BigInteger.prototype.subTo = bnpSubTo;
  BigInteger.prototype.multiplyTo = bnpMultiplyTo;
  BigInteger.prototype.squareTo = bnpSquareTo;
  BigInteger.prototype.divRemTo = bnpDivRemTo;
  BigInteger.prototype.invDigit = bnpInvDigit;
  BigInteger.prototype.isEven = bnpIsEven;
  BigInteger.prototype.exp = bnpExp;
  // public
  BigInteger.prototype.toString = bnToString;
  BigInteger.prototype.negate = bnNegate;
  BigInteger.prototype.abs = bnAbs;
  BigInteger.prototype.compareTo = bnCompareTo;
  BigInteger.prototype.bitLength = bnBitLength;
  BigInteger.prototype.mod = bnMod;
  BigInteger.prototype.modPowInt = bnModPowInt;
  // "constants"
  BigInteger.ZERO = nbv(0);
  BigInteger.ONE = nbv(1);
  // jsbn2 stuff
  // (protected) convert from radix string
  function bnpFromRadix(s,b) {
    this.fromInt(0);
    if(b == null) b = 10;
    var cs = this.chunkSize(b);
    var d = Math.pow(b,cs), mi = false, j = 0, w = 0;
    for(var i = 0; i < s.length; ++i) {
      var x = intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-" && this.signum() == 0) mi = true;
        continue;
      }
      w = b*w+x;
      if(++j >= cs) {
        this.dMultiply(d);
        this.dAddOffset(w,0);
        j = 0;
        w = 0;
      }
    }
    if(j > 0) {
      this.dMultiply(Math.pow(b,j));
      this.dAddOffset(w,0);
    }
    if(mi) BigInteger.ZERO.subTo(this,this);
  }
  // (protected) return x s.t. r^x < DV
  function bnpChunkSize(r) { return Math.floor(Math.LN2*this.DB/Math.log(r)); }
  // (public) 0 if this == 0, 1 if this > 0
  function bnSigNum() {
    if(this.s < 0) return -1;
    else if(this.t <= 0 || (this.t == 1 && this[0] <= 0)) return 0;
    else return 1;
  }
  // (protected) this *= n, this >= 0, 1 < n < DV
  function bnpDMultiply(n) {
    this[this.t] = this.am(0,n-1,this,0,0,this.t);
    ++this.t;
    this.clamp();
  }
  // (protected) this += n << w words, this >= 0
  function bnpDAddOffset(n,w) {
    if(n == 0) return;
    while(this.t <= w) this[this.t++] = 0;
    this[w] += n;
    while(this[w] >= this.DV) {
      this[w] -= this.DV;
      if(++w >= this.t) this[this.t++] = 0;
      ++this[w];
    }
  }
  // (protected) convert to radix string
  function bnpToRadix(b) {
    if(b == null) b = 10;
    if(this.signum() == 0 || b < 2 || b > 36) return "0";
    var cs = this.chunkSize(b);
    var a = Math.pow(b,cs);
    var d = nbv(a), y = nbi(), z = nbi(), r = "";
    this.divRemTo(d,y,z);
    while(y.signum() > 0) {
      r = (a+z.intValue()).toString(b).substr(1) + r;
      y.divRemTo(d,y,z);
    }
    return z.intValue().toString(b) + r;
  }
  // (public) return value as integer
  function bnIntValue() {
    if(this.s < 0) {
      if(this.t == 1) return this[0]-this.DV;
      else if(this.t == 0) return -1;
    }
    else if(this.t == 1) return this[0];
    else if(this.t == 0) return 0;
    // assumes 16 < DB < 32
    return ((this[1]&((1<<(32-this.DB))-1))<<this.DB)|this[0];
  }
  // (protected) r = this + a
  function bnpAddTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]+a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c += a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c += a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += a.s;
    }
    r.s = (c<0)?-1:0;
    if(c > 0) r[i++] = c;
    else if(c < -1) r[i++] = this.DV+c;
    r.t = i;
    r.clamp();
  }
  BigInteger.prototype.fromRadix = bnpFromRadix;
  BigInteger.prototype.chunkSize = bnpChunkSize;
  BigInteger.prototype.signum = bnSigNum;
  BigInteger.prototype.dMultiply = bnpDMultiply;
  BigInteger.prototype.dAddOffset = bnpDAddOffset;
  BigInteger.prototype.toRadix = bnpToRadix;
  BigInteger.prototype.intValue = bnIntValue;
  BigInteger.prototype.addTo = bnpAddTo;
  //======= end jsbn =======
  // Emscripten wrapper
  var Wrapper = {
    abs: function(l, h) {
      var x = new goog.math.Long(l, h);
      var ret;
      if (x.isNegative()) {
        ret = x.negate();
      } else {
        ret = x;
      }
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
    },
    ensureTemps: function() {
      if (Wrapper.ensuredTemps) return;
      Wrapper.ensuredTemps = true;
      Wrapper.two32 = new BigInteger();
      Wrapper.two32.fromString('4294967296', 10);
      Wrapper.two64 = new BigInteger();
      Wrapper.two64.fromString('18446744073709551616', 10);
      Wrapper.temp1 = new BigInteger();
      Wrapper.temp2 = new BigInteger();
    },
    lh2bignum: function(l, h) {
      var a = new BigInteger();
      a.fromString(h.toString(), 10);
      var b = new BigInteger();
      a.multiplyTo(Wrapper.two32, b);
      var c = new BigInteger();
      c.fromString(l.toString(), 10);
      var d = new BigInteger();
      c.addTo(b, d);
      return d;
    },
    stringify: function(l, h, unsigned) {
      var ret = new goog.math.Long(l, h).toString();
      if (unsigned && ret[0] == '-') {
        // unsign slowly using jsbn bignums
        Wrapper.ensureTemps();
        var bignum = new BigInteger();
        bignum.fromString(ret, 10);
        ret = new BigInteger();
        Wrapper.two64.addTo(bignum, ret);
        ret = ret.toString(10);
      }
      return ret;
    },
    fromString: function(str, base, min, max, unsigned) {
      Wrapper.ensureTemps();
      var bignum = new BigInteger();
      bignum.fromString(str, base);
      var bigmin = new BigInteger();
      bigmin.fromString(min, 10);
      var bigmax = new BigInteger();
      bigmax.fromString(max, 10);
      if (unsigned && bignum.compareTo(BigInteger.ZERO) < 0) {
        var temp = new BigInteger();
        bignum.addTo(Wrapper.two64, temp);
        bignum = temp;
      }
      var error = false;
      if (bignum.compareTo(bigmin) < 0) {
        bignum = bigmin;
        error = true;
      } else if (bignum.compareTo(bigmax) > 0) {
        bignum = bigmax;
        error = true;
      }
      var ret = goog.math.Long.fromString(bignum.toString()); // min-max checks should have clamped this to a range goog.math.Long can handle well
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
      if (error) throw 'range error';
    }
  };
  return Wrapper;
})();
//======= end closure i64 code =======
// === Auto-generated postamble setup entry stuff ===
Module['callMain'] = function callMain(args) {
  assert(runDependencies == 0, 'cannot call main when async dependencies remain! (listen on __ATMAIN__)');
  assert(!Module['preRun'] || Module['preRun'].length == 0, 'cannot call main when preRun functions remain to be called');
  args = args || [];
  ensureInitRuntime();
  var argc = args.length+1;
  function pad() {
    for (var i = 0; i < 4-1; i++) {
      argv.push(0);
    }
  }
  var argv = [allocate(intArrayFromString("/bin/this.program"), 'i8', ALLOC_NORMAL) ];
  pad();
  for (var i = 0; i < argc-1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), 'i8', ALLOC_NORMAL));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, 'i32', ALLOC_NORMAL);
  var ret;
  var initialStackTop = STACKTOP;
  try {
    ret = Module['_main'](argc, argv, 0);
  }
  catch(e) {
    if (e.name == 'ExitStatus') {
      return e.status;
    } else if (e == 'SimulateInfiniteLoop') {
      Module['noExitRuntime'] = true;
    } else {
      throw e;
    }
  } finally {
    STACKTOP = initialStackTop;
  }
  return ret;
}
function run(args) {
  args = args || Module['arguments'];
  if (runDependencies > 0) {
    Module.printErr('run() called, but dependencies remain, so not running');
    return 0;
  }
  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    var toRun = Module['preRun'];
    Module['preRun'] = [];
    for (var i = toRun.length-1; i >= 0; i--) {
      toRun[i]();
    }
    if (runDependencies > 0) {
      // a preRun added a dependency, run will be called later
      return 0;
    }
  }
  function doRun() {
    ensureInitRuntime();
    preMain();
    var ret = 0;
    calledRun = true;
    if (Module['_main'] && shouldRunNow) {
      ret = Module['callMain'](args);
      if (!Module['noExitRuntime']) {
        exitRuntime();
      }
    }
    if (Module['postRun']) {
      if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
      while (Module['postRun'].length > 0) {
        Module['postRun'].pop()();
      }
    }
    return ret;
  }
  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      if (!ABORT) doRun();
    }, 1);
    return 0;
  } else {
    return doRun();
  }
}
Module['run'] = Module.run = run;
// {{PRE_RUN_ADDITIONS}}
(function() {
function assert(check, msg) {
  if (!check) throw msg + new Error().stack;
}
Module['FS_createPath']('/', 'roms', true, true);
    function DataRequest() {}
    DataRequest.prototype = {
      requests: {},
      open: function(mode, name) {
        this.requests[name] = this;
      },
      send: function() {}
    };
    var filePreload0 = new DataRequest();
    filePreload0.open('GET', 'roms/games10.dsk', true);
    filePreload0.responseType = 'arraybuffer';
    filePreload0.onload = function() {
      var arrayBuffer = filePreload0.response;
      assert(arrayBuffer, 'Loading file roms/games10.dsk failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms', 'games10.dsk', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/games10.dsk');
      });
    };
    Module['addRunDependency']('fp roms/games10.dsk');
    filePreload0.send(null);
    var filePreload1 = new DataRequest();
    filePreload1.open('GET', 'roms/hd1.img', true);
    filePreload1.responseType = 'arraybuffer';
    filePreload1.onload = function() {
      var arrayBuffer = filePreload1.response;
      assert(arrayBuffer, 'Loading file roms/hd1.img failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms', 'hd1.img', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/hd1.img');
      });
    };
    Module['addRunDependency']('fp roms/hd1.img');
    filePreload1.send(null);
    var filePreload2 = new DataRequest();
    filePreload2.open('GET', 'roms/mac-plus.rom', true);
    filePreload2.responseType = 'arraybuffer';
    filePreload2.onload = function() {
      var arrayBuffer = filePreload2.response;
      assert(arrayBuffer, 'Loading file roms/mac-plus.rom failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms', 'mac-plus.rom', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/mac-plus.rom');
      });
    };
    Module['addRunDependency']('fp roms/mac-plus.rom');
    filePreload2.send(null);
    var filePreload3 = new DataRequest();
    filePreload3.open('GET', 'roms/macplus-pcex.rom', true);
    filePreload3.responseType = 'arraybuffer';
    filePreload3.onload = function() {
      var arrayBuffer = filePreload3.response;
      assert(arrayBuffer, 'Loading file roms/macplus-pcex.rom failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms', 'macplus-pcex.rom', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/macplus-pcex.rom');
      });
    };
    Module['addRunDependency']('fp roms/macplus-pcex.rom');
    filePreload3.send(null);
    var filePreload4 = new DataRequest();
    filePreload4.open('GET', 'roms/pce-config.cfg', true);
    filePreload4.responseType = 'arraybuffer';
    filePreload4.onload = function() {
      var arrayBuffer = filePreload4.response;
      assert(arrayBuffer, 'Loading file roms/pce-config.cfg failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms', 'pce-config.cfg', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/pce-config.cfg');
      });
    };
    Module['addRunDependency']('fp roms/pce-config.cfg');
    filePreload4.send(null);
    var filePreload5 = new DataRequest();
    filePreload5.open('GET', 'roms/pram-mac-plus.dat', true);
    filePreload5.responseType = 'arraybuffer';
    filePreload5.onload = function() {
      var arrayBuffer = filePreload5.response;
      assert(arrayBuffer, 'Loading file roms/pram-mac-plus.dat failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms', 'pram-mac-plus.dat', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/pram-mac-plus.dat');
      });
    };
    Module['addRunDependency']('fp roms/pram-mac-plus.dat');
    filePreload5.send(null);
    var filePreload6 = new DataRequest();
    filePreload6.open('GET', 'roms/ser_a.out', true);
    filePreload6.responseType = 'arraybuffer';
    filePreload6.onload = function() {
      var arrayBuffer = filePreload6.response;
      assert(arrayBuffer, 'Loading file roms/ser_a.out failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms', 'ser_a.out', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/ser_a.out');
      });
    };
    Module['addRunDependency']('fp roms/ser_a.out');
    filePreload6.send(null);
    var filePreload7 = new DataRequest();
    filePreload7.open('GET', 'roms/ser_b.out', true);
    filePreload7.responseType = 'arraybuffer';
    filePreload7.onload = function() {
      var arrayBuffer = filePreload7.response;
      assert(arrayBuffer, 'Loading file roms/ser_b.out failed.');
      var byteArray = !arrayBuffer.subarray ? new Uint8Array(arrayBuffer) : arrayBuffer;
      Module['FS_createPreloadedFile']('/roms', 'ser_b.out', byteArray, true, true, function() {
        Module['removeRunDependency']('fp roms/ser_b.out');
      });
    };
    Module['addRunDependency']('fp roms/ser_b.out');
    filePreload7.send(null);
    if (!Module.expectedDataFileDownloads) {
      Module.expectedDataFileDownloads = 0;
      Module.finishedDataFileDownloads = 0;
    }
    Module.expectedDataFileDownloads++;
    var PACKAGE_PATH = window['encodeURIComponent'](window.location.pathname.toString().substring(0, window.location.pathname.toString().lastIndexOf('/')) + '/');
    var PACKAGE_NAME = '/Users/jfriend/dev/jsmac/empce/pce20130508/build/bin/pce-macplus.data';
    var REMOTE_PACKAGE_NAME = 'pce-macplus.data';
    var PACKAGE_UUID = 'e387e09b-107b-4ff8-8767-98553fed3436';
    function fetchRemotePackage(packageName, callback, errback) {
      var xhr = new XMLHttpRequest();
      xhr.open('GET', packageName, true);
      xhr.responseType = 'arraybuffer';
      xhr.onprogress = function(event) {
        var url = packageName;
        if (event.loaded && event.total) {
          if (!xhr.addedTotal) {
            xhr.addedTotal = true;
            if (!Module.dataFileDownloads) Module.dataFileDownloads = {};
            Module.dataFileDownloads[url] = {
              loaded: event.loaded,
              total: event.total
            };
          } else {
            Module.dataFileDownloads[url].loaded = event.loaded;
          }
          var total = 0;
          var loaded = 0;
          var num = 0;
          for (var download in Module.dataFileDownloads) {
          var data = Module.dataFileDownloads[download];
            total += data.total;
            loaded += data.loaded;
            num++;
          }
          total = Math.ceil(total * Module.expectedDataFileDownloads/num);
          Module['setStatus']('Downloading data... (' + loaded + '/' + total + ')');
        } else if (!Module.dataFileDownloads) {
          Module['setStatus']('Downloading data...');
        }
      };
      xhr.onload = function(event) {
        var packageData = xhr.response;
        callback(packageData);
      };
      xhr.send(null);
    };
    function processPackageData(arrayBuffer) {
      Module.finishedDataFileDownloads++;
      assert(arrayBuffer, 'Loading data file failed.');
      var byteArray = new Uint8Array(arrayBuffer);
      var curr;
        curr = DataRequest.prototype.requests['roms/games10.dsk'];
        var data = byteArray.subarray(0, 1474560);
        var ptr = Module['_malloc'](1474560);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 1474560);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/hd1.img'];
        var data = byteArray.subarray(1474560, 22886400);
        var ptr = Module['_malloc'](21411840);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 21411840);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/mac-plus.rom'];
        var data = byteArray.subarray(22886400, 23017472);
        var ptr = Module['_malloc'](131072);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 131072);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/macplus-pcex.rom'];
        var data = byteArray.subarray(23017472, 23018298);
        var ptr = Module['_malloc'](826);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 826);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/pce-config.cfg'];
        var data = byteArray.subarray(23018298, 23026176);
        var ptr = Module['_malloc'](7878);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 7878);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/pram-mac-plus.dat'];
        var data = byteArray.subarray(23026176, 23026432);
        var ptr = Module['_malloc'](256);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 256);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/ser_a.out'];
        var data = byteArray.subarray(23026432, 23026432);
        var ptr = Module['_malloc'](0);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 0);
        curr.onload();
        curr = DataRequest.prototype.requests['roms/ser_b.out'];
        var data = byteArray.subarray(23026432, 23026432);
        var ptr = Module['_malloc'](0);
        Module['HEAPU8'].set(data, ptr);
        curr.response = Module['HEAPU8'].subarray(ptr, ptr + 0);
        curr.onload();
                Module['removeRunDependency']('datafile_/Users/jfriend/dev/jsmac/empce/pce20130508/build/bin/pce-macplus.data');
    };
    Module['addRunDependency']('datafile_/Users/jfriend/dev/jsmac/empce/pce20130508/build/bin/pce-macplus.data');
    function handleError(error) {
      console.error('package error:', error);
    };
    if (!Module.preloadResults)
      Module.preloadResults = {};
      Module.preloadResults[PACKAGE_NAME] = {fromCache: false};
      fetchRemotePackage(REMOTE_PACKAGE_NAME, processPackageData, handleError);
})();
if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}
// shouldRunNow refers to calling main(), not run().
var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}
run();
// {{POST_RUN_ADDITIONS}}
  // {{MODULE_ADDITIONS}}
